
extensions [matrix] ;Matrix Extension is necessary to perform Linear Regression Analysis

globals [
  s ;number of suppliers
  p ;Market Price
  w ;Profit of each Supplier
  Cvar ;Variable costs per innovation/product
  Cfix ;Periodic fixed costs for each supplier in the market
  bass-overall  bass-innovation  bass-imitation ;Variables to store General Bass Model figures
  error-overall   error-innovation   error-imitation ;Variables to measure the deviation of actuals to General Bass Model time-series
  CPLUS ;Consumer surplus
  SPLUS ;Supplier surplus
  LEVEL ;Diffusion level
  AWAREt ;Periodic number of aware consumers
  ADOPTt ;Periodic number of adopters
  temp ;Temporary variable for multiple purposes
  microdata ;Array to store microdata
  export export2  average_all ;Variables/Arrays to store Agent heterogeneity results
]

;----- 2 different kinds of Agents are created ('multi' Agent-based Simulation) -----;
breed [consumers consumer]
breed [suppliers supplier]

consumers-own [
  zi ;Individual Price Sensitivity (=Adoption Treshold)
  ni ;Individual number of neighbors in Small World
  timing ;Individual period of adoption
  aw_type ;Awareness type (internal or external)
  cat ;Adopter category
  order ;Necessary variable to calculate adopter category
  adopt_price ;Price to whiche the consumer adopted
  attributes ;Array to store multiple characteristics per consumer
]

suppliers-own [
  PROFITj ;suppliers individual profit
  status ;market status: in (1) or out (0) of market
]

to setup
  ca
  set Cvar 270 ;Variable costs -> 300 is static for all scenarios
  set Cfix 40000 ;Fix costs -> 40,000 is static for all scenarios  
  create-suppliers 10 ;Creation of 10 suppliers (potential rivals)
  consumer-config 
  ask consumers [set ni count consumers-on neighbors] ;Setup of n(i) individual number of neighbors in Small World
  set-current-plot "Willingness-to-pay"  histogram [(precision (zi / 100) 0) * 100] of consumers
  set-current-plot "Neighbors"  histogram [ni] of consumers
  set bass-overall [  240  561  983  1521  2183  2961  3821  4705  5540  6261  6830  7245  7527  7711  7825  7895  7938  7963  7978  7987  7992  7996  7997  7998  7999  7999  8000  8000  ]
  set bass-innovation [  240  233  223  211  194  175  151  125  99  74  52  35  23  14  9  5  3  2  1  1  0  0  0  0  0  0  0  0  ]
  set bass-imitation [  0  88  198  328  468  603  709  758  736  647  517  379  260  169  106  65  39  23  14  8  5  3  2  1  1  0  0  0  ]
end


to go
  ;----- Demand-side calculations -----;
  ask n-of M consumers [if color = white [set color green set aw_type 1]] ;Mass media Interactions
  ask consumers with [color = blue] [carefully [if random-float 1 < H [ask n-of 1 consumers-on neighbors [if color = white [set color green set aw_type 2]]]] []] ;Word-of-mouth Interactions
  set AWAREt count consumers with [color = green]
  
  ;----- Calculation of the Demand Curve via Linear Regression -----;
  let data-list sort-by [?1 > ?2] [zi] of consumers with [color = green] ;Creates a temp. list 'data-list' that contains the Price Sensitivity of all a consumers 
  let indep-var remove-item 0 (n-values (length data-list + 1) [?] ) ;Creates a temp. list to count the a consumers (1, 2, 3 ...) NOTE: Item 0 (=0) needs to be deleted
  let matrixvariable matrix:from-column-list (list data-list indep-var) ;Creates a temp. Matrix from the two temp. lists 
  let lin-output matrix:regress matrixvariable ;Performs a Linear Regression analysis.
                                               ;The output is a Logo nested list composed of two elements. The first element is a list containing the regression constant
                                               ;followed by the coefficients on each of the independent variables. The second element is a 3-element list containing the
                                               ;R2 statistic, the total sum of squares, and the residual sum of squares.
  let b item 0 (item 0 lin-output) ;Regression constant
  let a item 1 (item 0 lin-output) ;Slope: Coefficient of independent variable 
  let r2 item 0 (item 1 lin-output)
  
  ;----- Supply-side calculations -----;
  ;----- The following code are Cournot calculations /// -----;
  set w 0 
  set s 0
  while [w >= 0] [ ;Performs a loop (s + 1) until supplier profits are negative
    set s s + 1
    let q ((b - Cvar) / ((-1 * a) * (s + 1))) ;Supplier individual output quantity [temporary]
    set p (b + (a * (q * s))) ;Market price at global output quantity (q * s) [temporary]
    set w (((p - Cvar) * q) - Cfix)   ;Supplier individual profits [temporary]
    if s >= 1 AND w < 0 [set s s - 1] ;If the current loop results in negative profits, the loop ends and s is set as of the previous loop 
  ] 
  
  if s = 0 [ ;Exit threshold: Complete shakeout stops the simulation
    stop-threshold
    stop
  ] 
  
  ask suppliers with [who < s] [set status 1] ;Define which supplier is in the market
  ask suppliers with [who >= s] [set status 0] ;Define which supplier ist outside the market
  
  let q ((b - Cvar) / ((-1 * a) * (s + 1))) ;Supplier individual output quantity [final]
  set p (b + (a * (q * s))) ;Market price at global output quantity (q * s) [final]
  set w (((p - Cvar) * q) - Cfix)   ;Supplier individual profits [final]
  
  
                                    ;----- Adoption calculations -----;
  ifelse (q * s) <= count consumers with [zi >= p and color = green] [set ADOPTt (q * s)] [set ADOPTt count consumers with [zi >= p and color = green]] ;Sets no. of adopters
  
  
  ask suppliers with [ status = 1 ]  [
    ask n-of (ADOPTt / s) consumers with [zi >= p and color = green] [
      set color blue ;ADOPT!
      set CPLUS CPLUS + (zi - p)
      set timing ticks ; period of adoption
      set LEVEL LEVEL + 1
      set order LEVEL
      set adopt_price p
    ]
    set PROFITj PROFITj + w
  ]
  
  set SPLUS sum [PROFITj] of suppliers
  
  ;----- Plotting -----;
  set-current-plot "Demand function"
  clear-plot
  set-current-plot-pen "Potentials"
  foreach data-list [plot ?]
  set-current-plot-pen "Regression"
  foreach indep-var [plotxy (? - 1) (b + a * ?)]
  
  
  set-current-plot "Market Price" plotxy ticks p
  set-current-plot "Industry Lifecycle" plotxy ticks s
  set-current-plot "Supplier Profits"  ask suppliers with [status = 1] [set-current-plot-pen word "S" (who + 1) plotxy ticks (PROFITj / 1000)]
  
  set-current-plot "Non-cumulative Diffusion"
  set-current-plot-pen "Overall" plot count consumers with [color = blue and timing = ticks]
  set-current-plot-pen "Innovation" plot count consumers with [color = blue and timing = ticks and aw_type = 1]
  set-current-plot-pen "Imitation" plot count consumers with [color = blue and timing = ticks and aw_type = 2]
  if show-bass = TRUE [set-current-plot-pen "bass-overall" plot (item ticks bass-innovation + item ticks bass-imitation)]
  if show-bass = TRUE [set-current-plot-pen "bass-innovation" plot item ticks bass-innovation]
  if show-bass = TRUE [set-current-plot-pen "bass-imitation" plot item ticks bass-imitation]
  
  set-current-plot "Cumulative Diffusion"
  set-current-plot-pen "default" plot count consumers with [color = blue]
  if show-bass = TRUE [set-current-plot-pen "bass" plot item ticks bass-overall]
  
  set error-innovation error-innovation + (count consumers with [color = blue and timing = ticks and aw_type = 1] - item ticks bass-innovation) ^ 2
  set error-imitation error-imitation + (count consumers with [color = blue and timing = ticks and aw_type = 2] - item ticks bass-imitation) ^ 2
  set error-overall (error-imitation + error-innovation)
  
  set-current-plot "Error-to-Bass"
  set-current-plot-pen "overall" plot error-overall
  set-current-plot-pen "innovation" plot error-innovation
  set-current-plot-pen "imitation" plot error-imitation
  
  ;----- Set non-adopters unaware - Non-adopters will not adopt in future periods! [Assumption] -----;
  ask consumers with [color = green] [set color yellow]
  
  tick
end


to stop-threshold
  ;----- Defines adopter categories (Rogers) for each adopter -----;
  let cum_adopters count consumers with [color = blue]
  ask consumers with [color = blue] [
    if order <= cum_adopters [set cat 5] ;Laggards
    if order <= 0.84 * cum_adopters [set cat 4] ;Late Majority
    if order <= 0.50 * cum_adopters [set cat 3] ;Early Majority
    if order <= 0.16 * cum_adopters [set cat 2] ;Early Adopters
    if order <= 0.025 * cum_adopters [set cat 1] ;Innovators
  ]
  
  if input-validation = "microdata-file" OR input-validation = "microdata-code" [ 
    set temp 0
    set export []
    set export2 []
    set export lput "Category:    " export
    set export lput "Innovators" export
    set export lput "Early Adopters" export
    set export lput "Early Majority" export
    set export lput "Late Majority" export
    set export lput "Laggards" export
    set export2 lput export export2
    set export []
    let naming ["AGE:         "  "GENDER:      "  "EMPLOYMENT:  "  "JOBPOS:      "  "JOB:         "  "INDUSTRY:    "  "PUBLIC:      "  "WORKINGHOURS:"  "SQRENT:      "  "SCHOOL:      "  "QUALIFICATION:"  "LIVING:      "  "INCOME:      "  "SQMETER:     "  "RENT:        "  "HHINCOME:    "]
    set export lput "# Agents:    " export
    set export lput count consumers with [cat > 0] export
    set export lput count consumers with [cat = 1] export
    set export lput count consumers with [cat = 2] export
    set export lput count consumers with [cat = 3] export
    set export lput count consumers with [cat = 4] export
    set export lput count consumers with [cat = 5] export
    set export2 lput export export2
    set export []
    while [temp < 16] [
      set export lput item temp naming export
      set export lput precision mean [item temp attributes] of consumers with [cat > 0 AND item temp attributes != -1] 1 export
      set export lput precision mean [item temp attributes] of consumers with [cat = 1 AND item temp attributes != -1] 1 export
      set export lput precision mean [item temp attributes] of consumers with [cat = 2 AND item temp attributes != -1] 1 export
      set export lput precision mean [item temp attributes] of consumers with [cat = 3 AND item temp attributes != -1] 1 export
      set export lput precision mean [item temp attributes] of consumers with [cat = 4 AND item temp attributes != -1] 1 export
      set export lput precision mean [item temp attributes] of consumers with [cat = 5 AND item temp attributes != -1] 1 export
      set export2 lput export export2
      set export []
      set temp temp + 1
    ]
    foreach export2 [output-print ?]
  ]    
end


to consumer-config
  if input-validation = "no" [create-consumers 10936 [set zi random 3000 setxy random-pxcor random-pycor set color white set shape "square"]]
  
  if input-validation = "random-normal" [create-consumers 10936 [set zi random-normal 1597 400 setxy random-pxcor random-pycor set color white set shape "square"]]
  
  ;----- Creates 10.936 consumers with empirically validated characteristics in terms of z(i) and n(i) -----;
  if input-validation = "aggregated-microdata" [
    create-consumers 28 [set zi 0 + random 150 setxy random-pxcor random-pycor set color white ]
    create-consumers 128 [set zi 150 + random 150 setxy random-pxcor random-pycor set color white ]
    create-consumers 439 [set zi 300 + random 200 setxy random-pxcor random-pycor set color white ]
    create-consumers 872 [set zi 500 + random 200 setxy random-pxcor random-pycor set color white ]
    create-consumers 1085 [set zi 700 + random 200 setxy random-pxcor random-pycor set color white ]
    create-consumers 1319 [set zi 900 + random 200 setxy random-pxcor random-pycor set color white ]
    create-consumers 1475 [set zi 1100 + random 200 setxy random-pxcor random-pycor set color white ]
    create-consumers 1250 [set zi 1300 + random 200 setxy random-pxcor random-pycor set color white ]
    create-consumers 1028 [set zi 1500 + random 200 setxy random-pxcor random-pycor set color white ]
    create-consumers 954 [set zi 1700 + random 300 setxy random-pxcor random-pycor set color white ]
    create-consumers 661 [set zi 2000 + random 300 setxy random-pxcor random-pycor set color white ]
    create-consumers 492 [set zi 2300 + random 300 setxy random-pxcor random-pycor set color white ]
    create-consumers 273 [set zi 2600 + random 300 setxy random-pxcor random-pycor set color white ]
    create-consumers 258 [set zi 2900 + random 300 setxy random-pxcor random-pycor set color white ]
    create-consumers 181 [set zi 3200 + random 400 setxy random-pxcor random-pycor set color white ]
    create-consumers 130 [set zi 3600 + random 400 setxy random-pxcor random-pycor set color white ]
    create-consumers 85 [set zi 4000 + random 500 setxy random-pxcor random-pycor set color white ]
    create-consumers 86 [set zi 4500 + random 500 setxy random-pxcor random-pycor set color white ]
    create-consumers 50 [set zi 5000 + random 500 setxy random-pxcor random-pycor set color white ]
    create-consumers 46 [set zi 5500 + random 500 setxy random-pxcor random-pycor set color white ]
    create-consumers 31 [set zi 6000 + random 1500 setxy random-pxcor random-pycor set color white ]
    create-consumers 28 [set zi 7500 + random 2500 setxy random-pxcor random-pycor set color white ]
    create-consumers 23 [set zi 10000 + random 8000 setxy random-pxcor random-pycor set color white ]
    create-consumers 14 [set zi 18000 + random 2000 setxy random-pxcor random-pycor set color white ]
  ]
  
  if input-validation = "microdata-file" [
    ;AGE  GENDER  EMPLOYMENT  JOBPOS  JOB  INDUSTRY  PUBLIC  WORKINGHOURS  SQRENT  SCHOOL  QUALIFICATION  LIVING  INCOME  SQMETER  RENT  HHINCOME
    file-open "microdata.txt" ;reference to microdata file
    set temp [] ;creates an empty temporary list
    set microdata [] ;creates an empty microdata list
    while [file-at-end? = FALSE] [
      while [length temp != 16] [set temp fput file-read temp] ;expects 16 columns/values per row
      set temp reverse temp
      set microdata lput temp microdata
      set temp []
    ]
    file-close
    
    foreach microdata [
      create-consumers 1 [setxy random-pxcor random-pycor set color white set shape "square"
        set attributes ?
        set zi item 12 ?
      ]
    ]
    
  ]
  
  
  if input-validation = "microdata-code" [
    set microdata [
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  751  400  -1  17  ]
      [  53  1  1  2  844  52  8  98  -1  5  9  1  1211  400  -1  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  4  2374  400  -1  15  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  5  9  3  7713  400  -1  22  ]
      [  46  1  1  2  757  74  8  98  15  5  9  1  8622  400  -1  23  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1123  350  -1  10  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1519  350  -1  15  ]
      [  33  2  1  5  873  80  1  21  -1  5  9  1  2179  350  -1  20  ]
      [  52  1  1  5  751  41  1  38  -1  4  8  1  2698  350  -1  16  ]
      [  66  1  1  2  881  28  8  50  -1  -1  -1  1  4949  350  -1  21  ]
      [  43  1  1  2  886  85  8  60  9  5  9  1  5589  350  1100  22  ]
      [  44  1  1  5  757  31  8  70  -1  5  10  1  18107  350  -1  24  ]
      [  59  2  1  5  662  52  8  31  -1  1  3  1  1070  300  -1  6  ]
      [  39  2  1  1  821  85  8  40  -1  5  -1  3  1063  300  -1  7  ]
      [  48  1  1  2  51  1  8  80  -1  -1  -1  1  1806  300  -1  12  ]
      [  61  1  1  5  51  52  8  39  -1  1  3  1  1968  300  -1  10  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  5  3  3  2174  300  -1  11  ]
      [  38  1  1  5  780  70  8  50  -1  5  9  1  2351  300  -1  13  ]
      [  59  1  1  4  873  80  1  40  -1  5  9  1  2727  300  -1  15  ]
      [  48  1  1  2  785  51  8  60  -1  1  3  1  3136  300  -1  17  ]
      [  36  1  1  4  870  80  1  38  -1  5  9  1  3009  300  -1  14  ]
      [  61  1  1  4  880  80  1  46  -1  5  10  1  3211  300  -1  21  ]
      [  43  1  1  5  883  75  1  40  -1  5  9  1  3266  300  -1  16  ]
      [  57  1  1  2  750  70  8  60  -1  3  8  1  3991  300  -1  21  ]
      [  55  1  1  5  194  28  8  37  -1  1  5  1  4007  300  -1  17  ]
      [  67  1  8  2  841  85  8  15  -1  5  10  3  5209  300  -1  20  ]
      [  52  2  1  5  821  75  1  27  -1  5  10  1  7412  300  -1  24  ]
      [  63  1  1  2  813  74  8  75  -1  5  10  1  6205  300  -1  24  ]
      [  48  1  1  1  757  67  8  98  -1  -1  -1  1  16996  300  -1  23  ]
      [  49  1  1  2  841  85  8  40  -1  5  10  5  18467  300  -1  24  ]
      [  41  1  1  6  310  75  1  39  -1  1  3  1  2059  280  -1  15  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2964  280  -1  14  ]
      [  40  1  1  5  600  29  8  40  -1  5  8  1  4315  280  -1  18  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  3  3  3  4974  280  -1  18  ]
      [  53  1  1  5  701  63  8  40  -1  3  3  1  4768  280  -1  18  ]
      [  37  1  1  6  121  26  8  40  -1  1  3  1  1148  270  -1  9  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2843  270  -1  13  ]
      [  59  1  1  2  753  74  8  60  -1  5  9  1  7610  270  -1  23  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  490  260  0  5  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1068  260  -1  12  ]
      [  53  1  1  6  270  28  8  35  -1  1  3  1  1968  260  -1  16  ]
      [  39  1  1  5  796  85  1  38  -1  1  3  1  1732  260  -1  13  ]
      [  37  1  1  5  612  73  8  43  9  5  9  1  1802  260  1150  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1865  260  -1  11  ]
      [  50  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2257  260  -1  19  ]
      [  41  1  1  5  750  45  8  40  -1  1  -1  1  2824  260  -1  13  ]
      [  39  1  8  -1  -1  -1  -1  -1  50  1  -1  3  2757  260  -1  13  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  5  3  3  2710  260  -1  13  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  5  99  5  18741  260  -1  24  ]
      [  25  2  1  6  997  85  8  38  -1  -1  -1  6  37  250  -1  3  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  440  250  -1  3  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1157  250  -1  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1196  250  -1  7  ]
      [  45  1  1  6  141  51  8  56  -1  2  3  1  1324  250  -1  12  ]
      [  42  1  1  6  401  15  8  41  -1  1  3  1  1526  250  -1  15  ]
      [  39  1  1  6  290  29  8  39  -1  1  5  1  1884  250  -1  11  ]
      [  52  1  1  2  841  85  8  70  6  5  9  1  1955  250  650  10  ]
      [  39  1  1  6  742  40  8  38  -1  1  -1  1  2042  250  -1  11  ]
      [  41  1  1  2  254  28  8  50  -1  1  5  1  2233  250  -1  13  ]
      [  52  2  8  -1  -1  -1  -1  -1  29  5  8  3  2271  250  -1  23  ]
      [  59  1  1  2  683  22  8  40  -1  1  3  1  2799  250  -1  19  ]
      [  52  1  1  2  863  85  8  98  -1  3  5  1  2670  250  -1  13  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  5  9  5  2953  250  -1  15  ]
      [  50  1  1  5  774  23  8  38  -1  5  6  1  3355  250  -1  18  ]
      [  49  1  1  5  600  28  8  40  -1  5  9  1  4201  250  -1  17  ]
      [  47  1  1  2  750  52  8  50  -1  1  3  1  4578  250  -1  22  ]
      [  41  1  1  2  842  85  8  48  -1  5  10  1  5229  250  -1  20  ]
      [  52  1  1  2  750  29  8  60  -1  3  8  1  5475  250  -1  22  ]
      [  52  1  1  2  750  92  8  40  -1  5  9  1  7178  250  -1  23  ]
      [  40  1  1  5  750  24  8  60  20  -1  -1  1  13889  250  -1  23  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  4  8  5  16426  250  -1  23  ]
      [  58  2  1  5  785  29  8  26  -1  1  3  1  560  240  -1  15  ]
      [  46  1  1  6  51  1  8  40  -1  5  6  1  672  240  -1  15  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  945  240  -1  9  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  5  3  3  1106  240  -1  9  ]
      [  59  1  1  6  310  19  8  40  -1  -1  -1  1  1134  240  -1  11  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1384  240  -1  17  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1435  240  -1  13  ]
      [  44  2  1  5  787  75  1  39  -1  3  -1  1  1302  240  -1  15  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  9  3  3  1631  240  -1  13  ]
      [  60  1  1  5  780  65  8  37  -1  1  3  1  1582  240  -1  11  ]
      [  59  1  1  2  844  52  8  60  -1  5  9  1  1507  240  -1  21  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1511  240  -1  11  ]
      [  58  1  1  5  501  85  1  38  -1  3  3  1  1960  240  -1  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1939  240  -1  21  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2077  240  -1  12  ]
      [  39  1  1  1  751  28  8  98  11  5  8  1  2540  240  1000  14  ]
      [  36  1  1  2  750  60  8  50  -1  1  3  1  2479  240  -1  15  ]
      [  49  1  1  5  689  24  8  40  -1  3  3  1  3177  240  -1  14  ]
      [  44  1  1  2  622  45  8  80  -1  1  5  1  3114  240  -1  17  ]
      [  48  1  1  5  603  74  8  38  -1  4  8  1  3313  240  -1  16  ]
      [  33  1  1  1  997  45  8  50  -1  5  -1  1  4639  240  -1  21  ]
      [  62  1  1  2  670  29  8  60  -1  5  9  1  9083  240  -1  22  ]
      [  60  1  8  -1  -1  -1  -1  -1  8  3  4  5  7510  240  820  22  ]
      [  56  1  1  5  750  33  8  40  -1  3  3  1  8026  240  -1  23  ]
      [  64  1  1  2  841  85  8  60  -1  5  9  1  17252  240  -1  24  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  659  230  -1  4  ]
      [  42  1  1  6  483  52  8  46  -1  1  3  1  1430  230  -1  11  ]
      [  46  2  1  5  771  29  8  35  -1  1  3  1  1622  230  -1  14  ]
      [  51  1  1  5  620  64  8  40  -1  1  3  1  1720  230  -1  12  ]
      [  50  1  1  5  620  51  8  40  -1  1  3  1  2153  230  -1  19  ]
      [  45  1  1  1  483  45  8  50  -1  1  3  1  2147  230  -1  12  ]
      [  44  1  1  5  641  29  8  35  -1  1  3  1  2317  230  -1  13  ]
      [  33  1  1  5  601  34  8  38  -1  3  5  1  2438  230  -1  13  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2424  230  -1  15  ]
      [  51  1  1  4  873  80  1  39  -1  5  9  1  3371  230  -1  22  ]
      [  46  1  1  1  31  74  8  50  -1  5  9  1  9686  230  -1  22  ]
      [  42  1  1  2  842  85  8  60  -1  -1  99  1  10370  225  -1  23  ]
      [  24  1  8  -1  -1  -1  -1  -1  -1  3  3  2  771  220  -1  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  977  220  -1  12  ]
      [  57  1  1  5  691  65  1  38  -1  3  3  1  1047  220  -1  18  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1005  220  -1  18  ]
      [  59  1  1  2  750  45  8  40  -1  1  5  1  1437  220  -1  14  ]
      [  44  1  1  6  221  25  8  40  -1  3  3  1  1600  220  -1  12  ]
      [  35  1  1  6  471  45  8  39  -1  1  -1  1  1500  220  -1  10  ]
      [  50  1  1  6  254  29  8  35  -1  1  99  1  1671  220  -1  12  ]
      [  28  1  1  6  714  93  8  40  -1  2  3  1  1615  220  -1  12  ]
      [  33  1  1  5  651  28  8  40  -1  3  3  1  2067  220  -1  14  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2424  220  -1  15  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2427  220  -1  16  ]
      [  37  1  1  5  607  27  8  43  -1  4  8  1  2582  220  -1  18  ]
      [  56  1  1  5  611  73  8  40  -1  5  8  1  2361  220  -1  21  ]
      [  46  1  1  2  316  51  8  70  -1  3  5  1  2857  220  -1  13  ]
      [  35  1  1  2  813  74  8  70  -1  5  9  1  2694  220  -1  15  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3180  220  -1  14  ]
      [  61  1  1  1  441  45  8  40  -1  3  3  1  2938  220  -1  15  ]
      [  46  1  1  4  801  75  1  40  -1  4  7  1  3305  220  -1  17  ]
      [  49  1  1  2  842  85  8  38  -1  5  10  1  3501  220  -1  17  ]
      [  59  1  1  2  753  74  8  50  -1  3  3  1  4203  220  -1  19  ]
      [  36  1  1  5  881  31  8  40  -1  4  8  1  4440  220  -1  20  ]
      [  63  1  1  4  764  75  1  40  -1  -1  99  1  4476  220  -1  17  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  3  3  3  4950  220  -1  18  ]
      [  53  1  1  5  691  65  8  40  20  5  10  1  4755  220  -1  20  ]
      [  41  1  1  5  765  65  8  40  -1  5  -1  1  4868  220  -1  20  ]
      [  55  2  8  -1  -1  -1  -1  -1  -1  1  3  3  4907  220  -1  18  ]
      [  56  1  1  1  757  74  8  45  -1  3  8  1  17011  220  -1  23  ]
      [  52  1  1  1  704  67  8  50  -1  5  3  1  18003  220  -1  24  ]
      [  36  1  1  5  602  52  8  50  -1  5  8  1  1426  215  -1  8  ]
      [  59  1  1  6  441  45  8  38  -1  1  3  1  1663  215  -1  13  ]
      [  42  1  8  -1  -1  -1  -1  -1  -1  1  3  2  630  210  -1  10  ]
      [  31  1  1  1  281  50  8  70  -1  3  5  1  814  210  -1  17  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  5  9  3  765  210  -1  20  ]
      [  36  1  1  6  744  1  8  33  -1  1  5  1  1147  210  -1  11  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1396  210  -1  8  ]
      [  44  1  1  6  714  63  8  50  -1  3  99  1  1426  210  -1  12  ]
      [  43  1  1  5  282  1  8  40  -1  1  99  1  1492  210  -1  17  ]
      [  47  2  1  5  856  85  8  21  -1  3  5  1  1416  210  -1  9  ]
      [  36  1  1  2  441  45  8  50  -1  9  99  1  1368  210  -1  10  ]
      [  53  1  1  5  621  34  8  40  -1  1  5  1  1556  210  -1  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1685  210  -1  12  ]
      [  52  1  1  4  787  75  1  40  -1  1  3  1  2566  210  -1  12  ]
      [  44  1  1  6  273  29  8  37  -1  1  3  1  2601  210  -1  13  ]
      [  48  1  1  4  801  75  1  40  -1  4  7  1  2814  210  -1  14  ]
      [  53  1  1  5  601  45  8  37  -1  5  8  1  2964  210  -1  16  ]
      [  42  1  1  5  787  75  1  38  -1  3  7  1  3418  210  -1  15  ]
      [  40  1  1  5  621  29  8  40  -1  5  8  1  3270  210  -1  15  ]
      [  59  1  1  2  911  55  8  60  -1  5  5  1  3741  210  -1  19  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  3  3  4884  210  -1  18  ]
      [  53  1  1  1  714  60  8  55  -1  1  3  1  997  205  -1  9  ]
      [  23  1  1  9  801  75  1  38  -1  1  3  1  1011  205  -1  6  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1024  205  -1  10  ]
      [  52  1  1  1  441  45  8  60  -1  2  6  1  916  205  -1  19  ]
      [  26  1  1  5  603  45  8  37  -1  4  8  1  1360  205  -1  8  ]
      [  44  1  1  6  267  40  1  38  -1  3  5  1  3354  205  -1  18  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  179  200  -1  10  ]
      [  43  2  1  6  660  52  8  12  -1  1  3  4  457  200  -1  20  ]
      [  39  1  1  2  501  45  8  98  -1  2  5  1  382  200  -1  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  4  540  200  -1  4  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  672  200  -1  4  ]
      [  37  1  1  6  934  52  8  40  -1  1  -1  1  731  200  -1  9  ]
      [  44  2  1  5  856  85  8  40  -1  5  9  1  804  200  -1  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  987  200  -1  12  ]
      [  46  1  1  6  310  52  8  30  -1  3  3  1  1079  200  -1  9  ]
      [  39  1  1  6  741  75  1  32  -1  1  3  1  1223  200  -1  18  ]
      [  32  1  1  5  785  29  8  40  -1  3  3  1  1111  200  -1  13  ]
      [  68  2  1  1  886  85  8  8  -1  5  10  5  1290  200  -1  18  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1240  200  -1  8  ]
      [  42  1  1  4  891  91  1  25  -1  5  9  1  1166  200  -1  18  ]
      [  38  2  1  5  702  63  8  25  -1  5  3  1  1103  200  -1  15  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1137  200  -1  12  ]
      [  35  1  1  6  62  75  1  39  -1  1  3  1  1275  200  -1  7  ]
      [  46  1  1  2  261  45  8  80  -1  1  5  1  1439  200  -1  10  ]
      [  54  1  1  6  153  25  8  38  -1  1  4  1  1329  200  -1  14  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1402  200  -1  11  ]
      [  49  1  1  4  787  64  8  38  -1  1  3  1  1381  200  -1  13  ]
      [  52  2  1  5  863  91  1  38  -1  3  -1  1  1449  200  -1  14  ]
      [  32  1  8  -1  -1  -1  -1  -1  6  1  3  2  1437  200  400  8  ]
      [  38  1  1  6  290  31  8  39  -1  1  3  1  1463  200  -1  8  ]
      [  51  1  1  5  751  52  8  38  -1  1  3  1  1441  200  -1  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1400  200  -1  14  ]
      [  32  1  1  6  311  45  8  37  -1  3  4  1  1442  200  -1  12  ]
      [  53  1  1  6  531  21  8  38  -1  1  3  1  1641  200  -1  19  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1600  200  -1  11  ]
      [  46  1  1  5  221  28  8  38  -1  1  3  1  1507  200  -1  16  ]
      [  43  1  1  6  281  50  8  39  -1  1  3  1  1567  200  -1  11  ]
      [  32  1  1  6  316  24  8  38  -1  3  4  1  1600  200  -1  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  5  3  1672  200  -1  16  ]
      [  32  1  1  5  622  40  8  38  -1  3  5  1  1552  200  -1  13  ]
      [  39  1  1  5  603  75  1  38  -1  5  8  1  1770  200  -1  10  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  5  9  3  1885  200  -1  10  ]
      [  35  1  1  5  691  65  8  39  -1  5  5  1  1864  200  -1  10  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  5  3  1986  200  -1  15  ]
      [  58  1  1  6  241  34  8  35  -1  1  3  1  1976  200  -1  14  ]
      [  52  1  1  5  691  65  8  35  -1  1  3  1  1789  200  -1  16  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1792  200  -1  10  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1915  200  -1  13  ]
      [  26  1  1  6  254  29  8  35  -1  1  3  1  1944  200  -1  13  ]
      [  56  2  1  1  689  24  8  50  -1  1  -1  1  1919  200  -1  17  ]
      [  66  1  1  5  522  36  8  9  -1  3  5  3  1853  200  -1  17  ]
      [  47  2  1  4  873  80  1  20  -1  5  9  1  1820  200  -1  19  ]
      [  41  1  1  5  711  60  8  40  -1  2  3  1  1859  200  -1  12  ]
      [  68  1  1  1  662  51  8  30  -1  1  99  1  2165  200  -1  11  ]
      [  39  1  1  6  521  21  8  40  -1  4  3  1  2111  200  -1  13  ]
      [  45  1  1  5  651  24  8  38  -1  1  5  1  2274  200  -1  11  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2007  200  -1  12  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2170  200  -1  18  ]
      [  52  1  1  4  61  75  1  40  5  4  8  1  2122  200  450  11  ]
      [  43  1  1  5  651  90  1  39  -1  1  5  1  2013  200  -1  18  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2296  200  -1  11  ]
      [  54  1  1  6  780  17  8  40  -1  3  3  1  2148  200  -1  15  ]
      [  47  2  1  2  813  74  8  80  -1  5  8  1  2435  200  -1  12  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  5  99  3  2579  200  -1  12  ]
      [  41  1  1  6  62  75  1  38  -1  3  3  1  2313  200  -1  14  ]
      [  36  1  1  4  801  75  1  39  -1  3  3  1  2471  200  -1  14  ]
      [  49  2  1  2  842  85  8  40  -1  5  9  1  2326  200  -1  21  ]
      [  39  1  1  2  692  66  8  60  -1  5  3  1  2717  200  -1  15  ]
      [  51  1  1  5  603  75  1  39  -1  4  8  1  2879  200  -1  16  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  2860  200  -1  13  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2657  200  -1  15  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  5  5  3  2823  200  -1  13  ]
      [  42  1  1  5  751  55  8  65  12  3  3  1  2615  200  1000  15  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2693  200  -1  13  ]
      [  86  1  8  -1  -1  -1  -1  -1  -1  5  3  3  2747  200  -1  17  ]
      [  47  1  1  5  785  32  8  40  -1  5  3  1  2664  200  -1  13  ]
      [  51  1  1  4  873  80  1  38  -1  5  9  1  2824  200  -1  14  ]
      [  45  1  1  5  751  51  8  45  -1  1  3  1  2612  200  -1  19  ]
      [  56  1  1  4  765  65  1  39  -1  3  7  1  2888  200  -1  20  ]
      [  40  1  1  5  880  73  8  38  -1  5  9  1  2939  200  -1  16  ]
      [  52  1  1  4  787  65  1  39  -1  1  3  1  2932  200  -1  20  ]
      [  58  1  1  2  911  55  8  60  -1  3  5  1  3152  200  -1  18  ]
      [  63  1  1  5  651  64  8  39  -1  3  3  1  2946  200  -1  14  ]
      [  48  1  1  2  692  67  8  40  -1  1  5  1  2946  200  -1  14  ]
      [  42  1  1  6  651  15  8  38  -1  1  3  1  2916  200  -1  17  ]
      [  27  1  1  2  842  85  8  40  -1  5  9  1  2942  200  -1  15  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3402  200  -1  17  ]
      [  38  1  1  2  911  55  8  98  -1  5  99  1  3596  200  -1  15  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  3424  200  -1  21  ]
      [  38  1  1  5  600  90  8  55  8  1  3  1  3202  200  600  16  ]
      [  48  2  1  4  870  80  1  38  -1  5  8  1  3215  200  -1  15  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  -1  3  3716  200  -1  16  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3677  200  -1  16  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3813  200  -1  16  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  3889  200  -1  18  ]
      [  47  1  1  1  687  51  8  50  -1  3  3  1  3840  200  -1  21  ]
      [  58  1  1  4  873  80  1  40  -1  5  9  1  3685  200  -1  20  ]
      [  46  1  1  2  750  51  8  40  -1  5  1  1  3612  200  -1  21  ]
      [  63  1  1  1  841  85  8  30  -1  5  10  1  4291  200  -1  21  ]
      [  60  1  1  5  652  34  8  38  -1  3  8  1  4405  200  -1  17  ]
      [  68  1  8  -1  -1  -1  -1  -1  22  3  7  3  4157  200  -1  18  ]
      [  48  1  1  4  751  64  8  50  -1  5  9  1  4197  200  -1  17  ]
      [  93  2  1  2  813  74  8  10  -1  5  9  5  4576  200  -1  19  ]
      [  59  1  1  4  764  75  1  45  8  5  9  1  4554  200  600  18  ]
      [  71  1  1  2  813  74  8  40  -1  5  10  1  4818  200  -1  18  ]
      [  58  1  1  5  841  85  1  50  -1  5  10  1  5429  200  -1  19  ]
      [  60  2  8  -1  -1  -1  -1  -1  23  5  -1  5  5201  200  -1  19  ]
      [  49  1  1  5  772  64  8  40  -1  4  -1  1  5435  200  -1  21  ]
      [  43  1  1  4  761  91  1  40  -1  5  9  1  5169  200  -1  19  ]
      [  60  1  1  2  844  52  8  45  -1  5  9  1  5020  200  -1  19  ]
      [  62  1  1  2  750  63  8  65  -1  4  9  1  5539  200  -1  20  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  5  10  3  5515  200  -1  20  ]
      [  52  1  1  4  787  75  1  60  -1  3  7  1  7270  200  -1  21  ]
      [  39  1  1  2  750  28  8  60  -1  3  5  1  7424  200  -1  22  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  5  9  3  8630  200  -1  22  ]
      [  56  1  1  5  612  34  8  50  -1  5  10  1  9808  200  -1  23  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  -1  -1  5  9556  200  -1  23  ]
      [  59  1  1  5  751  34  8  60  -1  9  -1  1  11742  200  -1  23  ]
      [  55  1  1  5  620  45  8  40  -1  5  8  1  13622  200  -1  23  ]
      [  61  1  1  2  921  52  8  30  -1  1  4  1  16045  200  -1  23  ]
      [  49  2  8  -1  -1  -1  -1  -1  -1  5  8  4  207  195  -1  13  ]
      [  66  1  1  2  670  52  8  40  -1  1  3  1  2089  195  -1  16  ]
      [  53  1  1  4  874  80  1  38  -1  3  5  1  2476  195  -1  12  ]
      [  47  1  1  2  254  45  8  40  -1  1  5  1  5637  195  -1  20  ]
      [  45  2  8  -1  -1  -1  -1  -1  -1  3  99  3  629  190  -1  10  ]
      [  46  1  1  1  267  45  8  40  -1  1  5  1  753  190  -1  10  ]
      [  45  1  1  2  310  45  8  40  -1  2  5  1  963  190  -1  11  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1151  190  -1  10  ]
      [  46  2  1  5  787  75  1  39  -1  3  3  1  1311  190  -1  11  ]
      [  35  1  1  6  254  28  8  38  -1  2  3  1  1302  190  -1  13  ]
      [  44  1  1  6  796  45  8  48  -1  2  3  1  1474  190  -1  12  ]
      [  52  1  1  6  287  35  8  38  -1  2  3  1  1453  190  -1  16  ]
      [  51  1  1  6  323  28  8  39  -1  3  3  1  1624  190  -1  13  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1648  190  -1  9  ]
      [  43  1  1  6  742  27  8  38  -1  1  1  1  1676  190  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1870  190  -1  10  ]
      [  40  1  1  5  881  52  8  40  -1  5  9  1  1838  190  -1  13  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2139  190  -1  21  ]
      [  31  1  1  5  601  74  8  38  -1  5  8  1  2157  190  -1  14  ]
      [  34  1  1  4  873  80  1  40  -1  5  9  1  2061  190  -1  16  ]
      [  34  1  1  5  692  65  1  45  -1  5  5  1  2300  190  -1  14  ]
      [  33  1  1  5  772  93  8  40  -1  4  7  1  2487  190  -1  12  ]
      [  45  1  1  5  689  15  8  40  -1  5  9  1  2697  190  -1  13  ]
      [  48  1  1  2  750  93  8  40  -1  2  3  1  3109  190  -1  20  ]
      [  58  1  1  6  269  45  8  40  -1  1  3  1  3456  190  -1  17  ]
      [  41  1  1  1  316  52  8  40  -1  3  5  1  3789  190  -1  18  ]
      [  46  1  1  5  993  64  8  38  -1  4  8  1  3951  190  -1  16  ]
      [  64  1  1  2  670  51  8  60  -1  4  8  1  5305  190  -1  19  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  5  4  3  5422  190  -1  22  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  9759  190  -1  22  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  821  185  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  756  185  -1  5  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1135  185  -1  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1819  185  -1  10  ]
      [  60  1  1  1  621  74  8  40  -1  3  8  1  2141  185  -1  14  ]
      [  59  1  1  5  671  45  8  39  -1  1  3  1  2014  185  -1  11  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  2  3  3  2225  185  0  11  ]
      [  55  2  1  5  751  92  8  38  13  3  3  1  2933  185  1000  20  ]
      [  36  1  1  5  602  31  8  38  -1  5  8  1  3415  185  -1  15  ]
      [  43  1  1  5  620  25  8  50  -1  4  5  1  3557  185  -1  18  ]
      [  59  1  1  5  612  24  8  40  -1  9  -1  1  3751  185  -1  21  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  351  180  -1  3  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  486  180  -1  6  ]
      [  42  2  8  -1  -1  -1  -1  -1  10  5  9  4  346  180  880  8  ]
      [  53  2  1  5  789  45  8  6  -1  2  3  2  301  180  -1  3  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  4  3  571  180  -1  8  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  1  3  3  639  180  -1  4  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  3  3  887  180  -1  5  ]
      [  39  1  1  7  787  64  8  38  -1  1  5  8  865  180  -1  8  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  4  3  798  180  -1  12  ]
      [  65  2  1  6  744  22  8  9  -1  1  -1  3  944  180  -1  16  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  934  180  -1  14  ]
      [  91  1  8  -1  -1  -1  -1  -1  -1  5  9  3  905  180  -1  9  ]
      [  62  1  1  6  714  22  8  40  -1  1  -1  1  912  180  -1  9  ]
      [  53  1  1  2  813  74  8  50  -1  5  9  1  1087  180  -1  12  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  3  951  180  -1  17  ]
      [  55  1  1  6  254  45  8  40  -1  1  3  1  1005  180  -1  12  ]
      [  35  1  1  6  287  34  8  37  -1  1  3  1  1230  180  -1  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1234  180  -1  15  ]
      [  40  1  1  5  780  34  8  35  -1  1  3  1  1233  180  -1  11  ]
      [  53  1  1  2  901  93  8  50  -1  1  5  1  1177  180  -1  12  ]
      [  59  1  1  2  461  45  8  40  -1  1  3  1  1484  180  -1  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1398  180  -1  15  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1312  180  -1  16  ]
      [  52  1  1  6  714  63  8  39  -1  1  -1  1  1301  180  -1  10  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  5  99  3  1473  180  -1  8  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1481  180  -1  15  ]
      [  47  1  1  1  501  36  8  40  -1  1  3  1  1438  180  -1  11  ]
      [  35  1  1  6  501  36  8  38  -1  1  4  1  1430  180  -1  12  ]
      [  35  1  1  2  753  74  8  70  -1  5  7  1  1368  180  -1  15  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  5  10  3  1694  180  -1  10  ]
      [  53  1  1  6  359  17  8  39  -1  1  3  1  1578  180  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1515  180  -1  9  ]
      [  44  1  1  5  651  34  8  38  -1  1  5  1  1521  180  -1  9  ]
      [  39  1  1  6  546  26  8  40  -1  -1  -1  1  1590  180  -1  10  ]
      [  52  1  1  2  750  52  8  80  -1  3  5  1  1765  180  -1  10  ]
      [  30  1  8  -1  -1  -1  -1  -1  12  2  6  5  1732  180  860  16  ]
      [  40  1  1  6  531  18  8  40  -1  3  3  1  1773  180  -1  10  ]
      [  44  1  1  6  545  45  8  40  -1  1  3  1  1837  180  -1  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1719  180  -1  10  ]
      [  50  1  1  5  741  51  8  55  -1  1  3  1  1788  180  -1  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1789  180  -1  10  ]
      [  62  1  1  5  993  99  8  39  -1  1  3  1  1833  180  -1  13  ]
      [  59  1  1  6  281  50  8  35  -1  1  3  1  1708  180  -1  15  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2128  180  -1  16  ]
      [  59  1  1  6  290  29  8  35  -1  1  3  1  2123  180  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  7  5  9  3  2256  180  550  17  ]
      [  43  1  1  6  254  25  8  39  -1  3  3  1  2228  180  -1  14  ]
      [  42  1  1  1  662  51  8  45  -1  3  3  1  2052  180  -1  14  ]
      [  40  2  1  1  603  45  8  55  18  4  3  1  2035  180  1400  12  ]
      [  46  1  1  4  31  75  1  40  -1  5  7  1  2085  180  -1  14  ]
      [  60  1  1  5  601  29  8  40  -1  5  5  1  2018  180  -1  11  ]
      [  40  1  1  5  312  75  1  38  -1  3  3  1  2157  180  -1  11  ]
      [  34  1  1  6  265  34  8  35  -1  3  3  1  2389  180  -1  15  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2401  180  -1  12  ]
      [  42  1  1  5  691  65  8  50  -1  5  9  1  2366  180  -1  20  ]
      [  42  1  1  5  603  45  8  40  -1  4  8  1  2526  180  -1  14  ]
      [  38  1  1  5  884  93  8  38  -1  5  9  1  2521  180  760  15  ]
      [  36  1  1  5  603  45  8  50  -1  1  5  8  2574  180  -1  12  ]
      [  40  1  1  4  874  80  1  40  -1  4  5  1  2418  180  -1  16  ]
      [  42  1  1  5  691  65  8  38  -1  3  1  1  2466  180  -1  12  ]
      [  40  1  1  5  691  65  1  38  -1  3  3  1  2425  180  -1  12  ]
      [  54  1  1  5  600  63  8  40  -1  1  3  1  2838  180  -1  16  ]
      [  41  1  1  5  774  31  8  40  -1  5  9  1  2691  180  -1  13  ]
      [  59  1  1  5  623  28  8  45  -1  1  5  1  2892  180  -1  15  ]
      [  54  1  1  1  316  93  8  40  -1  1  3  1  2785  180  -1  19  ]
      [  54  1  1  2  261  45  8  52  -1  5  3  1  2881  180  -1  14  ]
      [  42  1  1  5  620  29  8  40  -1  4  3  1  2864  180  -1  13  ]
      [  30  1  1  5  662  50  8  50  -1  5  3  1  2615  180  -1  15  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  5  9  3  2738  180  -1  13  ]
      [  49  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2884  180  -1  19  ]
      [  70  1  1  2  703  74  8  40  19  3  3  1  3075  180  1700  16  ]
      [  56  1  1  5  876  80  1  38  -1  5  10  1  3108  180  -1  17  ]
      [  41  2  1  5  691  65  8  40  20  -1  -1  1  3079  180  1700  14  ]
      [  43  2  1  1  885  85  8  20  -1  4  8  1  3000  180  -1  17  ]
      [  56  1  1  4  868  75  1  39  -1  4  7  1  2958  180  -1  18  ]
      [  50  1  1  5  310  29  8  38  -1  5  5  1  3129  180  -1  16  ]
      [  49  1  1  4  873  80  1  50  -1  5  9  1  3081  180  -1  18  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  3  3  3  3011  180  -1  14  ]
      [  57  1  1  4  873  80  1  38  -1  5  9  1  3276  180  -1  16  ]
      [  45  1  1  2  609  74  8  60  -1  5  9  1  3436  180  -1  16  ]
      [  61  1  1  2  671  51  8  45  -1  5  9  1  3446  180  -1  18  ]
      [  49  1  1  1  241  45  8  40  -1  1  3  1  3388  180  -1  16  ]
      [  53  1  1  5  600  52  8  40  -1  5  9  1  3366  180  -1  16  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  3317  180  -1  15  ]
      [  48  1  1  2  750  28  8  50  -1  1  3  1  3416  180  -1  17  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  4  8  3  3387  180  -1  18  ]
      [  37  1  1  5  750  45  8  50  -1  5  8  1  3877  180  -1  16  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  3  1  3  3851  180  -1  16  ]
      [  44  1  1  5  774  64  8  38  15  -1  -1  1  3638  180  960  16  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  3  4  3  3685  180  -1  16  ]
      [  61  1  1  2  757  74  8  60  -1  -1  -1  1  3947  180  -1  17  ]
      [  42  1  1  2  704  66  8  75  11  3  3  1  3785  180  750  20  ]
      [  58  1  1  5  750  51  8  40  -1  1  3  1  3896  180  -1  16  ]
      [  48  1  1  5  691  65  8  40  -1  4  8  1  3654  180  -1  16  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  4  7  3  3983  180  -1  21  ]
      [  52  1  1  5  692  66  8  60  -1  1  3  1  3857  180  -1  18  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  5  9  3  4338  180  -1  21  ]
      [  60  1  1  4  871  80  1  70  -1  5  10  1  4134  180  -1  17  ]
      [  59  1  1  4  764  75  1  38  -1  5  9  1  4286  180  -1  17  ]
      [  37  1  1  2  844  52  8  60  -1  5  9  1  4741  180  -1  20  ]
      [  44  1  1  4  620  64  8  38  -1  1  3  1  4535  180  -1  20  ]
      [  53  1  1  4  872  80  1  42  -1  5  9  1  4629  180  -1  19  ]
      [  70  1  1  4  871  80  1  75  -1  5  10  3  4534  180  -1  18  ]
      [  37  1  1  5  841  85  1  60  -1  5  10  1  5611  180  -1  20  ]
      [  51  1  1  5  601  40  8  38  -1  5  8  1  5943  180  -1  21  ]
      [  62  1  1  2  757  74  8  70  -1  5  10  1  13744  180  -1  23  ]
      [  40  1  1  5  751  29  8  70  -1  5  9  1  15757  180  -1  23  ]
      [  56  1  1  5  771  91  8  40  -1  4  3  1  18752  180  -1  24  ]
      [  48  1  1  1  753  74  8  55  -1  4  8  1  551  175  -1  10  ]
      [  44  1  1  6  441  45  8  40  -1  2  3  1  802  175  -1  5  ]
      [  49  2  1  5  731  64  8  20  -1  3  3  1  1625  175  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1660  175  -1  10  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1947  175  -1  11  ]
      [  43  1  1  5  628  28  8  40  -1  3  3  1  2490  175  -1  14  ]
      [  53  1  1  4  870  80  1  38  -1  5  9  1  2690  175  -1  20  ]
      [  33  1  1  4  608  75  1  38  -1  3  6  1  2823  175  -1  14  ]
      [  51  2  1  4  873  80  1  29  -1  5  8  1  3123  175  -1  14  ]
      [  58  1  1  5  611  24  8  37  -1  5  9  1  3859  175  -1  22  ]
      [  49  1  1  5  607  34  8  40  18  -1  -1  1  5000  175  1400  21  ]
      [  33  2  8  -1  -1  -1  -1  -1  10  3  99  4  210  170  690  11  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  4  3  464  170  -1  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  5  541  170  -1  10  ]
      [  56  2  1  6  934  74  8  6  -1  1  3  3  705  170  -1  16  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  777  170  -1  5  ]
      [  28  2  8  5  853  85  8  40  -1  2  6  1  912  170  -1  8  ]
      [  36  1  1  5  788  27  8  35  -1  1  5  1  1187  170  -1  14  ]
      [  35  1  1  1  621  74  8  60  -1  4  5  1  1259  170  -1  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1415  170  0  12  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1339  170  -1  10  ]
      [  40  1  1  6  714  63  8  50  -1  1  3  1  1365  170  -1  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1339  170  -1  16  ]
      [  71  2  8  -1  -1  -1  -1  -1  5  1  5  3  1352  170  255  8  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1588  170  -1  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1590  170  -1  13  ]
      [  50  1  1  2  878  80  8  60  -1  1  5  1  1629  170  -1  14  ]
      [  43  1  1  2  51  1  8  65  -1  3  5  1  1520  170  -1  15  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1561  170  -1  12  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1575  170  -1  9  ]
      [  62  1  1  5  651  35  8  38  -1  1  3  1  1910  170  -1  10  ]
      [  40  1  1  6  310  60  8  37  -1  1  3  1  1869  170  -1  10  ]
      [  44  1  1  6  862  85  1  39  -1  3  3  1  1860  170  -1  11  ]
      [  51  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2061  170  -1  15  ]
      [  46  1  1  6  141  24  8  38  -1  1  3  1  2255  170  -1  16  ]
      [  45  1  1  5  741  34  8  45  -1  1  3  1  2299  170  -1  17  ]
      [  36  1  1  4  787  75  1  40  -1  5  9  1  2118  170  -1  13  ]
      [  50  1  1  2  701  63  8  40  -1  1  3  1  2185  170  -1  18  ]
      [  63  1  1  2  878  80  8  60  -1  3  3  1  2281  170  -1  21  ]
      [  35  1  1  6  996  34  8  35  -1  5  9  1  2047  170  -1  12  ]
      [  60  1  8  1  753  74  8  5  -1  -1  -1  3  2421  170  -1  12  ]
      [  43  1  1  5  785  20  8  35  -1  1  99  1  2475  170  -1  15  ]
      [  44  1  1  5  780  92  8  39  -1  5  9  1  2854  170  -1  15  ]
      [  38  1  1  5  780  72  8  40  -1  5  8  1  2779  170  -1  14  ]
      [  48  2  1  2  841  85  8  40  -1  5  10  1  3141  170  -1  19  ]
      [  55  1  1  2  841  85  8  50  -1  5  10  1  3030  170  -1  19  ]
      [  43  1  1  6  522  22  8  35  -1  1  3  1  3178  170  -1  14  ]
      [  41  1  1  2  750  28  8  40  -1  4  8  1  2979  170  -1  17  ]
      [  44  1  1  2  842  85  8  40  -1  -1  -1  1  3201  170  -1  15  ]
      [  55  1  1  4  874  80  1  45  -1  5  9  1  3203  170  -1  15  ]
      [  35  1  1  2  609  74  8  55  -1  4  8  1  3282  170  -1  15  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  5  9  3  3655  170  -1  16  ]
      [  55  1  1  5  780  34  8  40  -1  -1  -1  1  3973  170  -1  17  ]
      [  46  1  1  5  691  65  8  38  -1  3  3  5  4485  170  -1  17  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  5  9  5  4439  170  -1  17  ]
      [  53  1  1  4  764  75  1  40  -1  5  9  1  4580  170  1000  18  ]
      [  38  1  1  2  672  52  8  60  11  3  3  1  4574  170  780  18  ]
      [  63  1  1  4  871  80  1  30  -1  -1  -1  1  5343  170  -1  23  ]
      [  57  1  1  2  813  74  8  60  -1  5  9  1  6628  170  -1  22  ]
      [  46  1  1  5  750  51  8  65  16  5  9  1  13372  170  1250  23  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  902  169  -1  9  ]
      [  45  1  1  6  714  91  8  40  -1  1  3  1  1412  169  -1  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1842  169  -1  16  ]
      [  43  1  1  4  873  80  1  50  -1  5  8  1  3320  169  -1  15  ]
      [  45  1  1  4  871  80  1  45  11  5  10  1  4796  169  730  18  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  962  167  0  17  ]
      [  58  1  1  6  545  45  8  39  -1  1  -1  1  1574  167  -1  9  ]
      [  42  1  1  6  441  45  8  38  -1  3  3  1  1989  167  -1  10  ]
      [  31  1  1  4  801  75  1  40  -1  4  3  1  2305  167  -1  15  ]
      [  46  1  1  5  775  72  8  38  -1  5  9  1  2793  167  -1  17  ]
      [  60  1  1  1  687  30  8  50  -1  5  8  1  3276  167  -1  20  ]
      [  45  2  1  5  861  75  1  19  -1  4  8  1  718  165  -1  12  ]
      [  50  1  1  6  290  29  8  35  -1  1  3  1  1273  165  -1  14  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1910  165  -1  10  ]
      [  44  1  1  4  787  75  1  40  -1  9  3  1  2184  165  -1  11  ]
      [  40  1  1  5  780  92  8  40  10  3  3  1  2309  165  700  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  5  5  2522  165  -1  13  ]
      [  48  1  1  4  801  75  1  40  -1  5  3  1  3381  165  -1  19  ]
      [  51  1  1  4  873  80  1  40  -1  5  9  1  4221  165  -1  21  ]
      [  42  1  1  2  600  72  8  35  -1  5  9  1  1801  163  -1  16  ]
      [  57  1  1  5  691  65  8  39  -1  5  3  1  3880  163  900  17  ]
      [  68  1  8  1  871  80  8  38  -1  5  9  3  6231  163  -1  22  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1339  162  -1  11  ]
      [  36  1  1  6  541  11  8  40  -1  2  3  1  2246  162  -1  18  ]
      [  46  2  8  -1  -1  -1  -1  -1  -1  1  3  4  491  160  -1  14  ]
      [  31  2  1  4  870  80  1  25  -1  5  9  1  493  160  -1  3  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  331  160  -1  19  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  1  3  3  374  160  -1  6  ]
      [  62  2  1  2  911  55  8  90  -1  1  3  1  700  160  -1  4  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  509  160  -1  11  ]
      [  57  1  1  6  254  29  8  40  -1  2  3  1  535  160  -1  8  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  700  160  -1  5  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  739  160  -1  5  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  888  160  -1  10  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  854  160  -1  5  ]
      [  38  1  1  6  714  51  8  36  -1  2  3  1  858  160  -1  13  ]
      [  52  2  1  5  873  80  1  24  -1  -1  -1  1  979  160  -1  19  ]
      [  51  2  1  1  911  55  8  15  -1  1  3  4  964  160  -1  10  ]
      [  43  2  1  5  856  85  8  30  -1  3  3  1  966  160  -1  15  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  5  8  3  927  160  -1  10  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1059  160  -1  10  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1082  160  -1  12  ]
      [  50  2  8  -1  -1  -1  -1  -1  -1  5  1  5  1167  160  -1  7  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1171  160  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1164  160  -1  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1224  160  -1  21  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1273  160  -1  8  ]
      [  90  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1211  160  -1  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1220  160  -1  7  ]
      [  39  1  1  5  750  90  8  40  -1  5  3  1  1248  160  -1  12  ]
      [  45  2  1  5  772  45  8  23  -1  3  3  1  1413  160  -1  11  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1380  160  -1  10  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1380  160  -1  10  ]
      [  43  1  1  6  796  95  8  40  8  1  3  1  1371  160  515  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1358  160  -1  17  ]
      [  34  1  1  2  316  31  8  40  -1  1  5  1  1387  160  -1  8  ]
      [  56  1  1  6  512  34  8  35  -1  1  5  1  1328  160  -1  13  ]
      [  54  1  1  5  869  85  1  38  -1  2  5  1  1430  160  -1  14  ]
      [  36  1  1  6  482  45  8  40  -1  2  3  1  1448  160  -1  13  ]
      [  36  2  1  5  862  85  1  40  -1  2  5  1  1304  160  -1  9  ]
      [  30  1  1  5  671  51  8  44  -1  1  3  1  1512  160  -1  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1575  160  -1  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1631  160  0  9  ]
      [  40  2  1  4  870  80  1  38  -1  5  9  1  1623  160  -1  20  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1503  160  -1  13  ]
      [  49  1  1  6  269  29  8  38  -1  1  3  1  1597  160  -1  10  ]
      [  58  1  1  2  660  52  8  55  -1  3  8  1  1698  160  -1  17  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  8  1574  160  -1  15  ]
      [  37  2  1  5  780  74  8  39  -1  3  3  1  1698  160  -1  9  ]
      [  39  1  1  6  281  28  8  37  -1  1  3  1  1588  160  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1675  160  -1  10  ]
      [  36  2  1  1  704  70  8  40  -1  3  3  1  1583  160  -1  9  ]
      [  35  1  1  6  269  45  8  38  -1  1  3  1  1699  160  -1  11  ]
      [  40  1  1  6  512  34  8  35  -1  1  3  1  1511  160  -1  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  9  3  5  2  1688  160  500  11  ]
      [  58  2  1  5  856  85  8  25  -1  5  6  1  1512  160  -1  13  ]
      [  50  1  1  5  602  33  8  40  -1  5  9  1  1549  160  -1  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1945  160  -1  16  ]
      [  31  2  1  5  788  45  8  40  -1  3  3  1  1891  160  -1  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1965  160  -1  17  ]
      [  59  1  1  5  620  93  8  35  -1  1  3  1  1718  160  -1  11  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  4  3  3  1784  160  -1  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  99  3  1760  160  -1  10  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1856  160  -1  11  ]
      [  34  1  1  1  670  50  8  70  -1  1  3  1  1760  160  0  11  ]
      [  55  1  1  6  254  29  8  40  -1  1  3  1  1996  160  -1  14  ]
      [  53  1  1  5  521  85  8  40  -1  1  3  1  1928  160  -1  12  ]
      [  34  1  1  6  741  34  8  40  -1  1  3  1  1869  160  -1  13  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1934  160  -1  10  ]
      [  32  1  1  6  997  28  8  35  -1  1  5  1  1892  160  -1  18  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  3  -1  8  1933  160  -1  15  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  8  3  1860  160  -1  10  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  5  3  3  1995  160  -1  10  ]
      [  55  1  1  2  804  74  8  40  -1  3  5  1  2013  160  -1  12  ]
      [  59  1  1  5  651  45  8  36  -1  1  3  1  2143  160  -1  12  ]
      [  55  1  1  5  621  25  8  40  -1  1  5  1  2171  160  -1  17  ]
      [  48  1  1  5  178  22  8  37  10  3  5  1  2192  160  730  17  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2221  160  -1  15  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2142  160  -1  12  ]
      [  38  2  1  5  844  52  8  38  -1  5  9  1  2179  160  -1  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2041  160  -1  11  ]
      [  47  1  1  4  872  80  1  38  -1  5  8  1  2089  160  -1  15  ]
      [  52  1  1  6  714  60  8  40  -1  1  3  1  2218  160  -1  19  ]
      [  35  1  1  2  281  50  8  60  -1  3  5  1  2294  160  -1  15  ]
      [  38  1  1  6  544  45  8  50  -1  1  3  1  2184  160  -1  14  ]
      [  55  1  1  1  466  45  8  50  -1  1  3  1  2165  160  -1  16  ]
      [  51  1  1  5  521  28  8  35  -1  1  3  1  2261  160  -1  11  ]
      [  34  1  1  2  101  26  8  40  -1  2  3  1  2102  160  -1  13  ]
      [  42  1  1  5  751  24  8  43  -1  9  99  1  2580  160  -1  12  ]
      [  45  1  1  5  787  75  8  38  -1  1  3  1  2339  160  -1  12  ]
      [  35  1  1  5  621  24  8  39  -1  3  5  1  2382  160  -1  13  ]
      [  39  2  1  5  853  85  1  20  -1  3  5  1  2365  160  -1  16  ]
      [  35  1  1  1  623  28  8  37  -1  3  5  1  2547  160  -1  13  ]
      [  40  1  1  5  609  45  8  50  -1  3  3  1  2532  160  -1  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  5  10  5  2536  160  -1  12  ]
      [  32  1  1  5  620  28  8  38  -1  3  5  1  2302  160  -1  12  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  5  -1  3  2404  160  -1  21  ]
      [  37  1  1  5  71  45  8  55  -1  3  3  1  2400  160  -1  12  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2462  160  -1  15  ]
      [  52  1  1  4  765  75  1  40  -1  1  7  1  2441  160  -1  15  ]
      [  57  1  1  5  621  29  8  40  -1  1  5  1  2412  160  -1  12  ]
      [  40  1  1  5  780  20  8  40  -1  1  3  1  2433  160  -1  15  ]
      [  43  1  1  2  302  36  8  98  8  -1  -1  1  2319  160  500  12  ]
      [  31  1  1  5  881  51  8  43  -1  5  5  1  2472  160  -1  17  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  5  99  3  2484  160  -1  12  ]
      [  48  1  1  6  241  34  8  35  -1  1  3  1  2354  160  -1  14  ]
      [  53  1  1  5  774  64  8  38  -1  1  3  1  2520  160  -1  15  ]
      [  43  1  1  5  305  33  8  65  -1  1  3  1  2349  160  -1  18  ]
      [  37  1  1  4  787  75  1  40  -1  3  3  1  2372  160  -1  12  ]
      [  41  1  1  5  891  91  8  50  -1  5  9  1  2585  160  -1  12  ]
      [  50  1  1  4  765  75  1  38  -1  -1  -1  1  2474  160  -1  17  ]
      [  64  1  1  2  714  60  8  40  -1  1  -1  1  2587  160  -1  12  ]
      [  62  1  1  2  914  55  8  50  -1  3  4  1  2760  160  -1  15  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  5  2677  160  -1  14  ]
      [  66  1  1  2  750  28  8  50  -1  3  3  1  2877  160  -1  13  ]
      [  40  1  1  5  780  60  8  40  -1  3  8  1  2645  160  -1  17  ]
      [  45  1  1  5  773  65  8  39  -1  1  5  1  2601  160  -1  17  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  3  3  5  3130  160  -1  20  ]
      [  52  1  1  4  872  80  1  40  -1  5  9  1  2923  160  -1  18  ]
      [  57  1  1  5  883  26  8  39  -1  5  10  1  2928  160  -1  14  ]
      [  46  1  1  4  765  75  1  39  -1  5  7  1  2955  160  -1  17  ]
      [  48  1  1  5  633  24  8  37  -1  3  3  1  2901  160  -1  16  ]
      [  45  1  1  5  751  19  8  40  -1  1  3  1  3022  160  -1  15  ]
      [  62  1  1  4  811  75  1  50  11  5  9  1  3098  160  800  19  ]
      [  40  1  1  5  756  75  1  40  -1  -1  -1  1  3008  160  -1  14  ]
      [  49  1  1  4  608  75  1  39  -1  5  9  1  3117  160  -1  16  ]
      [  41  1  1  5  997  74  1  39  11  5  9  1  3154  160  770  15  ]
      [  49  1  1  5  521  25  8  40  -1  1  5  1  3050  160  -1  19  ]
      [  58  1  1  2  841  85  8  35  12  5  10  1  3054  160  800  21  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  3477  160  -1  15  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3569  160  -1  15  ]
      [  39  1  1  2  310  93  8  45  -1  3  5  1  3467  160  -1  17  ]
      [  49  1  1  5  671  29  8  38  -1  1  3  1  3510  160  -1  18  ]
      [  47  1  1  5  891  91  8  40  -1  5  9  1  3484  160  -1  15  ]
      [  59  2  1  5  780  52  8  40  -1  4  1  1  3769  160  -1  22  ]
      [  63  1  1  5  788  93  8  19  -1  5  8  4  3913  160  -1  19  ]
      [  63  1  1  5  603  45  8  42  -1  1  5  1  3895  160  -1  18  ]
      [  44  1  1  4  871  80  1  50  -1  5  10  1  3778  160  -1  16  ]
      [  41  1  1  1  250  72  8  55  10  3  5  1  3666  160  620  16  ]
      [  41  1  1  5  751  51  8  38  17  5  8  1  3815  160  1200  16  ]
      [  44  1  1  5  750  24  8  38  -1  5  9  1  4471  160  -1  18  ]
      [  64  1  1  2  608  93  8  30  -1  4  8  1  4651  160  -1  20  ]
      [  53  1  1  5  317  52  8  37  -1  3  3  1  4860  160  -1  19  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  4756  160  -1  18  ]
      [  37  1  1  5  621  25  8  40  -1  4  5  1  4560  160  -1  18  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  4  8  3  4792  160  -1  20  ]
      [  56  1  1  1  689  24  8  40  24  3  3  1  5044  160  1400  21  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  3  3  5481  160  -1  21  ]
      [  49  1  1  5  621  34  8  50  -1  1  4  1  5854  160  -1  22  ]
      [  55  1  1  5  785  32  8  65  -1  1  5  1  5958  160  -1  20  ]
      [  45  1  1  5  692  66  8  55  -1  1  3  1  5758  160  -1  22  ]
      [  45  1  1  5  750  52  8  40  -1  5  9  1  6753  160  -1  22  ]
      [  51  1  1  5  726  62  8  40  -1  3  3  1  9080  160  -1  23  ]
      [  48  1  1  5  603  45  8  50  -1  5  8  1  9932  160  -1  22  ]
      [  44  1  1  2  841  85  8  60  -1  5  9  1  14945  160  -1  23  ]
      [  43  2  1  2  841  85  8  40  -1  5  10  1  14152  160  -1  23  ]
      [  46  2  1  2  842  85  8  65  -1  5  10  1  11514  160  -1  24  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  3  5  19075  160  -1  24  ]
      [  59  1  1  2  753  74  8  98  -1  -1  -1  1  19347  160  -1  24  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1911  159  -1  10  ]
      [  55  1  1  5  863  85  1  38  -1  4  4  1  1704  159  -1  15  ]
      [  48  1  1  5  764  80  1  42  -1  5  10  1  2995  159  -1  18  ]
      [  44  1  1  5  620  93  8  40  -1  5  9  1  4685  159  1150  18  ]
      [  44  1  1  5  911  55  8  60  -1  5  5  1  5243  159  -1  19  ]
      [  57  2  1  6  521  18  8  23  -1  3  5  1  1192  157  -1  7  ]
      [  49  1  1  6  221  28  8  35  -1  3  3  1  1950  157  -1  16  ]
      [  41  1  8  5  787  75  1  39  -1  4  7  4  485  156  -1  13  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  5  9  5  963  156  -1  7  ]
      [  56  1  1  5  620  20  8  40  -1  1  5  1  1186  156  -1  15  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1467  156  -1  8  ]
      [  53  1  1  6  501  52  8  38  -1  1  3  1  1337  156  -1  19  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1956  156  -1  12  ]
      [  53  2  1  1  813  74  8  30  -1  5  9  1  1794  156  -1  16  ]
      [  61  1  1  6  505  20  8  38  -1  1  -1  1  1757  156  -1  12  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  2288  156  -1  14  ]
      [  47  1  1  5  691  65  8  39  -1  4  3  1  2146  156  -1  13  ]
      [  36  2  1  1  880  73  8  20  15  5  9  1  2086  156  1000  15  ]
      [  57  2  1  4  873  80  1  45  -1  5  9  1  2319  156  -1  18  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2530  156  -1  12  ]
      [  55  1  1  6  281  50  8  38  -1  1  5  1  2560  156  -1  13  ]
      [  54  1  1  4  731  64  8  39  -1  1  3  1  2494  156  -1  15  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2365  156  -1  15  ]
      [  47  1  1  2  281  50  8  60  -1  3  3  1  2979  156  -1  21  ]
      [  54  1  1  5  620  11  8  38  -1  1  3  1  2906  156  -1  22  ]
      [  70  1  8  -1  -1  -1  -1  -1  6  5  9  3  2904  156  400  14  ]
      [  53  1  1  4  787  75  1  40  -1  3  3  1  2983  156  -1  16  ]
      [  64  1  1  5  601  74  8  40  -1  3  8  1  4078  156  -1  20  ]
      [  53  1  1  5  691  65  8  60  -1  1  7  1  15907  156  -1  23  ]
      [  38  1  1  1  750  45  8  55  -1  1  3  1  430  155  -1  7  ]
      [  42  2  1  5  691  65  8  25  -1  5  3  1  1348  155  -1  8  ]
      [  42  2  1  5  853  85  1  20  -1  3  5  1  1475  155  -1  19  ]
      [  47  1  1  5  601  27  8  40  -1  2  8  1  1418  155  -1  12  ]
      [  35  1  1  2  510  45  8  56  -1  3  3  1  1689  155  -1  11  ]
      [  30  1  1  6  310  45  8  37  -1  3  3  1  2281  155  -1  12  ]
      [  51  1  1  5  780  27  8  40  -1  1  4  1  2422  155  -1  15  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2554  155  -1  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  3017  155  -1  19  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3262  155  -1  16  ]
      [  45  1  1  2  774  80  8  57  -1  4  8  1  3235  155  -1  17  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  5  9  3  3676  155  -1  16  ]
      [  46  1  1  5  689  24  8  40  -1  5  9  1  3619  155  -1  20  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  5  10  2  4610  155  -1  18  ]
      [  29  2  1  5  856  85  8  19  6  1  3  6  1100  154  355  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1326  154  -1  18  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  2  8  3  1307  154  -1  12  ]
      [  38  1  1  6  287  34  8  38  -1  1  3  1  1678  154  -1  9  ]
      [  46  1  1  4  787  75  1  38  -1  3  3  1  2020  154  -1  15  ]
      [  47  1  1  4  711  60  8  38  -1  1  3  1  2474  154  -1  15  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2386  154  -1  12  ]
      [  45  1  1  5  310  75  1  38  -1  1  5  1  2478  154  -1  15  ]
      [  39  1  1  6  310  29  8  40  -1  1  3  1  2499  154  -1  14  ]
      [  54  1  1  2  687  74  8  70  -1  5  3  1  9327  154  -1  22  ]
      [  38  1  1  5  487  45  8  45  -1  1  5  1  2137  153  -1  11  ]
      [  64  1  1  5  837  92  1  40  14  3  3  1  4065  153  770  22  ]
      [  45  1  1  5  689  29  8  50  -1  5  5  1  4020  153  -1  18  ]
      [  48  1  1  5  881  65  1  38  -1  4  3  1  2662  152  -1  14  ]
      [  46  1  1  2  750  51  8  40  -1  1  5  1  2707  152  -1  18  ]
      [  47  1  1  4  764  75  1  38  -1  3  7  1  3244  152  -1  17  ]
      [  39  1  1  5  750  28  8  40  -1  1  5  1  4352  152  -1  19  ]
      [  50  1  1  1  511  92  8  30  -1  5  9  1  145  150  0  14  ]
      [  34  1  1  5  852  85  8  60  -1  1  5  1  166  150  -1  21  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  3  3  3  475  150  -1  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  5  3  314  150  -1  10  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  488  150  -1  6  ]
      [  62  1  1  3  14  1  8  56  -1  1  3  3  421  150  0  12  ]
      [  53  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  402  150  -1  5  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  608  150  -1  10  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  600  150  -1  9  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  3  3  837  150  -1  5  ]
      [  60  2  8  5  997  45  8  4  -1  1  3  3  748  150  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  794  150  -1  8  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  724  150  -1  15  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  758  150  -1  5  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  752  150  -1  5  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  725  150  -1  6  ]
      [  50  1  8  -1  -1  -1  -1  -1  -1  5  9  2  744  150  -1  10  ]
      [  55  2  1  6  934  45  8  10  -1  1  -1  3  847  150  -1  14  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  5  3  825  150  -1  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  5  3  848  150  -1  7  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  5  3  784  150  -1  8  ]
      [  55  1  1  6  714  63  8  40  -1  1  3  1  714  150  -1  8  ]
      [  54  2  8  -1  -1  -1  -1  -1  -1  3  99  3  1084  150  -1  13  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  5  3  949  150  -1  8  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  999  150  -1  6  ]
      [  34  1  1  6  714  60  8  39  -1  1  3  1  947  150  -1  8  ]
      [  57  1  1  6  501  20  8  40  -1  1  3  1  923  150  -1  11  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1017  150  -1  6  ]
      [  33  1  1  1  241  28  8  23  -1  1  3  1  1010  150  -1  7  ]
      [  69  1  8  -1  -1  -1  -1  -1  6  1  -1  3  990  150  360  22  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  1  3  917  150  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  5  8  3  939  150  -1  16  ]
      [  42  2  1  6  522  31  8  40  -1  2  3  1  1004  150  -1  11  ]
      [  56  1  1  2  911  55  8  80  -1  1  3  1  909  150  -1  11  ]
      [  51  2  1  5  864  85  8  38  -1  1  -1  1  1131  150  -1  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1163  150  -1  8  ]
      [  33  1  1  5  803  75  1  39  -1  3  3  1  1291  150  -1  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1258  150  -1  8  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1270  150  -1  11  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1134  150  -1  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  3  3  4  1106  150  -1  22  ]
      [  50  2  1  5  789  51  8  20  -1  3  3  1  1250  150  -1  20  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1135  150  -1  11  ]
      [  49  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1285  150  -1  10  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1300  150  -1  12  ]
      [  80  2  1  2  911  55  8  60  -1  3  1  3  1212  150  -1  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1154  150  -1  12  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  3  -1  5  1257  150  -1  7  ]
      [  27  1  1  5  835  52  8  50  8  3  3  1  1134  150  432  12  ]
      [  39  2  1  5  852  85  1  40  10  2  6  1  1115  150  600  12  ]
      [  42  2  8  -1  -1  -1  -1  -1  -1  2  4  2  1278  150  -1  8  ]
      [  56  2  1  5  713  85  1  40  -1  3  -1  1  1316  150  180  8  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  5  6  3  1446  150  -1  8  ]
      [  52  1  1  6  231  28  8  40  -1  1  3  1  1460  150  -1  17  ]
      [  53  1  1  6  550  27  8  35  -1  1  -1  1  1425  150  -1  18  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1383  150  -1  14  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1450  150  -1  10  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  3  8  3  1421  150  -1  10  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  3  5  3  1471  150  -1  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1442  150  -1  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1393  150  -1  13  ]
      [  37  1  1  1  851  85  8  30  -1  5  5  1  1491  150  -1  12  ]
      [  47  1  1  5  861  80  1  19  -1  5  8  1  1397  150  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1319  150  -1  10  ]
      [  51  1  1  6  741  51  8  40  -1  1  3  1  1421  150  -1  18  ]
      [  38  1  1  6  531  74  8  38  9  1  4  1  1417  150  600  12  ]
      [  40  1  1  6  744  63  8  38  -1  1  3  1  1315  150  -1  9  ]
      [  43  1  1  6  316  32  8  36  -1  3  3  1  1305  150  -1  8  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  5  2  1448  150  -1  14  ]
      [  40  1  1  6  780  15  8  45  10  3  3  1  1458  150  600  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1363  150  -1  8  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1475  150  -1  9  ]
      [  43  1  1  2  750  1  8  40  -1  5  99  1  1397  150  -1  17  ]
      [  48  1  1  6  620  75  1  40  -1  2  3  1  1355  150  -1  13  ]
      [  46  1  1  5  611  73  8  45  -1  5  6  1  1323  150  -1  14  ]
      [  52  1  1  5  316  52  8  35  -1  1  3  1  1558  150  -1  9  ]
      [  46  1  1  4  711  60  8  40  -1  1  -1  1  1681  150  -1  15  ]
      [  45  1  1  6  714  51  8  40  9  2  3  1  1513  150  540  13  ]
      [  51  1  1  4  787  75  1  38  -1  4  3  1  1691  150  -1  9  ]
      [  43  1  1  6  804  74  8  40  -1  3  3  1  1645  150  -1  11  ]
      [  47  1  1  6  501  36  8  32  -1  1  3  1  1535  150  -1  15  ]
      [  45  1  1  6  221  29  8  40  10  1  3  1  1631  150  600  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1509  150  -1  9  ]
      [  31  1  1  6  461  45  8  40  -1  -1  -1  1  1500  150  -1  11  ]
      [  32  1  1  4  787  75  1  39  -1  3  3  1  1545  150  -1  15  ]
      [  42  1  1  5  622  24  8  40  -1  4  5  1  1595  150  -1  15  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1535  150  -1  9  ]
      [  36  1  1  6  274  24  8  39  -1  3  3  1  1507  150  0  9  ]
      [  54  1  1  6  273  29  8  37  -1  1  -1  1  1501  150  -1  12  ]
      [  38  1  1  6  714  52  8  40  -1  1  3  1  1699  150  -1  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1508  150  -1  16  ]
      [  40  1  1  2  750  55  8  60  11  3  -1  1  1611  150  650  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  99  3  1599  150  -1  9  ]
      [  32  1  1  2  501  45  8  70  -1  5  5  1  1551  150  -1  12  ]
      [  58  1  1  5  780  25  8  35  -1  1  4  1  1547  150  -1  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1554  150  -1  11  ]
      [  51  1  1  6  316  29  8  38  -1  1  3  1  1666  150  -1  10  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  5  10  3  1679  150  -1  9  ]
      [  54  1  1  5  676  51  8  45  -1  3  3  1  1852  150  -1  12  ]
      [  36  1  1  6  281  50  8  39  -1  1  5  1  1902  150  -1  10  ]
      [  41  2  1  5  787  75  1  39  -1  4  8  1  1975  150  -1  16  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1850  150  -1  16  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1841  150  -1  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1845  150  -1  11  ]
      [  28  1  1  6  501  35  8  35  -1  1  3  1  1995  150  -1  12  ]
      [  41  1  1  2  878  80  8  60  -1  1  3  1  1910  150  -1  13  ]
      [  32  1  1  6  274  13  8  38  -1  1  3  1  1979  150  -1  11  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  5  9  3  1743  150  -1  17  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1763  150  -1  10  ]
      [  31  1  1  5  602  25  8  35  -1  5  9  1  1722  150  -1  16  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1910  150  -1  10  ]
      [  43  1  1  5  316  62  8  38  -1  3  5  1  1944  150  -1  14  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1766  150  -1  10  ]
      [  32  1  1  5  501  45  8  38  -1  3  5  1  1862  150  -1  15  ]
      [  34  1  1  6  632  34  8  40  -1  3  3  1  1800  150  -1  10  ]
      [  52  1  1  1  609  74  8  48  -1  4  8  1  1745  150  -1  16  ]
      [  34  1  1  5  600  30  8  60  -1  4  8  1  1791  150  -1  10  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  5  2  1845  150  -1  22  ]
      [  60  1  1  4  796  80  1  40  -1  1  3  1  1864  150  -1  12  ]
      [  60  1  1  6  254  29  8  38  -1  1  3  1  1881  150  -1  11  ]
      [  44  1  1  5  787  75  1  39  -1  3  4  1  1765  150  -1  14  ]
      [  46  1  1  4  731  64  8  38  -1  1  3  1  1768  150  -1  10  ]
      [  48  1  1  5  623  75  1  39  -1  3  3  1  1931  150  -1  17  ]
      [  37  1  1  6  221  29  8  36  -1  1  3  1  1767  150  -1  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1749  150  -1  10  ]
      [  40  1  1  5  600  28  8  40  -1  1  5  1  1730  150  -1  12  ]
      [  40  2  1  1  821  92  8  60  -1  5  9  1  1771  150  -1  15  ]
      [  37  1  1  5  751  15  8  40  -1  2  8  1  1788  150  -1  21  ]
      [  44  1  1  5  751  51  8  50  -1  3  3  1  2201  150  -1  13  ]
      [  52  1  1  5  780  15  8  39  -1  1  3  1  2285  150  -1  18  ]
      [  53  2  8  -1  -1  -1  -1  -1  -1  5  9  4  2101  150  -1  11  ]
      [  58  1  1  6  131  26  8  40  -1  3  3  1  2186  150  -1  18  ]
      [  43  1  1  5  691  65  8  38  -1  5  99  1  2218  150  -1  15  ]
      [  41  1  1  5  600  25  8  37  -1  3  3  1  2295  150  -1  11  ]
      [  40  1  1  5  623  28  8  50  -1  5  5  1  2222  150  -1  14  ]
      [  40  1  1  1  875  22  8  12  -1  5  9  1  2058  150  -1  15  ]
      [  50  1  1  5  802  75  1  55  -1  1  3  1  2017  150  -1  17  ]
      [  53  1  1  5  501  36  8  38  -1  1  5  1  2068  150  -1  12  ]
      [  40  1  1  5  600  29  8  40  -1  5  8  1  2237  150  -1  15  ]
      [  51  1  1  5  787  75  1  39  -1  5  3  1  2083  150  -1  12  ]
      [  50  1  1  6  540  21  8  37  -1  1  3  1  2065  150  -1  14  ]
      [  48  1  1  5  623  45  8  40  -1  3  3  1  2136  150  -1  15  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2194  150  -1  11  ]
      [  54  1  1  5  281  50  8  38  -1  -1  -1  1  2576  150  -1  12  ]
      [  60  1  1  4  873  80  1  20  -1  5  9  1  2407  150  -1  20  ]
      [  36  2  1  5  780  72  8  40  -1  3  3  1  2486  150  -1  12  ]
      [  42  1  1  5  796  85  1  42  -1  3  5  1  2523  150  -1  12  ]
      [  32  1  1  5  601  33  8  39  -1  5  8  1  2404  150  -1  12  ]
      [  56  1  1  5  604  75  1  39  -1  3  3  1  2505  150  -1  16  ]
      [  30  2  1  5  788  29  8  37  4  5  3  1  2443  150  200  12  ]
      [  43  1  1  6  803  45  8  39  -1  1  3  1  2355  150  -1  16  ]
      [  52  1  1  5  777  72  8  38  -1  1  3  1  2454  150  -1  15  ]
      [  57  1  1  4  873  80  1  38  -1  5  9  1  2431  150  -1  17  ]
      [  47  1  1  5  620  45  8  42  -1  4  5  1  2370  150  -1  12  ]
      [  44  2  1  4  871  80  1  40  -1  5  9  1  2308  150  -1  12  ]
      [  46  2  1  2  750  51  8  65  -1  3  3  1  2332  150  -1  18  ]
      [  34  1  1  1  687  67  8  50  -1  3  -1  1  2368  150  -1  17  ]
      [  55  1  1  1  833  92  8  30  20  1  5  1  2431  150  1400  22  ]
      [  53  1  1  6  71  26  8  51  -1  1  3  1  2340  150  -1  18  ]
      [  52  1  1  5  751  29  8  40  -1  5  8  1  2382  150  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  9  -1  3  2591  150  -1  12  ]
      [  46  1  1  5  620  29  8  40  -1  1  5  1  2579  150  -1  14  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2458  150  -1  14  ]
      [  51  1  1  4  623  75  1  39  -1  1  3  1  2487  150  -1  12  ]
      [  48  1  1  4  787  75  1  39  -1  1  3  1  2447  150  -1  20  ]
      [  45  1  1  5  612  66  8  40  9  5  9  1  2693  150  500  14  ]
      [  53  1  1  5  628  24  8  38  -1  5  9  1  2835  150  -1  16  ]
      [  38  1  1  5  691  65  8  35  -1  4  9  1  2886  150  -1  15  ]
      [  35  1  1  5  601  28  8  40  -1  5  8  1  2814  150  -1  17  ]
      [  39  1  1  2  51  1  8  45  -1  1  5  1  2690  150  -1  14  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2652  150  -1  14  ]
      [  51  1  1  5  620  75  1  45  -1  5  9  1  2601  150  -1  13  ]
      [  59  1  1  2  692  66  8  40  -1  1  4  1  2886  150  -1  15  ]
      [  54  1  1  5  788  33  8  38  -1  1  3  1  2814  150  -1  18  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2732  150  -1  14  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2698  150  -1  13  ]
      [  51  1  1  4  873  80  1  38  -1  5  9  1  2718  150  -1  15  ]
      [  50  1  1  6  714  60  8  45  -1  1  -1  1  2636  150  -1  17  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2722  150  -1  13  ]
      [  46  1  1  5  677  28  8  35  10  5  7  1  2612  150  460  14  ]
      [  54  1  1  5  676  52  8  37  -1  1  3  1  3003  150  -1  15  ]
      [  38  1  1  6  254  28  8  38  -1  -1  -1  1  2959  150  -1  14  ]
      [  49  1  1  1  880  73  8  50  -1  5  9  5  3181  150  -1  16  ]
      [  53  1  1  5  764  75  1  39  -1  4  8  1  3137  150  -1  16  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  -1  -1  2  2916  150  -1  17  ]
      [  50  1  1  5  601  34  8  35  -1  5  8  1  3140  150  -1  14  ]
      [  41  1  1  6  714  63  8  90  -1  9  -1  1  3075  150  -1  15  ]
      [  41  1  1  5  600  24  8  40  -1  5  9  1  3108  150  -1  15  ]
      [  48  1  1  4  764  75  1  40  -1  3  99  1  3012  150  -1  14  ]
      [  55  1  1  4  891  91  1  80  9  5  9  1  3084  150  510  14  ]
      [  41  1  1  1  750  29  8  55  -1  3  5  1  3053  150  -1  16  ]
      [  49  1  1  1  995  45  8  70  -1  2  5  1  3039  150  -1  14  ]
      [  46  1  1  2  842  85  8  40  -1  5  9  1  2984  150  -1  14  ]
      [  58  1  1  4  870  80  1  38  -1  5  9  1  3415  150  -1  20  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  4  4  3  3493  150  -1  15  ]
      [  64  1  1  2  609  74  8  40  -1  5  8  1  3428  150  -1  17  ]
      [  48  1  1  2  841  85  8  70  -1  5  9  1  3494  150  -1  15  ]
      [  49  1  1  4  765  91  1  40  -1  5  7  1  3546  150  -1  17  ]
      [  47  1  1  5  254  29  8  42  -1  5  9  1  3491  150  -1  18  ]
      [  51  1  1  4  787  75  1  39  -1  4  5  1  3254  150  -1  17  ]
      [  53  1  1  5  602  30  8  40  -1  5  9  1  3354  150  -1  16  ]
      [  50  1  1  4  891  91  1  60  11  5  9  1  3508  150  750  17  ]
      [  46  1  1  5  751  70  8  40  -1  5  9  1  3293  150  -1  20  ]
      [  59  1  1  4  870  80  1  40  -1  5  9  1  3259  150  -1  20  ]
      [  90  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3548  150  -1  15  ]
      [  64  1  1  4  870  80  1  50  -1  5  9  1  3674  150  -1  18  ]
      [  46  1  1  5  780  92  8  38  -1  3  3  1  3659  150  -1  17  ]
      [  43  1  1  4  801  75  1  40  -1  3  3  1  3727  150  -1  20  ]
      [  55  1  1  2  491  52  8  60  -1  3  3  1  3828  150  -1  18  ]
      [  45  1  1  5  602  40  1  39  9  4  8  1  4036  150  600  18  ]
      [  58  1  1  5  841  85  1  55  -1  5  10  1  4864  150  -1  18  ]
      [  42  1  1  2  842  85  8  36  -1  5  9  1  4714  150  -1  22  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  5  9  3  4900  150  -1  19  ]
      [  58  1  1  2  911  55  8  70  -1  3  4  1  4854  150  -1  21  ]
      [  59  1  1  2  753  74  8  60  -1  4  8  1  4932  150  -1  20  ]
      [  49  1  1  5  622  33  8  45  -1  4  5  1  4876  150  -1  19  ]
      [  42  1  1  2  813  74  8  40  -1  4  9  1  4558  150  -1  20  ]
      [  50  1  1  5  174  24  8  38  -1  3  8  1  5362  150  -1  21  ]
      [  58  1  1  5  611  74  8  40  -1  5  10  1  5099  150  -1  21  ]
      [  40  1  1  5  911  55  8  55  -1  5  3  1  5286  150  -1  19  ]
      [  48  1  1  5  691  65  8  48  -1  3  8  1  5723  150  -1  21  ]
      [  54  1  1  2  670  32  8  55  -1  1  5  1  5548  150  -1  21  ]
      [  51  1  1  5  751  22  8  60  -1  5  9  1  5654  150  -1  20  ]
      [  53  1  1  5  689  24  8  40  -1  4  8  1  5817  150  -1  22  ]
      [  38  1  1  2  670  74  8  60  12  4  3  1  7175  150  700  21  ]
      [  51  1  1  6  521  34  8  40  -1  1  3  1  1753  149  -1  14  ]
      [  49  1  1  6  269  80  1  38  -1  1  4  1  2108  149  -1  12  ]
      [  91  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2861  149  -1  13  ]
      [  35  1  1  1  757  74  8  40  -1  5  9  1  3529  149  -1  17  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1016  148  -1  6  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1324  148  -1  8  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  4  4  3  1406  148  -1  8  ]
      [  46  1  1  6  741  51  8  45  -1  1  3  1  1975  148  -1  13  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2576  148  -1  14  ]
      [  43  2  1  5  53  52  8  39  -1  3  5  1  2857  148  -1  13  ]
      [  49  1  1  4  765  75  1  40  -1  5  8  1  2668  148  -1  21  ]
      [  34  1  1  5  602  29  8  40  -1  5  9  1  3355  148  -1  18  ]
      [  44  1  1  5  777  31  8  50  -1  5  9  1  3984  148  -1  17  ]
      [  50  1  1  5  751  28  8  60  -1  1  3  1  7169  148  -1  22  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1438  147  -1  8  ]
      [  35  1  1  2  692  66  8  60  -1  4  5  1  1681  147  -1  14  ]
      [  28  1  1  6  441  45  8  40  -1  1  3  1  1637  147  -1  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  4  3  2245  147  -1  12  ]
      [  36  1  1  6  310  24  8  38  -1  3  3  1  3135  147  -1  16  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1481  146  -1  8  ]
      [  33  1  1  5  780  50  8  40  -1  3  3  1  1666  146  -1  12  ]
      [  45  1  1  6  750  45  8  55  -1  1  3  1  2119  146  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2725  146  -1  14  ]
      [  43  1  1  6  268  45  8  38  -1  1  3  1  2861  146  -1  20  ]
      [  45  1  1  5  689  16  8  50  -1  3  3  1  3301  146  -1  20  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  267  145  -1  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1007  145  -1  10  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  99  3  1249  145  -1  14  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1256  145  -1  7  ]
      [  61  1  1  6  793  21  8  35  -1  2  3  1  1248  145  -1  15  ]
      [  56  1  1  6  274  45  8  40  -1  1  3  1  1467  145  -1  19  ]
      [  33  1  1  6  440  45  8  40  10  1  3  1  1612  145  600  13  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1549  145  -1  10  ]
      [  31  1  1  5  672  52  8  40  -1  1  3  1  1844  145  -1  10  ]
      [  35  2  1  5  844  52  8  28  -1  5  9  1  1998  145  -1  16  ]
      [  51  1  1  5  765  75  1  35  -1  3  5  1  1713  145  -1  13  ]
      [  48  1  1  6  441  45  8  42  -1  1  3  1  2049  145  -1  16  ]
      [  57  1  1  6  290  34  8  35  -1  1  3  1  2234  145  -1  12  ]
      [  41  1  1  5  780  51  8  40  -1  3  3  1  2138  145  -1  15  ]
      [  33  1  1  6  714  63  8  50  -1  1  3  1  2069  145  -1  11  ]
      [  53  1  1  2  813  74  8  70  -1  5  9  1  2728  145  -1  18  ]
      [  45  1  1  5  620  40  8  38  -1  1  3  1  2715  145  -1  15  ]
      [  42  1  1  4  801  75  1  40  -1  3  3  1  2696  145  -1  15  ]
      [  49  1  1  5  787  75  1  39  -1  5  9  1  2723  145  -1  19  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  3079  145  -1  16  ]
      [  44  1  1  5  787  75  1  39  -1  1  3  1  3016  145  -1  17  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  5  9  3  3243  145  -1  22  ]
      [  46  1  1  4  801  75  1  40  -1  4  -1  1  3435  145  -1  17  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3672  145  -1  17  ]
      [  38  1  1  5  751  22  8  45  -1  5  9  1  4083  145  -1  20  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  4  8  3  4178  145  -1  21  ]
      [  44  1  1  4  871  80  1  40  14  5  10  1  4623  145  800  18  ]
      [  49  1  1  5  750  1  8  40  -1  5  10  1  5085  145  -1  20  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  3  3  6956  145  -1  21  ]
      [  39  1  1  5  692  66  8  65  14  3  7  1  6069  145  860  21  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  16743  145  -1  23  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1400  144  -1  8  ]
      [  81  1  1  3  673  52  8  50  -1  1  -1  3  1934  144  -1  15  ]
      [  46  1  1  5  691  65  8  40  -1  3  3  1  4862  144  -1  22  ]
      [  50  1  1  5  602  31  8  40  -1  5  8  1  15814  144  -1  23  ]
      [  47  1  1  6  281  50  8  38  8  1  3  1  1558  143  500  11  ]
      [  39  1  1  5  787  75  1  38  -1  1  3  1  1731  143  -1  13  ]
      [  40  2  1  5  787  75  1  19  -1  3  3  1  1860  143  -1  13  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1760  143  -1  10  ]
      [  50  1  1  4  801  75  1  39  -1  4  8  1  3347  143  -1  17  ]
      [  57  1  1  5  600  32  8  40  -1  4  8  1  3478  143  -1  21  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  5  9  3  3999  143  -1  16  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1215  142  -1  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1388  142  -1  11  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1997  142  -1  10  ]
      [  38  1  1  6  273  29  8  35  -1  1  3  1  1760  142  -1  12  ]
      [  56  1  1  4  801  75  1  40  -1  1  3  1  2086  142  -1  11  ]
      [  54  1  1  2  601  29  8  60  -1  3  8  1  2635  142  -1  16  ]
      [  46  1  1  5  611  31  8  40  -1  5  10  1  3825  142  -1  17  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1160  141  -1  7  ]
      [  28  1  1  6  471  45  8  36  10  3  3  1  1268  141  505  12  ]
      [  44  1  1  6  714  45  8  38  -1  1  -1  1  1972  141  -1  11  ]
      [  36  2  8  -1  -1  -1  -1  -1  12  1  3  4  172  140  760  8  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  479  140  -1  3  ]
      [  45  1  8  -1  -1  -1  -1  -1  -1  1  3  3  391  140  -1  3  ]
      [  30  2  1  6  714  15  8  20  6  1  3  1  339  140  358  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  310  140  -1  3  ]
      [  25  2  8  -1  -1  -1  -1  -1  -1  5  -1  8  446  140  -1  12  ]
      [  61  1  1  3  705  92  8  60  -1  1  3  1  551  140  -1  8  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  4  576  140  -1  4  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  564  140  0  4  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  5  3  694  140  -1  12  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  -1  3  3  839  140  -1  11  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  741  140  -1  5  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  5  -1  3  881  140  -1  9  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  861  140  -1  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  5  3  716  140  -1  12  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  3  3  709  140  -1  17  ]
      [  46  1  1  6  714  60  8  40  -1  2  3  1  756  140  -1  9  ]
      [  40  1  1  1  672  52  8  40  -1  2  5  1  845  140  -1  8  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  892  140  -1  10  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  7  3  971  140  -1  10  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1025  140  -1  12  ]
      [  30  1  1  6  466  45  8  38  7  1  3  1  989  140  400  6  ]
      [  59  1  1  6  997  90  8  39  -1  2  6  8  1041  140  -1  10  ]
      [  58  1  1  4  751  75  1  38  -1  5  9  1  919  140  -1  18  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  5  6  3  1057  140  -1  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  918  140  -1  9  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  3  3  3  967  140  -1  14  ]
      [  26  2  1  5  780  50  8  25  9  1  3  1  1078  140  550  13  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  3  3  996  140  -1  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1078  140  -1  6  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1053  140  -1  12  ]
      [  41  1  1  5  603  45  8  40  -1  2  3  1  978  140  -1  11  ]
      [  53  1  1  5  711  60  8  40  -1  2  4  1  900  140  -1  12  ]
      [  53  1  1  6  796  29  8  40  -1  5  9  1  986  140  -1  13  ]
      [  64  1  1  2  673  52  8  40  -1  1  3  1  1046  140  -1  11  ]
      [  35  1  1  6  714  63  8  54  -1  1  3  1  984  140  -1  8  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1034  140  -1  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1141  140  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1222  140  -1  16  ]
      [  33  1  8  -1  -1  -1  -1  -1  8  1  -1  2  1105  140  450  7  ]
      [  47  1  1  6  201  27  8  36  -1  1  3  1  1207  140  -1  13  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1203  140  -1  10  ]
      [  65  2  1  5  784  52  8  8  -1  -1  -1  3  1139  140  -1  7  ]
      [  47  1  1  6  241  74  8  40  9  -1  3  1  1232  140  520  12  ]
      [  38  1  1  6  512  28  8  35  -1  3  -1  1  1211  140  -1  11  ]
      [  63  1  1  3  671  51  8  65  -1  1  3  1  1285  140  -1  10  ]
      [  54  1  1  1  852  85  8  52  -1  1  3  1  1248  140  780  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1290  140  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1144  140  -1  15  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1162  140  0  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1162  140  -1  13  ]
      [  65  2  1  2  876  80  8  70  -1  -1  1  1  1220  140  -1  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1252  140  -1  8  ]
      [  48  1  1  5  511  45  8  40  -1  2  3  1  1178  140  -1  13  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  2  3  2  1255  140  -1  16  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1413  140  -1  9  ]
      [  42  1  1  6  787  75  1  39  -1  1  3  1  1364  140  -1  13  ]
      [  37  1  1  6  501  45  8  39  -1  1  3  1  1347  140  -1  10  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1409  140  -1  9  ]
      [  33  1  1  6  254  74  8  35  -1  3  3  1  1475  140  -1  13  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  9  3  3  1415  140  -1  11  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  99  3  1359  140  -1  8  ]
      [  54  2  1  4  870  80  1  19  -1  5  9  1  1457  140  -1  12  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1399  140  -1  8  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1447  140  0  8  ]
      [  34  1  1  5  993  85  1  39  -1  4  5  1  1404  140  -1  8  ]
      [  48  1  1  5  691  65  8  37  -1  3  4  1  1354  140  -1  14  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1495  140  -1  10  ]
      [  39  1  1  6  231  28  8  35  -1  1  3  1  1342  140  -1  11  ]
      [  38  1  1  5  480  45  8  50  -1  1  99  1  1498  140  -1  10  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1367  140  -1  8  ]
      [  29  1  1  6  254  28  8  38  -1  1  3  1  1323  140  -1  13  ]
      [  43  2  1  5  780  26  8  40  -1  1  -1  1  1446  140  -1  21  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1431  140  -1  18  ]
      [  47  1  1  6  788  28  8  40  -1  3  1  1  1389  140  -1  12  ]
      [  40  2  1  5  765  25  8  38  -1  3  -1  1  1421  140  -1  17  ]
      [  48  2  1  1  813  74  8  40  -1  -1  -1  1  1407  140  -1  13  ]
      [  29  1  1  6  501  36  8  40  14  2  3  1  1449  140  800  10  ]
      [  54  1  1  2  670  34  8  60  -1  2  5  1  1413  140  -1  17  ]
      [  55  1  1  2  670  51  8  40  -1  2  5  1  1405  140  -1  11  ]
      [  53  1  1  5  751  22  8  40  -1  2  8  1  1386  140  -1  15  ]
      [  53  1  1  6  692  66  8  37  -1  5  9  1  1465  140  -1  19  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  3  4  5  1603  140  -1  11  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  3  5  1663  140  -1  17  ]
      [  31  1  1  6  11  1  8  40  -1  1  4  1  1634  140  -1  10  ]
      [  46  1  1  6  628  34  8  29  -1  3  3  1  1630  140  -1  9  ]
      [  42  1  1  6  254  75  1  39  -1  1  3  1  1515  140  -1  9  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1685  140  -1  12  ]
      [  73  2  8  -1  -1  -1  -1  -1  5  3  3  3  1549  140  250  9  ]
      [  50  1  1  6  796  80  1  38  -1  1  3  1  1505  140  -1  13  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1533  140  -1  11  ]
      [  68  1  1  5  780  28  8  35  -1  3  3  1  1661  140  -1  11  ]
      [  36  1  1  6  281  60  1  40  -1  1  3  1  1525  140  -1  10  ]
      [  47  1  1  6  254  29  8  38  -1  3  3  1  1609  140  -1  17  ]
      [  58  1  1  6  512  36  8  35  -1  1  5  1  1516  140  -1  10  ]
      [  39  1  1  6  510  45  8  40  -1  1  3  1  1675  140  -1  14  ]
      [  39  1  1  5  731  64  8  38  -1  1  3  1  1605  140  -1  12  ]
      [  57  1  1  5  772  24  8  19  -1  3  3  1  1667  140  -1  9  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  1  3  1655  140  -1  9  ]
      [  40  1  1  6  254  45  8  40  -1  3  3  1  1577  140  -1  13  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1547  140  -1  9  ]
      [  31  1  1  6  152  25  8  39  -1  3  -1  1  1517  140  -1  10  ]
      [  39  1  1  6  51  29  8  39  -1  1  3  1  1530  140  -1  14  ]
      [  22  1  1  6  471  45  8  40  -1  1  3  1  1513  140  -1  14  ]
      [  52  2  1  5  789  52  8  35  -1  3  99  1  1605  140  -1  19  ]
      [  60  1  1  5  171  22  8  35  -1  1  3  1  1537  140  -1  11  ]
      [  44  2  1  1  841  85  8  20  -1  5  10  1  1525  140  -1  15  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  99  3  1579  140  -1  14  ]
      [  33  2  1  6  662  52  8  37  -1  5  1  1  1623  140  397  9  ]
      [  32  2  1  5  691  65  8  30  -1  5  9  1  1615  140  -1  14  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  5  7  3  1811  140  -1  10  ]
      [  58  1  1  6  714  15  8  42  -1  -1  -1  1  1706  140  -1  10  ]
      [  38  1  1  6  273  29  8  38  -1  1  3  1  1703  140  -1  10  ]
      [  79  1  8  -1  -1  -1  -1  -1  7  3  8  3  1802  140  350  12  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1938  140  -1  17  ]
      [  42  1  1  5  652  91  8  37  -1  1  5  1  1932  140  -1  12  ]
      [  42  1  1  6  254  41  1  39  -1  1  3  1  1769  140  -1  12  ]
      [  53  1  1  5  602  80  1  40  -1  5  7  1  1721  140  -1  15  ]
      [  36  1  1  5  775  29  8  40  -1  1  3  1  1836  140  -1  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  4  3  1802  140  -1  17  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1874  140  -1  15  ]
      [  42  2  1  5  780  51  8  40  -1  4  8  1  1835  140  -1  16  ]
      [  43  1  1  4  765  75  1  40  -1  3  3  1  1858  140  -1  14  ]
      [  29  1  1  5  620  29  8  37  -1  1  5  1  1742  140  -1  13  ]
      [  60  1  8  5  691  65  8  38  -1  3  3  1  1885  140  -1  16  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1926  140  -1  11  ]
      [  52  1  1  4  757  75  1  40  -1  3  3  1  1788  140  -1  16  ]
      [  35  1  1  6  540  74  8  35  -1  1  3  1  1828  140  -1  11  ]
      [  44  1  1  6  191  29  8  38  -1  1  3  1  1887  140  -1  12  ]
      [  44  1  1  5  603  75  1  40  -1  5  6  1  1843  140  -1  15  ]
      [  39  2  1  5  691  65  8  38  -1  3  3  1  2065  140  -1  17  ]
      [  39  1  1  5  780  34  8  30  -1  5  9  1  2174  140  -1  17  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2281  140  -1  12  ]
      [  44  1  1  6  714  60  8  65  -1  1  3  1  2097  140  -1  13  ]
      [  43  1  1  5  765  74  8  35  -1  1  3  1  2068  140  -1  12  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2048  140  -1  12  ]
      [  43  1  1  6  805  92  1  39  -1  1  3  1  2208  140  -1  13  ]
      [  45  2  1  1  902  93  8  45  -1  1  3  1  2006  140  -1  15  ]
      [  39  1  1  1  317  92  8  50  9  3  5  1  2046  140  500  11  ]
      [  38  1  1  5  391  15  8  40  -1  1  3  1  2181  140  -1  13  ]
      [  34  1  1  4  787  64  8  38  3  1  3  1  2069  140  100  12  ]
      [  39  1  1  9  801  75  1  39  -1  5  5  1  2092  140  -1  11  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  5  3  5  2224  140  -1  13  ]
      [  55  1  1  5  316  29  8  38  -1  1  3  1  2160  140  -1  12  ]
      [  36  2  1  6  788  28  8  38  -1  3  3  1  2167  140  -1  11  ]
      [  29  1  1  5  778  80  1  36  8  4  5  1  2170  140  450  11  ]
      [  36  1  1  5  662  51  8  38  -1  3  99  1  2047  140  -1  12  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2110  140  -1  17  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2216  140  -1  17  ]
      [  39  1  1  6  225  28  8  35  8  1  3  1  2271  140  350  11  ]
      [  43  1  1  2  488  45  8  50  -1  2  5  1  2027  140  -1  14  ]
      [  44  1  1  5  274  40  1  40  -1  2  5  1  2063  140  -1  14  ]
      [  48  1  1  5  813  75  1  38  -1  5  9  1  2463  140  -1  13  ]
      [  40  1  1  5  701  27  8  40  -1  3  5  1  2562  140  -1  14  ]
      [  38  1  1  5  692  66  8  38  -1  4  3  1  2542  140  -1  15  ]
      [  49  1  1  4  997  75  1  38  -1  3  7  1  2349  140  -1  16  ]
      [  54  1  1  2  842  85  8  54  13  5  10  1  2341  140  770  13  ]
      [  41  1  1  4  765  75  1  39  -1  5  7  1  2513  140  -1  14  ]
      [  64  1  1  5  780  45  8  40  -1  1  3  1  2441  140  -1  12  ]
      [  48  1  1  5  310  52  8  40  -1  1  3  1  2513  140  -1  13  ]
      [  62  1  1  2  511  45  8  60  -1  1  5  1  2305  140  -1  12  ]
      [  40  1  1  6  751  51  8  40  -1  1  3  1  2454  140  -1  13  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2307  140  -1  12  ]
      [  56  1  1  1  757  74  8  50  -1  3  7  1  2404  140  -1  18  ]
      [  38  2  1  4  765  64  8  38  -1  5  7  1  2328  140  -1  18  ]
      [  48  1  1  5  691  65  8  40  -1  5  3  1  2807  140  -1  13  ]
      [  57  1  1  5  620  31  8  40  -1  1  3  1  2794  140  -1  17  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  5  2822  140  -1  13  ]
      [  61  1  1  2  750  29  8  50  -1  4  8  1  2878  140  -1  13  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2678  140  0  15  ]
      [  63  1  1  5  831  92  1  40  -1  5  9  1  2891  140  -1  14  ]
      [  41  1  1  6  549  75  1  38  -1  3  5  1  2608  140  -1  15  ]
      [  40  1  1  1  996  66  8  50  6  3  3  1  2790  140  300  13  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2667  140  -1  13  ]
      [  49  1  1  5  303  85  8  39  -1  1  -1  1  2752  140  -1  13  ]
      [  41  1  1  5  788  35  8  39  -1  3  5  1  2801  140  -1  13  ]
      [  39  1  1  4  629  92  1  39  -1  5  8  1  2738  140  -1  16  ]
      [  53  1  1  5  692  66  8  38  -1  3  3  1  2987  140  -1  15  ]
      [  45  1  1  5  612  33  8  40  13  5  9  1  2991  140  800  16  ]
      [  69  1  8  -1  -1  -1  -1  -1  15  5  9  3  2911  140  880  21  ]
      [  62  2  1  4  870  80  1  39  -1  5  9  1  3114  140  -1  14  ]
      [  33  1  1  5  750  33  8  35  -1  5  10  1  3050  140  -1  14  ]
      [  39  1  1  5  273  31  8  40  -1  1  3  1  3124  140  -1  15  ]
      [  44  1  1  4  801  75  1  40  -1  4  8  1  3000  140  -1  15  ]
      [  49  1  1  5  780  36  8  28  -1  1  3  1  3039  140  -1  17  ]
      [  53  1  1  5  621  45  8  40  -1  1  4  1  2984  140  -1  17  ]
      [  49  2  1  5  692  66  8  38  -1  3  4  1  3060  140  -1  21  ]
      [  43  1  1  5  774  29  8  60  -1  5  9  1  2941  140  -1  17  ]
      [  43  1  1  5  879  65  8  39  -1  4  3  1  3449  140  -1  15  ]
      [  35  2  8  2  841  85  8  40  -1  5  10  1  3567  140  -1  22  ]
      [  50  1  1  4  872  80  1  45  6  5  9  1  3321  140  350  15  ]
      [  40  1  1  4  609  45  1  40  -1  4  8  1  3577  140  -1  16  ]
      [  35  1  1  5  611  24  8  40  -1  5  9  1  3459  140  -1  19  ]
      [  77  1  1  1  753  74  8  40  -1  5  8  1  3296  140  -1  15  ]
      [  46  1  1  1  172  22  8  50  -1  1  5  1  3219  140  -1  21  ]
      [  40  1  1  5  601  29  8  40  -1  5  8  1  3542  140  -1  15  ]
      [  54  2  1  2  841  85  8  45  -1  5  9  1  3604  140  -1  17  ]
      [  57  1  1  5  751  85  8  50  -1  5  3  1  3656  140  -1  22  ]
      [  35  1  1  5  692  66  8  40  -1  5  5  1  3602  140  -1  16  ]
      [  56  1  1  4  801  75  1  40  -1  4  7  1  3978  140  -1  16  ]
      [  49  1  1  5  726  62  8  40  12  5  3  1  3671  140  750  16  ]
      [  51  1  1  4  761  75  1  50  17  5  7  1  3748  140  1050  21  ]
      [  37  1  1  4  801  75  1  55  -1  5  7  1  4473  140  -1  17  ]
      [  44  1  1  5  603  45  8  39  -1  5  8  1  4306  140  -1  19  ]
      [  54  1  1  5  600  51  8  39  14  5  6  1  4406  140  860  18  ]
      [  66  1  1  2  911  55  8  45  -1  3  3  1  4065  140  -1  22  ]
      [  42  1  1  5  821  22  8  38  15  5  9  1  4302  140  880  21  ]
      [  42  1  1  5  775  36  8  42  -1  5  9  1  4006  140  -1  19  ]
      [  60  1  1  4  872  80  1  55  -1  5  9  1  4329  140  -1  17  ]
      [  47  1  1  5  841  85  1  55  -1  5  7  1  4990  140  -1  19  ]
      [  36  1  1  5  835  92  8  60  -1  5  1  1  4857  140  -1  18  ]
      [  55  1  1  4  874  80  1  38  -1  5  8  1  4933  140  -1  20  ]
      [  43  1  1  5  310  31  8  40  -1  5  10  1  4846  140  650  18  ]
      [  42  1  1  5  841  85  8  40  -1  5  9  1  4989  140  -1  22  ]
      [  60  1  1  2  813  74  8  50  -1  5  9  1  5842  140  -1  20  ]
      [  61  1  1  2  401  15  8  65  -1  3  5  1  5579  140  -1  22  ]
      [  50  1  1  5  607  32  8  38  -1  5  9  1  6760  140  -1  22  ]
      [  48  1  1  2  691  65  8  70  -1  5  8  1  8053  140  -1  22  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  2  3  3  1669  139  -1  13  ]
      [  45  1  1  5  621  34  8  40  -1  3  5  1  1751  139  -1  10  ]
      [  42  2  1  4  764  75  1  38  16  5  10  1  3854  139  860  18  ]
      [  65  2  8  -1  -1  -1  -1  -1  9  5  8  3  1177  138  550  16  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1396  138  -1  12  ]
      [  41  1  1  6  487  45  8  39  -1  1  3  1  1389  138  -1  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1593  138  -1  10  ]
      [  49  2  1  5  789  22  8  37  -1  3  -1  1  1515  138  -1  9  ]
      [  38  1  1  5  692  66  8  38  -1  5  8  1  1945  138  -1  13  ]
      [  35  1  8  5  31  1  8  50  -1  5  9  1  1894  138  -1  15  ]
      [  47  1  1  4  787  75  1  40  -1  4  3  1  1908  138  -1  17  ]
      [  46  1  1  5  651  28  8  38  -1  3  5  1  1783  138  -1  13  ]
      [  47  1  1  6  741  52  8  39  -1  1  3  1  1978  138  -1  12  ]
      [  69  1  1  5  796  85  8  30  -1  1  3  3  2105  138  -1  16  ]
      [  35  1  1  5  854  85  8  38  11  3  3  1  2013  138  600  16  ]
      [  69  1  1  1  704  70  8  45  -1  5  9  1  2365  138  -1  17  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  5  10  3  2488  138  -1  13  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2302  138  -1  18  ]
      [  39  2  1  5  756  60  8  38  -1  5  9  1  2576  138  -1  12  ]
      [  47  2  1  2  841  85  8  40  11  5  9  1  2309  138  600  12  ]
      [  66  1  8  3  11  1  8  20  -1  1  -1  3  659  137  -1  7  ]
      [  42  1  1  6  13  29  8  40  -1  2  3  1  954  137  -1  12  ]
      [  39  1  1  5  622  32  8  40  -1  1  4  1  1353  137  -1  12  ]
      [  51  2  1  1  834  92  8  60  19  3  8  1  1580  137  1200  20  ]
      [  45  1  1  5  605  85  1  38  -1  4  5  1  2221  137  -1  14  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2404  137  -1  14  ]
      [  58  1  8  -1  -1  -1  -1  -1  6  5  9  3  2605  137  377  17  ]
      [  52  1  1  5  751  33  8  40  -1  3  3  1  3303  137  -1  17  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  1  99  3  610  136  -1  5  ]
      [  39  1  1  1  855  85  8  40  -1  1  5  1  724  136  -1  10  ]
      [  43  1  1  6  281  75  1  39  -1  1  3  1  950  136  -1  10  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1161  136  -1  8  ]
      [  56  1  1  5  511  75  1  38  -1  1  3  1  1428  136  -1  14  ]
      [  95  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1356  136  -1  19  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1689  136  -1  11  ]
      [  52  1  1  6  761  21  8  35  -1  1  3  1  1555  136  -1  14  ]
      [  34  1  1  6  273  29  8  35  10  4  3  1  1875  136  500  10  ]
      [  46  1  1  6  287  34  8  35  -1  1  3  1  1708  136  -1  17  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1805  136  -1  10  ]
      [  60  1  1  5  780  65  8  39  -1  1  3  1  2081  136  -1  12  ]
      [  57  1  1  5  311  32  8  35  -1  3  5  1  2076  136  -1  17  ]
      [  33  1  1  5  777  30  8  35  -1  3  4  1  2312  136  -1  12  ]
      [  58  1  1  5  774  25  8  38  11  5  8  1  3137  136  670  14  ]
      [  37  1  1  5  623  74  8  38  -1  3  3  1  4296  136  -1  18  ]
      [  51  1  1  5  611  30  8  53  -1  4  5  1  6179  136  -1  21  ]
      [  50  1  8  -1  -1  -1  -1  -1  -1  2  3  2  651  135  -1  11  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  862  135  -1  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  14  1  4  3  812  135  790  6  ]
      [  51  1  1  6  310  45  8  37  -1  1  3  1  705  135  -1  10  ]
      [  28  2  1  6  522  26  8  38  -1  1  3  1  778  135  300  10  ]
      [  39  1  1  6  281  50  8  37  -1  2  4  1  792  135  -1  11  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  1  3  3  891  135  -1  10  ]
      [  47  1  1  6  62  1  8  40  -1  1  3  1  886  135  -1  15  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  3  3  2  985  135  -1  8  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  3  3  900  135  -1  11  ]
      [  39  2  8  -1  -1  -1  -1  -1  14  1  -1  6  1135  135  700  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  6  3  1250  135  -1  11  ]
      [  54  1  1  5  796  75  1  45  13  1  3  1  1447  135  690  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1439  135  -1  16  ]
      [  49  1  1  6  290  36  8  38  -1  1  3  1  1311  135  -1  12  ]
      [  25  2  1  5  788  24  8  40  6  3  3  1  1339  135  300  14  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1596  135  -1  15  ]
      [  50  2  1  5  620  75  1  40  -1  2  6  1  1598  135  -1  17  ]
      [  36  1  1  5  441  75  1  39  -1  1  -1  1  1839  135  -1  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  4  1  3  1889  135  -1  17  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1876  135  -1  10  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1713  135  -1  11  ]
      [  43  2  1  5  787  75  1  36  -1  1  3  1  1842  135  -1  15  ]
      [  42  1  1  5  772  45  8  39  -1  2  4  1  2099  135  -1  11  ]
      [  35  1  1  6  487  45  8  39  -1  1  3  1  2234  135  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  3  3  3  2258  135  760  16  ]
      [  55  2  1  1  911  55  8  30  -1  3  3  1  2251  135  -1  11  ]
      [  36  1  1  5  175  85  1  39  -1  1  5  1  2065  135  -1  11  ]
      [  47  1  1  5  689  24  8  50  -1  5  4  1  2128  135  -1  13  ]
      [  50  1  1  2  101  26  8  70  -1  1  5  1  2253  135  -1  13  ]
      [  54  1  1  5  701  52  8  38  9  1  3  1  2540  135  439  16  ]
      [  42  1  1  4  801  75  1  40  -1  -1  -1  1  2535  135  -1  12  ]
      [  56  1  1  2  813  74  8  50  -1  5  9  1  2380  135  -1  14  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  4  5  3  2623  135  -1  15  ]
      [  53  1  1  5  411  85  1  38  -1  3  5  1  2651  135  -1  19  ]
      [  50  1  1  4  873  80  1  39  -1  5  9  1  2689  135  -1  13  ]
      [  53  1  1  4  765  75  1  40  -1  3  7  1  3059  135  -1  17  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  5  3  3304  135  -1  16  ]
      [  33  1  1  2  672  52  8  50  -1  5  3  1  4022  135  -1  17  ]
      [  36  1  1  5  754  74  8  45  -1  5  3  1  4188  135  -1  18  ]
      [  51  1  1  5  691  65  8  38  17  9  -1  1  5425  135  900  21  ]
      [  45  1  1  2  750  45  8  75  -1  5  8  1  5602  135  -1  22  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  5  9  3  5970  135  -1  20  ]
      [  38  1  1  2  691  67  8  70  -1  3  3  1  9186  135  -1  23  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1086  134  -1  10  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  919  134  -1  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1541  134  -1  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1937  134  -1  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1743  134  -1  18  ]
      [  42  1  1  6  311  35  8  36  -1  1  3  1  1877  134  -1  11  ]
      [  30  1  1  6  937  93  8  40  -1  2  3  1  1875  134  -1  10  ]
      [  39  1  1  6  505  36  8  30  -1  1  3  1  2146  134  -1  12  ]
      [  38  1  1  5  751  85  8  50  -1  5  3  1  2494  134  -1  12  ]
      [  55  1  1  4  870  80  1  50  8  5  9  1  3261  134  430  17  ]
      [  48  1  1  5  750  45  8  70  13  5  8  1  4256  134  780  18  ]
      [  39  1  1  5  662  52  8  60  -1  4  5  1  4963  134  -1  18  ]
      [  58  2  8  -1  -1  -1  -1  -1  9  3  3  3  965  133  450  11  ]
      [  33  1  1  6  267  45  8  40  -1  1  3  1  2817  133  -1  17  ]
      [  52  2  8  -1  -1  -1  -1  -1  -1  3  3  4  560  132  -1  15  ]
      [  46  1  1  6  281  34  8  29  -1  1  3  1  1891  132  -1  14  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1812  132  -1  10  ]
      [  29  1  1  9  801  75  1  40  -1  3  3  1  2041  132  250  12  ]
      [  47  1  1  6  268  75  1  38  -1  1  3  1  2580  132  -1  12  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2850  132  -1  16  ]
      [  49  1  1  4  801  75  1  39  -1  3  3  1  3146  132  -1  14  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  5  9  8  3373  132  -1  16  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1055  131  -1  6  ]
      [  33  2  1  5  411  85  8  40  -1  2  3  1  1786  131  -1  10  ]
      [  47  2  1  5  853  85  8  38  14  5  3  1  2166  131  720  18  ]
      [  39  2  8  -1  -1  -1  -1  -1  -1  5  8  4  172  130  -1  13  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  3  3  262  130  -1  16  ]
      [  60  2  1  5  780  74  8  8  -1  3  3  4  324  130  -1  15  ]
      [  54  1  1  2  833  92  8  80  -1  5  8  1  619  130  -1  9  ]
      [  33  2  1  5  857  74  8  20  -1  3  6  4  566  130  -1  15  ]
      [  32  1  1  5  912  55  8  20  -1  5  -1  1  582  130  -1  4  ]
      [  53  2  8  -1  -1  -1  -1  -1  -1  1  3  3  542  130  -1  9  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  667  130  -1  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  592  130  -1  4  ]
      [  25  1  8  -1  -1  -1  -1  -1  -1  3  3  2  654  130  -1  9  ]
      [  32  1  8  -1  -1  -1  -1  -1  9  2  3  2  695  130  500  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  3  3  3  827  130  -1  5  ]
      [  40  2  8  -1  -1  -1  -1  -1  -1  5  5  4  801  130  -1  10  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  1  3  708  130  -1  9  ]
      [  25  2  8  -1  -1  -1  -1  -1  8  1  -1  6  748  130  420  7  ]
      [  35  2  8  -1  -1  -1  -1  -1  6  5  3  2  715  130  300  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  751  130  -1  5  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  861  130  -1  5  ]
      [  41  2  1  5  431  52  8  30  -1  1  3  1  837  130  -1  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  739  130  -1  11  ]
      [  50  2  1  1  24  1  8  38  -1  1  3  1  706  130  -1  5  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  3  3  866  130  -1  5  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  883  130  -1  7  ]
      [  37  2  1  5  787  92  8  30  11  3  3  1  923  130  625  6  ]
      [  48  2  1  5  735  50  8  40  -1  1  3  1  1066  130  -1  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  999  130  -1  8  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  934  130  -1  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  923  130  -1  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  5  -1  3  1055  130  -1  16  ]
      [  34  2  1  5  853  85  1  30  11  3  5  1  921  130  500  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1002  130  -1  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  1  3  947  130  -1  6  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1006  130  -1  6  ]
      [  37  2  1  5  540  65  1  19  11  3  3  1  1036  130  510  12  ]
      [  37  1  1  6  241  35  8  39  -1  2  3  1  981  130  -1  11  ]
      [  42  1  1  6  443  45  8  40  -1  2  3  1  1064  130  -1  12  ]
      [  33  1  1  5  254  29  8  40  -1  2  5  1  1031  130  -1  11  ]
      [  37  1  1  6  273  29  8  40  -1  2  3  1  1031  130  -1  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1109  130  -1  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1108  130  -1  12  ]
      [  30  1  1  5  411  55  8  40  -1  1  3  1  1123  130  -1  12  ]
      [  39  1  1  6  51  1  8  41  -1  1  -1  1  1122  130  -1  7  ]
      [  47  1  1  6  441  45  8  39  -1  1  -1  1  1209  130  -1  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  5  8  2  1142  130  -1  7  ]
      [  45  2  1  5  780  85  1  39  -1  3  -1  1  1137  130  -1  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1199  130  -1  12  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1108  130  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1248  130  -1  9  ]
      [  46  2  1  5  661  52  8  23  -1  1  3  1  1152  130  -1  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1272  130  -1  8  ]
      [  71  1  1  1  714  15  8  10  -1  1  3  3  1172  130  -1  7  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1228  130  -1  7  ]
      [  42  1  1  6  281  26  8  50  -1  1  3  1  1291  130  -1  9  ]
      [  33  1  1  6  268  45  8  38  -1  1  3  1  1286  130  -1  7  ]
      [  50  2  1  5  921  85  8  40  -1  3  4  1  1145  130  -1  11  ]
      [  54  1  1  6  531  17  8  38  11  -1  -1  1  1200  130  630  15  ]
      [  47  2  1  5  863  85  1  40  -1  1  99  1  1263  130  -1  20  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1264  130  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1146  130  -1  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1134  130  -1  13  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1284  130  -1  7  ]
      [  37  1  1  6  662  52  8  31  -1  2  3  1  1264  130  -1  10  ]
      [  47  1  1  6  181  20  8  40  -1  2  3  1  1182  130  -1  13  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1298  130  -1  12  ]
      [  43  1  1  2  750  50  8  45  -1  5  6  1  1276  130  -1  10  ]
      [  51  1  1  5  787  75  1  39  -1  3  3  1  1412  130  -1  12  ]
      [  53  1  1  5  662  50  8  37  -1  1  3  1  1459  130  -1  8  ]
      [  32  1  1  6  440  45  8  40  -1  1  -1  1  1380  130  -1  10  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1390  130  -1  8  ]
      [  58  1  1  5  788  24  8  37  -1  -1  -1  1  1392  130  -1  8  ]
      [  32  1  1  5  691  67  1  38  -1  3  5  1  1404  130  -1  15  ]
      [  38  1  1  6  620  92  8  40  -1  4  5  1  1410  130  -1  12  ]
      [  36  2  8  -1  -1  -1  -1  -1  9  4  3  2  1424  130  500  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1496  130  -1  14  ]
      [  59  2  8  -1  -1  -1  -1  -1  10  3  3  3  1446  130  550  14  ]
      [  40  1  1  4  801  75  1  40  -1  1  3  1  1470  130  -1  15  ]
      [  41  1  1  5  788  91  8  38  -1  4  3  1  1344  130  -1  14  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1308  130  -1  9  ]
      [  53  1  1  5  751  31  8  40  -1  3  -1  1  1451  130  -1  12  ]
      [  31  1  1  6  441  45  8  40  -1  1  3  1  1432  130  0  10  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1367  130  -1  8  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1336  130  -1  14  ]
      [  38  1  1  6  290  29  8  40  -1  2  -1  1  1420  130  -1  12  ]
      [  43  1  1  5  607  27  8  45  -1  2  8  1  1487  130  -1  13  ]
      [  50  2  1  5  853  85  1  39  -1  3  3  1  1696  130  -1  9  ]
      [  34  1  1  6  482  45  8  39  7  1  3  1  1559  130  400  13  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1520  130  -1  10  ]
      [  38  1  8  -1  -1  -1  -1  -1  8  3  5  2  1641  130  460  9  ]
      [  37  1  1  5  620  74  8  35  -1  3  3  1  1667  130  -1  12  ]
      [  39  1  1  6  391  52  8  40  -1  1  3  1  1692  130  -1  9  ]
      [  56  1  1  5  401  15  8  39  -1  1  5  1  1695  130  -1  12  ]
      [  48  1  1  5  603  75  1  39  -1  5  8  1  1516  130  -1  9  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1619  130  -1  10  ]
      [  49  1  1  6  471  80  1  38  -1  1  3  1  1541  130  -1  15  ]
      [  59  1  1  2  750  51  8  70  -1  3  3  1  1605  130  0  10  ]
      [  48  1  1  2  268  45  8  50  -1  1  5  1  1691  130  -1  10  ]
      [  37  1  1  6  714  45  8  45  -1  1  3  1  1542  130  -1  10  ]
      [  38  1  1  6  550  28  8  38  9  1  3  1  1658  130  450  15  ]
      [  48  1  1  1  692  67  8  55  -1  3  3  1  1558  130  -1  14  ]
      [  62  1  8  5  549  45  8  4  -1  1  5  3  1671  130  -1  12  ]
      [  56  1  1  2  310  31  8  40  -1  2  7  1  1672  130  -1  15  ]
      [  42  1  1  2  662  52  8  60  -1  2  -1  1  1631  130  -1  9  ]
      [  45  1  1  5  316  45  8  40  -1  2  3  1  1601  130  -1  18  ]
      [  44  2  1  5  691  65  8  32  -1  5  3  1  1872  130  -1  11  ]
      [  33  1  1  6  290  35  8  30  -1  3  3  1  1829  130  -1  10  ]
      [  31  1  1  6  141  13  8  40  -1  1  3  1  1750  130  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1732  130  -1  14  ]
      [  43  1  1  5  51  85  1  38  5  1  3  1  1799  130  260  11  ]
      [  37  1  1  1  441  45  8  40  -1  3  5  1  1936  130  -1  13  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1896  130  -1  11  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1802  130  -1  10  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  5  9  3  1886  130  -1  10  ]
      [  37  1  1  5  701  60  8  38  8  3  3  1  1906  130  390  16  ]
      [  40  1  1  6  290  28  8  38  -1  3  5  1  1959  130  -1  11  ]
      [  38  1  1  6  512  26  8  38  -1  5  5  1  1843  130  -1  14  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1714  130  -1  12  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1805  130  -1  10  ]
      [  44  1  1  4  620  32  1  38  -1  3  5  1  1874  130  -1  10  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1823  130  -1  10  ]
      [  27  2  1  4  765  75  1  39  -1  5  5  1  1824  130  -1  15  ]
      [  59  1  1  5  303  85  8  40  -1  1  3  1  1795  130  -1  15  ]
      [  61  1  1  5  692  75  8  39  -1  3  3  1  1763  130  -1  12  ]
      [  44  2  1  5  780  75  1  40  13  2  5  1  1820  130  770  15  ]
      [  56  2  1  5  608  24  8  40  -1  5  10  1  1882  130  -1  17  ]
      [  31  2  1  5  775  34  8  30  -1  4  9  1  1846  130  -1  17  ]
      [  42  1  1  5  714  65  8  47  -1  1  3  1  2128  130  -1  15  ]
      [  49  1  1  6  268  45  8  37  -1  1  -1  1  2188  130  -1  11  ]
      [  33  1  1  6  744  63  8  39  -1  3  3  1  2158  130  -1  11  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2153  130  -1  13  ]
      [  40  1  1  5  269  75  1  38  -1  1  3  1  2173  130  -1  12  ]
      [  41  2  1  1  855  85  8  50  15  3  5  1  2094  130  900  11  ]
      [  56  2  1  5  787  75  1  39  -1  1  3  1  2130  130  -1  11  ]
      [  38  1  1  5  835  92  1  36  -1  3  3  1  2225  130  -1  11  ]
      [  36  1  1  6  521  28  8  37  -1  3  3  1  2233  130  -1  14  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2014  130  -1  11  ]
      [  41  1  1  5  601  34  8  40  -1  5  8  1  2009  130  -1  12  ]
      [  39  1  1  6  510  45  8  39  -1  1  3  1  2236  130  -1  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2206  130  -1  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2152  130  -1  11  ]
      [  39  1  1  4  787  75  1  39  9  3  3  1  2033  130  500  13  ]
      [  33  1  1  4  731  64  8  39  15  1  3  1  2077  130  780  13  ]
      [  62  1  8  4  750  75  1  40  -1  3  7  1  2258  130  -1  11  ]
      [  50  2  1  5  751  30  8  39  19  1  -1  1  2247  130  1100  11  ]
      [  37  1  1  1  171  22  8  40  -1  3  3  1  2012  130  -1  12  ]
      [  46  1  1  5  751  75  1  39  -1  5  8  1  2022  130  -1  15  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  3  3  3  2208  130  -1  11  ]
      [  33  2  1  5  603  20  8  40  16  5  8  1  2286  130  750  15  ]
      [  52  1  1  2  911  55  8  70  11  1  3  1  2032  130  600  14  ]
      [  45  1  1  6  540  17  8  39  -1  3  3  1  2246  130  -1  13  ]
      [  43  1  1  6  714  63  8  50  12  3  5  1  2265  130  720  12  ]
      [  51  1  1  5  891  91  8  40  -1  5  8  1  2154  130  -1  11  ]
      [  62  2  1  1  851  85  8  30  -1  5  7  1  2324  130  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  5  3  5  2370  130  -1  12  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2458  130  -1  15  ]
      [  48  1  1  5  691  65  8  39  9  3  3  1  2346  130  450  12  ]
      [  42  1  1  5  651  21  8  38  -1  1  3  1  2367  130  -1  13  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  4  -1  3  2543  130  -1  12  ]
      [  39  1  1  5  311  40  8  40  -1  9  5  1  2341  130  -1  13  ]
      [  37  1  1  5  785  27  8  40  -1  4  3  1  2525  130  -1  14  ]
      [  30  1  1  6  501  20  8  40  -1  1  3  1  2598  130  0  15  ]
      [  60  1  1  2  911  55  8  60  -1  -1  -1  1  2551  130  -1  16  ]
      [  46  1  1  6  141  24  8  38  -1  3  3  1  2400  130  -1  13  ]
      [  44  1  1  5  621  35  8  35  -1  3  3  1  2321  130  -1  14  ]
      [  40  1  1  5  465  45  1  39  -1  1  5  1  2378  130  0  12  ]
      [  38  1  1  5  751  31  8  45  -1  5  9  1  2554  130  -1  12  ]
      [  45  1  1  4  861  75  1  40  -1  4  8  1  2396  130  -1  14  ]
      [  42  1  1  5  751  51  8  40  16  5  9  1  2319  130  1000  17  ]
      [  37  1  1  6  290  34  8  35  -1  1  -1  1  2547  130  -1  13  ]
      [  55  2  1  5  780  52  8  35  -1  3  -1  1  2523  130  -1  12  ]
      [  39  1  1  1  268  45  8  80  -1  3  3  1  2513  130  -1  15  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2522  130  -1  13  ]
      [  58  1  1  4  603  60  8  38  -1  4  8  1  2523  130  -1  18  ]
      [  38  2  1  2  844  52  8  50  13  5  9  1  2459  130  650  18  ]
      [  42  2  1  5  602  30  8  40  -1  5  9  1  2370  130  -1  17  ]
      [  55  1  1  5  870  80  1  38  -1  5  9  1  2321  130  -1  19  ]
      [  62  1  1  2  603  45  8  40  -1  4  9  1  2760  130  -1  16  ]
      [  52  1  1  4  870  80  1  38  -1  -1  -1  1  2773  130  -1  15  ]
      [  30  1  1  4  872  80  1  37  -1  5  9  1  2673  130  -1  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2714  130  -1  19  ]
      [  54  1  1  6  273  29  8  35  -1  1  3  1  2875  130  -1  16  ]
      [  53  1  1  2  303  33  8  60  -1  3  5  1  2722  130  -1  21  ]
      [  60  1  1  5  602  75  1  39  -1  4  8  1  2877  130  -1  16  ]
      [  36  1  1  2  750  63  8  60  -1  1  3  1  2900  130  -1  15  ]
      [  35  1  1  4  801  75  1  40  -1  5  9  1  2623  130  -1  17  ]
      [  50  1  1  5  821  22  8  60  -1  5  9  1  2989  130  -1  14  ]
      [  37  1  1  5  776  72  8  35  -1  5  8  1  2932  130  -1  14  ]
      [  38  1  1  4  801  75  1  39  -1  3  99  1  3045  130  -1  15  ]
      [  40  1  1  5  787  75  1  39  11  5  3  1  3063  130  600  14  ]
      [  60  1  1  5  651  11  8  40  -1  1  3  1  2952  130  -1  18  ]
      [  41  1  1  4  787  64  8  40  -1  1  3  1  3168  130  -1  14  ]
      [  46  1  1  4  872  80  1  60  -1  5  9  1  3055  130  -1  14  ]
      [  55  1  1  4  787  75  1  38  -1  5  7  1  2996  130  -1  16  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  3159  130  -1  15  ]
      [  52  1  1  2  750  45  8  56  -1  1  5  1  2957  130  -1  16  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  99  3  2962  130  -1  19  ]
      [  30  1  1  2  912  55  8  45  10  3  3  1  3181  130  500  14  ]
      [  52  1  1  5  756  31  8  45  -1  1  99  1  3152  130  -1  17  ]
      [  38  1  1  2  603  74  8  40  -1  2  8  1  3086  130  -1  16  ]
      [  57  1  1  2  750  92  8  98  -1  5  8  1  3565  130  -1  17  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  3442  130  -1  21  ]
      [  35  1  1  5  442  45  8  40  -1  3  3  1  3542  130  -1  15  ]
      [  53  1  1  4  873  80  1  42  -1  5  9  1  3312  130  -1  17  ]
      [  35  1  1  1  603  74  8  42  -1  5  8  1  3587  130  -1  17  ]
      [  61  1  1  5  600  35  8  35  -1  5  9  1  3373  130  -1  18  ]
      [  29  1  1  6  316  34  8  35  -1  3  3  1  3370  130  -1  16  ]
      [  46  1  1  5  601  74  8  40  -1  9  -1  1  3265  130  -1  15  ]
      [  90  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  3660  130  -1  18  ]
      [  40  1  1  5  651  24  8  40  -1  3  5  1  3769  130  -1  17  ]
      [  39  1  1  5  600  80  1  40  -1  5  9  1  3890  130  -1  18  ]
      [  46  1  1  5  751  13  8  38  -1  5  3  1  3739  130  -1  16  ]
      [  56  1  1  5  633  29  8  40  -1  1  3  1  3628  130  -1  16  ]
      [  55  1  1  5  750  24  8  38  -1  5  9  1  3824  130  -1  16  ]
      [  42  1  1  5  626  33  8  38  -1  3  3  1  3650  130  -1  16  ]
      [  61  1  1  2  841  91  8  60  -1  5  10  1  3696  130  -1  22  ]
      [  62  1  1  4  872  80  1  45  -1  5  10  1  4351  130  -1  22  ]
      [  53  1  1  4  873  80  1  40  -1  5  9  1  4077  130  -1  17  ]
      [  36  1  1  5  776  64  8  39  17  5  9  1  4025  130  1000  20  ]
      [  56  1  1  5  612  85  1  60  -1  5  10  1  4020  130  -1  17  ]
      [  50  1  1  5  750  90  8  40  -1  1  3  1  4340  130  -1  19  ]
      [  51  1  1  5  600  31  8  52  -1  4  8  1  4083  130  -1  21  ]
      [  48  1  1  5  751  31  8  40  10  5  9  1  4176  130  500  19  ]
      [  51  1  1  5  785  24  8  70  -1  3  99  1  4842  130  -1  20  ]
      [  52  1  1  5  780  66  8  60  21  3  3  1  4839  130  1200  21  ]
      [  40  1  1  5  691  65  8  39  -1  3  3  1  4977  130  -1  20  ]
      [  41  1  1  5  751  65  8  40  -1  5  6  1  4822  130  -1  18  ]
      [  45  1  1  5  600  21  8  50  14  5  9  1  4536  130  750  18  ]
      [  38  1  1  5  751  65  8  45  -1  5  8  1  5451  130  -1  19  ]
      [  58  1  1  5  691  65  8  40  -1  -1  -1  1  5243  130  -1  21  ]
      [  59  1  1  5  620  29  8  35  -1  1  5  1  5044  130  -1  19  ]
      [  42  1  1  5  772  65  8  39  -1  3  3  1  5269  130  -1  20  ]
      [  63  1  1  5  880  24  8  55  -1  5  10  1  5336  130  -1  19  ]
      [  58  1  1  2  671  51  8  50  -1  5  3  1  5067  130  -1  19  ]
      [  42  1  1  2  600  74  8  50  -1  5  8  1  5083  130  -1  19  ]
      [  54  1  1  5  750  66  8  40  -1  3  3  1  5878  130  -1  21  ]
      [  63  1  8  -1  -1  -1  -1  -1  17  5  10  3  5878  130  1000  20  ]
      [  42  1  1  5  750  51  8  60  -1  3  5  1  5777  130  -1  21  ]
      [  37  1  1  2  911  55  8  98  17  5  9  1  7448  130  900  21  ]
      [  44  1  1  5  671  24  8  50  13  -1  -1  1  7141  130  600  21  ]
      [  41  1  1  1  886  85  8  60  -1  5  9  1  7375  130  -1  21  ]
      [  42  1  1  2  750  45  8  60  -1  4  5  1  7205  130  -1  21  ]
      [  48  1  1  5  777  51  8  40  -1  5  8  1  6124  130  -1  22  ]
      [  32  1  1  5  692  66  8  45  -1  5  3  1  8561  130  -1  22  ]
      [  39  1  8  -1  -1  -1  -1  -1  -1  1  3  5  7633  130  750  22  ]
      [  54  1  1  2  834  74  8  70  -1  5  9  1  10240  130  -1  23  ]
      [  24  1  1  5  671  51  8  43  7  3  3  1  1101  129  400  11  ]
      [  64  1  1  6  796  92  8  12  -1  3  3  3  1166  129  -1  10  ]
      [  36  1  1  6  546  45  8  50  -1  2  3  1  1275  129  -1  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  4  5  3  1363  129  -1  12  ]
      [  52  2  1  5  789  85  1  39  -1  5  9  1  1589  129  -1  15  ]
      [  45  1  1  5  750  52  8  40  -1  5  9  1  2836  129  -1  18  ]
      [  49  2  1  5  672  52  8  23  -1  1  3  1  888  128  -1  11  ]
      [  31  1  8  -1  -1  -1  -1  -1  -1  2  3  2  831  128  -1  7  ]
      [  50  1  1  6  254  1  8  40  -1  2  3  1  1037  128  -1  12  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1255  128  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1145  128  -1  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1238  128  0  10  ]
      [  62  1  8  5  714  1  8  4  -1  1  3  3  1448  128  -1  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1312  128  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1508  128  -1  9  ]
      [  47  2  1  5  787  75  1  19  -1  3  -1  1  1507  128  0  9  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1711  128  -1  10  ]
      [  62  2  1  5  991  91  8  4  -1  3  8  3  1868  128  -1  10  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2241  128  0  11  ]
      [  34  1  1  5  873  80  1  40  8  5  9  1  2066  128  326  15  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2985  128  -1  14  ]
      [  45  1  1  5  622  73  8  39  -1  5  3  1  2920  128  -1  16  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  5  99  3  3199  128  -1  14  ]
      [  59  1  1  2  844  52  8  50  -1  5  9  1  3809  128  -1  19  ]
      [  43  2  1  6  937  75  1  20  9  1  3  1  867  127  500  13  ]
      [  42  1  1  6  487  45  8  40  -1  2  3  1  1070  127  -1  10  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1352  127  -1  11  ]
      [  31  1  1  6  273  60  8  38  -1  3  3  1  1506  127  -1  9  ]
      [  40  2  1  1  859  85  8  18  10  5  5  1  1832  127  580  10  ]
      [  64  2  8  -1  -1  -1  -1  -1  10  1  3  3  1721  127  500  10  ]
      [  45  1  1  5  689  29  8  45  -1  5  9  1  1991  127  -1  15  ]
      [  44  1  1  5  852  85  8  60  -1  1  5  1  2261  127  -1  12  ]
      [  32  1  1  5  880  80  1  20  -1  5  8  1  2275  127  0  13  ]
      [  40  2  1  5  872  80  1  18  -1  5  7  1  2101  127  -1  14  ]
      [  53  1  1  2  841  85  8  48  -1  5  9  1  2280  127  -1  16  ]
      [  32  2  1  5  704  65  1  50  -1  5  5  1  2512  127  -1  19  ]
      [  59  1  1  2  884  80  8  50  -1  5  9  1  2448  127  -1  14  ]
      [  44  1  1  5  600  74  8  40  12  5  9  1  2886  127  600  15  ]
      [  44  1  1  5  761  25  8  35  -1  4  4  1  2763  127  -1  15  ]
      [  59  1  8  4  787  75  1  40  -1  4  7  1  2728  127  -1  15  ]
      [  50  1  1  5  692  66  8  40  -1  3  3  1  3159  127  -1  17  ]
      [  44  1  1  5  777  74  8  38  -1  4  8  1  2910  127  -1  14  ]
      [  55  1  1  5  678  29  8  40  -1  5  10  1  2905  127  -1  17  ]
      [  52  1  1  5  601  29  8  38  -1  4  5  1  3361  127  -1  19  ]
      [  42  1  1  5  601  29  8  35  -1  4  9  1  3837  127  -1  19  ]
      [  41  1  1  4  871  80  1  38  -1  5  9  1  4810  127  -1  21  ]
      [  23  2  8  -1  -1  -1  -1  -1  -1  2  3  8  163  126  -1  6  ]
      [  52  1  1  2  482  45  8  20  12  3  3  1  1094  126  600  14  ]
      [  50  1  1  6  522  28  8  40  3  2  -1  1  1100  126  126  13  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1110  126  -1  10  ]
      [  42  1  1  1  510  45  8  90  -1  1  5  1  1745  126  -1  17  ]
      [  44  1  1  5  751  64  8  38  -1  5  9  1  1779  126  -1  17  ]
      [  29  1  1  5  780  51  8  60  -1  2  4  1  1916  126  -1  11  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2041  126  -1  11  ]
      [  44  1  1  5  776  93  8  40  -1  4  5  1  2232  126  -1  12  ]
      [  25  1  1  5  624  74  8  45  9  3  3  1  2141  126  460  13  ]
      [  35  1  1  5  300  50  8  40  -1  4  5  1  2502  126  -1  14  ]
      [  45  1  1  5  751  25  8  40  15  5  10  1  3277  126  750  15  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  388  125  -1  6  ]
      [  43  1  8  6  290  28  8  8  -1  3  3  4  420  125  -1  12  ]
      [  28  2  1  5  856  85  8  25  -1  2  5  1  706  125  -1  12  ]
      [  37  2  1  1  836  93  8  70  7  5  9  1  786  125  329  5  ]
      [  30  2  1  6  901  93  8  38  -1  1  3  1  1033  125  -1  13  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1063  125  -1  7  ]
      [  41  1  1  1  267  45  8  40  -1  1  5  1  907  125  -1  13  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  932  125  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1025  125  -1  14  ]
      [  33  1  1  6  221  28  8  40  -1  1  4  1  1035  125  -1  6  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  971  125  -1  8  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1194  125  -1  13  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1161  125  -1  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1151  125  -1  7  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1295  125  -1  10  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1170  125  -1  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1296  125  -1  15  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1157  125  -1  9  ]
      [  51  1  1  5  609  74  8  60  20  5  8  1  1498  125  1100  11  ]
      [  35  1  1  6  270  31  8  35  -1  1  5  1  1377  125  -1  8  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1484  125  -1  8  ]
      [  47  1  1  6  721  61  8  45  -1  2  3  1  1385  125  -1  11  ]
      [  41  2  1  5  788  75  1  40  -1  2  3  1  1359  125  -1  14  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  6  3  1492  125  -1  8  ]
      [  41  1  1  4  788  64  8  38  -1  3  3  1  1598  125  -1  14  ]
      [  42  1  1  6  440  45  8  40  -1  1  3  1  1649  125  -1  15  ]
      [  43  1  1  6  741  63  8  45  -1  -1  -1  1  1588  125  -1  11  ]
      [  31  1  1  5  780  50  8  47  -1  1  3  1  1530  125  -1  9  ]
      [  53  1  1  6  269  40  1  38  -1  1  3  1  1520  125  -1  11  ]
      [  41  1  1  8  441  45  8  39  9  1  3  1  1692  125  480  9  ]
      [  63  1  1  5  780  22  8  60  -1  1  1  1  1579  125  -1  9  ]
      [  50  1  1  6  273  27  8  37  -1  3  3  1  1677  125  -1  11  ]
      [  34  1  1  5  780  30  8  40  5  3  3  1  1677  125  280  11  ]
      [  33  1  1  6  481  45  8  42  -1  1  3  1  1509  125  -1  9  ]
      [  39  1  1  6  265  29  8  35  -1  3  3  1  1553  125  -1  14  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1554  125  -1  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  3  3  1700  125  -1  20  ]
      [  57  1  1  5  602  74  8  40  -1  4  8  1  1641  125  -1  17  ]
      [  36  1  1  5  622  32  8  37  -1  2  3  1  1516  125  -1  15  ]
      [  31  1  1  6  937  74  8  40  -1  5  3  1  1847  125  -1  10  ]
      [  36  1  1  5  854  85  8  38  -1  3  3  1  1750  125  -1  15  ]
      [  43  2  1  5  856  85  1  40  -1  2  3  1  1909  125  -1  11  ]
      [  54  1  1  2  901  93  8  60  -1  2  5  1  1998  125  -1  12  ]
      [  62  1  1  5  11  1  8  60  -1  4  9  1  1875  125  -1  12  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  5  7  8  2209  125  -1  11  ]
      [  49  1  1  4  874  80  1  30  -1  1  5  1  2092  125  -1  16  ]
      [  32  1  1  4  771  75  1  40  -1  5  7  1  2091  125  -1  17  ]
      [  40  1  1  6  241  45  8  40  -1  1  3  1  2163  125  -1  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  5  5  3  2182  125  -1  15  ]
      [  36  2  1  5  750  93  8  50  20  5  3  1  2236  125  1050  11  ]
      [  50  1  1  6  550  24  8  36  -1  1  3  1  2238  125  -1  13  ]
      [  28  2  1  5  521  24  8  45  11  5  9  1  2156  125  500  18  ]
      [  35  1  1  1  313  45  8  60  -1  3  4  1  2027  125  -1  11  ]
      [  38  1  1  4  787  75  1  39  -1  3  3  1  2110  125  -1  12  ]
      [  42  1  1  4  702  60  8  39  -1  1  3  1  2480  125  -1  15  ]
      [  37  1  1  5  775  45  8  45  -1  3  3  1  2581  125  -1  14  ]
      [  56  1  1  5  881  92  8  40  -1  3  5  1  2554  125  -1  12  ]
      [  35  1  1  5  621  74  8  40  -1  3  5  1  2303  125  -1  12  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2464  125  -1  12  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  99  3  2630  125  -1  15  ]
      [  44  1  1  5  996  60  8  37  -1  5  9  1  3195  125  -1  15  ]
      [  51  1  1  2  692  66  8  60  -1  3  3  1  3117  125  -1  19  ]
      [  53  1  1  5  662  50  8  38  -1  3  3  1  3006  125  -1  14  ]
      [  49  1  1  5  880  80  1  42  -1  5  9  1  2908  125  -1  17  ]
      [  61  1  1  2  501  36  8  60  -1  1  5  1  3145  125  -1  15  ]
      [  44  1  1  5  780  25  8  40  -1  5  9  1  3084  125  -1  15  ]
      [  42  1  1  5  677  40  8  35  -1  4  8  1  3400  125  -1  17  ]
      [  38  1  1  5  779  30  8  50  -1  5  9  1  3234  125  -1  15  ]
      [  43  1  1  2  995  70  8  60  -1  1  5  1  3435  125  -1  21  ]
      [  40  1  1  4  801  75  1  40  -1  5  7  1  3553  125  -1  17  ]
      [  30  1  1  5  600  34  8  39  -1  4  8  1  3214  125  -1  16  ]
      [  55  1  1  4  872  80  1  40  -1  5  9  1  3366  125  -1  15  ]
      [  53  1  1  5  751  65  8  45  -1  5  9  1  4151  125  -1  17  ]
      [  45  1  1  2  621  29  8  54  -1  3  5  1  4899  125  -1  19  ]
      [  37  1  1  6  726  63  1  38  -1  1  3  1  4708  125  -1  18  ]
      [  36  1  1  5  813  74  8  50  25  5  10  1  8037  125  1500  22  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  899  124  -1  7  ]
      [  26  2  1  5  864  85  8  37  4  3  4  1  1033  124  200  12  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  965  124  -1  6  ]
      [  41  1  1  6  531  21  8  39  -1  1  -1  1  1307  124  500  13  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1493  124  -1  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1468  124  -1  14  ]
      [  41  1  1  6  274  60  8  38  -1  1  3  1  1432  124  -1  15  ]
      [  38  1  1  5  780  51  8  38  9  1  3  1  1811  124  450  12  ]
      [  53  1  1  5  622  29  8  39  -1  3  -1  1  1955  124  -1  10  ]
      [  51  1  1  5  873  80  1  40  -1  -1  -1  1  1843  124  -1  18  ]
      [  58  1  1  1  620  29  8  50  -1  1  5  1  2595  124  -1  15  ]
      [  58  1  1  1  609  74  8  45  -1  5  9  1  2379  124  -1  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  4  3  2376  124  -1  14  ]
      [  39  1  1  6  273  29  8  40  -1  4  3  1  2835  124  -1  14  ]
      [  40  1  1  5  778  64  8  40  -1  4  5  1  3345  124  -1  17  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1225  123  -1  8  ]
      [  41  1  1  5  772  52  8  40  -1  5  5  1  1345  123  -1  11  ]
      [  46  1  1  5  620  52  8  38  -1  5  -1  1  1569  123  -1  11  ]
      [  63  1  1  2  254  34  8  45  -1  1  4  1  1562  123  -1  12  ]
      [  42  1  1  5  802  52  8  38  -1  1  3  1  1595  123  -1  12  ]
      [  66  1  1  6  225  27  8  42  -1  1  3  1  1967  123  -1  11  ]
      [  55  1  1  4  787  75  1  39  -1  3  8  1  2126  123  -1  18  ]
      [  59  1  1  4  801  75  1  40  -1  5  8  1  2504  123  -1  15  ]
      [  34  1  1  5  676  52  8  40  -1  2  5  1  2584  123  -1  14  ]
      [  44  1  1  5  750  45  8  38  -1  5  8  1  3037  123  -1  15  ]
      [  41  1  1  5  780  85  8  39  -1  5  9  1  2046  122  -1  12  ]
      [  56  1  1  5  773  65  1  38  -1  3  5  1  2665  122  -1  13  ]
      [  40  1  1  9  801  75  1  60  11  5  9  1  3490  122  510  15  ]
      [  34  2  8  -1  -1  -1  -1  -1  8  -1  -1  6  798  121  325  5  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  919  121  -1  6  ]
      [  35  1  1  6  269  45  8  40  -1  2  3  1  1122  121  -1  9  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1690  121  -1  11  ]
      [  36  1  1  6  141  16  8  40  -1  1  3  1  2518  121  -1  15  ]
      [  58  1  1  1  750  93  8  15  -1  3  3  4  177  120  -1  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  8  3  178  120  -1  2  ]
      [  47  1  1  5  796  85  8  5  -1  5  5  1  158  120  0  14  ]
      [  29  2  8  3  780  45  8  10  -1  9  5  4  199  120  -1  23  ]
      [  67  2  1  1  833  92  8  30  -1  1  3  1  202  120  -1  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  378  120  -1  10  ]
      [  50  1  1  1  622  45  8  20  -1  1  5  1  414  120  -1  10  ]
      [  47  1  1  5  411  55  8  60  -1  3  3  1  318  120  -1  8  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  5  345  120  -1  12  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  5  -1  5  490  120  0  5  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  -1  3  3  421  120  -1  3  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  310  120  -1  5  ]
      [  32  2  1  6  411  85  8  20  -1  1  -1  1  311  120  -1  9  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  3  5  3  308  120  -1  6  ]
      [  53  2  1  6  531  29  8  23  -1  1  -1  1  354  120  -1  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  389  120  -1  7  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  5  6  3  345  120  -1  6  ]
      [  16  2  8  -1  -1  -1  -1  -1  -1  -1  -1  4  472  120  -1  3  ]
      [  44  1  1  6  461  45  8  40  -1  2  3  1  469  120  -1  12  ]
      [  53  1  1  6  731  22  8  6  13  1  3  4  670  120  700  6  ]
      [  47  2  1  1  833  92  8  45  -1  4  5  1  698  120  -1  4  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  5  3  627  120  0  5  ]
      [  29  1  1  6  912  62  8  20  11  -1  -1  1  501  120  600  12  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  698  120  -1  10  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  567  120  -1  4  ]
      [  59  1  1  2  931  93  8  60  -1  1  5  1  635  120  -1  4  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  4  3  614  120  -1  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  2  639  120  -1  17  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  558  120  -1  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  3  5  3  699  120  -1  7  ]
      [  53  1  1  1  851  85  8  25  -1  5  9  1  575  120  -1  13  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  5  6  573  120  -1  12  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  619  120  -1  4  ]
      [  59  2  1  5  931  85  1  20  -1  1  1  1  577  120  -1  13  ]
      [  23  1  1  7  881  36  8  35  -1  5  -1  1  614  120  -1  4  ]
      [  30  2  1  5  934  85  8  20  10  1  -1  6  502  120  460  7  ]
      [  55  1  8  6  741  31  8  2  -1  1  3  1  524  120  -1  10  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  632  120  -1  4  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  658  120  -1  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  602  120  0  15  ]
      [  70  1  1  3  14  1  8  20  -1  1  -1  1  646  120  -1  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  690  120  -1  4  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  659  120  -1  10  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  577  120  -1  4  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  5  10  3  519  120  -1  4  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  607  120  -1  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  5  3  649  120  -1  4  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  2  537  120  -1  7  ]
      [  49  1  1  6  522  24  8  40  -1  2  3  1  697  120  -1  13  ]
      [  48  1  8  -1  -1  -1  -1  -1  -1  2  5  2  549  120  350  10  ]
      [  35  1  8  -1  -1  -1  -1  -1  8  3  3  2  548  120  338  4  ]
      [  44  1  1  6  221  27  8  39  -1  2  3  1  591  120  -1  13  ]
      [  35  2  1  5  780  50  8  30  16  3  3  1  646  120  780  9  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  3  3  540  120  -1  9  ]
      [  53  1  1  6  784  75  1  40  -1  2  3  1  658  120  -1  9  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  869  120  -1  5  ]
      [  42  2  1  2  902  93  8  50  13  3  3  1  727  120  625  18  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  816  120  -1  5  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  3  3  3  842  120  -1  9  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  868  120  0  6  ]
      [  51  2  8  -1  -1  -1  -1  -1  -1  1  3  3  784  120  -1  5  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  832  120  -1  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  778  120  -1  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  864  120  -1  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  831  120  -1  19  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  835  120  -1  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  6  1  -1  3  848  120  300  8  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  732  120  -1  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  758  120  -1  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  777  120  -1  10  ]
      [  44  2  1  5  864  85  1  39  -1  -1  -1  1  857  120  -1  15  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  1  3  728  120  -1  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  842  120  -1  5  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  4  1  3  819  120  -1  5  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  3  777  120  -1  9  ]
      [  92  2  8  -1  -1  -1  -1  -1  -1  1  -1  5  791  120  -1  5  ]
      [  55  1  1  5  662  52  8  60  15  3  5  1  856  120  750  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  793  120  -1  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  3  3  875  120  -1  13  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  862  120  -1  5  ]
      [  40  2  8  -1  -1  -1  -1  -1  10  1  4  4  832  120  500  15  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  811  120  -1  5  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  796  120  -1  5  ]
      [  54  2  1  5  788  52  8  38  -1  1  -1  1  700  120  -1  5  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  774  120  -1  5  ]
      [  24  1  8  -1  -1  -1  -1  -1  -1  3  -1  4  764  120  -1  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  880  120  -1  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  862  120  -1  5  ]
      [  29  1  1  5  882  80  1  12  -1  5  -1  1  811  120  -1  5  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  724  120  -1  5  ]
      [  45  1  1  6  440  45  8  40  -1  2  3  1  763  120  -1  9  ]
      [  43  1  8  -1  -1  -1  -1  -1  -1  2  5  2  886  120  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  835  120  -1  10  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  2  5  3  747  120  -1  11  ]
      [  44  1  1  6  471  75  1  36  -1  2  3  1  844  120  -1  13  ]
      [  50  1  1  6  714  60  8  40  -1  2  3  1  735  120  -1  15  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  764  120  -1  10  ]
      [  56  1  1  6  522  52  8  40  -1  1  -1  1  732  120  -1  9  ]
      [  40  2  1  5  53  52  8  40  -1  2  3  1  720  120  -1  9  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  862  120  -1  9  ]
      [  48  1  1  6  934  45  1  8  -1  9  6  1  828  120  -1  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  2  1  3  726  120  -1  12  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  3  3  898  120  -1  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  4  3  831  120  -1  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  876  120  -1  17  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  993  120  -1  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1052  120  -1  10  ]
      [  63  1  1  1  753  74  8  50  50  5  -1  1  1042  120  -1  6  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1096  120  -1  7  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1008  120  -1  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  975  120  -1  9  ]
      [  52  1  1  6  411  55  8  40  9  1  3  1  996  120  482  7  ]
      [  53  1  1  5  652  80  1  50  -1  1  5  1  992  120  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  920  120  -1  10  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  975  120  -1  7  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  3  99  3  971  120  -1  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  -1  -1  5  1053  120  -1  11  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1021  120  -1  6  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1052  120  -1  6  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1090  120  -1  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1007  120  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  975  120  -1  11  ]
      [  54  1  1  5  857  80  1  40  -1  3  99  1  963  120  -1  14  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1095  120  -1  15  ]
      [  23  1  1  6  313  29  8  40  -1  1  2  1  1017  120  -1  9  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  1  5  3  946  120  -1  18  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  992  120  -1  6  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1039  120  -1  6  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1051  120  -1  15  ]
      [  41  2  1  5  735  30  8  37  -1  4  8  1  1028  120  -1  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1022  120  -1  8  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  987  120  -1  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  3  3  950  120  -1  6  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1095  120  -1  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  4  3  961  120  -1  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1059  120  -1  10  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  995  120  -1  6  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  956  120  -1  7  ]
      [  60  1  1  6  501  20  8  40  -1  1  3  1  1033  120  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  949  120  -1  14  ]
      [  53  1  1  1  602  74  8  50  -1  -1  -1  1  1067  120  -1  11  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1080  120  -1  8  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1000  120  -1  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1100  120  -1  6  ]
      [  42  2  1  5  691  65  8  38  -1  3  -1  1  935  120  -1  19  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1063  120  -1  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  958  120  -1  11  ]
      [  49  1  1  2  911  55  8  40  -1  2  6  1  1082  120  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1089  120  -1  11  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  936  120  -1  9  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1091  120  -1  12  ]
      [  39  1  1  6  254  28  8  39  -1  2  3  1  916  120  -1  10  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  4  3  985  120  -1  9  ]
      [  41  2  1  6  937  93  8  25  -1  2  3  1  922  120  -1  12  ]
      [  36  1  1  6  714  51  8  40  -1  2  3  1  1091  120  -1  15  ]
      [  43  1  1  6  281  50  8  40  -1  2  3  1  943  120  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  944  120  -1  8  ]
      [  48  1  1  2  750  20  8  60  -1  2  5  1  1006  120  -1  10  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  3  3  923  120  0  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  5  5  3  990  120  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  956  120  -1  6  ]
      [  39  1  1  6  714  63  8  40  -1  2  3  1  1069  120  -1  11  ]
      [  77  2  8  -1  -1  -1  -1  -1  7  1  -1  3  1032  120  350  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1258  120  -1  8  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  99  3  1263  120  -1  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1186  120  -1  7  ]
      [  42  2  1  5  856  85  8  26  -1  3  5  1  1283  120  -1  22  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1294  120  -1  7  ]
      [  61  1  1  2  750  45  8  50  -1  -1  -1  1  1283  120  -1  8  ]
      [  45  1  1  5  778  35  8  37  -1  5  99  1  1120  120  -1  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1266  120  -1  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1272  120  -1  9  ]
      [  51  1  1  1  744  74  8  20  -1  -1  -1  8  1103  120  -1  13  ]
      [  38  1  1  6  501  36  8  40  -1  1  3  1  1245  120  -1  15  ]
      [  41  1  1  6  270  85  8  38  -1  1  5  1  1258  120  -1  12  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1136  120  -1  7  ]
      [  35  1  1  6  501  52  8  40  -1  3  -1  1  1293  120  -1  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1136  120  -1  7  ]
      [  41  1  1  5  778  74  8  38  -1  1  3  1  1207  120  -1  11  ]
      [  45  1  1  2  488  45  8  60  11  1  5  1  1105  120  575  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1216  120  -1  8  ]
      [  50  1  1  4  891  91  1  20  16  5  9  1  1149  120  800  12  ]
      [  90  1  8  -1  -1  -1  -1  -1  10  9  3  3  1163  120  500  7  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1275  120  -1  7  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1110  120  -1  7  ]
      [  33  1  8  -1  -1  -1  -1  -1  11  1  -1  8  1252  120  540  9  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1244  120  -1  11  ]
      [  47  2  1  5  789  85  1  20  -1  3  3  1  1172  120  -1  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1167  120  -1  7  ]
      [  49  1  1  6  254  15  8  45  -1  1  3  1  1185  120  -1  10  ]
      [  35  1  1  6  620  85  8  40  12  1  5  1  1287  120  600  11  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  5  3  3  1239  120  -1  10  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1211  120  -1  9  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1182  120  -1  11  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1181  120  -1  7  ]
      [  62  1  1  6  991  75  1  38  -1  1  3  8  1174  120  -1  22  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1272  120  -1  21  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1207  120  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1195  120  -1  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1116  120  -1  8  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  9  99  3  1229  120  -1  7  ]
      [  34  2  1  6  714  51  8  40  12  1  3  1  1207  120  650  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1137  120  -1  16  ]
      [  43  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1298  120  -1  15  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1128  120  -1  17  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1263  120  -1  7  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  99  3  1275  120  -1  7  ]
      [  41  1  1  6  522  25  8  39  -1  1  -1  1  1117  120  460  9  ]
      [  34  1  1  1  831  92  8  40  7  3  3  1  1286  120  325  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1283  120  -1  10  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1257  120  -1  7  ]
      [  37  1  1  6  714  60  8  40  -1  2  3  1  1173  120  -1  11  ]
      [  38  1  1  5  510  45  8  39  -1  2  3  1  1118  120  -1  12  ]
      [  53  1  1  2  316  45  8  50  -1  2  5  1  1205  120  -1  13  ]
      [  46  1  1  6  268  45  8  40  -1  1  3  1  1212  120  -1  20  ]
      [  69  1  8  -1  -1  -1  -1  -1  7  -1  1  3  1228  120  315  10  ]
      [  47  1  1  6  546  45  8  40  -1  1  3  1  1108  120  -1  12  ]
      [  35  1  1  6  512  50  8  40  -1  2  3  1  1299  120  -1  12  ]
      [  39  1  1  6  269  45  8  40  -1  2  3  1  1100  120  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1162  120  -1  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  2  3  3  1182  120  -1  11  ]
      [  51  1  1  6  222  10  8  40  -1  1  3  1  1136  120  -1  14  ]
      [  43  2  1  5  864  85  1  38  -1  5  -1  1  1147  120  -1  11  ]
      [  43  1  1  6  550  27  8  40  -1  2  3  1  1281  120  -1  12  ]
      [  34  1  1  1  501  45  8  40  -1  2  5  1  1172  120  -1  9  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  1  3  1309  120  -1  8  ]
      [  43  2  1  5  676  52  8  38  -1  1  3  1  1447  120  -1  14  ]
      [  56  2  1  5  633  15  1  15  -1  3  -1  1  1300  120  -1  8  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1401  120  -1  11  ]
      [  43  1  1  2  441  45  8  98  9  -1  -1  1  1316  120  350  10  ]
      [  34  1  8  -1  -1  -1  -1  -1  10  1  -1  2  1340  120  469  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1324  120  -1  10  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  3  5  3  1360  120  -1  8  ]
      [  55  2  1  5  853  85  1  39  -1  1  3  1  1399  120  -1  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1422  120  -1  8  ]
      [  49  1  1  5  862  80  8  39  12  5  9  1  1371  120  600  14  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1318  120  -1  9  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1383  120  -1  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1487  120  -1  8  ]
      [  52  2  1  5  787  75  1  19  -1  1  3  1  1447  120  -1  8  ]
      [  40  1  1  6  744  36  8  35  -1  1  3  1  1372  120  -1  10  ]
      [  56  1  8  6  501  20  8  36  -1  1  -1  1  1433  120  -1  19  ]
      [  33  1  8  -1  -1  -1  -1  -1  13  4  3  2  1385  120  675  8  ]
      [  42  1  1  6  540  75  1  38  -1  3  3  1  1308  120  -1  13  ]
      [  44  1  1  6  310  28  8  38  -1  1  3  1  1398  120  -1  11  ]
      [  30  2  1  5  521  62  8  25  -1  5  3  1  1392  120  -1  11  ]
      [  31  1  1  5  671  24  8  38  -1  3  3  1  1444  120  0  14  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1393  120  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1413  120  -1  8  ]
      [  57  1  1  6  273  74  8  39  -1  1  3  1  1435  120  -1  12  ]
      [  39  2  1  5  660  52  8  20  13  5  -1  1  1348  120  580  8  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1449  120  -1  8  ]
      [  52  1  1  6  442  45  8  40  -1  1  3  1  1468  120  -1  16  ]
      [  59  1  1  6  716  45  1  40  -1  1  3  1  1333  120  -1  13  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1314  120  -1  11  ]
      [  23  2  1  5  853  85  8  38  -1  5  5  1  1355  120  -1  8  ]
      [  28  1  1  1  501  45  8  40  -1  1  3  1  1458  120  -1  11  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1458  120  -1  14  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1377  120  -1  15  ]
      [  35  1  1  5  891  91  8  40  -1  5  7  1  1356  120  0  8  ]
      [  35  1  1  5  483  45  8  38  11  3  3  1  1325  120  550  11  ]
      [  58  1  1  6  259  28  8  35  -1  1  3  1  1355  120  -1  16  ]
      [  47  1  1  3  485  45  8  40  12  3  5  1  1440  120  560  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1324  120  -1  8  ]
      [  60  1  1  5  876  92  8  4  -1  1  5  3  1392  120  -1  14  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1350  120  -1  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1419  120  -1  9  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1460  120  -1  14  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1391  120  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1368  120  -1  13  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  -1  -1  2  1385  120  -1  8  ]
      [  32  1  1  6  512  50  8  40  -1  1  3  1  1438  120  -1  10  ]
      [  42  1  1  6  487  45  8  40  -1  1  3  1  1489  120  -1  12  ]
      [  45  1  1  5  678  75  1  39  10  2  6  1  1330  120  500  19  ]
      [  47  1  1  6  221  50  8  35  -1  3  3  1  1381  120  -1  15  ]
      [  64  2  1  5  623  75  1  39  -1  4  5  1  1335  120  -1  8  ]
      [  29  1  1  5  609  74  8  39  9  5  9  1  1409  120  417  8  ]
      [  36  2  1  5  780  63  8  38  -1  -1  -1  1  1461  120  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1432  120  -1  8  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1423  120  -1  8  ]
      [  50  1  1  5  780  63  8  40  -1  -1  -1  1  1441  120  -1  13  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1449  120  0  11  ]
      [  35  1  1  5  703  22  8  40  -1  3  3  1  1400  120  -1  8  ]
      [  36  1  1  6  501  20  8  40  -1  2  3  1  1463  120  -1  12  ]
      [  35  1  1  2  871  80  8  40  -1  5  8  1  1391  120  -1  13  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1430  120  -1  8  ]
      [  46  1  1  5  854  85  1  40  -1  2  3  1  1486  120  -1  10  ]
      [  33  2  1  5  853  85  1  40  -1  2  -1  1  1345  120  -1  19  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1640  120  0  9  ]
      [  55  1  1  5  714  60  8  38  -1  3  3  1  1676  120  -1  14  ]
      [  61  1  1  2  715  62  8  50  -1  -1  -1  1  1663  120  -1  9  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1632  120  -1  14  ]
      [  34  1  1  5  863  85  8  38  10  3  3  1  1688  120  515  14  ]
      [  34  1  1  6  487  45  8  38  -1  1  3  1  1582  120  200  9  ]
      [  70  1  1  2  750  26  8  45  -1  4  8  1  1595  120  -1  18  ]
      [  40  2  1  5  691  65  8  38  -1  5  3  1  1632  120  -1  9  ]
      [  34  1  1  6  714  60  8  40  -1  1  3  1  1605  120  -1  9  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1661  120  -1  9  ]
      [  52  2  1  5  691  65  8  39  -1  3  3  1  1633  120  -1  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1629  120  -1  10  ]
      [  50  1  1  6  316  52  8  40  -1  1  -1  1  1700  120  -1  12  ]
      [  32  1  1  5  651  28  8  39  -1  3  3  1  1649  120  -1  9  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1532  120  -1  14  ]
      [  41  1  1  5  620  28  8  36  -1  1  3  1  1506  120  -1  10  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1525  120  -1  15  ]
      [  47  1  1  5  672  52  8  40  -1  1  3  1  1597  120  -1  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  2  1569  120  -1  12  ]
      [  32  2  1  5  853  85  1  39  -1  4  3  1  1595  120  -1  9  ]
      [  36  1  1  5  411  85  1  39  -1  4  3  1  1653  120  -1  15  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1655  120  -1  19  ]
      [  61  1  1  6  273  29  8  37  -1  1  3  1  1663  120  -1  9  ]
      [  60  1  1  6  935  90  8  39  -1  3  3  1  1561  120  -1  10  ]
      [  41  1  1  6  714  51  8  40  -1  3  3  1  1660  120  -1  11  ]
      [  63  1  1  5  780  71  8  20  -1  1  -1  1  1617  120  -1  9  ]
      [  53  1  1  6  290  75  1  38  -1  1  3  1  1647  120  -1  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1681  120  -1  12  ]
      [  44  1  1  5  620  28  8  35  -1  1  3  1  1597  120  -1  9  ]
      [  38  1  1  5  677  50  8  40  -1  5  3  1  1551  120  -1  9  ]
      [  36  1  1  6  714  45  8  39  8  1  3  1  1515  120  425  10  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1656  120  -1  9  ]
      [  42  1  1  5  683  22  8  35  10  5  8  1  1539  120  450  15  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1564  120  -1  12  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1518  120  -1  16  ]
      [  31  1  1  6  487  45  8  40  -1  1  3  1  1523  120  -1  11  ]
      [  54  1  1  6  290  34  8  40  -1  1  5  1  1694  120  -1  9  ]
      [  55  1  1  5  874  80  1  15  14  5  10  1  1521  120  750  10  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1637  120  -1  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1631  120  -1  11  ]
      [  38  1  1  4  784  75  1  40  -1  1  -1  1  1579  120  -1  11  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1565  120  -1  11  ]
      [  47  1  1  6  269  33  8  35  7  1  3  1  1541  120  306  9  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  4  8  2  1514  120  -1  9  ]
      [  40  1  1  6  391  52  8  40  -1  1  3  1  1580  120  -1  11  ]
      [  49  1  1  5  620  45  8  40  -1  1  3  1  1571  120  -1  16  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1577  120  -1  13  ]
      [  39  1  1  5  440  45  8  39  -1  1  5  1  1517  120  -1  9  ]
      [  34  1  1  6  431  15  8  40  -1  1  3  1  1583  120  -1  9  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1507  120  -1  12  ]
      [  38  1  1  2  673  52  8  45  -1  1  3  1  1524  120  -1  16  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1644  120  -1  9  ]
      [  62  1  1  5  788  75  1  38  -1  1  3  1  1647  120  -1  9  ]
      [  39  1  1  1  483  45  8  50  -1  1  3  1  1575  120  -1  9  ]
      [  58  1  1  6  714  63  8  60  -1  1  3  1  1674  120  -1  14  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1604  120  -1  9  ]
      [  32  1  1  6  310  29  8  35  -1  2  3  1  1593  120  -1  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1591  120  -1  12  ]
      [  51  1  1  6  714  63  8  40  -1  1  3  1  1628  120  -1  17  ]
      [  35  1  1  6  267  45  8  38  -1  2  3  1  1613  120  -1  16  ]
      [  37  1  1  5  883  75  1  40  -1  5  9  1  1698  120  -1  12  ]
      [  60  1  1  5  600  85  1  40  -1  5  8  1  1597  120  -1  15  ]
      [  42  1  1  5  876  92  1  40  -1  5  9  1  1673  120  -1  14  ]
      [  38  1  1  5  774  75  1  40  -1  5  9  1  1587  120  -1  14  ]
      [  53  1  1  6  744  63  1  40  -1  1  3  1  1729  120  -1  13  ]
      [  52  2  1  5  853  85  1  19  -1  3  3  1  1807  120  -1  10  ]
      [  47  2  1  5  751  15  8  32  -1  5  -1  1  1954  120  -1  11  ]
      [  38  1  1  2  673  52  8  60  -1  3  3  1  1864  120  -1  10  ]
      [  38  1  1  5  620  51  8  38  -1  3  3  1  1781  120  -1  13  ]
      [  48  2  1  5  789  99  8  38  17  3  3  1  1972  120  800  16  ]
      [  50  1  1  5  750  70  8  38  -1  5  5  1  1774  120  -1  10  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1783  120  -1  14  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1894  120  -1  10  ]
      [  45  1  1  6  466  45  8  40  -1  1  3  1  1760  120  -1  13  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1927  120  -1  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  4  5  3  1980  120  -1  10  ]
      [  55  1  1  6  265  74  8  35  -1  1  3  1  1803  120  -1  15  ]
      [  44  1  1  5  620  75  1  38  -1  3  3  1  1895  120  -1  14  ]
      [  39  1  1  4  801  75  1  39  -1  3  3  1  1911  120  -1  12  ]
      [  49  1  1  2  750  51  8  45  12  3  3  1  1892  120  600  17  ]
      [  34  1  1  6  274  35  8  35  -1  1  4  1  1948  120  -1  14  ]
      [  53  1  1  1  821  92  8  80  -1  5  9  1  1705  120  -1  20  ]
      [  44  1  1  5  642  45  8  40  13  4  5  1  1851  120  700  11  ]
      [  32  1  1  6  241  24  8  37  -1  1  3  1  1928  120  -1  10  ]
      [  46  1  1  6  254  10  8  38  -1  2  -1  1  1719  120  -1  10  ]
      [  62  2  1  4  873  80  1  38  -1  5  8  1  1700  120  -1  10  ]
      [  47  1  1  5  750  15  8  45  -1  3  3  1  1714  120  -1  16  ]
      [  56  1  1  6  791  74  8  55  15  -1  -1  1  1706  120  770  18  ]
      [  69  1  8  -1  -1  -1  -1  -1  13  3  3  3  1707  120  595  10  ]
      [  52  1  1  6  791  34  8  45  -1  -1  -1  1  1948  120  -1  12  ]
      [  32  1  1  5  521  27  8  36  -1  1  5  1  1752  120  -1  11  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1739  120  -1  15  ]
      [  46  1  1  6  651  34  8  29  -1  3  5  1  1968  120  -1  12  ]
      [  45  1  1  5  751  75  1  39  -1  3  3  1  1804  120  -1  14  ]
      [  51  1  1  6  270  45  8  50  -1  1  3  1  1797  120  -1  10  ]
      [  29  1  1  5  775  51  8  40  10  4  3  1  1955  120  500  10  ]
      [  43  1  1  6  311  50  8  35  -1  1  3  1  1814  120  -1  10  ]
      [  62  1  1  5  780  24  8  38  -1  3  3  1  1850  120  -1  10  ]
      [  38  1  1  6  281  75  1  39  13  1  3  1  1791  120  660  11  ]
      [  31  1  1  5  777  52  8  45  -1  1  3  1  1889  120  -1  13  ]
      [  42  1  1  6  152  25  8  37  -1  1  3  1  1969  120  -1  15  ]
      [  50  2  1  5  13  1  8  30  -1  1  -1  1  1956  120  -1  10  ]
      [  49  1  1  6  714  63  8  60  -1  1  5  1  1983  120  -1  17  ]
      [  34  1  1  6  488  45  8  45  8  1  3  1  1787  120  375  10  ]
      [  53  2  1  4  874  80  1  20  -1  5  9  1  1789  120  -1  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1740  120  -1  13  ]
      [  53  1  1  5  677  34  8  35  -1  4  99  1  1988  120  -1  13  ]
      [  29  1  1  6  620  34  8  38  6  1  3  1  1853  120  288  10  ]
      [  36  1  1  1  671  51  8  40  -1  1  1  1  1733  120  -1  10  ]
      [  34  1  1  5  605  45  8  39  10  4  8  1  1746  120  500  12  ]
      [  46  2  1  5  750  15  8  60  -1  -1  -1  1  1909  120  -1  10  ]
      [  53  1  1  5  691  65  1  39  -1  1  3  1  1714  120  -1  14  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  5  8  7  1802  120  -1  15  ]
      [  36  1  1  6  268  45  8  38  7  3  3  1  1733  120  330  11  ]
      [  45  1  1  6  441  45  8  39  -1  1  3  1  1963  120  -1  16  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1847  120  -1  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1825  120  -1  13  ]
      [  53  1  1  2  852  85  8  45  -1  1  3  1  1784  120  -1  17  ]
      [  31  1  1  5  316  29  8  45  -1  3  3  1  1847  120  -1  12  ]
      [  41  1  1  6  744  52  8  36  -1  1  3  1  1844  120  -1  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1846  120  0  11  ]
      [  49  1  1  4  764  75  1  40  -1  3  3  1  1794  120  -1  16  ]
      [  59  1  1  5  796  45  8  40  -1  1  3  1  1791  120  -1  14  ]
      [  45  1  1  6  442  45  8  40  -1  1  3  1  1980  120  -1  12  ]
      [  56  1  1  1  834  74  8  60  -1  4  9  1  1862  120  -1  18  ]
      [  33  2  1  5  780  55  8  30  -1  2  3  1  1882  120  -1  10  ]
      [  42  1  1  5  627  15  8  38  -1  5  8  1  1809  120  -1  13  ]
      [  34  1  1  6  466  45  8  40  -1  2  3  1  1967  120  -1  14  ]
      [  43  1  1  5  501  52  8  40  -1  2  -1  1  1873  120  -1  13  ]
      [  52  1  1  5  651  28  8  39  -1  2  5  1  1888  120  -1  18  ]
      [  32  1  1  6  662  52  8  40  -1  2  3  1  1701  120  -1  16  ]
      [  33  1  1  6  174  22  8  38  -1  2  5  1  1978  120  -1  11  ]
      [  51  1  1  6  620  28  8  40  -1  2  3  1  1960  120  -1  11  ]
      [  57  1  1  5  874  80  1  40  -1  5  9  1  1825  120  -1  16  ]
      [  36  1  1  4  765  75  1  40  8  5  8  1  1896  120  414  10  ]
      [  32  1  1  5  750  45  8  40  -1  2  5  1  1880  120  -1  15  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1819  120  -1  14  ]
      [  48  1  1  1  254  28  8  40  -1  2  3  1  1982  120  -1  16  ]
      [  50  1  1  6  265  28  8  36  -1  1  3  1  2026  120  -1  15  ]
      [  45  1  1  4  801  75  1  40  -1  3  5  1  2263  120  -1  16  ]
      [  36  1  1  6  501  36  8  37  -1  1  3  1  2228  120  -1  12  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2023  120  -1  16  ]
      [  41  1  1  6  270  34  8  29  -1  3  3  1  2149  120  -1  12  ]
      [  50  1  1  5  642  74  8  39  -1  1  6  1  2014  120  -1  16  ]
      [  57  1  1  2  511  45  8  50  -1  1  5  1  2165  120  -1  12  ]
      [  45  2  1  4  873  80  1  38  -1  5  8  1  2199  120  -1  14  ]
      [  37  1  1  5  864  85  1  19  15  3  3  1  2036  120  800  11  ]
      [  39  1  1  5  780  45  1  40  -1  3  5  1  2275  120  -1  11  ]
      [  38  1  1  4  997  75  1  38  -1  3  3  1  2038  120  -1  12  ]
      [  44  1  1  4  801  75  1  40  -1  3  3  1  2141  120  -1  15  ]
      [  34  1  1  6  993  24  8  38  13  3  3  1  2100  120  650  11  ]
      [  30  1  1  5  787  64  8  39  -1  1  3  1  2016  120  -1  11  ]
      [  48  1  1  6  222  28  8  35  -1  2  3  1  2013  120  -1  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  5  3  2200  120  -1  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  14  4  8  3  2264  120  750  18  ]
      [  42  1  1  5  780  51  8  38  -1  3  3  1  2036  120  -1  14  ]
      [  34  1  1  5  600  27  8  35  -1  4  8  1  2195  120  -1  11  ]
      [  47  1  1  6  651  25  8  40  -1  -1  -1  1  2201  120  -1  11  ]
      [  83  2  8  -1  -1  -1  -1  -1  7  5  9  3  2229  120  360  11  ]
      [  51  1  1  5  787  75  1  38  -1  1  5  1  2162  120  -1  11  ]
      [  42  1  1  5  751  65  1  40  -1  4  8  1  2051  120  -1  14  ]
      [  49  1  1  6  796  85  8  15  11  1  3  3  2129  120  500  17  ]
      [  46  1  1  4  712  60  8  39  -1  3  3  1  2218  120  -1  12  ]
      [  45  1  1  5  274  24  8  40  -1  1  3  1  2198  120  -1  15  ]
      [  39  1  1  5  701  63  8  32  -1  5  3  1  2178  120  -1  11  ]
      [  32  1  1  5  683  22  8  37  -1  5  3  1  2241  120  -1  11  ]
      [  33  1  1  5  780  52  8  38  -1  3  3  1  2071  120  -1  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2254  120  -1  16  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  3  3  3  2203  120  -1  11  ]
      [  43  1  1  2  254  51  8  60  -1  4  5  1  2154  120  -1  14  ]
      [  64  1  1  2  501  20  8  46  -1  1  5  1  2102  120  -1  11  ]
      [  63  1  1  2  501  36  8  40  -1  1  5  1  2188  120  -1  15  ]
      [  39  1  1  5  265  51  8  50  -1  1  3  1  2015  120  -1  11  ]
      [  53  1  1  6  254  34  8  38  -1  1  3  1  2141  120  -1  15  ]
      [  55  1  1  5  622  45  8  28  -1  1  3  1  2226  120  -1  11  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2026  120  -1  11  ]
      [  39  1  1  5  689  24  8  50  -1  1  3  1  2157  120  -1  13  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2284  120  -1  12  ]
      [  40  1  1  6  231  28  8  40  6  -1  -1  1  2178  120  288  14  ]
      [  37  1  1  6  290  27  8  37  -1  3  3  1  2072  120  -1  12  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  3  3  3  2254  120  -1  11  ]
      [  31  2  1  6  270  29  8  35  8  1  4  1  2245  120  400  11  ]
      [  40  1  1  5  881  29  8  35  -1  5  8  1  2048  120  -1  11  ]
      [  30  2  1  5  689  71  8  40  12  1  3  1  2154  120  650  11  ]
      [  48  2  1  5  691  65  1  34  -1  3  3  1  2157  120  -1  11  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2275  120  -1  17  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  2057  120  -1  11  ]
      [  47  1  1  6  935  75  1  38  -1  1  5  1  2183  120  -1  14  ]
      [  42  1  1  6  241  29  8  38  -1  1  99  1  2145  120  -1  12  ]
      [  41  1  1  5  750  63  8  40  -1  4  4  1  2044  120  -1  12  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  3  -1  3  2278  120  -1  12  ]
      [  40  1  1  5  671  60  8  40  -1  5  7  1  2016  120  -1  12  ]
      [  43  1  1  5  620  31  8  37  -1  3  5  1  2300  120  -1  13  ]
      [  34  1  1  2  750  74  8  60  -1  1  5  1  2010  120  0  12  ]
      [  89  1  8  -1  -1  -1  -1  -1  -1  3  7  3  2293  120  -1  12  ]
      [  62  1  1  6  254  45  8  38  -1  1  3  1  2094  120  -1  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2232  120  -1  12  ]
      [  54  1  1  5  622  24  8  40  -1  5  9  1  2106  120  -1  17  ]
      [  41  1  1  6  651  24  8  40  -1  5  5  1  2016  120  -1  16  ]
      [  62  1  1  5  609  75  1  40  -1  5  9  1  2016  120  -1  14  ]
      [  52  1  1  2  844  52  8  40  -1  5  9  1  2030  120  -1  20  ]
      [  40  1  1  5  780  45  8  45  -1  2  3  1  2149  120  -1  20  ]
      [  89  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2308  120  -1  12  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  3  5  3  2306  120  -1  15  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2547  120  -1  14  ]
      [  45  1  1  1  995  45  8  40  -1  1  3  1  2307  120  -1  13  ]
      [  52  1  1  5  691  65  1  38  -1  5  9  1  2327  120  -1  17  ]
      [  56  2  1  2  750  85  8  40  -1  -1  -1  1  2308  120  770  12  ]
      [  44  1  1  5  870  80  1  30  6  4  9  1  2420  120  300  16  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2476  120  -1  14  ]
      [  44  1  1  4  801  75  1  39  8  1  3  1  2371  120  400  13  ]
      [  29  2  1  5  753  74  8  40  7  3  4  1  2510  120  360  18  ]
      [  51  1  1  1  822  74  8  45  -1  5  9  1  2396  120  -1  12  ]
      [  34  1  1  1  602  74  8  40  -1  4  8  1  2532  120  -1  16  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  3  5  3  2347  120  -1  12  ]
      [  41  1  1  5  620  51  8  45  12  4  5  1  2582  120  500  14  ]
      [  47  1  1  5  787  99  8  37  -1  3  3  1  2518  120  -1  13  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  4  3  3  2453  120  -1  12  ]
      [  54  1  1  5  785  28  8  37  -1  1  3  1  2438  120  -1  14  ]
      [  46  2  1  5  641  34  8  40  13  1  3  1  2430  120  560  12  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  9  -1  3  2512  120  -1  12  ]
      [  45  1  1  5  914  55  8  40  -1  1  3  1  2328  120  -1  15  ]
      [  52  1  1  2  672  52  8  50  -1  1  3  1  2463  120  -1  20  ]
      [  37  1  1  6  313  15  8  38  -1  2  3  1  2444  120  -1  13  ]
      [  51  1  1  5  751  91  8  42  -1  4  3  1  2492  120  -1  14  ]
      [  30  1  1  5  788  72  8  40  -1  1  3  1  2446  120  -1  13  ]
      [  51  1  1  5  751  15  8  39  -1  5  3  1  2480  120  -1  15  ]
      [  33  1  1  5  774  50  8  35  20  5  9  1  2491  120  940  18  ]
      [  56  1  1  5  780  51  8  39  10  3  3  1  2583  120  500  18  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  3  3  3  2513  120  -1  12  ]
      [  54  1  1  5  843  85  8  39  -1  5  10  1  2442  120  -1  12  ]
      [  41  1  1  4  792  75  1  40  -1  3  3  1  2542  120  -1  14  ]
      [  40  1  1  4  881  64  8  39  -1  4  7  1  2324  120  -1  12  ]
      [  53  1  1  4  861  75  1  40  -1  5  3  1  2345  120  -1  12  ]
      [  44  1  1  1  692  67  8  60  13  5  8  1  2529  120  640  16  ]
      [  55  1  1  5  751  52  8  50  -1  3  3  1  2571  120  -1  13  ]
      [  60  1  1  6  744  75  1  38  -1  1  -1  1  2405  120  -1  12  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2366  120  -1  13  ]
      [  49  1  1  6  741  34  8  35  11  1  3  1  2556  120  420  12  ]
      [  35  1  1  4  813  75  1  45  -1  5  9  1  2580  120  -1  12  ]
      [  42  1  1  4  765  75  1  40  -1  5  9  1  2586  120  -1  12  ]
      [  57  2  1  5  789  29  8  32  -1  3  4  1  2610  120  -1  13  ]
      [  48  1  1  5  787  75  1  39  -1  3  7  1  2834  120  -1  14  ]
      [  57  1  1  4  873  80  1  39  -1  5  3  1  2601  120  -1  17  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2721  120  -1  19  ]
      [  52  1  1  5  623  45  8  39  -1  3  3  1  2644  120  -1  14  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  5  5  2779  120  -1  18  ]
      [  32  1  1  4  788  75  1  40  -1  5  8  1  2655  120  -1  13  ]
      [  44  1  1  5  765  45  8  39  5  1  3  1  2861  120  200  15  ]
      [  54  1  1  4  787  80  1  40  -1  5  9  1  2608  120  -1  17  ]
      [  32  1  1  5  607  51  8  40  -1  4  8  1  2713  120  0  15  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  4  3  2684  120  -1  13  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2900  120  -1  13  ]
      [  34  1  1  4  787  75  1  40  -1  3  5  1  2807  120  -1  15  ]
      [  59  1  1  2  670  52  8  50  -1  1  3  1  2848  120  -1  16  ]
      [  36  1  1  5  788  66  8  38  7  3  3  1  2825  120  330  17  ]
      [  40  1  1  5  777  72  8  40  -1  3  3  1  2602  120  -1  13  ]
      [  60  1  1  2  750  45  8  70  -1  1  5  1  2629  120  -1  17  ]
      [  47  1  1  5  651  15  8  38  -1  1  5  1  2649  120  -1  16  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  3  3  3  3122  120  -1  15  ]
      [  41  1  1  5  676  22  8  38  -1  3  3  1  3131  120  -1  21  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  5  3  3  3011  120  -1  16  ]
      [  64  1  1  5  721  61  8  40  -1  1  8  1  2928  120  -1  14  ]
      [  53  2  1  4  870  80  1  53  -1  5  9  1  2942  120  -1  21  ]
      [  53  1  1  5  692  65  1  40  -1  3  5  1  3110  120  -1  18  ]
      [  40  1  1  5  621  32  8  60  13  1  3  1  2923  120  650  14  ]
      [  47  1  1  5  751  34  8  54  -1  1  5  1  3003  120  -1  21  ]
      [  37  1  1  5  751  85  8  39  -1  3  3  1  2946  120  -1  15  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  3  3103  120  -1  18  ]
      [  43  1  1  4  765  75  1  38  -1  3  7  1  3077  120  -1  15  ]
      [  55  1  1  5  603  45  8  39  -1  5  9  1  2915  120  -1  18  ]
      [  62  1  1  5  881  24  8  39  -1  5  9  1  2910  120  -1  16  ]
      [  44  1  1  1  633  74  8  40  -1  2  5  1  3006  120  -1  16  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  3075  120  -1  14  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  5  9  3  3137  120  -1  14  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  3  5  2964  120  -1  20  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  5  -1  3  2939  120  -1  14  ]
      [  52  1  1  5  774  31  8  40  -1  4  8  1  3140  120  -1  17  ]
      [  54  1  1  2  813  74  8  60  16  5  9  1  2900  120  800  19  ]
      [  52  1  1  5  692  75  1  39  -1  1  3  1  3188  120  -1  16  ]
      [  41  1  1  4  765  75  1  39  11  4  5  1  3203  120  500  15  ]
      [  56  1  1  5  772  52  8  40  -1  9  3  1  3244  120  -1  15  ]
      [  43  1  1  2  673  50  8  60  -1  1  5  1  3430  120  -1  20  ]
      [  61  1  1  5  821  75  1  39  -1  5  9  1  3227  120  -1  19  ]
      [  47  1  1  6  651  31  8  38  -1  1  4  1  3231  120  -1  16  ]
      [  36  1  1  2  785  93  8  50  -1  1  3  1  3228  120  -1  15  ]
      [  60  2  1  5  841  85  1  40  -1  5  10  1  3527  120  -1  15  ]
      [  59  1  1  5  480  25  8  35  -1  1  5  1  3521  120  0  15  ]
      [  37  1  1  5  881  15  8  38  -1  5  9  1  3441  120  -1  15  ]
      [  30  1  1  5  774  30  8  60  -1  4  3  1  3481  120  -1  18  ]
      [  45  1  1  5  602  31  8  35  -1  5  8  1  3591  120  -1  17  ]
      [  40  1  1  5  621  29  8  40  -1  3  5  1  3355  120  -1  16  ]
      [  49  1  1  4  603  63  1  39  -1  4  8  1  3476  120  -1  19  ]
      [  51  2  1  2  842  85  8  98  11  5  9  1  3432  120  500  21  ]
      [  62  1  1  5  691  65  8  39  -1  4  7  1  3527  120  -1  15  ]
      [  49  2  1  5  691  65  8  55  -1  3  3  1  3510  120  -1  15  ]
      [  52  1  1  5  751  28  8  40  -1  5  9  1  3211  120  -1  15  ]
      [  55  1  1  4  811  75  1  40  -1  5  9  1  3639  120  -1  21  ]
      [  49  1  1  4  872  80  1  40  -1  5  9  1  3801  120  -1  17  ]
      [  41  1  1  5  774  72  8  50  -1  4  8  1  3609  120  -1  16  ]
      [  52  1  1  5  750  75  1  38  -1  1  8  1  3999  120  -1  18  ]
      [  52  1  1  5  600  31  8  40  -1  5  8  1  3918  120  -1  16  ]
      [  48  1  1  5  701  63  8  60  -1  3  3  1  3819  120  -1  16  ]
      [  42  1  1  5  281  50  8  60  -1  2  5  1  3639  120  -1  17  ]
      [  46  1  1  4  764  75  1  40  -1  5  10  1  4039  120  -1  19  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  5  9  3  4024  120  -1  17  ]
      [  59  1  1  5  751  25  8  60  -1  4  3  1  4234  120  -1  17  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  5  99  3  4405  120  -1  20  ]
      [  33  1  1  5  802  24  8  40  -1  1  3  1  4429  120  -1  18  ]
      [  38  1  1  5  774  30  8  40  -1  3  5  1  4393  120  -1  18  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  4483  120  -1  17  ]
      [  37  1  1  5  775  32  8  39  -1  5  9  1  4343  120  1150  17  ]
      [  45  1  1  5  841  85  1  40  -1  5  10  1  4230  120  -1  20  ]
      [  64  1  1  2  844  52  8  44  -1  5  9  1  4849  120  -1  18  ]
      [  51  1  1  1  779  72  8  40  -1  5  9  1  4938  120  -1  21  ]
      [  57  1  1  5  689  25  8  60  -1  3  5  1  4590  120  -1  20  ]
      [  47  2  1  4  873  80  1  50  -1  5  9  1  4917  120  -1  18  ]
      [  52  1  1  2  704  66  8  40  -1  3  3  1  4625  120  -1  19  ]
      [  46  2  1  5  772  74  8  10  20  5  9  4  4503  120  1050  18  ]
      [  51  1  1  5  692  67  8  60  -1  5  9  1  4527  120  -1  21  ]
      [  53  1  1  2  750  31  8  60  -1  1  3  1  4509  120  -1  22  ]
      [  46  1  1  2  51  1  8  75  12  4  8  1  5423  120  550  20  ]
      [  39  1  1  5  601  34  8  50  17  5  9  1  5331  120  860  21  ]
      [  36  1  1  5  780  24  8  40  -1  5  9  1  5023  120  -1  22  ]
      [  36  1  1  5  771  30  8  40  16  5  8  1  5307  120  820  23  ]
      [  52  1  1  5  607  35  8  60  -1  4  8  1  5729  120  -1  21  ]
      [  38  1  1  6  780  66  8  60  23  5  9  1  5850  120  1250  20  ]
      [  44  1  1  5  751  51  8  50  -1  4  5  1  5722  120  -1  20  ]
      [  44  1  1  5  780  25  8  60  -1  3  1  1  5619  120  -1  20  ]
      [  52  1  1  2  841  85  8  40  -1  5  10  1  7489  120  -1  22  ]
      [  60  1  1  2  673  52  8  60  -1  1  3  1  9049  120  -1  22  ]
      [  39  1  1  5  774  51  8  45  -1  5  -1  1  17297  120  -1  24  ]
      [  31  1  1  2  844  52  8  50  21  5  9  1  12821  120  1050  23  ]
      [  67  1  1  2  671  27  8  98  -1  3  3  1  19002  120  -1  24  ]
      [  33  1  1  5  704  65  8  55  14  5  3  1  18652  120  740  24  ]
      [  48  1  1  2  261  45  8  55  -1  1  5  1  19985  120  -1  24  ]
      [  47  1  1  6  268  45  8  40  7  1  3  1  1447  119  400  13  ]
      [  37  1  1  1  996  74  8  70  -1  3  3  1  1377  119  -1  8  ]
      [  50  1  1  5  765  45  8  46  -1  5  9  1  2423  119  -1  17  ]
      [  33  1  1  5  691  65  8  38  -1  5  3  1  2902  119  -1  14  ]
      [  55  2  8  -1  -1  -1  -1  -1  12  -1  -1  4  248  118  580  13  ]
      [  50  1  1  1  995  52  8  40  -1  -1  -1  1  1009  118  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  1  3  3  1041  118  339  12  ]
      [  60  1  8  -1  -1  -1  -1  -1  9  3  5  2  1127  118  367  7  ]
      [  56  1  1  6  254  24  8  37  -1  1  3  1  1381  118  -1  12  ]
      [  32  1  1  6  510  45  8  38  15  1  3  1  1475  118  720  8  ]
      [  40  1  1  6  531  28  8  37  9  1  -1  1  1355  118  470  11  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1409  118  -1  10  ]
      [  38  1  1  6  742  26  8  38  12  1  3  1  1470  118  500  10  ]
      [  56  1  1  6  290  27  8  40  9  1  3  1  1309  118  400  8  ]
      [  54  2  1  5  772  65  8  40  -1  3  3  1  1879  118  -1  11  ]
      [  58  1  1  6  714  63  8  14  -1  9  -1  5  2080  118  -1  11  ]
      [  42  2  1  5  780  17  8  37  9  3  3  1  2238  118  400  11  ]
      [  43  1  1  6  714  60  1  40  13  3  3  1  2278  118  700  13  ]
      [  41  1  1  5  774  73  8  38  14  5  9  1  2043  118  635  18  ]
      [  57  1  1  4  873  80  1  45  -1  5  9  1  2364  118  -1  13  ]
      [  41  1  1  4  801  75  1  38  -1  4  8  1  2359  118  -1  13  ]
      [  35  1  1  5  287  50  8  38  11  3  5  1  2387  118  565  12  ]
      [  43  1  1  5  777  31  8  35  -1  5  1  1  2537  118  -1  20  ]
      [  39  1  1  5  776  24  8  39  -1  4  3  1  2772  118  -1  13  ]
      [  37  1  1  5  821  72  8  38  -1  5  10  1  2785  118  -1  16  ]
      [  52  1  1  5  651  60  1  40  11  3  5  1  3040  118  585  17  ]
      [  52  1  1  2  460  45  8  70  -1  3  5  1  3722  118  -1  19  ]
      [  64  1  1  2  672  52  8  60  17  3  3  1  5353  118  790  21  ]
      [  47  1  1  2  704  67  8  50  8  3  4  1  5774  118  400  21  ]
      [  53  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1067  117  600  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  940  117  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  906  117  -1  10  ]
      [  40  1  1  5  714  15  8  37  9  1  3  1  1211  117  450  7  ]
      [  48  2  1  5  678  92  8  40  -1  2  3  1  1134  117  -1  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1322  117  -1  10  ]
      [  33  2  8  -1  -1  -1  -1  -1  10  3  4  4  1308  117  450  8  ]
      [  41  1  1  5  861  91  1  39  14  4  8  1  1681  117  750  14  ]
      [  36  2  8  -1  -1  -1  -1  -1  13  3  3  6  1595  117  710  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  8  3  1678  117  -1  11  ]
      [  41  1  1  6  521  17  8  38  12  1  3  1  2141  117  605  15  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2451  117  -1  12  ]
      [  47  2  1  4  870  80  1  30  -1  5  9  1  2734  117  -1  18  ]
      [  37  1  1  5  671  51  8  44  -1  3  3  1  3600  117  -1  18  ]
      [  48  1  1  4  811  75  1  40  -1  5  9  1  4789  117  -1  19  ]
      [  36  1  1  5  777  74  8  40  -1  5  8  1  18124  117  -1  24  ]
      [  34  2  1  4  873  80  1  38  -1  5  3  1  173  116  -1  13  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  3  3  838  116  -1  5  ]
      [  49  1  1  6  714  1  8  56  -1  2  3  1  723  116  285  12  ]
      [  35  1  1  6  442  28  8  40  9  2  4  1  972  116  435  15  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1493  116  -1  10  ]
      [  39  1  1  6  549  31  8  35  -1  1  3  1  1642  116  -1  15  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1593  116  -1  9  ]
      [  55  1  1  1  254  28  8  65  -1  4  8  1  1788  116  -1  10  ]
      [  39  1  1  5  602  64  8  35  -1  5  8  1  2227  116  -1  12  ]
      [  48  2  1  4  872  80  1  50  -1  5  9  1  3064  116  -1  14  ]
      [  52  1  1  5  750  75  1  60  -1  3  8  1  4384  116  -1  17  ]
      [  38  1  1  5  702  63  8  8  -1  4  8  4  341  115  -1  14  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  473  115  -1  14  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  2  6  2  377  115  -1  3  ]
      [  49  1  1  5  676  51  8  45  -1  5  9  1  350  115  -1  12  ]
      [  49  1  8  -1  -1  -1  -1  -1  18  5  -1  8  537  115  800  6  ]
      [  35  1  1  1  834  74  8  60  -1  5  8  1  710  115  -1  5  ]
      [  38  1  1  6  731  64  8  35  16  1  3  1  755  115  800  13  ]
      [  50  2  1  5  864  85  8  20  -1  3  3  1  756  115  -1  5  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  896  115  -1  5  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  5  3  850  115  -1  5  ]
      [  44  1  1  2  254  28  8  40  -1  2  6  1  890  115  -1  14  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  883  115  -1  14  ]
      [  29  2  1  5  787  75  1  39  12  3  3  1  935  115  615  14  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  5  5  933  115  -1  6  ]
      [  28  2  8  -1  -1  -1  -1  -1  11  5  -1  4  1027  115  480  15  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1071  115  -1  6  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1068  115  -1  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  964  115  -1  6  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1277  115  -1  10  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  9  -1  3  1175  115  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  4  2  1174  115  -1  16  ]
      [  45  1  1  6  51  1  8  39  -1  1  3  1  1207  115  -1  7  ]
      [  44  2  1  5  852  91  8  30  10  4  4  1  1277  115  475  14  ]
      [  32  1  1  6  270  40  1  35  -1  1  3  1  1182  115  0  12  ]
      [  45  1  1  6  281  50  8  38  -1  1  3  1  1211  115  -1  19  ]
      [  43  2  1  6  660  85  1  38  -1  1  3  1  1238  115  -1  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1276  115  -1  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1147  115  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  2  5  3  1295  115  -1  13  ]
      [  32  2  1  5  870  80  1  60  7  5  9  1  1289  115  305  12  ]
      [  48  2  1  5  771  75  1  40  16  2  3  1  1142  115  800  10  ]
      [  45  1  1  6  482  99  8  40  -1  2  3  1  1251  115  -1  14  ]
      [  33  1  1  5  788  72  8  39  15  3  3  1  1459  115  720  17  ]
      [  43  1  1  6  141  24  8  40  9  3  3  1  1384  115  425  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1469  115  -1  12  ]
      [  71  1  8  -1  -1  -1  -1  -1  12  3  6  3  1476  115  550  9  ]
      [  37  1  1  6  276  51  8  57  -1  1  3  1  1341  115  -1  8  ]
      [  43  1  1  5  787  75  1  40  -1  2  3  1  1385  115  -1  16  ]
      [  42  1  1  6  714  85  1  38  11  1  3  1  1617  115  545  9  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1594  115  -1  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1674  115  -1  9  ]
      [  31  1  1  6  628  17  8  37  -1  3  3  1  1602  115  -1  9  ]
      [  40  1  1  6  744  10  8  38  7  1  3  1  1715  115  330  12  ]
      [  54  1  1  5  316  29  8  39  -1  1  3  1  1777  115  -1  17  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1779  115  -1  10  ]
      [  46  1  1  6  714  26  8  40  -1  3  3  1  1883  115  -1  11  ]
      [  34  1  1  6  281  50  8  37  -1  1  3  1  1979  115  -1  10  ]
      [  38  1  1  5  683  72  8  40  -1  5  8  1  1854  115  -1  10  ]
      [  37  1  1  6  621  34  8  35  14  3  5  1  1898  115  600  11  ]
      [  34  2  1  5  764  85  1  40  12  5  3  1  1861  115  550  15  ]
      [  46  2  1  5  787  75  1  40  -1  2  3  1  1923  115  -1  13  ]
      [  44  1  1  1  620  93  8  38  -1  1  3  1  2227  115  -1  13  ]
      [  59  1  1  5  662  52  8  50  -1  3  8  1  2197  115  -1  11  ]
      [  43  1  1  5  788  75  1  39  -1  3  3  1  2195  115  -1  14  ]
      [  50  1  1  6  521  34  8  35  -1  3  3  1  2141  115  -1  14  ]
      [  50  1  1  5  780  29  8  38  -1  1  7  1  2001  115  -1  20  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  2084  115  -1  11  ]
      [  50  1  1  4  801  75  1  40  -1  2  3  1  2111  115  -1  15  ]
      [  40  1  1  5  778  74  8  39  -1  3  5  1  2515  115  -1  15  ]
      [  54  1  1  4  872  80  1  40  -1  5  9  1  2455  115  -1  16  ]
      [  55  1  1  5  620  40  8  35  -1  1  3  1  2763  115  -1  17  ]
      [  89  1  8  -1  -1  -1  -1  -1  19  4  7  3  2879  115  900  19  ]
      [  30  1  1  5  603  45  8  40  11  9  9  1  2881  115  515  17  ]
      [  52  2  1  5  633  24  8  38  -1  1  3  1  2675  115  -1  13  ]
      [  56  1  1  4  787  60  8  38  14  3  8  1  2653  115  700  13  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  5  9  3  3173  115  -1  18  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  5  3  3096  115  -1  14  ]
      [  57  1  1  4  873  80  1  38  -1  5  9  1  3066  115  -1  15  ]
      [  62  2  1  2  672  51  8  40  -1  1  3  1  3074  115  -1  14  ]
      [  46  1  1  5  780  13  8  40  -1  3  3  1  3395  115  -1  15  ]
      [  61  1  1  1  670  24  8  60  -1  5  -1  1  3442  115  -1  15  ]
      [  46  2  1  5  633  24  8  40  12  3  3  1  3278  115  615  15  ]
      [  40  1  1  6  273  85  1  39  -1  3  3  1  3494  115  500  17  ]
      [  53  1  1  5  600  31  8  40  12  5  8  1  3252  115  550  19  ]
      [  35  1  1  5  751  21  8  40  -1  -1  -1  1  3797  115  -1  16  ]
      [  56  1  1  5  841  85  8  40  -1  5  10  1  3809  115  -1  21  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  3990  115  -1  16  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  3  3  3  3933  115  -1  16  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  9  3  4192  115  -1  18  ]
      [  51  1  1  2  750  33  8  35  -1  1  3  1  4705  115  -1  18  ]
      [  63  1  1  5  764  91  1  38  -1  5  8  1  5481  115  -1  20  ]
      [  46  1  1  1  774  74  8  50  27  3  5  1  5027  115  1400  19  ]
      [  57  1  1  5  750  66  8  45  -1  1  3  1  5809  115  -1  20  ]
      [  46  1  1  5  751  35  8  46  24  3  5  1  5582  115  1200  21  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  6  233  114  -1  5  ]
      [  39  1  1  5  813  45  8  35  13  5  9  1  407  114  615  14  ]
      [  50  1  1  1  837  74  8  25  9  5  8  1  504  114  325  10  ]
      [  87  2  8  -1  -1  -1  -1  -1  12  1  3  3  861  114  585  5  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1053  114  -1  6  ]
      [  35  2  8  -1  -1  -1  -1  -1  5  1  3  4  1236  114  200  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1184  114  -1  9  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  3  -1  3  1331  114  -1  10  ]
      [  53  1  1  6  716  75  1  39  5  1  1  1  1316  114  250  8  ]
      [  40  1  1  6  501  60  8  38  -1  -1  4  1  1334  114  -1  11  ]
      [  72  1  8  -1  -1  -1  -1  -1  9  3  8  3  1668  114  425  9  ]
      [  24  1  1  5  683  22  8  37  10  5  3  1  1668  114  411  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1830  114  -1  12  ]
      [  41  1  1  6  741  32  8  40  -1  1  3  1  2149  114  -1  11  ]
      [  44  1  1  5  672  27  8  35  -1  3  3  1  2133  114  -1  14  ]
      [  52  1  1  4  787  64  8  39  -1  3  3  1  2892  114  -1  17  ]
      [  54  1  1  5  621  34  8  39  -1  1  5  1  5299  114  -1  19  ]
      [  23  1  1  9  801  75  1  40  4  3  3  1  631  113  125  4  ]
      [  46  1  1  6  220  34  8  38  -1  1  3  1  1295  113  -1  12  ]
      [  46  2  8  -1  -1  -1  -1  -1  -1  1  -1  2  1162  113  -1  7  ]
      [  34  1  1  6  241  35  8  36  -1  1  3  1  1421  113  -1  14  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  -1  3  3  1631  113  -1  9  ]
      [  56  1  1  6  531  65  8  38  8  -1  -1  1  1616  113  380  13  ]
      [  48  2  1  1  852  85  8  20  10  5  9  1  1647  113  450  12  ]
      [  27  1  1  4  997  75  1  46  8  5  -1  1  2013  113  380  11  ]
      [  55  2  1  5  796  85  1  38  -1  -1  -1  3  2138  113  -1  11  ]
      [  41  1  1  4  765  75  1  40  -1  5  6  1  2053  113  -1  15  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2471  113  -1  14  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2852  113  -1  13  ]
      [  37  1  1  5  671  37  8  40  12  5  3  1  3399  113  625  15  ]
      [  54  1  1  5  841  85  1  50  -1  5  10  1  3881  113  -1  19  ]
      [  53  1  1  6  531  50  8  40  -1  2  3  1  894  112  -1  10  ]
      [  48  1  1  6  401  15  8  38  -1  1  3  1  933  112  -1  12  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  980  112  -1  6  ]
      [  50  1  1  5  714  63  8  40  9  1  3  1  1026  112  374  9  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  5  3  991  112  -1  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1272  112  -1  7  ]
      [  45  1  1  6  540  28  8  37  11  3  3  1  1268  112  500  12  ]
      [  45  2  1  6  23  1  8  40  -1  2  3  1  1196  112  -1  10  ]
      [  68  1  1  6  501  36  8  39  -1  1  3  1  1433  112  -1  12  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1374  112  -1  11  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1378  112  0  8  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1423  112  -1  11  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1500  112  -1  8  ]
      [  48  1  1  6  714  65  1  38  -1  3  4  1  1329  112  -1  14  ]
      [  57  1  1  5  788  45  8  40  -1  1  3  1  1359  112  -1  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1605  112  -1  10  ]
      [  52  1  8  -1  -1  -1  -1  -1  8  4  5  3  1528  112  345  15  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  9  9  2  1796  112  -1  10  ]
      [  38  1  1  6  714  63  8  40  -1  -1  -1  1  1954  112  -1  10  ]
      [  37  1  1  6  51  1  8  39  -1  1  3  1  1860  112  -1  10  ]
      [  60  1  1  5  622  29  8  38  10  1  3  1  1901  112  490  10  ]
      [  47  2  1  5  861  85  8  42  11  4  8  1  2006  112  500  11  ]
      [  42  2  1  5  787  75  1  39  11  3  3  1  2115  112  480  20  ]
      [  42  1  1  4  787  75  1  40  -1  5  5  1  2111  112  -1  11  ]
      [  51  1  1  5  663  52  8  38  -1  1  3  1  2152  112  -1  14  ]
      [  33  1  1  5  880  73  8  40  14  5  10  1  2099  112  665  11  ]
      [  58  1  1  5  549  41  1  38  -1  1  5  1  2343  112  -1  19  ]
      [  41  1  1  5  861  85  8  40  -1  5  9  1  2536  112  -1  17  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2894  112  -1  17  ]
      [  57  1  1  4  811  75  1  40  13  5  8  1  3043  112  600  17  ]
      [  51  1  1  6  178  21  8  35  -1  1  3  1  3333  112  -1  17  ]
      [  34  2  1  5  304  52  8  20  -1  5  3  1  734  111  -1  10  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1476  111  -1  8  ]
      [  59  1  1  5  677  22  8  40  -1  1  3  1  1584  111  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2297  111  -1  11  ]
      [  44  1  1  5  750  72  8  55  14  5  9  1  3754  111  650  19  ]
      [  49  1  8  -1  -1  -1  -1  -1  13  1  3  6  132  110  480  5  ]
      [  52  2  1  6  661  52  8  48  -1  -1  -1  1  459  110  -1  3  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  5  3  481  110  -1  13  ]
      [  64  1  8  3  14  1  8  15  -1  1  3  3  362  110  -1  3  ]
      [  44  2  1  5  754  74  8  15  -1  3  1  1  382  110  -1  13  ]
      [  39  1  8  -1  -1  -1  -1  -1  9  2  3  2  370  110  420  10  ]
      [  44  2  8  -1  -1  -1  -1  -1  -1  3  3  8  304  110  -1  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  586  110  -1  7  ]
      [  63  1  8  6  997  93  8  8  -1  1  3  3  589  110  -1  4  ]
      [  43  2  1  6  773  52  8  25  12  1  -1  1  666  110  530  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  613  110  -1  18  ]
      [  50  1  1  5  796  80  8  35  -1  3  3  1  580  110  -1  8  ]
      [  21  1  8  -1  -1  -1  -1  -1  10  1  3  4  681  110  485  6  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  550  110  -1  18  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  522  110  -1  7  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  1  -1  2  674  110  -1  10  ]
      [  50  1  1  6  742  45  8  40  -1  1  3  1  606  110  -1  13  ]
      [  51  1  8  -1  -1  -1  -1  -1  -1  2  3  2  539  110  -1  9  ]
      [  43  2  8  -1  -1  -1  -1  -1  -1  2  3  2  578  110  -1  15  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  773  110  -1  12  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  873  110  0  5  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  3  3  770  110  -1  10  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  1  3  769  110  -1  11  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  877  110  -1  5  ]
      [  89  2  8  -1  -1  -1  -1  -1  10  1  3  3  818  110  417  5  ]
      [  72  1  8  3  14  1  8  29  -1  1  -1  3  725  110  0  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  2  5  3  746  110  -1  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  715  110  -1  8  ]
      [  25  1  1  5  780  65  8  40  -1  3  4  8  785  110  -1  10  ]
      [  38  1  1  1  687  51  8  50  11  2  3  1  753  110  500  11  ]
      [  62  1  1  2  750  50  8  40  -1  1  3  1  872  110  -1  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  3  758  110  -1  8  ]
      [  33  1  1  6  714  51  8  40  9  -1  -1  1  803  110  350  10  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1041  110  -1  6  ]
      [  46  2  1  6  522  25  8  38  4  1  3  1  986  110  125  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  930  110  -1  10  ]
      [  50  2  1  5  870  80  1  20  -1  4  8  1  975  110  -1  16  ]
      [  91  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  960  110  -1  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  3  3  3  1012  110  600  10  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  3  3  926  110  -1  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1033  110  -1  6  ]
      [  35  1  1  6  742  20  8  39  15  3  3  1  947  110  730  11  ]
      [  32  2  8  5  661  52  8  10  12  1  3  6  1054  110  565  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  966  110  -1  18  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  5  5  3  1080  110  -1  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  941  110  -1  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  15  1  -1  3  917  110  690  7  ]
      [  35  2  1  5  813  17  8  20  19  3  3  1  938  110  920  11  ]
      [  25  1  1  5  854  85  8  37  -1  1  3  1  1098  110  0  6  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1028  110  430  7  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  3  99  2  925  110  -1  8  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1035  110  -1  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1069  110  -1  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1084  110  -1  6  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  957  110  -1  8  ]
      [  51  1  8  -1  -1  -1  -1  -1  -1  1  3  3  983  110  0  6  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  3  3  981  110  -1  9  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  949  110  -1  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1030  110  -1  14  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1090  110  -1  6  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1012  110  -1  6  ]
      [  34  1  1  5  805  93  8  40  -1  2  3  1  901  110  -1  7  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  2  5  2  1036  110  -1  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  973  110  -1  6  ]
      [  47  1  8  -1  -1  -1  -1  -1  -1  2  3  2  986  110  -1  11  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1286  110  -1  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1201  110  0  14  ]
      [  43  1  1  6  351  18  8  40  -1  1  -1  1  1186  110  -1  15  ]
      [  46  2  1  5  853  85  8  38  11  5  4  1  1248  110  500  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  9  -1  3  1103  110  -1  13  ]
      [  35  1  1  6  441  85  8  40  13  1  3  1  1298  110  600  12  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1290  110  -1  8  ]
      [  58  1  1  5  602  40  8  37  12  5  8  1  1103  110  500  12  ]
      [  49  1  1  6  401  15  8  24  -1  3  5  1  1150  110  -1  15  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  1  5  2  1276  110  -1  9  ]
      [  34  1  1  6  254  28  8  40  -1  3  3  1  1194  110  -1  15  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1148  110  -1  10  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1285  110  -1  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1186  110  -1  12  ]
      [  50  1  1  5  853  85  1  38  -1  5  5  1  1121  110  -1  12  ]
      [  52  1  1  6  741  36  8  40  -1  3  3  1  1175  110  -1  14  ]
      [  38  1  1  6  282  1  8  38  -1  1  3  1  1271  110  -1  10  ]
      [  51  1  1  6  714  63  8  38  -1  1  1  1  1243  110  -1  15  ]
      [  41  1  1  6  101  13  8  39  -1  1  3  1  1293  110  -1  10  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1256  110  -1  10  ]
      [  29  1  1  6  741  34  8  35  7  1  3  1  1288  110  300  15  ]
      [  61  1  8  -1  -1  -1  -1  -1  18  1  4  3  1112  110  800  15  ]
      [  62  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1172  110  430  7  ]
      [  30  2  1  5  627  18  8  40  -1  3  5  1  1282  110  150  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1129  110  -1  7  ]
      [  65  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1223  110  550  7  ]
      [  79  1  8  -1  -1  -1  -1  -1  7  3  3  3  1259  110  310  7  ]
      [  21  1  1  9  801  75  1  37  9  1  3  1  1150  110  351  8  ]
      [  42  1  1  6  546  45  8  40  -1  2  3  1  1269  110  -1  15  ]
      [  44  1  1  6  488  45  8  38  -1  2  3  1  1151  110  -1  7  ]
      [  37  1  1  2  488  45  8  70  -1  2  5  1  1134  110  0  10  ]
      [  24  1  1  6  488  45  8  50  -1  3  3  1  1193  110  -1  12  ]
      [  35  1  1  5  603  45  8  40  -1  5  99  1  1102  110  -1  12  ]
      [  30  1  1  6  441  45  8  40  -1  1  3  1  1243  110  -1  10  ]
      [  30  1  1  6  268  45  8  40  -1  2  3  1  1293  110  -1  10  ]
      [  64  1  1  1  902  85  8  18  -1  1  3  3  1113  110  -1  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  4  5  3  1297  110  -1  10  ]
      [  49  1  1  6  997  45  8  40  -1  2  3  1  1129  110  -1  11  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1166  110  -1  13  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  4  99  2  1324  110  -1  12  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1301  110  0  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1498  110  -1  13  ]
      [  49  1  1  6  174  22  8  38  -1  1  3  1  1404  110  -1  13  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  4  4  3  1342  110  -1  11  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1322  110  -1  8  ]
      [  26  1  1  5  771  74  8  37  8  3  3  1  1335  110  330  8  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  5  -1  2  1398  110  -1  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1407  110  -1  8  ]
      [  39  1  1  5  796  80  8  38  -1  1  3  1  1397  110  -1  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1408  110  -1  8  ]
      [  53  2  1  5  853  85  8  20  -1  3  5  1  1317  110  -1  8  ]
      [  67  1  1  2  441  45  8  20  -1  1  3  3  1445  110  -1  10  ]
      [  38  1  1  5  862  85  1  29  8  3  -1  1  1488  110  345  8  ]
      [  39  1  1  5  836  92  1  40  -1  3  3  1  1385  110  -1  8  ]
      [  53  1  1  6  510  45  8  39  -1  1  3  1  1451  110  -1  8  ]
      [  44  1  1  2  609  74  8  60  -1  5  9  1  1341  110  -1  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1389  110  -1  11  ]
      [  49  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1475  110  -1  13  ]
      [  36  1  1  6  540  22  8  38  -1  1  3  1  1328  110  -1  8  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1371  110  -1  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  5  3  1464  110  550  8  ]
      [  38  1  1  6  505  20  8  37  -1  5  3  1  1417  110  -1  12  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1355  110  -1  12  ]
      [  57  2  1  5  626  75  1  20  -1  5  5  1  1487  110  -1  12  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1347  110  0  8  ]
      [  69  1  8  -1  -1  -1  -1  -1  10  1  3  3  1335  110  480  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1441  110  -1  11  ]
      [  49  1  1  5  787  75  1  38  -1  3  8  1  1331  110  -1  15  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1325  110  -1  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1306  110  -1  11  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1391  110  -1  8  ]
      [  28  1  1  6  191  27  8  35  8  1  3  1  1319  110  310  11  ]
      [  38  1  1  6  460  45  8  40  -1  3  5  1  1486  110  -1  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  3  8  3  1386  110  -1  10  ]
      [  47  1  1  5  61  75  1  40  -1  5  8  1  1369  110  -1  16  ]
      [  52  1  1  6  461  45  8  40  -1  2  3  1  1393  110  -1  10  ]
      [  55  1  1  6  255  35  8  40  -1  1  3  1  1579  110  -1  11  ]
      [  35  1  1  5  854  85  1  39  13  3  3  1  1683  110  600  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1614  110  -1  11  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1537  110  -1  9  ]
      [  59  1  1  6  501  51  8  38  9  3  3  1  1609  110  425  10  ]
      [  49  1  1  2  911  55  8  60  9  -1  -1  1  1589  110  375  13  ]
      [  46  1  1  5  751  15  8  38  -1  1  3  1  1510  110  -1  14  ]
      [  28  2  1  5  780  36  8  55  10  3  99  1  1547  110  414  15  ]
      [  38  1  1  6  775  25  8  40  -1  1  5  1  1693  110  -1  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1626  110  -1  9  ]
      [  74  1  8  -1  -1  -1  -1  -1  8  1  4  3  1673  110  320  10  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1501  110  -1  10  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  3  -1  5  1687  110  -1  9  ]
      [  48  1  1  5  863  85  1  40  -1  1  3  1  1510  110  -1  9  ]
      [  29  1  1  6  714  45  8  55  8  1  3  1  1545  110  350  11  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1507  110  -1  9  ]
      [  53  1  1  5  793  85  1  38  -1  -1  -1  1  1523  110  -1  9  ]
      [  24  1  1  6  241  34  8  38  10  1  3  1  1627  110  500  9  ]
      [  49  1  1  6  483  45  8  39  -1  1  3  1  1580  110  -1  9  ]
      [  42  1  1  5  620  36  8  40  -1  3  5  1  1644  110  -1  13  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  99  3  1616  110  -1  13  ]
      [  40  2  1  2  901  93  8  98  6  1  5  1  1678  110  300  9  ]
      [  60  1  1  5  620  75  1  39  -1  4  3  1  1509  110  -1  15  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  6  3  1554  110  -1  18  ]
      [  42  1  1  2  911  55  8  98  -1  1  3  1  1721  110  -1  17  ]
      [  47  1  1  6  300  33  8  36  -1  1  3  1  1834  110  -1  10  ]
      [  56  1  1  5  773  65  8  38  9  3  5  1  1885  110  335  16  ]
      [  34  1  1  5  776  75  1  38  14  3  3  1  1702  110  650  14  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1914  110  0  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1931  110  -1  11  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1728  110  -1  10  ]
      [  47  1  1  6  441  45  8  40  -1  1  3  1  1781  110  -1  12  ]
      [  40  1  1  5  780  90  8  38  -1  3  3  1  1776  110  -1  12  ]
      [  32  1  1  6  254  75  1  39  10  3  3  1  1886  110  410  10  ]
      [  40  1  1  5  651  17  8  38  -1  1  3  1  1791  110  -1  10  ]
      [  35  1  1  6  501  51  8  40  -1  3  3  1  1972  110  450  10  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1793  110  -1  13  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1852  110  -1  10  ]
      [  43  1  1  4  801  75  1  45  -1  4  3  1  1885  110  -1  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1985  110  -1  11  ]
      [  42  1  1  6  264  40  1  38  15  1  3  1  1897  110  660  12  ]
      [  54  1  1  5  789  91  8  70  12  1  3  1  1939  110  550  17  ]
      [  36  1  1  6  254  10  8  38  -1  1  3  1  1795  110  0  12  ]
      [  51  1  1  1  705  92  8  45  -1  1  3  1  1770  110  -1  12  ]
      [  30  1  1  6  152  25  8  37  -1  -1  -1  1  1847  110  -1  10  ]
      [  38  1  1  4  787  64  8  40  -1  3  3  1  1998  110  -1  10  ]
      [  33  1  1  5  222  29  8  35  -1  3  3  1  1994  110  -1  10  ]
      [  46  1  1  6  540  34  8  35  -1  1  -1  1  1724  110  -1  14  ]
      [  44  1  1  5  750  32  8  38  -1  3  3  1  1996  110  -1  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  2  3  1813  110  -1  11  ]
      [  48  1  1  6  742  36  8  38  9  1  -1  1  1799  110  430  18  ]
      [  78  1  1  2  501  36  8  50  -1  1  3  1  1996  110  -1  10  ]
      [  45  1  1  5  701  63  1  39  -1  3  3  1  1997  110  0  12  ]
      [  48  2  1  5  868  80  8  35  14  5  8  1  1831  110  660  11  ]
      [  32  1  1  6  273  28  8  38  -1  1  3  1  1948  110  -1  13  ]
      [  58  1  1  5  793  1  8  40  -1  1  3  1  1912  110  -1  15  ]
      [  42  1  1  5  691  65  8  38  -1  3  3  1  1993  110  -1  12  ]
      [  43  1  1  5  731  64  8  39  -1  3  3  1  1825  110  -1  14  ]
      [  48  1  1  2  268  45  8  40  -1  2  3  1  1876  110  -1  15  ]
      [  30  2  1  5  787  75  1  38  13  2  3  1  1904  110  500  10  ]
      [  50  1  1  5  772  24  8  38  -1  4  4  1  2082  110  -1  16  ]
      [  37  1  1  5  671  51  8  38  -1  4  3  1  2084  110  -1  11  ]
      [  34  1  1  6  991  34  8  40  -1  1  99  1  2168  110  -1  15  ]
      [  40  1  1  4  629  60  8  39  -1  3  5  1  2218  110  -1  12  ]
      [  57  1  1  6  714  45  8  60  -1  1  3  1  2122  110  -1  15  ]
      [  36  1  1  6  391  15  8  45  -1  1  3  1  2209  110  0  12  ]
      [  41  1  1  6  141  24  8  37  -1  1  3  1  2060  110  -1  12  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2128  110  -1  13  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  2288  110  -1  15  ]
      [  34  1  1  6  71  26  8  40  -1  1  5  1  2001  110  -1  13  ]
      [  43  1  1  6  310  45  8  60  -1  3  3  1  2099  110  -1  15  ]
      [  55  1  1  6  270  29  8  36  -1  1  3  1  2018  110  -1  14  ]
      [  60  1  1  5  620  28  8  55  16  9  99  1  2286  110  700  15  ]
      [  58  1  1  4  801  75  1  40  -1  3  3  1  2024  110  -1  15  ]
      [  45  1  1  5  651  34  8  40  -1  1  5  1  2147  110  -1  17  ]
      [  54  1  1  5  788  22  8  38  10  1  99  1  2289  110  485  13  ]
      [  49  1  1  1  886  85  8  20  -1  5  9  1  2093  110  -1  17  ]
      [  55  1  1  4  874  80  1  40  -1  3  5  1  2199  110  -1  18  ]
      [  48  1  1  6  714  45  8  45  -1  1  3  1  2171  110  -1  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2272  110  -1  12  ]
      [  53  1  1  6  441  45  8  40  -1  1  3  1  2108  110  -1  13  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2085  110  -1  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2015  110  -1  14  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2170  110  -1  17  ]
      [  33  1  1  5  651  50  8  38  -1  2  5  1  2279  110  -1  13  ]
      [  45  1  1  4  801  75  1  40  -1  2  3  1  2188  110  -1  16  ]
      [  54  1  1  5  750  28  8  40  -1  3  5  1  2532  110  -1  16  ]
      [  51  1  1  4  872  80  1  40  -1  5  10  1  2388  110  -1  12  ]
      [  46  1  1  6  141  24  8  38  11  1  3  1  2487  110  450  13  ]
      [  49  1  1  6  714  60  1  38  -1  1  3  1  2367  110  -1  16  ]
      [  43  2  1  4  814  75  1  60  -1  1  3  1  2306  110  -1  17  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2563  110  -1  16  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2549  110  -1  15  ]
      [  49  1  1  6  174  22  8  35  8  1  3  1  2360  110  346  16  ]
      [  32  1  1  5  691  75  1  39  14  5  8  1  2425  110  605  12  ]
      [  80  1  8  -1  -1  -1  -1  -1  6  1  -1  3  2474  110  259  17  ]
      [  44  1  1  2  750  45  8  40  -1  1  5  1  2477  110  -1  17  ]
      [  47  2  1  4  823  92  1  45  15  5  10  1  2335  110  700  12  ]
      [  52  2  1  4  870  75  1  35  -1  5  9  1  2424  110  -1  12  ]
      [  41  2  1  5  775  72  8  37  -1  5  9  1  2531  110  -1  14  ]
      [  46  1  1  5  608  93  1  38  -1  5  9  1  2511  110  -1  19  ]
      [  60  1  1  5  603  70  8  38  -1  5  8  1  2478  110  -1  12  ]
      [  45  1  1  2  753  67  8  50  -1  5  8  1  2313  110  -1  14  ]
      [  53  1  1  5  841  85  8  65  -1  5  10  1  2640  110  -1  15  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2724  110  -1  13  ]
      [  44  1  1  4  801  75  1  37  -1  3  7  1  2873  110  -1  17  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  5  9  3  2780  110  -1  13  ]
      [  55  1  1  5  620  75  1  39  -1  3  5  1  2630  110  -1  21  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  3  5  3  2627  110  -1  13  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2697  110  -1  13  ]
      [  59  1  1  4  873  80  1  38  -1  5  9  1  2792  110  -1  13  ]
      [  59  1  1  6  741  51  8  40  12  1  5  1  2730  110  510  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  4  3  2793  110  -1  17  ]
      [  32  2  1  4  873  80  1  23  -1  5  8  1  2631  110  -1  13  ]
      [  39  1  1  5  788  74  8  38  25  1  5  1  2624  110  1200  14  ]
      [  44  1  1  5  692  66  8  37  -1  -1  3  1  2828  110  -1  13  ]
      [  49  1  1  5  317  75  1  39  -1  3  3  1  2822  110  -1  13  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  5  6  3  2867  110  -1  13  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  5  7  3  2674  110  -1  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  6  3  3  3  2708  110  213  13  ]
      [  48  1  1  4  764  75  1  40  -1  5  10  1  2800  110  -1  15  ]
      [  47  1  1  5  692  66  8  40  -1  5  9  1  2764  110  -1  20  ]
      [  47  1  1  5  612  73  8  44  -1  5  9  1  2926  110  -1  15  ]
      [  36  1  1  5  775  36  8  40  -1  5  5  1  3093  110  -1  14  ]
      [  36  1  1  5  623  74  8  40  -1  5  5  1  3026  110  -1  15  ]
      [  45  1  1  2  692  66  8  60  -1  1  5  1  3026  110  -1  15  ]
      [  63  1  1  5  620  29  8  35  -1  1  3  1  3169  110  -1  14  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  4  4  3  3064  110  -1  14  ]
      [  41  1  1  5  600  29  8  37  -1  4  8  1  3108  110  -1  14  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  3062  110  -1  20  ]
      [  46  1  1  5  751  24  8  38  -1  3  3  1  3025  110  -1  14  ]
      [  37  1  1  5  714  60  8  40  12  3  3  1  3287  110  550  20  ]
      [  50  1  1  5  750  64  8  39  15  3  3  1  3287  110  630  15  ]
      [  56  1  1  4  602  64  8  38  -1  4  8  1  3539  110  -1  15  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  5  3  3301  110  -1  20  ]
      [  37  1  1  2  268  45  8  40  -1  3  5  1  3278  110  -1  17  ]
      [  41  1  1  5  750  28  8  40  -1  3  5  1  3453  110  -1  17  ]
      [  42  1  1  5  600  34  8  30  -1  5  10  1  3857  110  -1  16  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  4  99  3  3927  110  -1  17  ]
      [  54  1  1  4  886  80  1  40  -1  -1  -1  1  3964  110  -1  16  ]
      [  46  2  1  5  880  24  8  60  -1  5  9  1  3617  110  -1  18  ]
      [  64  1  1  4  823  75  1  55  -1  1  99  1  3601  110  -1  16  ]
      [  41  1  1  5  689  37  8  38  -1  3  3  1  3845  110  -1  22  ]
      [  42  1  1  6  312  64  8  39  -1  1  3  1  4381  110  -1  17  ]
      [  53  1  1  4  765  80  1  39  -1  5  8  1  4350  110  0  17  ]
      [  46  1  1  5  705  64  8  45  8  4  8  1  4091  110  380  17  ]
      [  60  1  1  5  687  51  8  50  12  1  3  1  4272  110  600  18  ]
      [  44  1  1  2  842  85  8  35  23  5  10  1  4339  110  1100  19  ]
      [  56  1  1  5  780  24  8  50  22  -1  -1  1  4720  110  1000  18  ]
      [  37  1  1  2  316  45  8  40  -1  5  5  1  4583  110  -1  20  ]
      [  40  1  1  5  751  52  8  48  -1  3  5  1  4658  110  -1  18  ]
      [  38  1  1  5  881  65  8  38  14  5  9  1  4846  110  700  21  ]
      [  60  1  1  5  841  85  1  39  14  5  10  1  4994  110  650  19  ]
      [  56  1  1  5  751  66  8  55  -1  1  3  1  5445  110  -1  20  ]
      [  36  1  1  5  308  33  8  40  9  5  5  1  5349  110  404  20  ]
      [  48  1  1  1  689  33  8  50  -1  5  9  1  5563  110  -1  22  ]
      [  52  2  1  5  813  91  8  60  -1  5  9  1  6255  110  -1  21  ]
      [  40  1  1  5  602  31  1  40  16  5  9  1  7200  110  780  21  ]
      [  51  1  1  5  751  29  8  40  -1  3  5  1  7178  110  -1  21  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  416  109  -1  3  ]
      [  32  1  1  2  627  93  8  50  12  5  -1  1  969  109  400  6  ]
      [  36  1  1  6  292  45  8  37  -1  3  99  1  1642  109  -1  17  ]
      [  71  1  8  -1  -1  -1  -1  -1  12  5  8  3  1542  109  550  9  ]
      [  57  1  1  5  501  52  8  50  7  1  3  1  1637  109  315  9  ]
      [  32  2  1  4  785  28  1  40  14  4  3  1  2162  109  650  18  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2605  109  0  15  ]
      [  42  1  1  4  764  91  1  48  16  5  9  1  3932  109  730  16  ]
      [  38  1  1  4  776  60  8  39  -1  1  5  1  4606  109  -1  20  ]
      [  37  1  8  -1  -1  -1  -1  -1  -1  1  3  2  637  108  -1  12  ]
      [  51  1  8  -1  -1  -1  -1  -1  8  -1  -1  2  823  108  328  12  ]
      [  64  1  1  6  714  1  8  12  -1  4  6  3  870  108  -1  9  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  5  9  2  979  108  -1  18  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1216  108  -1  8  ]
      [  41  1  1  6  145  25  8  40  -1  1  3  1  1167  108  -1  11  ]
      [  69  2  8  -1  -1  -1  -1  -1  10  1  3  3  1230  108  510  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1354  108  -1  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1613  108  -1  13  ]
      [  38  1  1  1  934  45  8  45  -1  2  3  1  1597  108  -1  15  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1538  108  -1  14  ]
      [  34  1  1  6  531  28  8  40  11  1  3  1  1521  108  515  9  ]
      [  47  1  1  5  317  32  8  40  -1  3  5  1  1582  108  -1  12  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1692  108  -1  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1731  108  -1  10  ]
      [  44  1  1  6  101  45  8  40  -1  1  3  1  1797  108  -1  14  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1718  108  -1  12  ]
      [  47  1  1  5  620  29  8  40  -1  3  5  1  1751  108  -1  13  ]
      [  38  1  1  5  692  66  8  38  -1  5  3  8  1895  108  -1  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1806  108  -1  10  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  5  -1  3  1834  108  -1  10  ]
      [  51  1  1  5  600  75  1  40  -1  2  5  1  1999  108  -1  14  ]
      [  58  1  1  5  836  52  8  48  -1  3  -1  1  2170  108  -1  15  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  3  8  3  2008  108  -1  14  ]
      [  42  1  1  5  316  85  8  39  -1  3  5  1  2193  108  -1  12  ]
      [  37  1  1  6  802  34  8  48  -1  1  3  1  2339  108  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2769  108  -1  17  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2706  108  -1  15  ]
      [  57  1  1  4  873  80  1  40  -1  5  9  1  2990  108  550  16  ]
      [  51  2  1  5  841  66  8  38  -1  5  9  1  3110  108  -1  21  ]
      [  61  1  1  4  811  75  1  40  -1  5  9  1  3301  108  -1  20  ]
      [  48  1  1  5  750  29  8  38  -1  5  9  1  3214  108  -1  19  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  9  3  3950  108  -1  19  ]
      [  37  2  1  6  934  45  8  5  13  1  -1  4  225  107  625  6  ]
      [  50  1  8  -1  -1  -1  -1  -1  -1  1  3  2  603  107  -1  10  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  598  107  -1  11  ]
      [  19  1  8  -1  -1  -1  -1  -1  -1  1  3  2  698  107  -1  4  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  740  107  -1  12  ]
      [  37  1  8  -1  -1  -1  -1  -1  -1  2  5  2  783  107  -1  5  ]
      [  44  1  1  6  491  45  8  40  10  3  3  1  1131  107  425  11  ]
      [  42  1  1  5  915  55  8  40  7  3  3  1  1410  107  288  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  7  1  3  3  1684  107  300  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1582  107  -1  9  ]
      [  37  1  1  5  750  63  8  45  12  1  -1  1  1729  107  565  11  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1725  107  -1  14  ]
      [  38  1  1  5  779  72  8  35  -1  5  3  1  2292  107  -1  15  ]
      [  35  1  1  5  623  45  8  40  -1  3  5  1  2049  107  -1  12  ]
      [  32  1  1  5  881  64  8  40  11  5  9  1  2217  107  469  16  ]
      [  45  1  1  5  317  92  8  38  -1  1  3  1  2307  107  -1  18  ]
      [  41  1  1  6  440  45  8  40  11  1  1  1  2321  107  404  12  ]
      [  32  1  1  1  660  52  8  50  12  1  3  1  2487  107  407  13  ]
      [  46  1  1  4  801  75  1  39  16  3  4  1  2458  107  800  15  ]
      [  48  1  1  5  687  34  8  35  -1  3  5  1  3403  107  -1  15  ]
      [  48  1  1  9  801  75  1  40  -1  3  5  1  4148  107  -1  19  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1014  106  -1  11  ]
      [  33  2  1  5  853  85  1  20  12  2  5  1  963  106  530  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1191  106  -1  10  ]
      [  33  2  1  1  871  80  8  18  -1  5  1  1  1209  106  -1  7  ]
      [  41  1  1  6  269  45  8  40  -1  2  1  1  1209  106  -1  21  ]
      [  53  1  1  5  662  52  8  39  7  1  3  1  1477  106  270  19  ]
      [  69  1  8  2  401  15  8  5  -1  1  5  3  1392  106  -1  11  ]
      [  54  1  1  6  796  45  8  36  11  1  3  1  1436  106  500  13  ]
      [  31  2  1  5  662  52  8  19  10  1  3  1  1434  106  350  8  ]
      [  35  1  1  6  544  28  8  38  -1  2  4  1  1643  106  -1  10  ]
      [  37  2  1  5  622  72  8  30  -1  3  3  1  1805  106  -1  12  ]
      [  52  1  1  6  310  45  8  38  -1  3  3  1  1922  106  -1  10  ]
      [  38  1  1  5  714  60  8  40  -1  2  3  1  1804  106  -1  10  ]
      [  52  1  1  6  255  28  8  37  12  1  3  1  2225  106  535  14  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  3  3  2175  106  -1  14  ]
      [  45  1  1  5  310  33  8  40  14  1  3  1  2079  106  620  11  ]
      [  62  1  1  5  629  75  1  40  19  3  3  1  2124  106  800  16  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  5  3  3  2403  106  -1  13  ]
      [  41  1  1  5  612  62  8  40  -1  5  9  1  2434  106  -1  13  ]
      [  40  1  1  1  512  50  8  50  -1  1  5  1  3155  106  -1  14  ]
      [  41  1  1  4  873  80  1  39  -1  5  9  1  3022  106  -1  14  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  5  9  3  3154  106  -1  14  ]
      [  59  1  1  5  601  29  8  40  -1  4  8  1  3260  106  -1  18  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  3  99  3  3625  106  -1  18  ]
      [  56  1  1  5  774  99  8  40  13  5  8  1  4619  106  570  18  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  514  105  -1  7  ]
      [  29  2  8  -1  -1  -1  -1  -1  13  3  3  2  575  105  550  10  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  3  3  3  612  105  -1  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  2  5  3  548  105  -1  8  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  2  539  105  -1  9  ]
      [  57  1  1  5  802  75  1  24  -1  2  3  1  662  105  -1  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  1  -1  3  741  105  600  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  4  3  809  105  -1  14  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  758  105  -1  15  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  862  105  -1  9  ]
      [  36  1  8  -1  -1  -1  -1  -1  12  1  -1  2  995  105  500  8  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1099  105  0  10  ]
      [  42  2  1  5  863  85  8  25  -1  4  3  1  1028  105  -1  13  ]
      [  49  1  1  6  531  17  8  38  11  -1  -1  1  1089  105  500  13  ]
      [  53  1  1  5  672  52  8  38  -1  1  3  1  963  105  -1  9  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1041  105  -1  6  ]
      [  51  1  1  6  310  45  8  40  -1  2  3  1  949  105  -1  10  ]
      [  27  2  1  5  856  85  8  38  9  3  3  1  1213  105  400  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  2  3  3  1201  105  -1  8  ]
      [  27  1  1  6  488  45  8  40  10  1  3  1  1234  105  425  9  ]
      [  39  2  1  1  851  85  8  20  -1  5  3  1  1238  105  -1  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1153  105  -1  7  ]
      [  50  1  1  6  310  31  8  37  -1  1  3  1  1213  105  -1  12  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1205  105  -1  9  ]
      [  80  1  8  -1  -1  -1  -1  -1  10  1  3  3  1140  105  390  12  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1229  105  -1  11  ]
      [  36  1  1  5  854  85  8  40  -1  5  9  1  1279  105  540  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1468  105  700  12  ]
      [  38  1  1  6  714  93  8  60  14  3  3  1  1373  105  645  12  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1462  105  -1  11  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1453  105  -1  9  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1417  105  -1  15  ]
      [  32  1  1  6  744  51  8  40  -1  2  3  1  1390  105  -1  10  ]
      [  44  1  1  5  771  75  1  40  -1  3  6  1  1413  105  225  10  ]
      [  60  2  1  5  873  80  1  20  -1  1  6  1  1368  105  -1  8  ]
      [  58  1  1  1  886  91  8  40  -1  4  10  1  1347  105  -1  14  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1630  105  -1  10  ]
      [  47  1  1  6  254  34  8  35  11  1  4  1  1667  105  450  12  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1681  105  -1  14  ]
      [  29  1  1  6  742  21  8  40  -1  1  3  1  1669  105  -1  13  ]
      [  56  1  1  5  788  75  1  39  -1  1  4  1  1552  105  -1  18  ]
      [  39  1  1  6  545  1  1  37  -1  1  3  1  1645  105  -1  10  ]
      [  44  1  1  6  461  45  8  40  8  1  -1  1  1597  105  350  15  ]
      [  51  1  1  4  750  60  8  39  -1  1  3  1  1652  105  -1  13  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1635  105  -1  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1664  105  -1  9  ]
      [  47  1  1  6  254  28  8  40  -1  1  3  1  1586  105  -1  10  ]
      [  60  1  1  5  750  45  8  20  12  3  3  1  1540  105  600  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1672  105  -1  14  ]
      [  41  2  1  2  911  55  8  75  7  3  3  1  1563  105  246  13  ]
      [  37  1  1  5  620  34  8  28  -1  3  5  1  1763  105  -1  10  ]
      [  55  1  1  5  310  29  8  39  -1  1  3  1  1801  105  -1  15  ]
      [  39  1  1  6  714  15  8  60  9  1  3  1  1899  105  400  12  ]
      [  60  1  8  -1  -1  -1  -1  -1  7  1  3  3  1867  105  279  10  ]
      [  44  1  1  4  629  64  8  38  -1  5  3  1  2000  105  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1751  105  -1  11  ]
      [  31  1  1  6  623  45  8  40  14  4  5  1  1894  105  650  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  4  6  3  1827  105  -1  13  ]
      [  42  1  1  6  540  34  8  35  8  1  3  1  1837  105  360  12  ]
      [  69  1  8  -1  -1  -1  -1  -1  7  3  8  3  1822  105  315  10  ]
      [  34  1  1  5  621  29  8  40  -1  3  5  1  1845  105  -1  13  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1720  105  -1  15  ]
      [  31  1  1  5  254  28  8  50  13  2  3  1  2229  105  525  11  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  3  8  3  2127  105  -1  16  ]
      [  27  1  1  5  691  65  8  45  28  5  9  1  2234  105  1400  18  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2100  105  -1  12  ]
      [  39  1  1  6  779  66  8  37  10  3  3  1  2160  105  450  12  ]
      [  36  1  1  6  141  24  8  39  11  3  3  1  2146  105  500  14  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2157  105  -1  16  ]
      [  34  1  1  5  772  90  8  38  12  5  3  1  2239  105  550  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  10  5  7  3  2163  105  400  12  ]
      [  36  1  1  6  254  32  8  50  10  1  3  1  2483  105  400  12  ]
      [  46  1  1  5  814  66  1  38  -1  1  3  1  2544  105  -1  15  ]
      [  60  1  1  5  674  22  8  30  -1  5  3  1  2356  105  -1  14  ]
      [  58  1  8  5  512  34  8  40  -1  1  5  1  2388  105  -1  15  ]
      [  36  1  1  5  750  52  8  40  12  5  9  1  2438  105  600  18  ]
      [  40  1  1  5  602  32  8  38  -1  4  8  1  2358  105  -1  16  ]
      [  44  2  1  5  671  28  8  35  14  3  5  1  2700  105  660  13  ]
      [  46  2  1  4  874  80  1  40  -1  5  9  1  2663  105  -1  13  ]
      [  52  1  1  2  273  29  8  60  -1  3  4  1  3070  105  -1  14  ]
      [  48  1  1  5  831  92  1  36  14  5  9  1  3108  105  550  16  ]
      [  40  1  1  4  870  80  1  40  -1  5  9  1  3331  105  -1  15  ]
      [  50  1  1  5  881  29  8  40  -1  5  8  1  5515  105  -1  20  ]
      [  62  1  8  -1  -1  -1  -1  -1  12  1  3  6  214  104  500  7  ]
      [  37  1  8  -1  -1  -1  -1  -1  -1  2  5  2  575  104  -1  10  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1098  104  -1  6  ]
      [  66  1  8  3  996  29  8  20  -1  1  5  3  1063  104  -1  6  ]
      [  32  1  1  5  880  73  8  40  13  5  9  1  916  104  540  17  ]
      [  33  2  8  -1  -1  -1  -1  -1  -1  2  3  8  1009  104  -1  10  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  984  104  -1  8  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1167  104  -1  11  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1194  104  -1  8  ]
      [  63  1  1  5  512  34  8  35  -1  -1  -1  1  1259  104  -1  12  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  3  -1  3  1194  104  -1  10  ]
      [  37  1  1  6  254  45  8  38  14  1  3  1  1292  104  650  9  ]
      [  33  1  1  6  179  22  8  37  10  3  3  1  1214  104  460  12  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1164  104  -1  18  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1199  104  -1  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1239  104  -1  7  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1314  104  -1  10  ]
      [  62  2  1  1  875  80  8  20  -1  5  9  1  1364  104  -1  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1477  104  -1  11  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1442  104  -1  12  ]
      [  47  2  1  5  864  85  8  30  7  1  3  1  1327  104  300  8  ]
      [  48  1  1  5  550  29  8  39  -1  5  9  1  1436  104  -1  14  ]
      [  28  1  1  6  540  28  8  40  10  2  3  1  1440  104  428  14  ]
      [  57  1  1  6  796  29  8  40  -1  2  3  1  1381  104  -1  10  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1515  104  -1  9  ]
      [  54  1  1  5  269  29  8  45  8  1  3  1  1521  104  320  9  ]
      [  41  1  1  5  854  85  1  39  -1  3  3  1  1669  104  -1  14  ]
      [  56  1  1  5  671  51  8  39  -1  3  3  1  1669  104  -1  11  ]
      [  44  1  1  5  787  75  1  38  -1  1  3  1  1647  104  -1  15  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1510  104  -1  12  ]
      [  95  2  8  -1  -1  -1  -1  -1  8  1  -1  3  1638  104  378  9  ]
      [  49  2  1  5  885  80  1  40  12  5  9  1  1548  104  421  9  ]
      [  36  1  1  2  411  55  8  98  9  3  5  1  1717  104  400  12  ]
      [  37  1  1  6  194  28  8  35  -1  3  5  1  1741  104  -1  15  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1740  104  -1  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1818  104  -1  10  ]
      [  46  1  1  6  714  51  8  38  -1  1  3  1  1704  104  -1  13  ]
      [  39  2  1  5  787  75  1  40  12  2  6  1  1947  104  530  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  7  4  7  3  2108  104  300  13  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2033  104  -1  11  ]
      [  49  1  1  6  531  34  8  35  -1  3  2  1  2284  104  -1  15  ]
      [  32  1  1  5  775  72  8  55  10  5  9  1  2101  104  427  12  ]
      [  26  2  1  5  780  52  8  38  13  4  3  1  2497  104  500  15  ]
      [  45  1  1  4  801  75  1  40  -1  3  3  1  2509  104  -1  16  ]
      [  53  2  1  4  870  80  1  38  -1  5  9  1  2540  104  -1  12  ]
      [  33  1  1  5  691  65  8  39  15  5  3  1  2987  104  600  18  ]
      [  44  1  1  5  776  66  8  38  -1  5  5  1  3327  104  -1  15  ]
      [  60  1  1  5  841  85  8  40  -1  5  10  1  3535  104  -1  22  ]
      [  55  1  1  5  777  31  8  40  -1  1  3  1  3746  104  -1  18  ]
      [  40  1  1  5  772  70  8  40  -1  5  3  1  4668  104  -1  18  ]
      [  31  1  1  5  788  65  8  39  18  5  8  1  5890  104  840  21  ]
      [  38  2  1  6  992  93  8  12  9  1  -1  1  317  103  330  8  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  771  103  -1  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  5  9  3  955  103  -1  11  ]
      [  35  1  1  6  714  63  8  40  14  5  8  1  1300  103  560  10  ]
      [  41  1  1  6  222  29  8  40  10  4  8  1  1278  103  400  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1191  103  0  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  1  3  3  1466  103  366  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  17  1  3  3  1481  103  800  9  ]
      [  36  1  1  5  788  75  8  40  -1  3  3  1  1660  103  -1  15  ]
      [  60  1  1  2  488  45  8  40  -1  1  3  1  1568  103  -1  10  ]
      [  47  1  1  5  774  80  8  39  12  5  99  1  1787  103  500  13  ]
      [  56  1  1  4  765  93  1  39  -1  4  8  1  1903  103  -1  14  ]
      [  60  1  1  5  835  92  1  14  7  1  3  1  1798  103  265  17  ]
      [  39  1  1  6  201  27  8  40  9  -1  -1  1  2230  103  360  11  ]
      [  57  1  1  2  852  85  8  65  -1  1  5  1  2136  103  -1  15  ]
      [  38  2  1  5  787  75  1  38  13  2  3  1  2075  103  500  13  ]
      [  52  1  1  5  620  45  8  37  14  5  8  1  2540  103  650  12  ]
      [  23  1  1  6  540  36  8  40  12  9  3  1  2399  103  540  14  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  3  8  3  2478  103  -1  13  ]
      [  43  1  1  5  821  22  8  39  15  5  9  1  2454  103  700  13  ]
      [  71  1  8  -1  -1  -1  -1  -1  15  5  10  3  2587  103  620  12  ]
      [  44  2  1  5  764  91  8  40  14  2  3  1  2416  103  600  15  ]
      [  47  1  1  5  721  61  8  40  12  5  9  1  3885  103  460  20  ]
      [  20  1  8  -1  -1  -1  -1  -1  -1  3  -1  8  190  102  -1  2  ]
      [  34  1  8  -1  -1  -1  -1  -1  10  1  3  6  352  102  404  7  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  627  102  -1  4  ]
      [  53  2  1  5  856  85  8  13  11  5  5  1  655  102  505  4  ]
      [  34  1  1  8  853  85  8  39  14  5  9  1  515  102  570  10  ]
      [  54  2  8  -1  -1  -1  -1  -1  -1  1  -1  6  630  102  -1  15  ]
      [  18  1  8  -1  -1  -1  -1  -1  7  -1  -1  4  812  102  271  5  ]
      [  45  1  1  6  501  20  8  40  7  2  3  1  842  102  250  10  ]
      [  30  1  1  6  268  45  8  37  -1  1  3  1  949  102  0  6  ]
      [  47  1  1  6  480  45  8  42  -1  5  3  1  983  102  -1  11  ]
      [  27  1  1  6  501  36  8  40  -1  2  3  1  1031  102  -1  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1117  102  -1  12  ]
      [  50  1  1  1  995  70  8  40  15  2  3  1  1261  102  700  17  ]
      [  35  2  1  5  787  75  1  40  8  2  3  1  1256  102  340  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1381  102  -1  8  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1490  102  -1  13  ]
      [  40  2  1  5  789  85  8  40  -1  3  3  1  1438  102  -1  15  ]
      [  75  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1451  102  475  12  ]
      [  36  1  1  6  24  1  8  40  -1  2  3  1  1458  102  -1  13  ]
      [  31  1  1  5  629  27  8  35  -1  1  4  1  1573  102  -1  13  ]
      [  34  1  1  5  801  75  1  38  16  4  4  1  1642  102  700  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1870  102  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  11  1  4  3  1756  102  394  15  ]
      [  59  1  8  5  651  34  8  29  -1  1  3  8  2078  102  -1  11  ]
      [  54  1  1  6  620  29  8  38  -1  1  3  1  2006  102  -1  11  ]
      [  55  1  1  6  221  35  8  37  -1  1  3  1  2289  102  -1  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2498  102  -1  22  ]
      [  58  1  1  5  874  80  1  38  -1  5  9  1  2766  102  -1  15  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2808  102  -1  15  ]
      [  49  1  1  5  623  29  8  60  -1  1  3  1  3863  102  -1  16  ]
      [  53  1  1  5  993  34  8  37  -1  1  3  1  4361  102  -1  20  ]
      [  39  1  1  5  881  24  8  39  -1  5  5  1  5669  102  -1  20  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  3  3  810  101  -1  8  ]
      [  34  1  1  5  791  74  8  60  13  1  -1  1  985  101  469  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  10  1  -1  3  968  101  386  17  ]
      [  42  2  1  5  788  66  8  25  -1  1  3  1  1076  101  351  13  ]
      [  61  1  1  5  801  75  1  38  11  1  99  1  1028  101  450  10  ]
      [  51  1  8  -1  -1  -1  -1  -1  -1  2  3  2  1063  101  -1  10  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1374  101  -1  10  ]
      [  52  1  1  5  853  85  1  38  -1  3  4  1  1644  101  -1  16  ]
      [  32  1  1  6  540  25  8  39  -1  1  3  1  1745  101  -1  13  ]
      [  52  2  1  4  873  80  1  38  -1  5  9  1  2473  101  -1  12  ]
      [  37  1  1  9  801  75  1  50  10  3  3  1  2544  101  454  13  ]
      [  81  1  8  -1  -1  -1  -1  -1  18  3  3  5  2611  101  730  13  ]
      [  42  1  1  5  775  72  8  40  -1  5  9  1  3007  101  -1  19  ]
      [  63  1  1  4  788  75  1  39  -1  4  7  1  4467  101  -1  17  ]
      [  40  1  1  5  750  51  8  40  18  5  9  1  13813  101  770  23  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  1  1  3  76  100  -1  2  ]
      [  31  1  1  1  261  45  8  50  -1  1  3  1  134  100  -1  3  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  283  100  -1  2  ]
      [  30  2  1  1  670  74  8  15  14  3  3  1  181  100  650  12  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  232  100  0  2  ]
      [  41  2  8  -1  -1  -1  -1  -1  14  1  3  8  183  100  550  18  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  199  100  -1  10  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  378  100  -1  5  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  367  100  -1  8  ]
      [  31  2  1  6  661  52  8  20  12  1  3  1  439  100  525  10  ]
      [  22  1  1  11  714  91  1  38  -1  4  -1  1  461  100  200  3  ]
      [  86  1  8  -1  -1  -1  -1  -1  -1  1  3  3  300  100  -1  4  ]
      [  59  2  8  -1  -1  -1  -1  -1  9  1  4  2  464  100  350  12  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  418  100  0  3  ]
      [  25  1  1  6  531  75  8  38  8  -1  -1  1  367  100  350  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  403  100  -1  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  454  100  -1  3  ]
      [  23  1  8  -1  -1  -1  -1  -1  -1  5  -1  8  370  100  -1  3  ]
      [  25  2  8  -1  -1  -1  -1  -1  -1  5  3  3  377  100  -1  3  ]
      [  21  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  461  100  -1  3  ]
      [  27  2  8  -1  -1  -1  -1  -1  -1  5  -1  8  399  100  -1  3  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  4  3  416  100  -1  3  ]
      [  48  2  1  5  660  52  8  25  -1  2  3  1  423  100  -1  9  ]
      [  21  1  1  11  994  85  1  40  -1  3  3  1  476  100  -1  3  ]
      [  50  1  1  1  687  51  8  60  -1  2  5  1  383  100  -1  11  ]
      [  41  2  8  -1  -1  -1  -1  -1  -1  1  3  3  573  100  -1  5  ]
      [  65  2  1  3  796  23  8  5  6  -1  -1  3  551  100  220  4  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  545  100  -1  10  ]
      [  33  1  8  -1  -1  -1  -1  -1  -1  5  3  8  661  100  -1  4  ]
      [  44  1  1  2  672  52  8  80  17  1  8  1  624  100  525  4  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  1  3  2  669  100  -1  6  ]
      [  42  2  1  5  853  85  8  20  13  5  4  1  576  100  550  6  ]
      [  35  2  1  5  780  10  8  27  -1  3  4  1  603  100  -1  11  ]
      [  46  1  8  -1  -1  -1  -1  -1  -1  1  3  2  573  100  -1  4  ]
      [  50  1  1  5  660  52  8  21  -1  1  3  1  623  100  -1  11  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  678  100  -1  4  ]
      [  45  2  1  5  863  80  1  25  -1  1  3  1  511  100  -1  8  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  538  100  -1  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  543  100  -1  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  554  100  -1  4  ]
      [  82  1  8  -1  -1  -1  -1  -1  9  1  4  3  584  100  400  10  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  552  100  -1  6  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  644  100  -1  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  591  100  -1  4  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  655  100  -1  10  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  558  100  -1  4  ]
      [  27  2  1  1  662  52  8  18  -1  4  3  1  518  100  -1  4  ]
      [  29  1  8  -1  -1  -1  -1  -1  25  5  -1  4  542  100  1200  4  ]
      [  21  2  1  6  784  51  8  4  -1  5  -1  4  665  100  -1  4  ]
      [  93  2  8  -1  -1  -1  -1  -1  13  1  -1  3  527  100  600  4  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  649  100  -1  4  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  656  100  0  4  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  662  100  -1  4  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  1  3  3  700  100  -1  4  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  5  3  569  100  -1  5  ]
      [  41  2  1  5  853  85  8  2  11  5  3  1  567  100  480  4  ]
      [  43  1  1  1  501  45  8  40  -1  2  4  1  598  100  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  623  100  -1  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  655  100  -1  8  ]
      [  57  1  1  2  911  55  8  40  -1  1  3  1  602  100  0  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  9  1  3  3  672  100  360  11  ]
      [  39  1  1  6  310  29  8  40  5  2  3  1  608  100  183  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  636  100  -1  13  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  1  3  745  100  -1  5  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  800  100  -1  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  841  100  -1  5  ]
      [  64  2  8  6  411  55  8  7  -1  1  -1  3  725  100  130  5  ]
      [  28  1  8  -1  -1  -1  -1  -1  -1  1  3  2  735  100  -1  5  ]
      [  44  1  8  -1  -1  -1  -1  -1  -1  3  3  2  846  100  409  6  ]
      [  62  1  1  6  51  85  8  4  -1  1  3  3  796  100  -1  5  ]
      [  46  2  1  5  660  52  8  80  -1  -1  -1  1  868  100  -1  5  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  787  100  0  9  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  5  5  3  882  100  -1  5  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  3  3  3  798  100  -1  5  ]
      [  52  2  8  -1  -1  -1  -1  -1  -1  1  3  3  711  100  -1  10  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  1  3  3  750  100  0  5  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  1  3  704  100  -1  8  ]
      [  39  1  8  -1  -1  -1  -1  -1  8  1  3  2  716  100  340  11  ]
      [  39  2  1  5  789  80  1  17  -1  3  3  1  855  100  -1  12  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  890  100  -1  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  737  100  -1  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  700  100  -1  5  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  818  100  -1  15  ]
      [  43  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  826  100  -1  10  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  804  100  -1  8  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  868  100  -1  5  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  783  100  -1  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  780  100  -1  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  2  757  100  -1  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  12  9  -1  3  751  100  469  8  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  717  100  -1  5  ]
      [  23  2  1  5  853  85  1  38  9  3  -1  1  788  100  358  5  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  788  100  -1  16  ]
      [  42  2  1  5  142  85  8  37  -1  1  3  1  899  100  525  12  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  801  100  -1  5  ]
      [  34  1  1  2  391  15  8  40  -1  1  5  1  707  100  -1  8  ]
      [  22  1  1  6  511  45  8  40  -1  1  3  1  783  100  -1  5  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  876  100  -1  14  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  844  100  -1  9  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  817  100  -1  5  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  1  3  721  100  0  5  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  811  100  -1  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  842  100  -1  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  866  100  -1  9  ]
      [  21  1  1  6  441  45  8  40  9  1  3  1  777  100  322  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  723  100  -1  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  7  1  3  3  713  100  300  10  ]
      [  36  1  1  2  482  45  8  60  -1  5  3  1  730  100  -1  13  ]
      [  53  1  1  6  23  1  8  40  -1  2  -1  1  800  100  -1  8  ]
      [  31  2  1  4  870  80  1  16  -1  2  3  1  816  100  -1  7  ]
      [  41  1  8  -1  -1  -1  -1  -1  -1  1  3  2  921  100  -1  16  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  945  100  -1  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1075  100  -1  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1067  100  -1  6  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1050  100  -1  7  ]
      [  61  2  1  4  997  75  1  20  -1  -1  -1  1  1081  100  -1  6  ]
      [  40  2  1  5  902  93  8  14  -1  1  3  3  1017  100  -1  10  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  912  100  -1  11  ]
      [  69  2  1  5  661  51  8  18  -1  -1  -1  3  1069  100  -1  12  ]
      [  59  1  1  1  837  74  8  50  -1  3  3  1  918  100  -1  12  ]
      [  61  1  8  -1  -1  -1  -1  -1  9  -1  -1  8  912  100  300  11  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1000  100  0  6  ]
      [  36  1  1  6  742  15  8  40  -1  -1  -1  1  1090  100  -1  10  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  905  100  -1  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1048  100  -1  12  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  3  3  3  953  100  -1  7  ]
      [  57  1  8  -1  -1  -1  -1  -1  10  1  3  3  946  100  380  12  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1022  100  -1  18  ]
      [  31  2  1  5  780  85  8  38  -1  3  3  1  1009  100  -1  15  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1031  100  -1  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1032  100  -1  6  ]
      [  24  2  1  5  53  52  8  40  3  1  -1  1  1008  100  120  12  ]
      [  78  2  8  -1  -1  -1  -1  -1  7  1  -1  3  1049  100  250  18  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1057  100  0  6  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  961  100  -1  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  944  100  -1  6  ]
      [  48  1  1  6  310  91  1  39  -1  1  3  1  966  100  -1  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1039  100  -1  7  ]
      [  37  1  1  5  689  51  8  50  11  9  5  1  1072  100  400  11  ]
      [  50  2  1  5  780  27  8  10  -1  1  3  3  972  100  -1  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1011  100  -1  8  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  980  100  -1  6  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  989  100  -1  6  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1004  100  -1  6  ]
      [  63  1  1  6  714  85  8  4  -1  1  3  3  935  100  -1  12  ]
      [  45  2  1  5  662  52  8  23  13  1  3  1  1015  100  590  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  10  9  -1  3  981  100  400  12  ]
      [  56  2  8  -1  -1  -1  -1  -1  -1  1  3  3  964  100  -1  17  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1023  100  -1  11  ]
      [  36  1  1  1  487  20  8  50  -1  3  5  1  1047  100  -1  10  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  99  3  996  100  -1  11  ]
      [  23  1  1  6  287  29  8  40  -1  1  3  1  1093  100  -1  6  ]
      [  42  1  1  2  441  45  8  60  -1  1  5  1  1068  100  -1  10  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1019  100  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  962  100  -1  19  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1015  100  -1  6  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1021  100  -1  8  ]
      [  53  1  1  5  663  15  8  40  -1  2  3  1  1051  100  -1  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  916  100  -1  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  947  100  -1  15  ]
      [  60  1  1  2  172  22  8  40  -1  1  5  1  1005  100  -1  9  ]
      [  43  1  1  6  714  26  8  40  -1  2  3  1  905  100  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1071  100  -1  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1015  100  -1  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  929  100  -1  6  ]
      [  38  1  1  4  801  75  1  48  -1  2  6  1  966  100  -1  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  967  100  -1  12  ]
      [  42  2  1  6  522  52  8  31  -1  2  3  1  1049  100  -1  9  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  985  100  -1  6  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  2  3  1046  100  -1  11  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  959  100  -1  11  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  919  100  -1  6  ]
      [  46  1  1  6  273  60  8  38  -1  -1  -1  1  930  100  -1  11  ]
      [  38  1  1  5  268  45  8  40  -1  2  3  1  1079  100  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1025  100  -1  13  ]
      [  41  1  8  -1  -1  -1  -1  -1  -1  2  3  8  907  100  -1  9  ]
      [  52  2  1  2  901  93  8  40  10  2  3  1  1078  100  360  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  10  1  3  3  914  100  420  10  ]
      [  90  1  8  -1  -1  -1  -1  -1  -1  1  99  3  1157  100  0  11  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1212  100  -1  7  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1258  100  -1  11  ]
      [  37  1  1  6  796  70  8  39  -1  3  3  1  1133  100  0  12  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1223  100  -1  8  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1260  100  -1  7  ]
      [  42  1  1  6  501  45  8  39  -1  1  3  1  1237  100  -1  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1161  100  -1  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1152  100  -1  7  ]
      [  53  2  1  6  931  93  8  32  -1  1  -1  1  1239  100  -1  7  ]
      [  43  2  1  5  915  65  8  32  -1  1  3  1  1233  100  -1  15  ]
      [  46  2  1  5  836  52  8  39  -1  -1  -1  1  1237  100  -1  7  ]
      [  25  1  1  5  780  52  8  38  -1  3  3  1  1254  100  0  9  ]
      [  31  2  1  5  788  72  8  40  7  5  3  1  1120  100  290  7  ]
      [  55  1  8  -1  -1  -1  -1  -1  7  4  3  2  1299  100  280  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  1  3  3  1109  100  375  7  ]
      [  52  1  1  2  672  52  8  38  -1  3  4  1  1182  100  -1  11  ]
      [  74  2  8  -1  -1  -1  -1  -1  14  1  3  3  1125  100  600  7  ]
      [  55  1  1  6  501  92  8  38  -1  1  3  1  1189  100  425  11  ]
      [  51  1  1  6  714  75  1  40  -1  1  -1  1  1135  100  -1  12  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1152  100  -1  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1191  100  -1  7  ]
      [  91  1  8  -1  -1  -1  -1  -1  -1  5  5  3  1197  100  -1  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1275  100  -1  10  ]
      [  48  1  1  6  742  26  8  40  -1  1  3  1  1216  100  -1  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1136  100  -1  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1170  100  0  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  9  1  3  3  1238  100  336  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1158  100  -1  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1195  100  -1  7  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1128  100  -1  7  ]
      [  56  1  1  6  714  52  8  39  -1  1  3  1  1161  100  -1  12  ]
      [  23  1  1  5  854  85  8  45  -1  5  3  1  1227  100  -1  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1131  100  -1  8  ]
      [  40  2  1  2  841  85  8  30  11  5  10  1  1157  100  396  7  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1250  100  -1  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1281  100  -1  12  ]
      [  47  1  1  6  714  63  8  40  -1  1  3  1  1294  100  -1  11  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1283  100  -1  7  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1179  100  -1  14  ]
      [  49  2  1  5  787  74  1  38  -1  3  1  1  1216  100  -1  7  ]
      [  37  1  1  5  676  51  8  40  21  1  -1  1  1159  100  880  10  ]
      [  28  1  1  6  310  52  8  37  5  1  3  1  1128  100  175  9  ]
      [  52  1  1  6  281  50  8  39  -1  1  3  1  1205  100  -1  9  ]
      [  37  2  1  5  692  66  8  30  9  5  3  1  1194  100  400  7  ]
      [  59  1  1  6  471  75  1  37  -1  1  3  1  1300  100  -1  7  ]
      [  37  2  1  5  780  50  8  41  -1  1  3  1  1231  100  0  7  ]
      [  52  1  1  6  511  34  8  35  -1  1  3  1  1160  100  -1  11  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1159  100  -1  11  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1169  100  0  7  ]
      [  72  1  8  3  14  1  8  30  1  1  3  3  1191  100  40  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1137  100  -1  8  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1135  100  -1  7  ]
      [  44  1  1  5  795  92  1  45  -1  2  6  1  1264  100  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1184  100  -1  7  ]
      [  40  1  1  6  290  28  8  40  14  3  3  1  1261  100  550  7  ]
      [  30  1  1  6  488  45  8  39  10  2  5  1  1192  100  450  12  ]
      [  36  1  1  6  391  15  8  30  12  1  3  1  1249  100  500  8  ]
      [  38  2  1  5  789  26  8  28  -1  1  1  1  1261  100  -1  7  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1206  100  -1  7  ]
      [  47  1  1  6  714  28  8  38  9  2  3  1  1248  100  325  7  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1133  100  -1  20  ]
      [  48  2  1  5  662  52  8  20  -1  1  3  1  1241  100  -1  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1132  100  -1  7  ]
      [  46  1  1  6  441  45  8  40  13  1  3  1  1217  100  600  12  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  4  5  3  1222  100  -1  10  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1209  100  -1  21  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1249  100  -1  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1219  100  -1  9  ]
      [  44  1  1  1  841  85  8  13  14  5  9  1  1250  100  555  7  ]
      [  38  2  1  5  789  75  1  29  -1  2  6  1  1300  100  -1  13  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1132  100  -1  7  ]
      [  61  1  1  5  632  75  1  40  -1  1  3  1  1125  100  -1  9  ]
      [  41  1  1  5  662  52  8  40  -1  2  3  1  1190  100  -1  11  ]
      [  31  1  1  1  796  93  8  40  -1  2  3  1  1278  100  -1  12  ]
      [  54  1  1  6  511  45  8  39  -1  2  3  1  1123  100  -1  15  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1136  100  -1  12  ]
      [  50  1  1  2  750  63  8  40  -1  2  3  1  1109  100  -1  17  ]
      [  29  1  1  6  281  50  8  40  7  2  3  1  1281  100  260  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  6  8  1204  100  -1  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1261  100  -1  11  ]
      [  50  1  1  5  652  91  8  40  -1  3  5  1  1103  100  -1  16  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  4  1110  100  -1  10  ]
      [  32  2  1  6  221  28  8  38  12  2  3  1  1269  100  500  12  ]
      [  50  1  1  6  714  63  8  40  21  2  3  1  1158  100  605  12  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1191  100  -1  9  ]
      [  40  1  1  6  268  45  8  40  -1  2  3  1  1272  100  -1  15  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  5  4  3  1372  100  -1  8  ]
      [  36  1  1  6  935  90  1  42  13  4  3  1  1333  100  500  8  ]
      [  51  1  1  5  692  66  8  38  -1  3  3  1  1338  100  -1  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1333  100  -1  11  ]
      [  32  1  1  6  281  34  8  40  9  1  3  1  1382  100  368  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1357  100  -1  9  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1462  100  0  8  ]
      [  25  2  1  5  691  65  8  39  15  5  3  1  1493  100  665  13  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1441  100  -1  8  ]
      [  45  1  1  6  283  35  8  35  -1  1  3  1  1374  100  -1  10  ]
      [  39  1  1  5  780  63  8  48  -1  3  3  1  1375  100  -1  12  ]
      [  61  1  1  6  461  45  8  38  8  1  3  1  1360  100  306  12  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1412  100  -1  12  ]
      [  39  1  1  6  796  91  8  45  11  1  3  1  1375  100  400  9  ]
      [  69  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  1433  100  469  13  ]
      [  46  2  1  5  692  66  8  38  19  3  3  1  1327  100  880  13  ]
      [  61  1  1  2  179  22  8  40  10  1  3  1  1481  100  421  17  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1449  100  -1  8  ]
      [  81  1  8  -1  -1  -1  -1  -1  13  1  -1  3  1430  100  510  8  ]
      [  42  2  1  5  787  75  1  38  17  3  3  1  1414  100  600  14  ]
      [  42  1  1  6  281  50  8  40  17  1  3  1  1451  100  600  14  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1439  100  -1  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1319  100  -1  8  ]
      [  45  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1391  100  -1  13  ]
      [  56  2  1  5  672  52  8  19  13  1  3  1  1401  100  610  15  ]
      [  86  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1354  100  -1  15  ]
      [  55  1  1  6  201  29  8  40  11  1  3  1  1464  100  450  13  ]
      [  40  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1346  100  -1  8  ]
      [  49  1  1  6  522  52  8  46  7  1  3  1  1422  100  320  8  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1456  100  -1  8  ]
      [  23  1  1  6  521  29  8  40  10  1  3  1  1387  100  400  8  ]
      [  39  1  1  2  411  55  8  60  -1  1  3  1  1330  100  -1  12  ]
      [  78  1  8  -1  -1  -1  -1  -1  13  1  3  3  1419  100  530  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1490  100  -1  13  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1406  100  -1  8  ]
      [  60  1  8  -1  -1  -1  -1  -1  16  1  3  3  1317  100  700  15  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1326  100  -1  10  ]
      [  49  1  1  5  135  28  8  38  -1  1  3  1  1386  100  -1  13  ]
      [  44  1  1  6  741  63  8  39  -1  1  3  1  1396  100  -1  12  ]
      [  40  1  1  6  287  50  8  40  9  1  3  1  1435  100  350  12  ]
      [  30  1  1  6  323  28  8  40  -1  1  -1  1  1408  100  -1  8  ]
      [  45  1  1  5  861  85  8  29  14  5  8  1  1459  100  600  14  ]
      [  31  1  1  6  501  45  8  38  -1  1  3  1  1488  100  -1  10  ]
      [  31  2  1  5  862  85  1  30  -1  3  3  1  1360  100  -1  8  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1415  100  -1  8  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1362  100  -1  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1480  100  -1  9  ]
      [  46  1  1  6  287  50  8  37  -1  1  3  1  1335  100  -1  12  ]
      [  34  2  1  5  787  91  8  40  -1  5  9  1  1352  100  580  17  ]
      [  37  1  1  5  714  63  8  98  -1  -1  -1  1  1339  100  -1  8  ]
      [  38  1  1  6  549  29  8  40  -1  3  8  1  1457  100  -1  10  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1401  100  -1  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1465  100  -1  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1373  100  -1  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1400  100  -1  10  ]
      [  58  2  1  1  673  52  8  40  16  1  3  1  1418  100  600  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1318  100  -1  8  ]
      [  39  1  1  6  273  29  8  37  7  1  3  1  1480  100  300  11  ]
      [  37  2  1  5  704  99  8  39  -1  1  3  1  1330  100  -1  8  ]
      [  48  1  1  5  780  50  8  38  11  3  3  1  1397  100  495  10  ]
      [  54  1  1  1  391  15  8  40  -1  1  5  1  1481  100  -1  17  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1307  100  -1  8  ]
      [  45  1  1  6  171  22  8  35  -1  1  3  1  1450  100  -1  12  ]
      [  39  1  1  6  310  45  8  38  -1  3  3  1  1467  100  -1  8  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1451  100  -1  12  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1440  100  -1  8  ]
      [  60  2  1  6  522  15  8  40  -1  1  -1  3  1407  100  -1  13  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1399  100  -1  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  3  6  3  1473  100  -1  13  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1319  100  -1  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1368  100  -1  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1360  100  -1  9  ]
      [  45  1  1  6  316  34  8  50  -1  2  5  1  1407  100  -1  11  ]
      [  44  1  1  6  101  45  8  40  -1  2  3  1  1425  100  -1  13  ]
      [  43  2  1  6  731  64  8  40  -1  2  1  1  1361  100  -1  15  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1303  100  -1  8  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  6  3  1310  100  -1  12  ]
      [  40  1  1  5  621  35  8  38  -1  1  4  1  1630  100  615  12  ]
      [  59  1  1  6  254  45  8  40  -1  1  4  1  1562  100  -1  14  ]
      [  36  2  1  5  642  74  8  39  -1  -1  -1  1  1638  100  -1  15  ]
      [  34  1  1  6  267  45  8  37  -1  3  99  1  1556  100  -1  16  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1570  100  -1  12  ]
      [  31  1  1  6  937  74  8  40  8  1  -1  1  1571  100  300  9  ]
      [  42  1  1  6  267  27  8  35  12  1  3  1  1570  100  400  10  ]
      [  43  1  1  5  753  74  8  39  -1  3  3  1  1500  100  -1  12  ]
      [  71  1  8  -1  -1  -1  -1  -1  12  1  3  3  1564  100  500  13  ]
      [  48  1  1  6  141  24  8  48  -1  1  3  1  1560  100  -1  9  ]
      [  56  1  1  5  620  75  1  39  -1  1  3  1  1654  100  -1  9  ]
      [  49  1  1  4  874  80  1  25  9  5  9  1  1580  100  375  9  ]
      [  35  1  1  6  714  74  8  45  -1  3  3  1  1624  100  -1  11  ]
      [  42  1  1  5  751  52  8  53  14  5  9  1  1672  100  560  14  ]
      [  34  1  1  5  633  24  8  38  -1  1  3  1  1535  100  -1  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1618  100  -1  10  ]
      [  57  1  1  4  814  75  1  40  -1  1  3  1  1669  100  -1  9  ]
      [  43  1  1  4  712  60  8  39  5  3  3  1  1525  100  197  18  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  4  3  3  1529  100  -1  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  9  1  -1  3  1637  100  380  10  ]
      [  31  1  1  5  692  65  8  50  18  5  3  1  1665  100  800  14  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  3  4  3  1650  100  -1  9  ]
      [  76  1  8  -1  -1  -1  -1  -1  16  3  3  3  1570  100  700  10  ]
      [  50  1  1  5  750  64  8  38  -1  4  4  1  1696  100  -1  13  ]
      [  32  1  1  5  608  22  8  42  14  5  9  1  1582  100  550  16  ]
      [  39  1  1  6  487  45  8  40  -1  1  3  1  1610  100  -1  14  ]
      [  52  1  1  5  441  45  8  40  -1  1  3  1  1680  100  -1  13  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1587  100  -1  10  ]
      [  49  1  1  5  787  75  1  39  14  1  3  1  1670  100  550  11  ]
      [  51  1  1  6  131  26  8  38  9  1  -1  1  1670  100  350  11  ]
      [  33  1  1  5  620  33  8  40  9  4  5  1  1611  100  410  9  ]
      [  54  1  1  6  756  24  8  38  -1  1  3  1  1681  100  -1  15  ]
      [  44  1  1  6  221  29  8  37  16  1  3  1  1614  100  650  11  ]
      [  42  1  1  5  692  66  8  40  -1  3  3  1  1543  100  -1  11  ]
      [  57  1  1  1  62  1  8  40  -1  1  3  1  1595  100  -1  9  ]
      [  36  1  1  5  785  34  8  40  10  5  4  1  1538  100  400  12  ]
      [  46  1  1  4  801  75  1  39  12  3  3  1  1667  100  500  15  ]
      [  36  1  1  5  254  13  8  38  -1  1  3  1  1583  100  -1  10  ]
      [  46  1  1  6  273  34  8  38  -1  1  3  1  1627  100  -1  11  ]
      [  57  1  8  -1  -1  -1  -1  -1  15  1  3  3  1646  100  600  9  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1506  100  -1  9  ]
      [  53  1  1  5  701  62  8  38  14  5  1  1  1615  100  600  13  ]
      [  42  2  1  5  857  85  1  38  9  3  5  1  1530  100  420  22  ]
      [  40  1  1  5  711  60  8  38  13  1  3  1  1648  100  560  14  ]
      [  58  2  1  5  788  52  8  20  -1  4  -1  1  1642  100  -1  9  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1656  100  -1  9  ]
      [  46  1  1  6  714  63  8  60  -1  1  3  1  1603  100  -1  14  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  5  3  1646  100  -1  11  ]
      [  50  1  1  5  691  65  8  38  -1  3  3  1  1669  100  -1  9  ]
      [  32  1  1  2  392  15  8  55  11  1  5  1  1534  100  430  12  ]
      [  32  1  1  6  540  34  8  40  -1  9  3  1  1662  100  -1  14  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1500  100  -1  10  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1585  100  -1  10  ]
      [  30  1  1  6  531  34  8  38  -1  1  -1  1  1510  100  -1  11  ]
      [  37  1  1  6  993  31  8  40  13  9  -1  1  1660  100  535  11  ]
      [  45  1  1  6  482  45  8  40  -1  2  3  1  1535  100  -1  10  ]
      [  47  2  8  -1  -1  -1  -1  -1  -1  2  3  5  1523  100  -1  9  ]
      [  36  1  1  4  787  75  1  40  -1  2  3  1  1604  100  -1  14  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1628  100  -1  12  ]
      [  48  1  1  5  676  52  8  40  -1  2  3  1  1667  100  -1  15  ]
      [  50  1  1  6  714  60  8  60  -1  2  3  1  1522  100  -1  13  ]
      [  46  2  1  5  784  66  8  10  -1  3  3  1  1739  100  -1  10  ]
      [  42  1  1  6  545  45  8  38  -1  1  -1  1  1701  100  -1  11  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1854  100  -1  11  ]
      [  47  2  8  -1  -1  -1  -1  -1  10  1  3  4  1941  100  400  12  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  8  3  1792  100  -1  12  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1956  100  -1  13  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1940  100  -1  18  ]
      [  56  1  1  5  677  52  8  40  8  3  3  1  1858  100  250  10  ]
      [  51  1  1  6  744  45  8  42  -1  1  3  1  1842  100  -1  12  ]
      [  37  1  1  6  255  28  8  38  9  1  5  1  1891  100  350  14  ]
      [  76  2  8  -1  -1  -1  -1  -1  10  3  3  3  1908  100  420  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1954  100  -1  12  ]
      [  61  1  1  6  540  26  8  35  -1  1  3  1  1735  100  -1  13  ]
      [  41  1  1  6  24  1  8  40  -1  1  -1  1  1984  100  -1  15  ]
      [  26  1  1  6  267  45  8  40  -1  1  3  1  1828  100  -1  10  ]
      [  43  1  1  5  661  52  8  40  13  1  3  1  1798  100  520  10  ]
      [  33  1  1  6  441  45  8  39  11  1  3  1  1725  100  300  14  ]
      [  34  1  1  4  801  75  1  38  11  4  3  1  1827  100  400  10  ]
      [  52  1  1  6  311  15  8  40  -1  1  3  1  1746  100  0  10  ]
      [  48  1  1  5  701  63  8  40  -1  3  3  1  1937  100  -1  14  ]
      [  48  1  1  5  775  72  8  40  -1  3  3  1  1969  100  -1  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1820  100  -1  11  ]
      [  36  1  1  5  780  24  8  40  16  3  3  1  1903  100  700  12  ]
      [  43  1  1  5  392  15  8  40  9  1  3  1  1858  100  400  15  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  -1  5  5  1877  100  -1  18  ]
      [  54  1  1  6  511  45  8  40  -1  1  3  1  1991  100  -1  17  ]
      [  46  1  1  6  531  63  8  40  -1  1  -1  1  1931  100  -1  10  ]
      [  47  1  1  6  540  31  8  38  -1  1  3  1  1879  100  -1  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1902  100  -1  10  ]
      [  28  1  1  5  672  52  8  39  6  1  3  1  1751  100  150  11  ]
      [  43  1  1  5  678  72  8  50  11  4  3  1  1790  100  400  15  ]
      [  24  1  1  6  141  24  8  42  -1  1  3  1  1897  100  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  1  -1  3  1948  100  600  10  ]
      [  50  1  1  4  787  75  1  39  12  1  3  1  1853  100  490  17  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1932  100  -1  17  ]
      [  34  1  1  5  267  52  8  39  -1  3  3  1  1788  100  -1  10  ]
      [  80  2  8  -1  -1  -1  -1  -1  7  1  3  3  1772  100  300  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1871  100  -1  11  ]
      [  48  1  1  5  780  45  8  38  -1  3  5  1  1967  100  -1  17  ]
      [  45  1  8  -1  -1  -1  -1  -1  16  1  1  2  1994  100  600  10  ]
      [  45  1  1  5  864  85  8  38  -1  1  3  1  1713  100  0  10  ]
      [  66  1  1  2  750  52  8  50  -1  1  3  3  1913  100  -1  14  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1981  100  -1  11  ]
      [  39  1  1  5  501  45  8  38  -1  1  3  1  1744  100  -1  10  ]
      [  46  1  1  5  142  85  8  48  12  9  -1  1  1910  100  366  10  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1876  100  0  11  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1800  100  -1  15  ]
      [  58  1  1  6  269  28  8  38  -1  1  3  1  1931  100  -1  10  ]
      [  41  1  1  6  471  75  1  38  -1  1  3  1  1816  100  -1  12  ]
      [  42  1  1  6  273  25  8  38  7  1  -1  1  1899  100  300  12  ]
      [  33  1  1  5  678  34  8  35  17  3  3  1  1764  100  740  12  ]
      [  51  1  1  6  290  29  8  35  -1  1  3  1  1948  100  -1  12  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1783  100  -1  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1752  100  -1  10  ]
      [  46  1  1  6  714  40  1  40  -1  1  4  1  1964  100  -1  13  ]
      [  41  1  1  6  442  26  8  39  12  1  3  1  1897  100  460  11  ]
      [  35  1  1  5  780  70  8  37  9  3  5  1  1783  100  350  10  ]
      [  53  1  1  5  875  80  1  50  10  1  8  1  1950  100  420  12  ]
      [  35  1  1  6  540  45  8  40  11  3  5  1  1808  100  440  12  ]
      [  32  1  1  6  621  29  8  37  7  1  3  1  1743  100  300  11  ]
      [  39  1  1  5  780  24  8  37  10  4  8  1  1781  100  400  16  ]
      [  33  1  1  6  267  45  8  39  -1  1  3  1  1925  100  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1927  100  -1  14  ]
      [  49  1  1  6  268  45  8  39  -1  1  3  1  1848  100  -1  13  ]
      [  54  1  1  5  853  85  8  29  11  3  5  1  1896  100  375  10  ]
      [  62  1  1  5  863  85  1  39  9  1  5  1  1779  100  350  13  ]
      [  42  1  1  5  641  45  8  38  -1  3  3  1  1717  100  -1  15  ]
      [  60  1  1  6  72  29  8  35  -1  1  3  1  1833  100  -1  11  ]
      [  48  2  1  6  531  24  8  24  -1  1  3  1  1720  100  -1  10  ]
      [  28  1  1  6  268  45  8  40  -1  1  3  1  1994  100  -1  12  ]
      [  39  1  1  6  264  27  8  40  -1  1  3  1  1991  100  -1  10  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1784  100  -1  10  ]
      [  48  1  1  6  714  51  8  40  13  1  3  1  1841  100  500  13  ]
      [  40  1  1  6  540  29  8  37  -1  1  3  1  1963  100  -1  12  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1785  100  -1  15  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1914  100  -1  10  ]
      [  33  2  1  5  171  22  8  40  13  5  9  1  1882  100  487  13  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  3  6  8  1982  100  -1  15  ]
      [  44  1  1  5  607  74  8  38  -1  5  9  1  1912  100  -1  13  ]
      [  49  1  1  2  750  45  8  40  -1  2  5  1  1890  100  -1  17  ]
      [  35  1  1  4  801  75  1  40  -1  5  3  1  1973  100  -1  10  ]
      [  53  1  1  6  521  26  8  38  -1  2  5  1  1964  100  -1  16  ]
      [  51  1  1  5  611  24  8  38  -1  5  6  1  1855  100  -1  15  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  4  7  3  2280  100  -1  13  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2087  100  -1  13  ]
      [  51  2  1  5  787  75  1  39  -1  3  3  1  2127  100  -1  11  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  4  3  3  2115  100  -1  11  ]
      [  68  1  1  5  780  51  8  15  -1  5  4  5  2123  100  -1  11  ]
      [  42  1  1  5  692  66  8  38  12  3  3  1  2199  100  490  11  ]
      [  30  1  1  2  670  55  8  50  -1  3  3  1  2039  100  0  11  ]
      [  43  1  1  5  878  80  8  40  -1  1  3  1  2126  100  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2131  100  -1  12  ]
      [  60  1  1  4  874  80  1  38  -1  4  9  1  2067  100  -1  11  ]
      [  50  1  1  5  780  28  8  40  -1  1  3  1  2008  100  -1  11  ]
      [  48  1  1  6  714  63  8  98  7  1  3  1  2235  100  276  14  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  4  5  3  2092  100  -1  12  ]
      [  46  1  1  5  787  75  1  38  -1  3  7  1  2270  100  -1  13  ]
      [  35  1  1  5  600  31  8  35  -1  4  8  1  2119  100  -1  11  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2037  100  -1  11  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  3  6  3  2165  100  -1  18  ]
      [  55  1  1  4  872  80  1  40  -1  5  10  1  2224  100  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  4  3  3  2178  100  -1  11  ]
      [  32  1  1  5  775  72  8  36  11  5  9  1  2062  100  450  13  ]
      [  45  1  1  5  602  34  8  28  -1  -1  99  1  2125  100  -1  11  ]
      [  43  1  1  5  813  91  1  39  5  5  8  1  2185  100  190  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2106  100  -1  15  ]
      [  57  1  1  6  311  63  8  35  -1  1  3  1  2200  100  -1  18  ]
      [  38  1  1  5  777  24  8  37  -1  3  3  1  2022  100  -1  14  ]
      [  27  1  1  6  488  45  8  70  -1  3  3  1  2296  100  0  12  ]
      [  34  1  1  6  714  63  8  42  -1  3  4  1  2183  100  -1  13  ]
      [  30  2  1  4  870  80  1  40  7  5  7  1  2089  100  300  18  ]
      [  46  1  1  5  785  28  8  40  -1  1  3  1  2232  100  -1  14  ]
      [  93  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2012  100  -1  15  ]
      [  38  1  1  4  802  75  1  52  -1  1  3  1  2071  100  -1  15  ]
      [  45  1  1  4  731  64  8  39  -1  1  3  1  2279  100  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  1  3  2222  100  -1  11  ]
      [  45  2  1  5  914  55  8  20  -1  3  3  1  2124  100  -1  14  ]
      [  48  1  1  5  604  75  1  40  -1  4  8  1  2236  100  -1  13  ]
      [  50  2  1  4  787  75  1  40  -1  -1  -1  1  2266  100  -1  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2068  100  0  11  ]
      [  31  2  1  4  870  80  1  38  17  5  3  1  2173  100  700  20  ]
      [  54  1  1  5  689  51  8  50  11  1  3  1  2159  100  450  12  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2096  100  -1  12  ]
      [  41  2  1  4  765  75  1  40  -1  5  7  1  2176  100  -1  11  ]
      [  41  2  1  5  789  91  8  40  13  1  4  1  2240  100  500  11  ]
      [  38  1  1  5  624  10  8  50  -1  3  5  1  2250  100  -1  11  ]
      [  39  1  1  4  801  75  1  40  -1  5  3  1  2293  100  -1  14  ]
      [  58  2  1  5  886  85  1  40  -1  5  9  1  2192  100  -1  16  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2451  100  -1  16  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2486  100  -1  13  ]
      [  64  1  1  2  662  93  8  40  10  1  4  1  2416  100  400  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2369  100  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  5  9  3  2385  100  675  12  ]
      [  40  2  1  5  861  85  8  40  13  3  3  1  2526  100  500  14  ]
      [  62  1  1  5  780  52  8  10  11  1  3  3  2437  100  390  13  ]
      [  38  1  1  5  141  24  8  38  -1  3  3  1  2434  100  -1  12  ]
      [  33  1  1  4  787  64  8  39  12  1  3  1  2375  100  510  13  ]
      [  56  1  1  4  801  75  1  39  9  3  4  1  2451  100  360  15  ]
      [  71  2  1  1  611  74  8  40  -1  5  9  1  2435  100  -1  12  ]
      [  51  1  1  5  652  80  1  40  -1  -1  -1  1  2530  100  -1  19  ]
      [  32  1  1  4  873  80  1  40  -1  5  9  1  2564  100  -1  12  ]
      [  57  1  1  5  703  62  8  48  -1  3  3  1  2570  100  500  12  ]
      [  57  1  1  4  870  80  1  40  -1  5  9  1  2391  100  -1  21  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2417  100  -1  13  ]
      [  45  2  1  5  671  24  8  38  -1  3  -1  1  2326  100  -1  16  ]
      [  41  1  1  6  714  60  8  60  -1  1  3  1  2580  100  -1  14  ]
      [  34  1  1  5  603  75  1  38  -1  5  8  1  2464  100  0  12  ]
      [  50  1  1  6  270  29  8  35  -1  1  3  1  2464  100  -1  13  ]
      [  51  1  1  5  788  35  8  35  -1  1  3  1  2522  100  -1  12  ]
      [  39  1  1  6  310  45  8  40  17  3  3  1  2342  100  750  13  ]
      [  52  1  1  4  801  75  1  40  -1  3  5  1  2384  100  -1  14  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2600  100  -1  17  ]
      [  30  1  1  4  811  75  1  40  16  5  9  1  2583  100  600  15  ]
      [  33  2  1  5  689  24  8  38  -1  -1  -1  1  2533  100  -1  12  ]
      [  55  1  1  4  884  75  1  40  -1  2  3  1  2522  100  -1  14  ]
      [  53  1  1  6  663  15  8  50  -1  9  -1  1  2888  100  -1  13  ]
      [  48  1  1  5  652  34  8  29  -1  3  5  1  2886  100  -1  16  ]
      [  44  1  1  5  772  15  8  38  -1  1  3  1  2848  100  -1  14  ]
      [  40  1  1  5  622  33  8  55  -1  1  3  1  2651  100  -1  16  ]
      [  40  1  1  4  801  75  1  38  -1  5  7  1  2720  100  0  13  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2727  100  -1  13  ]
      [  52  1  1  5  600  75  1  45  -1  5  3  1  2791  100  -1  13  ]
      [  63  1  1  4  882  80  1  40  -1  5  9  1  2803  100  -1  13  ]
      [  45  2  1  5  869  85  8  55  -1  3  4  1  2839  100  124  13  ]
      [  63  1  1  2  901  93  8  70  -1  1  5  1  2682  100  -1  13  ]
      [  48  1  1  5  691  65  8  40  -1  4  8  1  2826  100  -1  13  ]
      [  53  2  1  5  841  85  8  70  18  5  -1  1  2871  100  750  13  ]
      [  26  1  1  5  174  22  8  35  18  1  3  1  2785  100  770  17  ]
      [  32  1  1  5  316  26  8  50  -1  1  5  1  2847  100  -1  14  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2917  100  0  15  ]
      [  37  1  1  5  788  75  1  39  13  5  5  1  3124  100  570  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  3000  100  -1  14  ]
      [  35  1  1  5  662  50  8  40  10  3  3  1  2985  100  366  16  ]
      [  41  1  1  2  911  55  8  40  17  1  3  1  3189  100  700  14  ]
      [  49  1  1  5  600  73  1  39  -1  4  8  1  2919  100  -1  15  ]
      [  43  1  1  6  135  33  8  36  12  1  3  1  3179  100  450  21  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  9  3  3091  100  -1  15  ]
      [  47  1  1  5  411  55  8  60  -1  3  3  1  2964  100  -1  21  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  3  3174  100  -1  14  ]
      [  48  1  1  1  821  92  8  60  22  5  10  1  2986  100  1000  14  ]
      [  50  1  1  5  316  29  8  40  -1  1  5  1  2909  100  -1  14  ]
      [  38  1  1  2  704  67  8  50  -1  5  -1  1  3076  100  590  21  ]
      [  54  1  1  4  871  75  1  60  21  5  9  1  2937  100  880  14  ]
      [  31  1  1  2  701  63  8  60  13  4  99  1  2940  100  540  19  ]
      [  45  1  1  5  751  72  8  60  -1  5  9  1  3354  100  -1  16  ]
      [  52  1  1  5  750  85  8  35  -1  5  -1  1  3498  100  -1  20  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  3274  100  -1  15  ]
      [  55  1  1  4  764  75  1  38  15  5  9  1  3300  100  675  22  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  4  3  3  3361  100  -1  16  ]
      [  53  1  1  5  751  51  8  40  -1  3  8  1  3260  100  -1  15  ]
      [  37  1  1  1  282  29  8  50  -1  3  5  1  3419  100  0  15  ]
      [  46  1  1  5  780  93  8  60  -1  5  -1  1  3551  100  -1  21  ]
      [  34  1  1  5  607  62  8  55  21  5  9  1  3413  100  860  16  ]
      [  34  1  1  5  775  72  8  40  15  4  8  1  3235  100  550  17  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  5  10  3  3300  100  -1  15  ]
      [  56  1  1  4  764  75  1  40  18  3  8  1  3583  100  700  15  ]
      [  52  1  1  1  705  74  8  50  -1  2  3  1  3361  100  -1  22  ]
      [  54  1  1  4  622  64  8  38  -1  2  3  1  3752  100  -1  16  ]
      [  42  1  1  5  714  60  1  50  14  2  3  1  3680  100  600  16  ]
      [  53  1  1  4  801  75  1  38  -1  4  7  1  3865  100  -1  19  ]
      [  45  1  1  2  842  85  8  60  -1  5  8  1  3930  100  -1  16  ]
      [  34  1  1  5  440  45  8  40  10  5  6  1  3709  100  420  17  ]
      [  55  1  1  4  764  75  1  39  11  5  7  1  3883  100  409  17  ]
      [  53  1  1  5  622  30  8  40  -1  1  5  1  3986  100  -1  21  ]
      [  50  1  1  4  870  80  1  30  -1  5  9  1  3992  100  -1  16  ]
      [  54  1  1  5  835  92  1  38  -1  4  8  1  3718  100  -1  22  ]
      [  44  1  1  5  273  29  8  38  -1  5  3  1  3708  100  -1  16  ]
      [  48  2  1  5  776  72  8  50  -1  5  9  1  3792  100  -1  16  ]
      [  60  1  1  1  753  74  8  12  -1  -1  -1  1  3684  100  -1  16  ]
      [  54  1  1  5  756  31  8  40  -1  5  9  1  3808  100  -1  18  ]
      [  75  2  1  1  886  85  8  3  -1  5  10  3  3713  100  -1  16  ]
      [  45  1  1  1  841  85  8  40  -1  5  9  1  3873  100  -1  16  ]
      [  46  1  1  2  750  45  8  40  -1  2  3  1  3790  100  -1  20  ]
      [  36  1  1  2  911  55  8  85  33  1  3  1  4486  100  1300  17  ]
      [  37  1  1  4  61  1  1  40  -1  5  8  1  4210  100  -1  17  ]
      [  35  1  1  5  600  31  8  40  8  5  9  1  4085  100  341  19  ]
      [  41  1  1  5  776  72  8  40  -1  4  8  1  4197  100  -1  17  ]
      [  63  1  1  5  751  99  8  39  -1  5  9  1  4968  100  -1  18  ]
      [  50  1  1  2  750  26  8  60  11  5  8  1  4866  100  480  22  ]
      [  30  2  1  5  841  85  1  50  14  5  9  1  4762  100  550  18  ]
      [  43  1  1  2  310  45  8  40  -1  1  5  1  4771  100  -1  20  ]
      [  65  1  1  2  911  55  8  48  -1  1  3  1  4781  100  -1  19  ]
      [  47  1  1  2  841  85  8  65  15  5  10  1  5342  100  640  19  ]
      [  38  1  1  5  755  33  8  70  -1  5  10  1  5272  100  -1  19  ]
      [  52  1  1  2  602  45  8  60  -1  3  8  1  5233  100  -1  21  ]
      [  58  1  1  2  842  85  8  60  -1  -1  -1  1  5937  100  -1  20  ]
      [  55  1  1  2  841  85  8  35  -1  5  9  1  5832  100  -1  20  ]
      [  34  1  1  5  691  65  8  50  12  5  5  1  5660  100  525  20  ]
      [  56  1  1  5  602  24  8  40  -1  5  8  1  5905  100  600  20  ]
      [  44  1  1  2  841  85  8  50  -1  5  9  1  5585  100  -1  23  ]
      [  43  1  1  2  254  50  8  98  -1  -1  -1  1  5527  100  -1  20  ]
      [  54  1  1  2  753  74  8  60  -1  3  3  1  7182  100  -1  21  ]
      [  41  1  1  5  805  85  1  38  -1  3  3  1  7336  100  -1  21  ]
      [  60  1  1  5  821  22  8  55  -1  5  8  1  7313  100  -1  21  ]
      [  49  1  1  5  603  27  8  60  -1  5  8  1  9544  100  -1  22  ]
      [  28  1  1  5  651  27  8  98  -1  -1  -1  1  18560  100  -1  21  ]
      [  40  2  8  -1  -1  -1  -1  -1  10  1  3  4  99  99  380  10  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  769  99  -1  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  730  99  -1  5  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1013  99  -1  6  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1142  99  -1  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  10  1  3  3  1101  99  420  11  ]
      [  61  1  1  6  546  45  8  40  -1  1  3  1  1222  99  -1  12  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  3  8  3  1175  99  -1  7  ]
      [  42  1  1  5  796  75  1  47  6  1  -1  1  1587  99  210  10  ]
      [  59  1  1  6  323  28  8  38  12  -1  -1  1  1518  99  420  10  ]
      [  30  1  1  5  689  34  8  37  13  3  3  1  1739  99  550  15  ]
      [  33  1  1  6  269  29  8  37  -1  1  3  1  1810  99  -1  10  ]
      [  52  1  1  2  691  74  8  60  12  5  9  1  2561  99  510  12  ]
      [  56  2  1  6  142  24  8  37  -1  1  -1  1  3819  99  -1  16  ]
      [  63  1  1  4  872  80  1  47  -1  5  9  1  5393  99  -1  19  ]
      [  36  2  8  -1  -1  -1  -1  -1  14  5  4  4  297  98  520  15  ]
      [  54  1  1  1  715  60  8  50  -1  1  3  1  231  98  -1  7  ]
      [  31  2  8  -1  -1  -1  -1  -1  -1  3  3  2  358  98  243  3  ]
      [  30  2  8  -1  -1  -1  -1  -1  11  1  1  6  406  98  393  9  ]
      [  33  1  8  -1  -1  -1  -1  -1  12  5  -1  3  524  98  475  11  ]
      [  40  2  1  2  750  15  8  70  -1  5  8  1  582  98  -1  11  ]
      [  47  1  8  -1  -1  -1  -1  -1  12  1  -1  3  551  98  350  12  ]
      [  41  2  1  5  662  52  8  20  -1  2  3  1  530  98  -1  10  ]
      [  75  2  8  -1  -1  -1  -1  -1  14  1  3  3  767  98  500  5  ]
      [  54  1  8  -1  -1  -1  -1  -1  10  1  3  6  709  98  400  10  ]
      [  91  1  8  -1  -1  -1  -1  -1  11  5  -1  3  872  98  450  9  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  844  98  -1  14  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  -1  3  3  840  98  -1  10  ]
      [  38  1  8  -1  -1  -1  -1  -1  -1  2  5  2  823  98  -1  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  770  98  -1  11  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  2  5  2  728  98  -1  10  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  3  3  970  98  0  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1006  98  -1  12  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1024  98  -1  6  ]
      [  52  2  8  6  714  60  8  12  -1  1  4  3  1055  98  -1  6  ]
      [  50  1  1  5  912  55  8  40  9  1  3  1  929  98  370  10  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  984  98  -1  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1048  98  -1  6  ]
      [  60  1  8  -1  -1  -1  -1  -1  10  1  5  2  1066  98  347  11  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  3  5  3  1060  98  -1  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1262  98  -1  7  ]
      [  29  1  1  6  281  50  8  40  9  2  3  1  1174  98  342  8  ]
      [  33  1  1  6  254  28  8  40  14  5  3  1  1247  98  590  12  ]
      [  50  1  1  6  72  29  8  37  -1  -1  -1  1  1118  98  -1  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1185  98  -1  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1294  98  450  7  ]
      [  47  2  1  1  670  52  8  50  -1  1  3  1  1205  98  -1  11  ]
      [  50  1  1  6  323  28  8  38  9  -1  -1  1  1209  98  361  14  ]
      [  47  2  1  6  934  52  8  12  21  1  3  4  1123  98  960  7  ]
      [  59  1  1  6  744  52  8  38  -1  3  -1  1  1387  98  -1  11  ]
      [  30  1  1  6  254  27  8  40  13  1  3  1  1429  98  500  8  ]
      [  63  1  1  6  937  74  8  9  8  1  3  3  1479  98  300  8  ]
      [  53  2  1  6  358  17  8  40  -1  1  1  1  1481  98  -1  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1309  98  -1  10  ]
      [  81  2  8  -1  -1  -1  -1  -1  17  1  3  3  1500  98  640  8  ]
      [  41  1  1  6  221  29  8  40  -1  1  3  1  1389  98  -1  13  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1312  98  388  11  ]
      [  32  1  1  5  316  34  8  39  -1  1  3  1  1576  98  -1  9  ]
      [  26  1  1  6  632  29  8  35  10  1  3  1  1682  98  400  9  ]
      [  43  1  1  2  750  45  8  70  18  1  5  1  1550  98  750  13  ]
      [  42  1  1  6  531  28  8  40  -1  -1  -1  1  1793  98  -1  11  ]
      [  53  1  1  4  801  75  1  40  -1  1  3  1  1784  98  -1  15  ]
      [  36  1  1  6  270  28  8  38  12  3  3  1  1945  98  500  12  ]
      [  49  1  1  6  531  50  8  40  16  -1  -1  1  1746  98  600  15  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1811  98  -1  14  ]
      [  30  1  1  6  141  15  8  40  12  1  1  1  2090  98  500  13  ]
      [  46  1  1  6  442  45  8  39  -1  2  99  1  2052  98  -1  15  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2225  98  -1  11  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2083  98  -1  14  ]
      [  50  1  1  4  787  60  8  38  -1  2  6  1  2059  98  -1  15  ]
      [  29  1  1  4  873  80  1  40  9  5  9  1  2292  98  400  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  10  1  3  3  2058  98  350  16  ]
      [  53  2  1  5  677  31  8  40  -1  1  3  1  2093  98  -1  11  ]
      [  45  2  1  5  787  75  1  39  16  1  7  1  2400  98  720  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2519  98  -1  12  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  2332  98  -1  12  ]
      [  54  1  1  5  290  33  8  38  -1  1  3  1  2413  98  -1  15  ]
      [  40  2  1  5  775  72  8  25  -1  3  3  1  2539  98  -1  13  ]
      [  28  2  1  4  880  80  1  40  13  5  9  1  2381  98  500  17  ]
      [  43  1  1  4  814  75  1  40  17  2  3  1  2358  98  700  15  ]
      [  42  1  1  4  801  75  1  40  -1  2  5  1  2574  98  -1  15  ]
      [  41  1  1  6  310  40  8  40  -1  1  4  1  2608  98  -1  13  ]
      [  39  2  1  1  995  74  8  50  14  3  5  1  2996  98  550  21  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  3  -1  3  3100  98  -1  21  ]
      [  43  1  1  5  813  66  8  39  8  5  9  1  2944  98  340  14  ]
      [  36  1  1  6  273  29  8  35  -1  1  3  1  4167  98  -1  17  ]
      [  56  1  1  5  777  72  8  40  -1  5  10  1  5510  98  -1  22  ]
      [  30  2  1  5  997  85  8  15  -1  5  8  1  565  97  -1  4  ]
      [  31  2  1  5  780  85  8  20  -1  3  -1  1  721  97  -1  13  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  759  97  -1  5  ]
      [  77  2  8  -1  -1  -1  -1  -1  7  -1  -1  3  707  97  249  5  ]
      [  37  1  1  6  411  85  8  30  13  -1  -1  1  783  97  430  7  ]
      [  68  2  8  -1  -1  -1  -1  -1  10  3  3  3  777  97  300  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  992  97  -1  6  ]
      [  41  1  1  1  931  93  8  60  10  -1  -1  1  912  97  440  10  ]
      [  59  2  1  5  735  75  1  39  10  3  99  1  1282  97  410  7  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1133  97  -1  7  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  3  4  3  1199  97  -1  7  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1491  97  -1  9  ]
      [  58  2  8  -1  -1  -1  -1  -1  13  5  9  3  1514  97  500  9  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  9  8  3  1549  97  -1  10  ]
      [  87  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1510  97  -1  12  ]
      [  53  1  1  5  692  66  8  39  11  3  5  1  1934  97  475  16  ]
      [  30  1  1  5  841  85  1  38  -1  5  10  1  1934  97  -1  10  ]
      [  36  1  1  5  540  34  8  38  15  1  1  1  1837  97  490  16  ]
      [  52  1  1  5  641  45  8  38  -1  3  3  1  1876  97  -1  16  ]
      [  28  1  1  6  175  21  8  35  -1  1  -1  1  2080  97  -1  12  ]
      [  35  2  1  5  813  73  8  45  14  5  9  1  2470  97  600  17  ]
      [  50  2  1  5  676  52  8  40  -1  3  3  1  2772  97  540  13  ]
      [  40  1  1  5  623  93  8  38  -1  3  5  1  2736  97  -1  13  ]
      [  42  1  1  2  701  63  8  50  19  3  3  1  2895  97  700  15  ]
      [  52  1  1  5  603  45  8  40  19  1  3  1  3419  97  720  20  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  3  3  558  96  -1  6  ]
      [  69  1  8  -1  -1  -1  -1  -1  8  5  -1  3  806  96  240  8  ]
      [  53  1  8  -1  -1  -1  -1  -1  6  2  4  2  836  96  174  6  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  806  96  -1  7  ]
      [  53  1  1  6  141  24  8  40  -1  2  3  1  1028  96  -1  8  ]
      [  35  1  1  6  714  63  8  40  -1  1  3  1  1012  96  -1  10  ]
      [  62  1  8  -1  -1  -1  -1  -1  7  1  4  3  1260  96  260  12  ]
      [  43  1  1  6  51  1  8  38  12  1  3  1  1172  96  480  12  ]
      [  70  1  8  -1  -1  -1  -1  -1  10  1  3  3  1243  96  390  10  ]
      [  44  1  1  6  488  45  8  40  11  1  3  1  1294  96  400  11  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1152  96  -1  10  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1235  96  -1  7  ]
      [  61  1  1  6  231  29  8  38  -1  1  3  1  1298  96  -1  16  ]
      [  50  1  1  6  540  25  8  40  13  5  9  1  1284  96  510  19  ]
      [  68  2  8  -1  -1  -1  -1  -1  8  1  -1  3  1246  96  315  10  ]
      [  45  2  1  5  785  10  8  32  -1  2  6  1  1125  96  -1  11  ]
      [  34  2  1  5  859  85  8  30  7  2  8  1  1276  96  300  12  ]
      [  43  1  1  6  714  50  8  40  -1  2  3  1  1137  96  -1  10  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1349  96  -1  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  11  1  3  3  1433  96  416  10  ]
      [  44  1  1  6  254  27  8  40  6  1  -1  1  1316  96  200  10  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1393  96  -1  8  ]
      [  40  1  1  5  672  52  8  40  10  1  3  1  1474  96  395  13  ]
      [  23  1  1  6  221  29  8  38  8  1  -1  1  1308  96  350  8  ]
      [  32  2  1  6  923  55  8  40  -1  4  -1  1  1391  96  -1  8  ]
      [  46  1  1  6  211  34  8  37  11  1  3  1  1308  96  400  10  ]
      [  33  1  1  5  620  29  8  38  15  2  3  1  1476  96  515  14  ]
      [  40  1  1  5  629  62  8  39  -1  4  4  1  1514  96  -1  13  ]
      [  33  1  1  6  934  74  8  40  11  3  4  1  1647  96  436  14  ]
      [  47  1  1  6  222  33  8  36  10  1  3  1  1560  96  405  13  ]
      [  52  1  1  6  254  29  8  37  11  3  3  1  1586  96  460  13  ]
      [  43  1  1  6  281  35  8  35  -1  1  3  1  1544  96  -1  16  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1560  96  -1  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1702  96  -1  11  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1726  96  -1  11  ]
      [  31  1  1  6  731  64  8  38  13  3  3  1  1897  96  500  10  ]
      [  38  1  1  6  488  45  8  38  11  1  3  1  1767  96  432  10  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1949  96  -1  10  ]
      [  49  1  1  5  401  52  8  39  8  1  3  1  1868  96  250  14  ]
      [  44  1  1  5  608  74  8  40  -1  4  8  1  2029  96  -1  11  ]
      [  28  1  1  5  802  75  1  37  -1  1  3  1  2000  96  -1  16  ]
      [  45  1  1  5  281  50  8  40  -1  1  5  1  2067  96  -1  17  ]
      [  54  1  1  6  803  75  1  39  -1  1  3  1  2090  96  -1  21  ]
      [  46  1  1  5  788  55  8  38  10  3  5  1  2280  96  361  12  ]
      [  44  1  1  5  23  1  1  40  -1  2  3  1  2155  96  -1  17  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  2347  96  -1  12  ]
      [  44  1  1  5  775  30  8  35  23  4  8  1  2666  96  1000  16  ]
      [  39  1  1  4  764  75  1  34  -1  5  9  1  2690  96  -1  13  ]
      [  49  1  1  5  51  1  8  38  11  1  5  1  2998  96  450  14  ]
      [  37  1  1  5  775  62  8  40  13  5  9  1  2915  96  550  14  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2976  96  -1  18  ]
      [  45  1  1  5  662  35  8  50  -1  3  5  1  3203  96  -1  18  ]
      [  57  1  1  5  780  36  8  50  -1  1  3  1  3309  96  -1  18  ]
      [  79  2  8  -1  -1  -1  -1  -1  19  5  9  3  3559  96  590  15  ]
      [  41  1  1  4  691  65  8  38  27  5  3  1  3810  96  1150  16  ]
      [  44  1  1  5  832  92  1  60  20  5  6  1  4357  96  800  17  ]
      [  60  1  1  5  600  33  8  48  16  2  8  1  4176  96  710  17  ]
      [  65  1  1  5  623  45  8  40  -1  1  3  1  4666  96  -1  18  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  265  95  -1  4  ]
      [  35  2  1  5  744  71  8  25  -1  1  1  1  326  95  -1  6  ]
      [  66  1  1  5  915  55  8  25  12  3  3  1  439  95  510  10  ]
      [  35  1  8  -1  -1  -1  -1  -1  8  4  3  2  342  95  325  3  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  3  3  427  95  -1  3  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  3  3  474  95  -1  3  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  676  95  -1  4  ]
      [  35  2  8  6  531  32  8  40  5  1  -1  8  646  95  180  4  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  766  95  -1  5  ]
      [  71  1  8  -1  -1  -1  -1  -1  6  1  1  3  704  95  185  8  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  864  95  -1  5  ]
      [  41  1  8  -1  -1  -1  -1  -1  10  4  8  2  893  95  360  8  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  4  3  747  95  -1  9  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  9  3  833  95  -1  12  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  6  3  787  95  -1  5  ]
      [  34  2  8  -1  -1  -1  -1  -1  12  2  3  2  832  95  400  10  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  1  3  3  793  95  0  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  851  95  -1  8  ]
      [  58  1  1  1  501  45  8  40  -1  1  5  1  884  95  -1  9  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  969  95  -1  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  1  1  3  919  95  375  11  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  995  95  -1  8  ]
      [  52  1  8  -1  -1  -1  -1  -1  10  3  3  3  948  95  400  14  ]
      [  31  1  1  6  255  28  8  40  13  2  6  1  965  95  565  11  ]
      [  43  2  8  -1  -1  -1  -1  -1  13  1  -1  6  991  95  405  11  ]
      [  40  1  8  -1  -1  -1  -1  -1  -1  2  5  3  1034  95  -1  12  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  996  95  -1  6  ]
      [  47  1  1  6  714  93  8  40  -1  2  3  1  969  95  -1  7  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  900  95  -1  9  ]
      [  37  2  8  -1  -1  -1  -1  -1  13  5  7  2  1168  95  520  7  ]
      [  48  1  1  2  300  52  8  45  -1  1  5  1  1122  95  -1  12  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1258  95  -1  10  ]
      [  29  1  1  6  391  15  8  40  11  3  -1  1  1213  95  420  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1249  95  0  7  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1132  95  -1  7  ]
      [  47  1  1  6  780  45  8  39  -1  1  3  1  1124  95  -1  11  ]
      [  19  2  1  7  853  85  1  38  13  3  -1  1  1164  95  450  7  ]
      [  33  1  8  -1  -1  -1  -1  -1  13  2  4  6  1245  95  450  7  ]
      [  40  2  1  5  772  75  1  40  9  5  3  1  1198  95  315  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1252  95  -1  10  ]
      [  48  1  1  6  741  52  8  37  17  3  1  1  1461  95  600  11  ]
      [  63  2  1  5  864  85  8  20  -1  1  3  1  1367  95  -1  8  ]
      [  29  1  1  5  300  93  8  37  -1  1  -1  1  1399  95  435  8  ]
      [  38  1  1  6  174  22  8  37  11  3  3  1  1359  95  430  12  ]
      [  64  1  1  6  911  55  8  15  -1  1  3  3  1482  95  -1  10  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1439  95  -1  20  ]
      [  66  1  1  6  179  22  8  15  -1  1  -1  3  1494  95  -1  8  ]
      [  34  1  1  5  805  85  1  40  -1  3  4  1  1350  95  0  13  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1407  95  -1  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1362  95  -1  11  ]
      [  25  2  1  5  751  74  8  40  21  5  3  1  1330  95  900  13  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1486  95  -1  10  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1327  95  -1  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1521  95  -1  10  ]
      [  48  1  1  5  310  74  8  40  11  1  3  1  1652  95  425  11  ]
      [  87  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1582  95  -1  13  ]
      [  47  1  1  1  268  28  8  45  -1  1  5  1  1683  95  -1  12  ]
      [  32  1  1  5  775  72  8  40  -1  5  3  1  1510  95  -1  11  ]
      [  30  1  1  6  141  24  8  38  -1  -1  -1  1  1681  95  -1  13  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1581  95  -1  9  ]
      [  51  1  1  6  540  40  1  35  8  1  3  1  1608  95  300  9  ]
      [  51  1  1  6  225  28  8  37  8  1  3  1  1520  95  322  12  ]
      [  31  2  1  5  641  74  8  40  -1  3  3  1  1573  95  -1  15  ]
      [  49  1  1  6  401  85  8  39  -1  1  3  1  1551  95  -1  16  ]
      [  54  1  8  6  270  33  8  35  -1  1  3  1  1570  95  -1  16  ]
      [  68  1  8  -1  -1  -1  -1  -1  10  4  10  3  1587  95  361  11  ]
      [  36  1  1  6  290  80  8  38  -1  2  3  1  1575  95  -1  9  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  5  10  3  1628  95  -1  12  ]
      [  36  1  1  4  873  80  1  38  -1  5  9  1  1920  95  -1  15  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1948  95  -1  11  ]
      [  39  1  1  6  241  45  8  40  12  1  -1  1  1843  95  425  12  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1929  95  -1  14  ]
      [  59  1  1  6  441  45  8  44  -1  1  3  1  1793  95  -1  10  ]
      [  44  1  1  5  813  91  8  40  17  5  8  1  2013  95  700  12  ]
      [  29  1  1  5  750  74  8  35  20  5  -1  1  2051  95  860  17  ]
      [  39  2  1  5  692  66  8  38  -1  3  4  1  2271  95  -1  11  ]
      [  45  1  1  6  290  27  8  35  -1  1  3  1  2182  95  -1  15  ]
      [  43  2  1  5  678  31  8  40  12  3  3  1  2137  95  530  11  ]
      [  32  1  1  6  269  45  8  39  19  1  3  1  2234  95  840  13  ]
      [  31  1  1  1  813  74  8  40  9  5  10  1  2131  95  380  11  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  5  3  3  2384  95  -1  12  ]
      [  50  2  1  2  310  45  8  65  -1  1  5  1  2548  95  -1  18  ]
      [  47  2  1  4  870  80  1  38  -1  5  9  1  2373  95  0  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  1  3  2334  95  -1  12  ]
      [  49  1  1  6  714  60  8  60  10  1  3  1  2401  95  350  14  ]
      [  37  1  1  5  281  34  8  40  13  1  3  1  2382  95  500  14  ]
      [  39  1  1  6  323  29  8  40  -1  1  -1  1  2372  95  -1  12  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  4  8  3  2534  95  -1  16  ]
      [  48  1  1  5  692  66  8  40  -1  5  9  1  2767  95  -1  17  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2888  95  -1  13  ]
      [  45  1  1  5  787  85  1  39  -1  3  3  1  3144  95  -1  19  ]
      [  41  1  1  4  787  75  1  39  14  5  4  1  2903  95  575  14  ]
      [  30  1  1  5  841  85  1  60  13  5  10  1  3054  95  560  14  ]
      [  62  2  8  -1  -1  -1  -1  -1  19  5  9  3  3340  95  790  15  ]
      [  59  1  1  4  874  80  1  60  -1  5  8  1  3727  95  -1  21  ]
      [  43  1  1  5  602  30  8  40  -1  5  8  1  3625  95  -1  17  ]
      [  39  1  1  5  750  91  8  60  -1  5  9  1  5422  95  -1  20  ]
      [  61  1  1  5  750  21  8  37  -1  3  8  1  5530  95  -1  21  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  8891  95  -1  22  ]
      [  27  2  8  -1  -1  -1  -1  -1  -1  -1  -1  4  317  94  -1  3  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  5  2  457  94  -1  15  ]
      [  54  2  8  -1  -1  -1  -1  -1  11  1  -1  3  700  94  400  8  ]
      [  95  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  500  94  489  4  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  773  94  -1  5  ]
      [  23  2  1  5  741  92  8  40  13  5  3  1  1096  94  500  11  ]
      [  28  2  1  5  661  52  8  40  -1  2  3  1  1016  94  222  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  959  94  -1  11  ]
      [  45  1  1  5  714  60  1  38  10  3  5  1  1244  94  314  14  ]
      [  37  2  1  2  670  52  8  30  14  3  5  1  1370  94  630  8  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1381  94  -1  9  ]
      [  60  1  1  6  714  28  8  37  -1  1  3  1  1492  94  -1  8  ]
      [  51  1  1  1  691  74  8  16  -1  1  8  1  1405  94  0  16  ]
      [  48  2  1  6  321  31  8  40  -1  3  -1  3  1354  94  -1  12  ]
      [  49  1  1  6  540  26  8  40  9  1  3  1  1340  94  320  15  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  3  8  3  1675  94  -1  11  ]
      [  31  1  1  6  714  64  8  38  12  2  3  1  1668  94  461  13  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  5  5  3  1798  94  -1  10  ]
      [  31  1  1  6  270  29  8  35  12  3  3  1  1766  94  500  13  ]
      [  54  1  1  6  316  40  8  37  -1  1  3  1  1969  94  -1  15  ]
      [  41  1  1  6  714  63  8  40  -1  1  -1  1  1834  94  -1  12  ]
      [  47  1  8  -1  -1  -1  -1  -1  12  5  9  5  2133  94  449  11  ]
      [  46  1  1  6  212  28  8  38  11  1  -1  1  2168  94  400  15  ]
      [  53  1  1  5  741  52  8  38  11  3  3  1  2018  94  396  18  ]
      [  64  1  8  -1  -1  -1  -1  -1  11  1  3  3  2027  94  420  18  ]
      [  53  1  1  4  801  75  1  40  14  1  7  1  2052  94  535  17  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  4  3  2  2319  94  -1  16  ]
      [  59  2  1  5  886  85  1  38  -1  4  10  1  2829  94  -1  13  ]
      [  55  1  1  1  836  74  8  40  -1  5  3  1  2681  94  -1  13  ]
      [  30  2  1  5  834  72  8  15  -1  1  -1  4  656  93  -1  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  700  93  340  9  ]
      [  32  2  1  5  703  93  8  40  -1  2  3  1  634  93  -1  9  ]
      [  49  1  1  1  870  80  8  10  -1  5  8  4  728  93  -1  12  ]
      [  44  1  1  6  471  45  8  40  6  2  3  1  748  93  220  9  ]
      [  34  2  8  -1  -1  -1  -1  -1  -1  5  -1  8  1090  93  -1  6  ]
      [  41  1  1  6  442  45  8  40  11  -1  -1  1  1084  93  400  6  ]
      [  59  2  8  -1  -1  -1  -1  -1  14  1  -1  3  1217  93  505  11  ]
      [  34  2  8  -1  -1  -1  -1  -1  10  1  -1  8  1168  93  378  8  ]
      [  49  1  1  6  487  45  8  40  -1  2  3  1  1237  93  -1  12  ]
      [  40  1  1  6  254  63  8  35  -1  1  3  1  1492  93  -1  14  ]
      [  23  1  1  6  269  34  8  37  8  3  3  1  1415  93  314  8  ]
      [  30  2  1  5  863  80  8  39  10  3  4  1  1426  93  338  13  ]
      [  42  1  8  6  796  70  8  2  11  4  9  4  1447  93  410  8  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1639  93  -1  12  ]
      [  29  1  1  1  780  70  8  60  17  4  3  1  1645  93  650  10  ]
      [  54  1  1  5  600  28  8  39  -1  5  8  1  1585  93  -1  11  ]
      [  41  2  1  4  870  80  1  38  14  5  9  1  1711  93  600  16  ]
      [  38  1  1  5  621  31  8  40  10  1  3  1  1733  93  400  11  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2016  93  -1  16  ]
      [  55  1  1  4  622  64  8  39  12  4  3  1  2234  93  450  16  ]
      [  53  2  1  4  868  75  1  40  -1  5  8  1  2592  93  -1  12  ]
      [  41  1  1  5  778  51  8  38  13  4  8  1  2578  93  550  16  ]
      [  45  1  1  6  264  24  8  39  -1  1  3  1  2561  93  -1  13  ]
      [  33  2  1  2  834  72  8  40  23  5  7  1  3137  93  960  14  ]
      [  55  1  1  4  764  75  1  38  26  3  5  1  2989  93  1050  16  ]
      [  63  1  1  5  511  45  8  40  -1  1  3  1  3239  93  -1  15  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  623  92  0  4  ]
      [  36  1  8  -1  -1  -1  -1  -1  12  1  -1  5  667  92  450  4  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  3  3  554  92  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  99  3  538  92  -1  6  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  2  510  92  -1  8  ]
      [  39  1  8  -1  -1  -1  -1  -1  7  2  3  8  601  92  255  5  ]
      [  58  2  1  5  789  91  8  25  -1  3  3  1  719  92  0  15  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  5  8  2  784  92  -1  11  ]
      [  48  1  8  -1  -1  -1  -1  -1  -1  2  3  2  814  92  -1  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  817  92  -1  5  ]
      [  71  2  8  -1  -1  -1  -1  -1  12  1  3  3  1048  92  427  6  ]
      [  30  2  8  -1  -1  -1  -1  -1  11  3  -1  4  1024  92  394  6  ]
      [  66  2  8  -1  -1  -1  -1  -1  10  3  3  3  1034  92  369  6  ]
      [  40  1  8  -1  -1  -1  -1  -1  9  1  3  2  998  92  270  10  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1294  92  -1  7  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1173  92  -1  7  ]
      [  55  1  1  4  731  64  8  39  -1  1  3  1  1244  92  -1  10  ]
      [  46  1  1  5  780  92  8  39  13  1  3  1  1112  92  510  10  ]
      [  29  2  1  5  772  52  8  38  11  5  3  1  1164  92  440  12  ]
      [  27  1  1  6  441  45  8  55  13  2  2  1  1260  92  390  7  ]
      [  44  1  1  6  222  33  8  40  11  2  3  1  1227  92  400  10  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1317  92  -1  8  ]
      [  60  1  8  -1  -1  -1  -1  -1  15  1  3  3  1373  92  480  12  ]
      [  34  1  1  5  751  92  8  40  12  3  3  1  1313  92  450  8  ]
      [  29  1  1  5  865  85  1  39  10  5  4  1  1358  92  360  8  ]
      [  62  1  1  6  135  26  8  37  8  1  -1  1  1440  92  300  10  ]
      [  44  1  1  6  441  45  8  38  13  1  3  1  1482  92  500  15  ]
      [  36  1  1  5  823  92  1  39  -1  5  8  1  1409  92  -1  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1302  92  -1  9  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1358  92  -1  8  ]
      [  39  1  1  6  358  17  8  40  -1  1  3  1  1431  92  -1  12  ]
      [  35  2  8  -1  -1  -1  -1  -1  12  1  3  6  1327  92  335  13  ]
      [  37  2  1  5  788  75  1  45  12  2  6  1  1324  92  470  14  ]
      [  47  1  1  6  318  34  8  35  -1  9  3  1  1675  92  -1  14  ]
      [  28  1  1  6  997  25  8  40  -1  1  3  1  1619  92  -1  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1591  92  -1  11  ]
      [  80  2  8  -1  -1  -1  -1  -1  11  1  3  3  1612  92  420  9  ]
      [  34  1  1  6  311  25  8  40  14  3  3  1  1606  92  580  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1651  92  421  9  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1679  92  -1  9  ]
      [  59  1  1  5  703  74  8  38  -1  3  5  1  1809  92  -1  13  ]
      [  79  1  8  -1  -1  -1  -1  -1  9  1  8  3  1922  92  310  11  ]
      [  40  1  1  5  651  29  8  38  -1  3  5  1  1938  92  -1  12  ]
      [  53  1  1  1  661  55  8  70  15  1  3  1  1916  92  550  12  ]
      [  48  2  1  5  751  85  8  39  -1  1  4  1  1746  92  -1  18  ]
      [  30  1  1  5  627  45  8  40  12  4  8  1  1998  92  435  13  ]
      [  44  2  1  5  789  65  8  39  11  3  4  1  1793  92  425  11  ]
      [  50  1  1  6  270  28  8  39  8  1  3  1  1791  92  305  16  ]
      [  76  1  8  -1  -1  -1  -1  -1  7  1  3  3  1716  92  180  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  3  8  3  2172  92  -1  13  ]
      [  60  1  8  -1  -1  -1  -1  -1  13  3  99  3  2039  92  520  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2037  92  -1  11  ]
      [  32  1  1  5  775  72  8  40  16  5  9  1  2213  92  650  18  ]
      [  35  1  1  5  713  74  8  40  13  1  -1  1  2009  92  439  11  ]
      [  60  1  1  5  626  80  1  39  11  3  8  1  2202  92  469  11  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2094  92  -1  11  ]
      [  21  1  1  5  754  74  8  40  -1  3  3  1  2498  92  -1  17  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  5  9  3  2507  92  400  12  ]
      [  43  2  1  5  750  91  8  40  10  5  9  1  2495  92  380  16  ]
      [  30  2  1  5  753  67  8  40  18  5  9  1  2819  92  670  20  ]
      [  32  1  1  2  852  85  8  40  14  3  5  1  2693  92  460  15  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2994  92  -1  14  ]
      [  45  1  1  5  622  32  8  39  -1  5  5  1  3481  92  -1  15  ]
      [  36  1  1  5  775  60  8  40  15  5  8  1  3237  92  640  17  ]
      [  48  1  1  5  821  22  8  50  9  5  9  1  3535  92  360  15  ]
      [  46  1  1  5  651  31  8  40  14  1  3  1  3312  92  420  16  ]
      [  33  1  1  6  269  29  8  45  15  -1  -1  1  3601  92  600  16  ]
      [  49  1  1  6  796  70  8  4  11  -1  -1  2  466  91  452  7  ]
      [  41  2  1  6  934  75  1  13  8  1  -1  1  417  91  295  5  ]
      [  60  1  8  6  744  22  8  12  11  3  3  3  1046  91  400  13  ]
      [  44  2  1  5  754  74  8  40  12  3  3  1  1004  91  348  15  ]
      [  39  1  1  6  511  45  8  40  8  2  3  1  1008  91  264  10  ]
      [  28  2  1  5  831  91  8  28  8  5  9  1  978  91  331  6  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1215  91  -1  10  ]
      [  44  2  1  5  789  74  8  40  12  2  3  1  1280  91  479  13  ]
      [  37  1  1  6  502  29  8  40  26  2  4  1  1253  91  1100  12  ]
      [  60  2  1  5  921  85  8  39  -1  3  5  1  1409  91  -1  14  ]
      [  34  1  1  5  774  72  8  40  -1  3  4  1  1675  91  -1  15  ]
      [  66  2  8  5  780  15  8  12  -1  -1  -1  3  1559  91  -1  15  ]
      [  46  1  1  6  265  29  8  35  -1  1  -1  1  1685  91  -1  17  ]
      [  57  1  1  6  225  29  8  35  -1  1  3  1  1514  91  -1  10  ]
      [  52  1  1  6  744  29  8  35  -1  1  3  1  1907  91  -1  13  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2043  91  -1  12  ]
      [  81  2  8  -1  -1  -1  -1  -1  15  -1  -1  3  2477  91  525  12  ]
      [  23  1  1  9  801  75  1  32  11  3  3  1  2468  91  450  15  ]
      [  56  1  1  5  421  15  8  40  -1  5  9  1  2419  91  -1  12  ]
      [  34  1  1  5  691  65  8  50  -1  5  9  1  3662  91  -1  21  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  1  3  249  90  -1  9  ]
      [  31  1  1  5  702  63  8  12  14  5  -1  8  228  90  460  11  ]
      [  46  1  8  -1  -1  -1  -1  -1  9  1  3  2  189  90  345  5  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  273  90  -1  2  ]
      [  46  1  8  -1  -1  -1  -1  -1  -1  1  3  2  259  90  -1  10  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  442  90  0  3  ]
      [  35  2  8  -1  -1  -1  -1  -1  10  1  3  4  385  90  400  10  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  342  90  -1  3  ]
      [  29  2  1  5  691  65  1  38  -1  3  3  1  385  90  0  13  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  359  90  -1  3  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  395  90  -1  3  ]
      [  46  1  1  1  471  45  8  40  50  1  3  1  416  90  -1  3  ]
      [  48  2  8  -1  -1  -1  -1  -1  9  1  3  2  366  90  264  11  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  323  90  -1  6  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  591  90  -1  4  ]
      [  65  2  8  -1  -1  -1  -1  -1  4  1  -1  3  514  90  135  4  ]
      [  61  1  8  -1  -1  -1  -1  -1  9  1  5  6  626  90  365  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  587  90  -1  4  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  635  90  -1  4  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  672  90  -1  12  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  646  90  0  4  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  519  90  -1  4  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  535  90  -1  4  ]
      [  27  1  8  -1  -1  -1  -1  -1  11  1  3  2  640  90  400  6  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  2  3  3  506  90  -1  5  ]
      [  40  1  8  -1  -1  -1  -1  -1  -1  2  3  2  668  90  0  7  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  3  3  681  90  -1  4  ]
      [  41  1  8  -1  -1  -1  -1  -1  -1  2  3  2  697  90  -1  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  521  90  0  7  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  1  3  2  528  90  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  580  90  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  787  90  -1  5  ]
      [  35  1  8  -1  -1  -1  -1  -1  7  2  3  2  733  90  250  5  ]
      [  67  1  8  -1  -1  -1  -1  -1  6  1  -1  3  771  90  200  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  723  90  -1  5  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  738  90  -1  6  ]
      [  38  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  737  90  -1  10  ]
      [  56  2  8  -1  -1  -1  -1  -1  -1  1  3  5  861  90  -1  11  ]
      [  26  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  732  90  0  5  ]
      [  92  2  8  -1  -1  -1  -1  -1  -1  1  3  3  801  90  -1  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  734  90  -1  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  866  90  -1  9  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  832  90  -1  5  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  831  90  -1  13  ]
      [  79  1  8  -1  -1  -1  -1  -1  10  5  9  3  777  90  340  6  ]
      [  67  2  8  -1  -1  -1  -1  -1  8  5  9  3  768  90  280  5  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  898  90  -1  10  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  715  90  -1  5  ]
      [  36  1  8  6  531  1  8  40  -1  3  5  1  781  90  330  5  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  1  3  3  764  90  -1  5  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  714  90  0  7  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  -1  -1  8  703  90  -1  5  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  755  90  -1  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  741  90  -1  11  ]
      [  56  2  8  -1  -1  -1  -1  -1  -1  1  3  4  897  90  -1  5  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  807  90  -1  5  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  1  3  3  742  90  -1  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  714  90  -1  5  ]
      [  44  1  8  -1  -1  -1  -1  -1  -1  1  3  3  734  90  -1  5  ]
      [  30  1  1  5  861  85  8  40  -1  5  8  1  891  90  -1  5  ]
      [  56  1  8  -1  -1  -1  -1  -1  13  5  8  6  896  90  440  10  ]
      [  67  2  8  -1  -1  -1  -1  -1  11  1  3  3  870  90  400  8  ]
      [  27  2  1  5  782  85  1  20  11  2  5  1  744  90  400  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  6  3  826  90  -1  9  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  751  90  -1  12  ]
      [  31  1  1  6  254  29  8  40  -1  3  3  1  770  90  -1  11  ]
      [  60  1  8  6  13  1  8  14  -1  1  3  1  770  90  -1  10  ]
      [  56  1  1  6  273  45  8  34  -1  2  3  1  758  90  -1  11  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  863  90  0  10  ]
      [  70  1  1  2  705  92  8  70  -1  -1  -1  1  949  90  -1  14  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  931  90  0  6  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1095  90  -1  6  ]
      [  55  2  1  6  662  52  8  4  -1  1  3  3  1001  90  -1  9  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1059  90  -1  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  12  1  3  3  918  90  450  11  ]
      [  43  2  8  -1  -1  -1  -1  -1  11  1  3  2  1063  90  400  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  12  1  3  3  952  90  450  11  ]
      [  30  1  1  6  310  45  8  38  10  1  3  1  1034  90  360  8  ]
      [  33  1  8  -1  -1  -1  -1  -1  -1  1  3  2  991  90  -1  11  ]
      [  53  1  8  -1  -1  -1  -1  -1  15  1  1  2  1083  90  550  9  ]
      [  26  2  1  5  853  85  8  38  -1  3  3  1  1059  90  -1  12  ]
      [  23  2  1  6  662  52  8  38  9  1  3  1  955  90  310  12  ]
      [  39  1  1  6  741  45  8  38  13  1  -1  1  1076  90  457  9  ]
      [  53  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  995  90  300  7  ]
      [  47  2  1  5  789  92  8  30  11  3  3  1  982  90  380  6  ]
      [  62  1  8  6  937  93  8  9  -1  1  3  3  962  90  -1  8  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  3  3  907  90  -1  10  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  1  3  1020  90  -1  6  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  949  90  -1  6  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  958  90  -1  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  947  90  -1  6  ]
      [  36  2  1  6  321  31  8  27  -1  1  -1  1  991  90  0  12  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  999  90  -1  6  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  940  90  -1  7  ]
      [  43  2  1  7  788  32  8  37  -1  3  4  1  994  90  -1  6  ]
      [  79  1  8  -1  -1  -1  -1  -1  7  3  1  3  985  90  245  8  ]
      [  61  2  8  -1  -1  -1  -1  -1  13  3  3  3  946  90  480  6  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1004  90  -1  8  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1080  90  0  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1011  90  -1  6  ]
      [  64  2  8  -1  -1  -1  -1  -1  13  1  -1  3  916  90  500  6  ]
      [  44  1  1  5  620  64  8  40  -1  1  3  1  908  90  -1  10  ]
      [  35  1  8  -1  -1  -1  -1  -1  10  3  3  8  965  90  390  10  ]
      [  61  1  1  2  901  93  8  28  -1  1  5  1  915  90  -1  6  ]
      [  77  1  8  -1  -1  -1  -1  -1  9  1  3  3  1064  90  320  7  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1094  90  -1  11  ]
      [  37  1  1  6  442  52  8  43  9  1  -1  1  1033  90  297  8  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  919  90  0  6  ]
      [  56  1  8  -1  -1  -1  -1  -1  12  1  3  3  1059  90  370  10  ]
      [  33  2  1  5  774  52  8  38  -1  3  -1  1  984  90  180  11  ]
      [  47  2  1  6  153  25  8  39  8  1  -1  1  990  90  280  6  ]
      [  36  1  8  -1  -1  -1  -1  -1  -1  1  -1  6  961  90  450  6  ]
      [  44  1  1  6  254  13  8  40  -1  2  3  1  1086  90  -1  9  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  995  90  -1  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1068  90  -1  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  925  90  0  9  ]
      [  51  2  1  5  870  80  8  38  -1  5  6  1  1049  90  -1  10  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1004  90  -1  6  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1059  90  -1  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1042  90  0  10  ]
      [  49  1  1  6  460  1  8  42  -1  1  -1  1  1185  90  450  9  ]
      [  28  1  1  4  801  75  1  40  -1  3  3  1  1187  90  335  7  ]
      [  59  1  1  5  714  45  8  40  -1  1  3  1  1245  90  -1  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1286  90  0  7  ]
      [  49  2  8  -1  -1  -1  -1  -1  9  1  3  2  1164  90  350  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1190  90  -1  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1130  90  -1  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1242  90  -1  10  ]
      [  70  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  1105  90  426  9  ]
      [  52  1  1  6  714  18  8  37  -1  1  3  1  1204  90  -1  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1255  90  -1  7  ]
      [  34  1  1  5  281  50  8  39  13  1  99  1  1186  90  450  13  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1294  90  -1  11  ]
      [  35  1  1  6  742  37  8  37  -1  3  4  1  1190  90  -1  8  ]
      [  31  2  1  5  672  52  8  39  -1  3  3  1  1291  90  -1  7  ]
      [  48  1  1  6  141  24  8  38  -1  1  3  1  1178  90  -1  12  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1194  90  -1  7  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  5  3  3  1233  90  -1  7  ]
      [  39  1  1  6  254  28  8  38  -1  1  -1  1  1286  90  -1  12  ]
      [  46  2  8  -1  -1  -1  -1  -1  12  3  4  4  1143  90  460  7  ]
      [  36  2  8  -1  -1  -1  -1  -1  13  5  4  4  1219  90  450  7  ]
      [  31  1  1  6  225  29  8  38  5  -1  -1  1  1177  90  150  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1270  90  -1  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1215  90  -1  8  ]
      [  81  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1252  90  396  7  ]
      [  44  1  1  6  254  28  8  39  -1  1  3  1  1133  90  -1  7  ]
      [  47  1  1  5  391  15  8  40  -1  1  3  1  1143  90  -1  16  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1194  90  -1  8  ]
      [  47  1  1  5  691  65  8  38  -1  3  3  1  1186  90  -1  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1250  90  -1  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  9  1  3  3  1177  90  306  11  ]
      [  29  1  1  5  787  75  1  40  13  3  3  1  1159  90  410  7  ]
      [  50  2  1  5  789  85  8  40  9  2  3  1  1283  90  282  7  ]
      [  47  1  1  6  70  10  8  40  -1  2  1  1  1153  90  -1  13  ]
      [  33  1  1  5  863  80  1  40  -1  2  3  1  1285  90  -1  11  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1197  90  -1  7  ]
      [  61  1  1  5  788  60  1  40  -1  1  4  1  1285  90  -1  7  ]
      [  46  1  1  6  546  45  8  40  -1  2  3  1  1124  90  -1  14  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1169  90  -1  7  ]
      [  48  1  1  6  744  28  8  38  -1  2  3  1  1256  90  -1  17  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1145  90  -1  10  ]
      [  49  1  1  6  281  50  8  38  -1  2  3  1  1172  90  -1  15  ]
      [  43  1  1  6  660  52  8  38  -1  2  3  1  1106  90  -1  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1338  90  -1  8  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  4  1  5  1399  90  -1  8  ]
      [  48  1  1  6  744  51  8  42  -1  1  4  1  1386  90  -1  12  ]
      [  49  1  1  5  796  70  8  40  14  1  5  1  1359  90  560  10  ]
      [  68  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1409  90  320  8  ]
      [  67  1  8  -1  -1  -1  -1  -1  7  1  3  3  1466  90  250  9  ]
      [  62  1  1  6  714  63  8  40  -1  1  -1  1  1464  90  -1  10  ]
      [  47  1  1  5  780  28  8  40  13  3  3  1  1399  90  480  15  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1371  90  -1  10  ]
      [  54  2  1  4  789  85  1  38  -1  3  3  1  1484  90  -1  8  ]
      [  47  1  1  1  101  26  8  45  -1  1  3  1  1460  90  -1  12  ]
      [  41  1  1  5  175  22  8  39  -1  -1  -1  1  1432  90  -1  8  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  5  5  3  1332  90  -1  8  ]
      [  30  1  1  6  471  45  8  40  14  1  -1  1  1361  90  500  13  ]
      [  39  1  1  5  51  1  8  50  13  3  5  1  1443  90  500  8  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1336  90  -1  8  ]
      [  31  1  1  5  620  28  8  35  12  4  3  1  1364  90  450  13  ]
      [  59  1  1  5  540  45  8  38  -1  1  3  1  1404  90  -1  15  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1415  90  0  8  ]
      [  44  1  1  6  51  1  1  38  -1  3  3  1  1346  90  -1  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1354  90  -1  13  ]
      [  45  1  1  5  714  60  8  40  10  3  3  1  1315  90  350  10  ]
      [  32  2  1  5  872  80  1  19  8  5  9  1  1366  90  300  8  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1476  90  -1  8  ]
      [  32  2  1  5  780  65  8  30  11  3  4  1  1354  90  380  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1368  90  -1  16  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1440  90  -1  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1392  90  -1  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1466  90  -1  11  ]
      [  28  1  1  6  441  45  8  40  -1  1  -1  1  1390  90  -1  14  ]
      [  29  1  1  6  714  63  8  50  16  1  3  1  1444  90  640  8  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1391  90  -1  8  ]
      [  38  1  1  6  796  80  8  38  8  1  3  1  1412  90  315  12  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1483  90  -1  8  ]
      [  30  1  1  6  492  36  8  37  -1  1  99  1  1469  90  0  10  ]
      [  49  1  1  6  254  31  8  35  7  1  3  1  1353  90  257  14  ]
      [  61  2  8  -1  -1  -1  -1  -1  8  1  3  3  1389  90  195  8  ]
      [  43  1  1  6  255  35  8  45  12  5  9  1  1319  90  450  9  ]
      [  52  1  1  6  441  75  1  38  3  1  3  1  1311  90  100  8  ]
      [  41  2  8  -1  -1  -1  -1  -1  15  9  -1  2  1374  90  500  15  ]
      [  48  1  1  6  281  50  8  40  12  2  3  1  1484  90  417  14  ]
      [  49  1  1  2  750  50  8  40  -1  2  3  1  1464  90  -1  14  ]
      [  69  1  8  -1  -1  -1  -1  -1  12  1  8  3  1478  90  434  11  ]
      [  36  2  1  5  856  85  8  32  -1  2  6  1  1439  90  -1  15  ]
      [  34  1  1  6  540  21  8  40  -1  2  3  1  1472  90  -1  8  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1588  90  -1  9  ]
      [  60  2  1  1  821  22  8  40  -1  -1  -1  1  1589  90  -1  9  ]
      [  35  1  1  2  881  51  8  40  11  5  5  1  1554  90  350  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1578  90  308  9  ]
      [  35  2  1  5  787  34  8  30  -1  3  5  1  1614  90  -1  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1629  90  -1  10  ]
      [  33  1  1  6  441  45  8  38  8  1  3  1  1686  90  250  14  ]
      [  37  2  1  5  672  65  8  39  -1  3  3  1  1651  90  400  9  ]
      [  68  1  8  -1  -1  -1  -1  -1  13  1  3  3  1607  90  500  11  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1567  90  -1  9  ]
      [  41  2  1  5  856  85  8  20  7  3  3  1  1615  90  250  9  ]
      [  26  1  1  6  281  34  8  40  12  1  3  1  1579  90  445  10  ]
      [  38  1  1  5  540  21  8  40  -1  3  3  1  1615  90  0  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1536  90  -1  11  ]
      [  44  1  1  6  510  45  8  40  8  1  3  1  1532  90  250  9  ]
      [  36  1  1  6  501  20  8  38  -1  3  3  1  1639  90  -1  9  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1700  90  -1  10  ]
      [  43  1  1  5  841  85  8  38  17  5  10  1  1593  90  675  12  ]
      [  34  1  1  1  775  72  8  50  10  3  3  1  1605  90  365  13  ]
      [  41  1  1  6  310  75  1  38  -1  1  3  1  1698  90  -1  9  ]
      [  50  1  1  6  540  24  8  38  9  1  3  1  1573  90  340  15  ]
      [  44  1  1  6  310  40  8  38  -1  1  3  1  1606  90  -1  13  ]
      [  55  1  1  6  440  45  8  40  12  1  -1  1  1566  90  300  17  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1620  90  -1  9  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1556  90  -1  9  ]
      [  31  1  1  6  546  45  8  40  9  1  3  1  1618  90  350  10  ]
      [  45  1  1  5  772  51  8  40  8  3  3  1  1686  90  300  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1632  90  -1  13  ]
      [  45  2  1  5  411  85  1  39  -1  3  4  1  1611  90  -1  9  ]
      [  42  1  1  6  254  51  8  38  -1  1  3  1  1663  90  -1  15  ]
      [  38  2  1  5  171  74  8  40  16  1  3  1  1556  90  650  14  ]
      [  36  1  1  4  801  75  1  39  -1  3  3  1  1606  90  -1  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1507  90  -1  11  ]
      [  27  1  1  6  290  34  8  35  11  1  3  1  1678  90  430  12  ]
      [  36  1  1  6  997  28  8  38  -1  9  4  1  1530  90  -1  9  ]
      [  26  2  1  5  788  34  8  35  -1  3  5  1  1542  90  -1  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1524  90  -1  9  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1526  90  -1  14  ]
      [  58  1  1  5  692  66  8  60  15  1  5  1  1564  90  500  9  ]
      [  54  2  1  5  789  26  8  38  -1  1  3  1  1554  90  -1  9  ]
      [  59  1  1  2  672  52  8  75  -1  3  4  1  1500  90  -1  9  ]
      [  40  1  1  5  632  33  8  35  -1  1  3  1  1588  90  -1  13  ]
      [  21  1  1  6  742  63  1  65  17  1  1  1  1606  90  700  14  ]
      [  43  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1675  90  -1  10  ]
      [  42  1  1  6  274  40  8  38  -1  1  3  1  1552  90  0  9  ]
      [  45  2  1  5  921  95  8  38  12  3  3  1  1529  90  434  9  ]
      [  63  1  1  5  620  24  8  40  -1  5  6  1  1654  90  -1  12  ]
      [  46  1  1  6  512  34  8  38  -1  2  3  1  1685  90  -1  10  ]
      [  44  1  1  6  531  25  8  38  8  2  -1  1  1882  90  276  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  5  1881  90  -1  12  ]
      [  33  1  1  6  254  28  8  35  7  1  -1  1  1843  90  240  10  ]
      [  51  1  1  5  756  65  8  39  -1  5  3  1  1755  90  -1  10  ]
      [  48  1  1  4  787  64  8  39  -1  1  1  1  1991  90  -1  13  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1768  90  -1  14  ]
      [  38  1  1  6  788  17  8  37  -1  1  -1  1  1741  90  400  12  ]
      [  40  1  1  5  778  30  8  30  18  5  9  1  1788  90  650  16  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  5  10  3  1906  90  -1  10  ]
      [  39  1  1  5  714  60  1  38  10  1  -1  1  1884  90  310  11  ]
      [  39  1  1  6  292  29  8  37  -1  1  3  1  1822  90  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1889  90  -1  11  ]
      [  43  1  1  6  501  24  8  38  14  1  3  1  1800  90  550  12  ]
      [  55  1  1  5  600  24  8  45  -1  1  8  1  1863  90  -1  10  ]
      [  41  1  8  -1  -1  -1  -1  -1  -1  1  3  8  1744  90  -1  12  ]
      [  28  1  1  6  660  51  8  40  6  5  3  1  1906  90  200  15  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1874  90  -1  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  3  3  1788  90  420  11  ]
      [  38  1  1  5  787  75  1  38  17  3  3  1  1778  90  615  11  ]
      [  56  1  1  6  316  90  1  39  -1  3  3  1  1753  90  -1  12  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1798  90  -1  10  ]
      [  32  1  1  6  250  34  8  35  9  1  -1  1  1744  90  300  13  ]
      [  47  2  1  5  661  52  8  25  -1  1  4  3  1899  90  -1  12  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1740  90  -1  10  ]
      [  47  1  1  5  623  45  8  40  -1  3  3  1  1775  90  -1  13  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1937  90  -1  10  ]
      [  66  2  8  -1  -1  -1  -1  -1  11  1  3  3  1946  90  400  10  ]
      [  45  1  1  5  691  65  8  39  12  3  3  1  1911  90  455  15  ]
      [  44  1  1  5  281  50  8  38  -1  3  3  1  1761  90  -1  11  ]
      [  47  1  1  5  608  32  8  40  14  5  8  1  1710  90  400  15  ]
      [  42  1  1  5  874  80  1  38  -1  5  8  1  1819  90  -1  10  ]
      [  35  1  1  4  801  75  1  40  12  2  5  1  1792  90  450  17  ]
      [  57  1  1  5  787  75  1  40  -1  5  9  1  1989  90  -1  21  ]
      [  27  1  1  2  911  55  8  70  -1  3  3  1  1740  90  -1  14  ]
      [  58  2  1  4  872  80  1  35  -1  5  9  1  2020  90  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2133  90  -1  11  ]
      [  30  2  1  5  821  22  8  40  15  5  9  1  2200  90  600  14  ]
      [  44  1  1  5  620  28  8  35  -1  5  5  1  2122  90  -1  15  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2265  90  -1  12  ]
      [  52  1  1  5  651  27  8  35  -1  1  5  1  2196  90  -1  20  ]
      [  31  1  1  5  751  74  8  45  11  5  9  1  2048  90  462  12  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  8  3  2268  90  -1  11  ]
      [  40  2  1  4  870  80  1  20  8  5  9  1  2112  90  300  11  ]
      [  46  2  1  4  787  75  1  38  -1  5  7  1  2254  90  -1  11  ]
      [  37  2  1  5  780  74  8  16  13  3  3  1  2157  90  500  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2226  90  -1  11  ]
      [  59  1  1  5  780  51  8  40  6  3  3  1  2113  90  225  11  ]
      [  28  2  1  4  873  80  1  39  -1  5  9  1  2268  90  -1  17  ]
      [  33  1  1  5  691  65  8  39  16  5  5  1  2009  90  600  15  ]
      [  48  1  1  5  780  75  1  38  -1  5  9  1  2172  90  -1  11  ]
      [  35  2  1  5  841  85  1  60  -1  5  9  1  2142  90  -1  11  ]
      [  49  1  1  5  777  93  8  38  -1  1  99  1  2268  90  -1  17  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2283  90  -1  11  ]
      [  38  1  1  5  621  45  8  36  -1  1  5  1  2058  90  -1  12  ]
      [  32  1  1  4  873  80  1  50  11  5  9  1  2247  90  440  15  ]
      [  48  2  8  5  671  31  8  40  18  3  8  1  2193  90  750  21  ]
      [  44  1  1  5  871  80  1  40  -1  5  10  1  2036  90  -1  17  ]
      [  42  1  1  6  714  63  8  40  -1  1  -1  1  2018  90  -1  17  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2193  90  -1  11  ]
      [  38  1  1  5  711  60  8  40  -1  2  4  1  2234  90  -1  11  ]
      [  32  1  1  5  911  55  8  40  14  3  4  1  2126  90  570  13  ]
      [  49  1  1  4  801  75  1  40  -1  3  3  1  2573  90  -1  15  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2399  90  -1  15  ]
      [  46  1  1  6  443  35  8  39  15  3  3  1  2389  90  520  13  ]
      [  43  1  1  5  609  74  8  60  15  5  8  1  2588  90  460  14  ]
      [  57  1  1  2  841  85  8  98  12  -1  -1  1  2573  90  400  14  ]
      [  33  1  1  5  775  34  8  35  9  5  8  1  2451  90  300  15  ]
      [  55  1  1  6  521  63  8  35  23  3  3  1  2314  90  800  16  ]
      [  46  1  1  6  318  50  8  36  10  1  3  1  2476  90  358  12  ]
      [  58  1  1  6  620  29  8  40  -1  -1  -1  1  2425  90  -1  12  ]
      [  29  1  1  5  785  28  8  38  -1  3  3  1  2316  90  0  14  ]
      [  34  1  1  6  254  28  8  37  10  -1  -1  1  2600  90  380  13  ]
      [  61  1  1  5  731  64  8  39  10  1  4  1  2539  90  400  12  ]
      [  39  1  1  5  788  45  8  38  -1  5  3  1  2438  90  -1  12  ]
      [  41  1  1  6  601  32  8  38  9  5  5  1  2413  90  300  16  ]
      [  30  1  1  5  772  29  8  40  7  3  3  1  2497  90  259  12  ]
      [  62  1  1  1  780  70  8  40  -1  1  3  1  2468  90  -1  13  ]
      [  41  1  1  5  772  64  8  45  17  5  5  1  2593  90  600  15  ]
      [  53  2  1  6  531  34  8  35  9  1  3  1  2374  90  324  12  ]
      [  38  1  1  5  726  62  8  40  16  5  9  1  2496  90  590  17  ]
      [  78  1  8  -1  -1  -1  -1  -1  13  3  99  3  2345  90  480  13  ]
      [  51  1  1  1  687  74  8  60  15  1  4  1  2574  90  605  12  ]
      [  33  1  1  5  704  70  8  60  13  5  8  1  2387  90  500  12  ]
      [  37  1  1  6  540  21  8  40  -1  3  3  1  2840  90  -1  13  ]
      [  38  1  1  2  911  55  8  98  -1  3  3  1  2882  90  -1  13  ]
      [  44  1  1  2  911  55  8  98  -1  5  3  1  2882  90  -1  13  ]
      [  51  1  1  5  600  45  8  38  -1  5  8  1  2778  90  -1  14  ]
      [  35  1  1  5  780  51  8  36  13  3  3  1  2832  90  500  13  ]
      [  30  1  1  4  870  80  1  40  11  5  9  1  2759  90  350  17  ]
      [  37  1  1  5  689  52  8  40  11  1  3  1  2883  90  450  14  ]
      [  33  1  1  5  775  35  8  40  11  4  8  1  2789  90  350  13  ]
      [  46  1  1  4  765  80  1  40  13  3  7  1  2824  90  400  17  ]
      [  59  1  1  4  608  75  1  39  -1  3  8  1  2894  90  -1  17  ]
      [  59  1  1  6  716  75  1  34  15  1  3  1  2978  90  600  16  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  5  8  3  3055  90  -1  14  ]
      [  29  2  1  6  331  18  8  65  9  5  3  1  2927  90  350  17  ]
      [  32  1  1  5  441  45  8  50  11  3  4  1  3012  90  410  14  ]
      [  29  1  1  5  881  52  8  40  14  5  9  1  3150  90  500  20  ]
      [  27  1  1  5  726  62  8  40  20  5  9  1  3089  90  790  14  ]
      [  38  1  1  4  802  75  1  56  -1  1  5  1  3058  90  -1  17  ]
      [  42  1  1  5  620  29  8  37  -1  1  3  1  3098  90  -1  14  ]
      [  35  1  1  5  691  65  8  50  20  5  9  1  2941  90  700  19  ]
      [  60  1  1  2  750  45  8  40  -1  5  9  1  3038  90  -1  17  ]
      [  35  1  1  5  603  45  8  40  8  5  8  1  3024  90  246  14  ]
      [  37  1  1  5  774  32  8  40  21  4  3  1  3370  90  800  17  ]
      [  58  1  1  5  750  25  8  40  9  1  3  1  3598  90  350  15  ]
      [  56  1  1  5  602  31  8  40  16  5  9  1  3242  90  665  19  ]
      [  34  1  1  5  310  29  8  55  -1  1  3  1  3797  90  -1  16  ]
      [  38  1  1  2  750  52  8  40  21  5  9  1  3631  90  750  16  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  5  9  3  3856  90  -1  16  ]
      [  41  1  1  1  609  45  8  50  -1  4  8  1  4557  90  414  18  ]
      [  61  1  1  2  609  74  8  70  -1  5  7  1  4948  90  -1  19  ]
      [  51  1  1  1  774  72  8  44  -1  5  9  1  4693  90  -1  18  ]
      [  45  1  1  6  316  28  8  35  -1  1  5  1  5413  90  -1  19  ]
      [  75  1  1  5  911  24  8  40  -1  5  8  1  5928  90  -1  20  ]
      [  40  1  1  2  750  72  8  50  -1  5  9  1  6369  90  -1  22  ]
      [  42  1  1  5  750  67  8  40  23  5  -1  1  16016  90  860  23  ]
      [  37  1  1  5  691  65  8  40  -1  5  9  1  19340  90  -1  24  ]
      [  65  1  1  6  714  60  8  10  10  1  3  3  604  89  390  7  ]
      [  41  1  8  -1  -1  -1  -1  -1  12  2  3  2  613  89  430  10  ]
      [  50  1  8  -1  -1  -1  -1  -1  -1  1  3  2  764  89  -1  14  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  834  89  -1  6  ]
      [  36  1  1  5  714  52  8  20  -1  5  3  1  938  89  -1  13  ]
      [  20  2  8  6  773  52  8  10  8  1  -1  4  996  89  290  6  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  955  89  -1  6  ]
      [  45  1  1  6  912  55  8  25  16  1  3  1  1071  89  570  9  ]
      [  41  1  1  5  780  51  8  38  18  1  3  1  1192  89  650  12  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1115  89  -1  7  ]
      [  55  2  1  1  995  52  8  98  11  4  -1  1  1126  89  350  11  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1130  89  -1  7  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1252  89  -1  7  ]
      [  35  1  1  6  521  28  8  42  13  1  3  1  1281  89  492  15  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1141  89  -1  9  ]
      [  36  1  1  6  712  60  8  38  13  1  3  1  1260  89  400  10  ]
      [  45  1  1  5  250  24  8  40  -1  2  3  1  1250  89  -1  11  ]
      [  39  1  1  6  713  10  8  40  10  1  3  1  1499  89  350  9  ]
      [  33  1  1  5  622  30  8  40  10  4  3  1  1481  89  400  12  ]
      [  31  1  1  6  311  36  8  35  4  3  3  1  1484  89  130  8  ]
      [  38  1  1  6  741  21  8  39  9  1  -1  1  1335  89  300  10  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1366  89  -1  8  ]
      [  33  1  1  5  861  85  8  40  5  2  4  1  1483  89  174  11  ]
      [  51  2  1  1  813  80  8  20  -1  5  9  1  1587  89  470  11  ]
      [  41  1  1  6  714  26  8  40  -1  1  -1  1  1550  89  -1  12  ]
      [  26  2  1  4  801  75  1  39  8  3  3  1  1562  89  315  9  ]
      [  37  2  1  5  780  52  8  37  12  5  3  1  1697  89  320  9  ]
      [  49  1  1  6  241  29  8  35  12  1  3  1  1552  89  348  15  ]
      [  35  1  1  5  780  60  8  38  14  1  -1  1  1656  89  535  14  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1825  89  -1  11  ]
      [  63  1  1  5  894  91  8  9  14  1  3  1  1868  89  505  13  ]
      [  41  1  1  6  310  34  8  36  11  3  3  1  1742  89  380  13  ]
      [  68  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1759  89  560  12  ]
      [  37  2  1  5  773  52  8  20  12  3  -1  1  1951  89  455  11  ]
      [  52  1  1  5  871  80  1  27  11  5  9  1  1941  89  370  10  ]
      [  41  1  1  6  351  92  1  39  8  -1  3  1  2039  89  275  11  ]
      [  41  1  1  5  691  65  8  38  -1  3  3  1  2212  89  -1  11  ]
      [  36  1  1  4  603  75  1  39  13  5  9  1  2158  89  500  11  ]
      [  78  1  8  -1  -1  -1  -1  -1  14  4  -1  3  2185  89  400  11  ]
      [  50  2  1  2  832  80  8  30  -1  3  3  1  2140  89  -1  17  ]
      [  33  1  1  4  813  75  1  39  -1  5  8  1  2373  89  -1  14  ]
      [  46  1  1  5  780  22  8  40  13  5  8  1  2370  89  487  17  ]
      [  40  1  1  5  689  15  8  40  -1  3  3  1  2571  89  -1  12  ]
      [  52  1  1  2  753  74  8  60  -1  5  5  1  3469  89  -1  15  ]
      [  46  2  1  1  851  85  8  15  22  5  9  1  209  88  860  16  ]
      [  26  1  1  8  501  20  8  40  13  5  -1  1  449  88  460  5  ]
      [  33  1  8  -1  -1  -1  -1  -1  -1  2  3  2  471  88  -1  5  ]
      [  35  1  8  -1  -1  -1  -1  -1  10  2  3  2  441  88  385  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  812  88  -1  5  ]
      [  41  1  8  -1  -1  -1  -1  -1  8  2  6  3  727  88  300  5  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  9  -1  3  795  88  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  923  88  -1  6  ]
      [  37  1  1  6  997  75  1  40  10  4  -1  1  1021  88  333  6  ]
      [  48  2  1  6  523  52  8  38  -1  1  -1  1  903  88  0  7  ]
      [  26  1  1  6  421  52  8  39  11  1  -1  1  994  88  400  11  ]
      [  52  1  1  5  501  45  8  40  12  1  3  1  1046  88  425  10  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1023  88  -1  6  ]
      [  63  1  8  6  792  80  8  8  8  1  3  3  969  88  250  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1098  88  -1  10  ]
      [  30  1  1  5  780  51  8  40  10  4  3  1  1115  88  370  7  ]
      [  24  1  1  5  622  31  8  38  -1  5  3  1  1222  88  -1  7  ]
      [  24  1  1  6  310  74  8  38  16  3  3  1  1245  88  630  7  ]
      [  40  2  1  5  788  80  1  31  10  3  3  1  1201  88  380  8  ]
      [  33  1  1  2  881  92  8  50  -1  5  9  1  1214  88  -1  13  ]
      [  59  1  1  5  787  75  1  38  14  1  -1  1  1327  88  500  11  ]
      [  29  1  1  2  750  29  8  40  -1  4  8  1  1309  88  0  11  ]
      [  35  1  1  6  912  55  8  49  12  1  -1  1  1466  88  410  10  ]
      [  53  1  1  6  281  50  8  37  -1  1  3  1  1414  88  -1  12  ]
      [  42  1  1  6  741  31  8  38  11  -1  -1  1  1448  88  420  14  ]
      [  65  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  1486  88  327  8  ]
      [  34  1  1  6  488  45  8  40  11  1  -1  1  1426  88  400  8  ]
      [  58  1  1  6  511  29  8  35  7  1  3  1  1387  88  230  13  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1411  88  0  8  ]
      [  39  1  1  6  461  45  8  38  -1  1  3  1  1408  88  -1  10  ]
      [  36  1  1  6  935  90  1  38  16  1  -1  1  1662  88  545  9  ]
      [  53  1  1  6  316  64  8  38  -1  1  3  1  1941  88  387  10  ]
      [  52  1  1  4  787  60  8  39  -1  1  3  1  1823  88  -1  11  ]
      [  46  2  1  5  788  45  8  40  -1  5  9  1  1886  88  -1  11  ]
      [  60  1  1  5  174  65  1  39  13  1  3  1  2078  88  440  11  ]
      [  62  2  1  4  870  80  1  50  -1  5  9  1  2581  88  -1  12  ]
      [  54  1  1  4  874  80  1  40  -1  5  9  1  2378  88  -1  18  ]
      [  57  1  1  5  611  24  8  40  17  5  8  1  4503  88  605  18  ]
      [  45  1  1  5  600  45  8  50  11  5  9  1  8783  88  400  22  ]
      [  68  2  8  -1  -1  -1  -1  -1  8  1  -1  3  482  87  250  3  ]
      [  27  1  8  5  691  65  8  25  7  5  3  1  481  87  250  3  ]
      [  55  1  8  -1  -1  -1  -1  -1  9  1  5  3  624  87  317  8  ]
      [  60  1  1  1  305  52  8  40  -1  3  6  1  690  87  -1  7  ]
      [  90  2  8  -1  -1  -1  -1  -1  7  1  3  3  838  87  252  5  ]
      [  22  1  1  6  24  92  8  40  7  1  3  1  742  87  245  5  ]
      [  29  2  8  -1  -1  -1  -1  -1  11  5  8  6  999  87  339  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1151  87  -1  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  10  1  3  3  1119  87  309  12  ]
      [  37  2  8  -1  -1  -1  -1  -1  13  1  -1  2  1286  87  490  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1154  87  -1  12  ]
      [  34  1  1  5  660  51  8  38  -1  2  8  1  1169  87  -1  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  19  1  3  3  1467  87  655  9  ]
      [  62  2  8  -1  -1  -1  -1  -1  12  1  3  3  1363  87  360  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  9  4  3  1441  87  650  13  ]
      [  41  2  1  5  780  51  8  39  16  3  4  1  1341  87  540  16  ]
      [  31  2  1  6  531  34  8  30  13  1  3  1  1691  87  450  9  ]
      [  51  1  1  6  310  85  1  37  -1  1  4  1  1657  87  -1  17  ]
      [  52  1  1  6  714  45  8  45  -1  1  3  1  1594  87  -1  9  ]
      [  44  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1869  87  -1  11  ]
      [  43  1  1  5  672  52  8  40  -1  -1  -1  1  1919  87  -1  10  ]
      [  39  1  1  5  600  31  8  35  -1  5  8  1  1744  87  -1  15  ]
      [  39  1  1  5  750  80  1  39  -1  5  8  1  1791  87  -1  17  ]
      [  55  2  1  5  683  22  8  35  16  1  1  1  2000  87  655  18  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1844  87  -1  12  ]
      [  47  2  1  5  661  52  8  30  14  1  3  1  2179  87  510  11  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  5  7  3  2162  87  -1  12  ]
      [  58  1  1  5  691  65  1  38  -1  1  4  1  2177  87  -1  11  ]
      [  43  1  1  5  626  24  8  50  -1  4  5  1  2214  87  -1  15  ]
      [  44  1  1  6  316  29  8  36  14  1  3  1  2133  87  500  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  9  -1  3  2266  87  -1  11  ]
      [  52  1  1  6  241  28  8  35  -1  1  3  1  2554  87  -1  17  ]
      [  43  1  1  9  801  75  1  46  9  3  4  1  2383  87  314  16  ]
      [  35  1  1  5  841  85  8  38  17  5  9  1  2662  87  650  13  ]
      [  32  1  1  4  612  80  1  60  20  5  10  1  2825  87  780  13  ]
      [  36  1  8  -1  -1  -1  -1  -1  12  1  -1  2  461  86  347  11  ]
      [  70  1  8  -1  -1  -1  -1  -1  16  1  3  3  603  86  520  6  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  629  86  -1  6  ]
      [  56  1  8  -1  -1  -1  -1  -1  16  1  -1  2  610  86  575  7  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  3  3  579  86  -1  16  ]
      [  29  1  1  6  714  60  8  40  8  2  3  1  670  86  258  8  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  892  86  -1  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  853  86  -1  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  953  86  -1  6  ]
      [  32  2  1  5  912  55  8  50  13  4  3  1  1079  86  470  6  ]
      [  47  1  1  5  706  65  8  40  -1  2  6  1  1027  86  315  10  ]
      [  48  2  1  5  780  45  8  12  -1  3  3  1  930  86  -1  10  ]
      [  40  2  1  6  921  93  8  39  11  3  3  1  941  86  439  7  ]
      [  32  2  8  -1  -1  -1  -1  -1  12  2  3  2  991  86  430  8  ]
      [  50  1  1  6  485  25  8  37  -1  1  3  1  1156  86  -1  11  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1285  86  -1  9  ]
      [  42  1  1  5  269  45  8  38  -1  3  3  1  1295  86  -1  14  ]
      [  44  1  1  5  750  70  8  35  9  4  8  1  1272  86  288  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  1184  86  305  8  ]
      [  43  2  1  5  853  85  1  20  8  4  4  1  1132  86  260  8  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1292  86  -1  11  ]
      [  59  1  1  5  620  60  8  38  -1  3  99  1  1408  86  490  13  ]
      [  30  1  1  5  742  37  8  40  -1  1  3  1  1405  86  -1  8  ]
      [  46  1  1  5  512  34  8  40  -1  1  99  1  1366  86  -1  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1489  86  -1  9  ]
      [  61  1  1  5  787  75  1  39  12  1  3  1  1362  86  450  10  ]
      [  61  1  8  6  141  24  8  39  10  1  3  1  1376  86  346  8  ]
      [  72  1  8  -1  -1  -1  -1  -1  11  3  3  3  1385  86  400  11  ]
      [  43  1  1  6  744  51  8  38  14  1  3  1  1566  86  459  13  ]
      [  35  1  1  2  315  52  8  50  17  3  5  1  1630  86  650  9  ]
      [  77  1  8  -1  -1  -1  -1  -1  12  3  4  3  1654  86  410  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  14  1  3  3  1609  86  499  9  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1590  86  0  9  ]
      [  33  1  1  6  714  60  8  51  11  1  3  1  1591  86  294  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  11  1  3  3  1514  86  400  10  ]
      [  46  2  1  5  789  92  1  39  14  5  3  1  1506  86  530  9  ]
      [  45  2  1  5  780  19  8  38  12  1  3  1  1672  86  475  9  ]
      [  36  1  1  5  621  28  8  40  9  3  99  1  1514  86  300  14  ]
      [  48  1  1  6  546  45  8  40  -1  1  3  1  1564  86  -1  9  ]
      [  57  1  8  -1  -1  -1  -1  -1  12  1  3  3  1681  86  400  13  ]
      [  35  1  1  5  290  34  8  55  -1  1  5  1  1526  86  -1  10  ]
      [  42  2  1  5  780  74  8  32  16  3  3  1  1628  86  600  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  12  1  4  3  1575  86  385  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1550  86  -1  13  ]
      [  50  1  1  6  310  45  8  40  14  2  3  1  1605  86  400  9  ]
      [  36  1  1  6  483  45  8  40  13  2  3  1  1598  86  500  15  ]
      [  52  1  1  5  780  75  1  40  10  2  3  1  1667  86  312  11  ]
      [  38  1  1  6  714  51  8  39  -1  1  3  1  1879  86  -1  11  ]
      [  31  2  1  5  789  80  8  40  17  5  9  1  1868  86  565  10  ]
      [  50  1  1  5  401  52  8  38  13  1  5  1  1795  86  535  16  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1898  86  -1  10  ]
      [  49  1  1  6  268  24  8  40  12  1  3  1  1825  86  382  10  ]
      [  40  2  1  5  778  75  1  38  -1  1  3  1  1853  86  -1  10  ]
      [  54  1  1  6  222  34  8  35  12  1  3  1  1920  86  450  14  ]
      [  45  1  1  6  511  45  8  39  9  1  3  1  1965  86  295  10  ]
      [  59  1  8  6  290  29  8  35  -1  1  3  1  1856  86  -1  10  ]
      [  33  1  1  5  660  29  8  39  14  3  3  1  1910  86  359  11  ]
      [  37  1  1  2  687  51  8  45  13  2  3  1  1800  86  422  11  ]
      [  42  2  1  4  873  80  1  39  11  5  9  1  2247  86  414  11  ]
      [  29  1  1  5  602  32  8  39  12  5  8  1  2143  86  345  14  ]
      [  45  1  1  6  540  34  8  40  -1  5  5  1  2116  86  -1  17  ]
      [  50  1  1  4  802  75  1  56  -1  1  3  1  2223  86  -1  15  ]
      [  33  1  1  5  622  64  8  38  10  1  3  1  2229  86  350  17  ]
      [  38  1  1  6  531  28  8  37  6  1  -1  1  2042  86  225  12  ]
      [  57  1  1  5  677  29  8  38  10  1  3  1  2093  86  353  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  10  3  3  3  2279  86  318  11  ]
      [  25  2  1  5  822  99  8  39  -1  3  4  1  2260  86  -1  11  ]
      [  37  1  1  4  872  80  1  50  16  5  10  1  2315  86  540  12  ]
      [  35  1  1  5  751  24  8  60  -1  5  5  1  2432  86  -1  12  ]
      [  49  2  1  4  870  80  1  38  11  5  9  1  2347  86  405  12  ]
      [  33  1  1  5  771  66  8  37  -1  5  10  1  2496  86  -1  12  ]
      [  52  1  1  4  801  75  1  39  14  3  7  1  2530  86  360  16  ]
      [  39  1  1  5  993  92  8  38  19  4  3  1  2633  86  680  13  ]
      [  47  1  1  5  750  71  8  40  17  3  3  1  2648  86  600  14  ]
      [  57  1  1  4  801  75  1  40  -1  3  7  1  2713  86  -1  16  ]
      [  58  1  1  4  872  80  1  38  16  5  8  1  2921  86  580  14  ]
      [  49  1  1  5  701  63  8  40  14  3  3  1  2948  86  500  16  ]
      [  54  2  1  5  641  45  8  39  -1  1  3  1  2919  86  -1  14  ]
      [  40  2  1  5  883  24  8  40  -1  5  9  1  4193  86  -1  17  ]
      [  40  1  1  5  692  67  8  55  16  3  3  1  5249  86  500  19  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  6  213  85  -1  3  ]
      [  53  2  8  -1  -1  -1  -1  -1  12  1  4  4  166  85  400  12  ]
      [  33  1  8  -1  -1  -1  -1  -1  50  1  3  2  303  85  -1  3  ]
      [  31  1  8  5  391  15  8  22  13  1  5  1  427  85  410  11  ]
      [  23  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  399  85  -1  7  ]
      [  40  1  8  -1  -1  -1  -1  -1  -1  1  3  2  324  85  -1  8  ]
      [  32  1  8  -1  -1  -1  -1  -1  5  5  3  4  455  85  130  3  ]
      [  54  2  8  -1  -1  -1  -1  -1  -1  3  3  2  531  85  -1  4  ]
      [  35  1  8  -1  -1  -1  -1  -1  8  2  3  2  632  85  275  4  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  5  5  513  85  -1  4  ]
      [  46  1  8  -1  -1  -1  -1  -1  11  1  3  2  679  85  368  7  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  586  85  -1  4  ]
      [  38  2  8  -1  -1  -1  -1  -1  -1  3  3  6  545  85  -1  5  ]
      [  33  1  8  6  522  50  8  40  12  5  -1  1  524  85  400  6  ]
      [  35  2  8  -1  -1  -1  -1  -1  10  5  9  2  614  85  360  4  ]
      [  91  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  512  85  -1  4  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  505  85  -1  10  ]
      [  30  1  8  6  531  63  8  5  -1  5  3  1  678  85  -1  4  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  1  3  638  85  -1  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  516  85  -1  7  ]
      [  42  2  1  1  869  80  8  40  9  3  3  1  818  85  290  5  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  703  85  -1  10  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  3  3  871  85  -1  5  ]
      [  37  1  1  6  531  74  8  40  11  1  3  1  700  85  425  10  ]
      [  58  1  8  -1  -1  -1  -1  -1  11  1  3  3  865  85  360  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  727  85  -1  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  10  1  3  3  845  85  383  8  ]
      [  55  2  1  5  780  35  8  17  -1  3  3  1  883  85  -1  12  ]
      [  28  2  8  -1  -1  -1  -1  -1  12  1  1  2  809  85  400  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  9  1  3  3  798  85  300  9  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  872  85  -1  5  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  753  85  -1  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  884  85  -1  7  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  2  3  3  703  85  -1  7  ]
      [  38  1  1  2  662  50  8  40  14  -1  -1  1  1010  85  380  10  ]
      [  24  2  1  5  662  52  8  37  16  1  3  1  990  85  500  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1018  85  -1  8  ]
      [  23  1  1  6  401  52  8  40  -1  1  3  1  1081  85  0  8  ]
      [  41  2  1  5  780  93  8  19  12  3  3  1  915  85  425  6  ]
      [  20  2  1  5  869  85  8  40  -1  1  4  1  1022  85  450  10  ]
      [  41  1  1  5  780  63  8  40  -1  -1  -1  1  911  85  -1  6  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  4  3  964  85  -1  10  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1071  85  -1  6  ]
      [  65  2  1  3  780  45  8  30  -1  3  4  3  1002  85  -1  11  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  5  9  3  1057  85  -1  6  ]
      [  39  1  1  6  440  45  8  40  -1  2  3  1  957  85  -1  11  ]
      [  49  1  1  1  687  52  8  43  11  2  5  1  1050  85  340  11  ]
      [  52  2  1  6  631  1  8  15  -1  2  -1  1  938  85  -1  6  ]
      [  50  1  8  -1  -1  -1  -1  -1  12  1  3  6  1228  85  398  8  ]
      [  34  2  1  1  833  92  8  40  17  5  9  1  1199  85  570  15  ]
      [  75  1  1  2  832  92  8  60  15  5  9  1  1228  85  600  14  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  3  4  3  1225  85  -1  10  ]
      [  46  2  1  6  997  20  8  37  -1  1  3  1  1266  85  479  11  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1188  85  -1  8  ]
      [  34  2  1  5  857  85  8  39  12  5  5  1  1204  85  460  12  ]
      [  58  2  1  5  787  75  1  38  -1  1  -1  1  1117  85  -1  7  ]
      [  45  2  1  5  641  28  8  38  -1  1  3  1  1166  85  -1  7  ]
      [  48  2  1  5  171  22  8  40  11  3  3  1  1143  85  350  7  ]
      [  53  2  1  5  785  26  8  20  11  1  3  1  1133  85  390  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1262  85  -1  8  ]
      [  25  1  1  6  411  55  8  45  11  3  3  1  1211  85  385  8  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1233  85  -1  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1189  85  -1  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  8  1  3  3  1126  85  300  9  ]
      [  37  2  1  5  771  99  8  39  11  1  3  1  1200  85  430  7  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1158  85  0  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1183  85  -1  7  ]
      [  40  1  1  6  267  45  8  38  11  4  3  1  1122  85  304  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  8  3  1154  85  -1  18  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1201  85  0  10  ]
      [  34  2  8  -1  -1  -1  -1  -1  12  4  8  2  1101  85  435  8  ]
      [  58  1  1  6  441  45  8  40  -1  1  3  1  1407  85  0  8  ]
      [  40  1  1  5  511  45  8  40  24  -1  -1  1  1357  85  860  8  ]
      [  82  1  8  -1  -1  -1  -1  -1  7  1  -1  3  1411  85  225  13  ]
      [  39  2  1  5  863  80  8  39  13  9  8  1  1333  85  460  12  ]
      [  48  1  8  -1  -1  -1  -1  -1  12  3  3  2  1441  85  375  8  ]
      [  33  1  1  6  714  90  1  38  -1  1  -1  1  1339  85  -1  8  ]
      [  34  2  1  4  787  75  1  38  -1  5  4  1  1304  85  425  13  ]
      [  47  1  1  6  912  55  8  40  17  1  -1  1  1320  85  600  10  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1441  85  -1  12  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1472  85  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  4  99  3  1445  85  -1  8  ]
      [  35  1  1  2  302  36  8  40  11  3  3  1  1310  85  350  12  ]
      [  45  1  1  6  714  63  8  60  10  1  3  1  1353  85  380  13  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1435  85  -1  10  ]
      [  55  1  1  6  788  34  8  20  12  1  3  1  1481  85  450  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  14  3  3  3  1459  85  540  10  ]
      [  44  2  1  6  521  25  8  45  11  1  3  1  1490  85  425  11  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1477  85  0  8  ]
      [  47  1  1  6  545  24  8  38  12  3  3  1  1346  85  326  10  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1441  85  -1  11  ]
      [  86  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1349  85  -1  10  ]
      [  43  1  1  5  712  60  8  40  12  2  3  1  1302  85  428  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  6  5  9  3  1338  85  146  10  ]
      [  35  1  1  5  864  85  8  38  18  3  3  1  1676  85  655  14  ]
      [  34  2  8  -1  -1  -1  -1  -1  10  1  3  3  1601  85  350  9  ]
      [  44  2  1  5  853  85  1  40  -1  3  3  1  1573  85  0  9  ]
      [  30  1  1  5  267  45  8  43  10  3  5  1  1592  85  350  11  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  9  -1  3  1580  85  300  11  ]
      [  35  1  1  6  269  50  8  40  10  5  -1  1  1617  85  305  9  ]
      [  29  1  1  5  603  45  8  40  12  5  9  1  1524  85  400  9  ]
      [  52  1  1  5  864  85  8  49  14  1  3  1  1522  85  500  13  ]
      [  80  1  8  -1  -1  -1  -1  -1  8  1  99  3  1566  85  250  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1595  85  -1  9  ]
      [  34  1  1  5  935  90  8  45  11  1  1  1  1601  85  375  12  ]
      [  30  1  1  2  316  45  8  70  12  3  5  1  1615  85  410  9  ]
      [  38  1  1  6  287  34  8  39  15  1  -1  1  1673  85  500  9  ]
      [  58  1  8  -1  -1  -1  -1  -1  11  1  5  3  1532  85  390  12  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  1  3  3  1563  85  430  13  ]
      [  48  1  1  6  521  40  8  38  -1  1  3  1  1667  85  -1  13  ]
      [  39  1  1  6  741  15  8  40  11  1  -1  1  1591  85  365  9  ]
      [  55  1  1  6  401  52  8  40  9  1  5  1  1615  85  300  9  ]
      [  38  1  1  5  712  60  8  40  -1  2  3  1  1579  85  -1  11  ]
      [  51  1  1  2  878  80  8  60  13  2  5  1  1593  85  430  11  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1926  85  -1  10  ]
      [  90  1  8  -1  -1  -1  -1  -1  -1  4  5  3  1721  85  0  10  ]
      [  35  1  1  5  778  63  8  40  10  4  3  1  1841  85  350  15  ]
      [  41  1  1  5  780  45  8  40  -1  5  3  1  1763  85  -1  10  ]
      [  60  1  1  5  651  51  8  35  -1  1  3  1  1998  85  -1  10  ]
      [  38  1  1  6  540  50  8  35  10  1  -1  1  1860  85  322  12  ]
      [  40  1  1  5  772  55  8  40  13  4  3  1  1994  85  452  11  ]
      [  60  1  1  4  765  75  1  39  9  4  7  1  1819  85  334  17  ]
      [  78  1  8  -1  -1  -1  -1  -1  10  2  3  3  1983  85  385  10  ]
      [  33  1  1  5  689  28  8  48  20  1  3  1  1895  85  720  16  ]
      [  41  1  1  1  254  45  8  50  12  1  5  1  1914  85  400  11  ]
      [  37  1  1  1  481  45  8  11  16  1  3  1  1707  85  620  10  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1903  85  -1  10  ]
      [  41  1  1  5  772  64  8  60  13  4  5  1  1861  85  432  14  ]
      [  33  1  1  5  821  92  8  38  20  5  9  1  1778  85  770  10  ]
      [  82  1  8  -1  -1  -1  -1  -1  10  3  3  3  1970  85  324  10  ]
      [  37  1  1  5  775  72  8  40  -1  1  3  1  1874  85  0  11  ]
      [  33  1  1  6  241  28  8  30  15  1  -1  1  1895  85  460  13  ]
      [  40  1  1  5  854  91  8  38  11  1  3  1  1768  85  357  11  ]
      [  40  1  1  6  481  45  8  40  13  -1  -1  1  1911  85  438  10  ]
      [  32  1  1  4  997  75  1  40  14  5  8  1  1754  85  465  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  3  3  3  2088  85  374  12  ]
      [  25  1  1  6  531  25  8  40  10  3  3  1  2079  85  355  14  ]
      [  59  1  1  6  741  34  8  35  -1  1  3  1  2194  85  -1  12  ]
      [  37  1  1  6  726  62  8  39  14  1  3  1  2158  85  520  12  ]
      [  62  1  1  5  993  66  8  40  -1  3  3  1  2038  85  -1  13  ]
      [  43  1  1  6  267  45  8  42  -1  1  3  1  2267  85  -1  14  ]
      [  30  1  1  6  501  36  8  40  -1  3  5  1  2012  85  -1  11  ]
      [  44  1  1  5  691  65  8  40  -1  1  3  1  2203  85  -1  13  ]
      [  34  1  1  5  777  32  8  50  15  3  5  1  2293  85  500  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  9  1  4  3  2136  85  300  12  ]
      [  37  1  1  4  765  75  1  39  10  5  7  1  2307  85  320  15  ]
      [  40  1  1  5  750  75  1  40  11  3  5  1  2505  85  440  16  ]
      [  34  1  1  5  751  22  8  40  -1  3  3  1  2559  85  -1  12  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2385  85  0  16  ]
      [  43  1  1  2  750  34  8  60  13  3  4  1  2540  85  450  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2554  85  -1  14  ]
      [  54  2  1  4  873  80  1  38  12  5  9  1  2589  85  350  12  ]
      [  41  1  1  5  788  36  8  39  9  3  3  1  2398  85  260  14  ]
      [  26  1  1  6  931  55  8  40  11  -1  -1  1  2534  85  350  12  ]
      [  38  1  1  5  691  65  8  40  15  5  3  1  2820  85  560  17  ]
      [  53  1  1  4  801  75  1  39  -1  5  7  1  2817  85  -1  13  ]
      [  50  1  1  4  801  75  1  38  19  5  3  1  2778  85  700  18  ]
      [  38  1  1  5  601  32  8  40  23  5  9  1  2772  85  900  13  ]
      [  35  1  1  4  61  75  1  40  13  5  9  1  3033  85  434  15  ]
      [  33  1  1  4  629  75  1  39  13  5  9  1  2994  85  440  17  ]
      [  44  1  1  2  268  45  8  60  -1  1  4  1  3140  85  -1  19  ]
      [  66  2  8  -1  -1  -1  -1  -1  12  5  9  3  3116  85  420  15  ]
      [  51  1  1  2  753  74  8  60  9  4  8  1  3014  85  250  14  ]
      [  33  1  1  5  776  32  8  35  14  5  9  1  2983  85  390  14  ]
      [  38  1  1  5  881  24  8  38  -1  5  5  1  3723  85  -1  16  ]
      [  58  1  1  5  785  25  8  38  14  3  3  1  4327  85  500  18  ]
      [  30  1  1  5  750  24  8  60  16  5  8  1  4949  85  600  18  ]
      [  55  1  1  2  750  29  8  50  -1  3  8  1  5805  85  -1  21  ]
      [  30  1  1  5  757  74  8  45  27  5  9  1  5911  85  1000  20  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  -1  -1  4  193  84  -1  2  ]
      [  69  1  8  -1  -1  -1  -1  -1  8  1  3  3  365  84  230  4  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  1  5  3  363  84  450  8  ]
      [  33  1  8  -1  -1  -1  -1  -1  -1  4  -1  4  496  84  0  3  ]
      [  38  2  8  -1  -1  -1  -1  -1  13  -1  -1  6  566  84  360  5  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  534  84  -1  4  ]
      [  52  1  8  -1  -1  -1  -1  -1  10  2  3  2  520  84  354  6  ]
      [  69  2  8  -1  -1  -1  -1  -1  11  1  3  3  573  84  400  4  ]
      [  59  2  8  -1  -1  -1  -1  -1  12  1  3  3  515  84  350  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  744  84  -1  12  ]
      [  69  2  8  -1  -1  -1  -1  -1  10  1  3  3  715  84  384  5  ]
      [  56  2  1  5  856  85  8  40  -1  2  -1  1  722  84  -1  8  ]
      [  52  1  1  5  780  74  8  40  11  5  9  1  877  84  340  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  11  1  3  3  1013  84  350  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  9  1  3  3  970  84  300  10  ]
      [  83  2  8  -1  -1  -1  -1  -1  9  1  -1  3  957  84  288  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  918  84  -1  8  ]
      [  44  1  1  6  141  24  8  40  4  2  3  1  972  84  140  10  ]
      [  44  1  1  1  622  93  8  40  8  2  3  1  950  84  235  11  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1112  84  -1  7  ]
      [  62  1  1  6  622  75  1  20  17  9  -1  1  1221  84  650  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1273  84  -1  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1268  84  -1  9  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1255  84  -1  7  ]
      [  30  2  8  -1  -1  -1  -1  -1  13  1  3  6  1262  84  460  7  ]
      [  78  2  8  -1  -1  -1  -1  -1  8  3  -1  3  1175  84  220  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1224  84  -1  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  10  1  3  3  1194  84  348  7  ]
      [  56  1  1  5  714  52  8  38  -1  2  5  1  1101  84  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1453  84  -1  8  ]
      [  33  2  8  -1  -1  -1  -1  -1  9  3  3  6  1326  84  300  9  ]
      [  27  1  1  5  691  75  1  39  -1  4  7  1  1410  84  -1  13  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  3  3  1486  84  400  8  ]
      [  32  1  1  5  785  31  8  38  -1  3  3  1  1399  84  -1  14  ]
      [  64  1  8  -1  -1  -1  -1  -1  7  3  3  3  1402  84  228  12  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1493  84  -1  11  ]
      [  78  2  8  -1  -1  -1  -1  -1  8  1  3  3  1398  84  267  8  ]
      [  48  1  1  6  310  31  8  37  13  1  3  1  1557  84  452  13  ]
      [  38  1  1  5  754  74  8  40  13  4  8  1  1668  84  470  11  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1657  84  -1  9  ]
      [  62  1  1  6  741  29  8  35  -1  1  3  1  1638  84  -1  12  ]
      [  47  1  1  5  779  85  8  39  18  5  8  1  1684  84  645  15  ]
      [  34  1  1  5  660  52  8  38  12  3  3  1  1835  84  420  10  ]
      [  45  1  1  6  744  34  8  39  14  1  3  1  1957  84  500  10  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  3  5  1700  84  -1  11  ]
      [  56  1  8  -1  -1  -1  -1  -1  9  1  3  3  1856  84  300  14  ]
      [  37  1  1  5  651  17  8  38  9  1  5  1  1741  84  332  11  ]
      [  36  1  1  6  853  85  1  40  14  1  3  1  1816  84  475  13  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2269  84  -1  11  ]
      [  43  1  1  4  787  64  8  39  15  5  3  1  2114  84  477  16  ]
      [  72  1  8  -1  -1  -1  -1  -1  9  1  3  3  2279  84  240  11  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  2263  84  -1  11  ]
      [  31  1  1  6  323  34  8  39  10  3  3  1  2268  84  316  11  ]
      [  31  1  1  5  601  34  8  35  14  5  9  1  2052  84  500  11  ]
      [  33  1  1  5  841  85  1  55  23  5  10  1  2336  84  860  19  ]
      [  47  1  1  6  742  63  8  40  12  1  -1  1  2406  84  450  12  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  5  10  3  2537  84  -1  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  8  -1  -1  3  2686  84  278  13  ]
      [  50  1  1  5  780  93  8  37  18  1  5  1  2848  84  680  15  ]
      [  45  1  1  5  775  72  8  35  12  5  9  1  2696  84  381  15  ]
      [  52  1  1  5  871  80  1  45  14  5  10  1  2997  84  450  18  ]
      [  54  1  1  5  714  60  8  50  -1  3  3  1  3940  84  -1  19  ]
      [  60  1  1  5  620  45  8  40  -1  3  3  1  5025  84  -1  19  ]
      [  24  2  8  5  672  52  8  38  11  1  3  1  244  83  355  11  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  3  -1  3  461  83  -1  17  ]
      [  46  2  1  5  937  75  1  24  13  9  -1  1  443  83  450  9  ]
      [  44  2  8  -1  -1  -1  -1  -1  7  2  3  8  500  83  211  4  ]
      [  53  1  1  2  714  93  8  80  -1  -1  -1  1  627  83  -1  4  ]
      [  59  1  1  1  441  45  8  80  -1  4  5  1  766  83  -1  10  ]
      [  33  2  8  -1  -1  -1  -1  -1  11  1  3  6  707  83  300  5  ]
      [  24  1  1  6  181  20  8  40  11  3  3  1  978  83  340  6  ]
      [  58  1  8  -1  -1  -1  -1  -1  7  -1  -1  3  934  83  240  9  ]
      [  73  2  8  -1  -1  -1  -1  -1  9  1  3  3  1046  83  310  6  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  -1  3  904  83  319  6  ]
      [  46  2  8  -1  -1  -1  -1  -1  10  2  3  2  905  83  341  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1245  83  460  7  ]
      [  52  1  1  5  662  52  8  39  15  1  3  1  1135  83  510  12  ]
      [  25  2  1  5  863  80  1  40  14  3  4  1  1140  83  420  17  ]
      [  35  2  1  5  787  64  8  25  14  1  3  1  1144  83  545  7  ]
      [  32  1  1  6  510  45  8  39  11  1  3  1  1248  83  375  7  ]
      [  58  1  1  5  303  85  8  38  -1  3  5  1  1218  83  -1  19  ]
      [  74  1  8  -1  -1  -1  -1  -1  13  1  3  3  1174  83  480  10  ]
      [  33  1  1  5  703  74  8  40  13  5  9  1  1123  83  500  7  ]
      [  57  2  1  5  787  75  1  39  14  1  3  1  1218  83  520  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  11  1  3  3  1194  83  400  10  ]
      [  37  2  8  -1  -1  -1  -1  -1  10  9  -1  4  1108  83  328  7  ]
      [  43  1  1  6  310  45  8  40  -1  1  3  1  1220  83  -1  7  ]
      [  53  2  1  5  780  75  1  39  10  1  3  1  1149  83  300  12  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1353  83  -1  8  ]
      [  36  1  1  6  323  28  8  35  3  3  3  1  1318  83  100  14  ]
      [  44  1  1  6  274  29  8  37  -1  1  3  1  1430  83  -1  15  ]
      [  35  1  1  5  692  66  8  42  18  1  3  1  1484  83  600  9  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  1  3  3  1421  83  430  8  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  99  3  1370  83  -1  8  ]
      [  36  1  1  1  995  29  8  42  8  2  3  1  1429  83  251  12  ]
      [  33  1  8  -1  -1  -1  -1  -1  11  1  3  2  1413  83  341  8  ]
      [  26  1  1  5  871  80  1  50  17  5  9  1  1525  83  600  12  ]
      [  33  1  1  5  312  64  8  40  -1  1  3  1  1653  83  -1  9  ]
      [  52  1  1  6  744  63  8  36  -1  1  3  1  1501  83  -1  13  ]
      [  45  1  1  6  791  24  8  39  -1  1  3  1  1687  83  -1  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  1561  83  400  10  ]
      [  56  1  1  6  373  34  8  35  13  1  -1  1  1628  83  460  14  ]
      [  26  1  1  4  801  75  1  39  10  3  99  1  1594  83  317  12  ]
      [  28  1  1  6  521  28  8  40  15  3  3  1  2000  83  560  11  ]
      [  53  1  1  5  787  75  1  38  13  1  3  1  1971  83  400  11  ]
      [  34  1  1  6  281  34  8  40  -1  1  3  1  1954  83  -1  10  ]
      [  70  1  8  -1  -1  -1  -1  -1  12  3  3  3  1710  83  384  13  ]
      [  69  1  8  -1  -1  -1  -1  -1  11  1  99  3  1743  83  382  10  ]
      [  41  1  1  6  141  24  8  38  13  1  3  1  1845  83  500  13  ]
      [  49  1  1  6  521  25  8  35  14  -1  3  1  1905  83  525  13  ]
      [  69  2  8  -1  -1  -1  -1  -1  8  1  3  3  1835  83  303  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  11  1  6  3  1877  83  253  15  ]
      [  43  1  1  5  885  92  8  40  9  5  9  1  1990  83  246  10  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2134  83  -1  12  ]
      [  49  2  1  4  870  80  1  38  12  5  9  1  2075  83  425  11  ]
      [  47  1  1  5  714  63  8  40  8  1  1  1  2003  83  250  11  ]
      [  43  1  1  5  440  45  8  40  11  3  3  1  2153  83  362  12  ]
      [  36  1  1  4  814  75  1  40  9  3  99  1  2590  83  269  12  ]
      [  55  1  1  5  600  28  8  35  13  1  5  1  2326  83  450  13  ]
      [  32  1  1  5  691  65  8  39  -1  5  9  1  2361  83  -1  12  ]
      [  56  1  1  6  714  63  8  60  12  1  3  1  2700  83  400  17  ]
      [  87  1  8  -1  -1  -1  -1  -1  -1  3  7  3  2759  83  560  14  ]
      [  43  1  1  6  254  28  8  35  -1  1  3  1  3049  83  -1  14  ]
      [  51  1  1  5  300  29  8  36  -1  1  3  1  3179  83  -1  17  ]
      [  33  1  1  5  787  75  1  40  11  3  3  1  3345  83  300  15  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  5  9  5  4695  83  -1  18  ]
      [  31  2  8  -1  -1  -1  -1  -1  13  1  -1  6  206  82  340  4  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  326  82  408  6  ]
      [  18  2  1  8  661  15  8  40  5  1  -1  1  302  82  153  5  ]
      [  21  1  1  8  281  50  8  40  13  3  -1  1  435  82  398  13  ]
      [  73  2  8  -1  -1  -1  -1  -1  14  3  3  3  672  82  450  4  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  3  3  644  82  -1  4  ]
      [  36  2  1  6  854  85  8  16  15  1  -1  1  659  82  565  7  ]
      [  31  2  1  6  411  34  8  22  -1  1  -1  1  525  82  -1  11  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  586  82  -1  4  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  679  82  -1  13  ]
      [  53  1  1  6  274  1  8  40  -1  2  3  1  550  82  -1  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  14  -1  -1  3  766  82  500  9  ]
      [  33  2  8  -1  -1  -1  -1  -1  14  1  3  2  749  82  495  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  739  82  -1  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  741  82  -1  12  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  882  82  -1  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  5  1  3  3  703  82  150  6  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  2  892  82  -1  9  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  733  82  -1  8  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  3  3  957  82  -1  6  ]
      [  62  1  1  6  51  85  8  30  12  1  3  1  941  82  420  11  ]
      [  91  2  8  -1  -1  -1  -1  -1  12  3  -1  3  950  82  400  6  ]
      [  80  1  8  -1  -1  -1  -1  -1  14  9  -1  3  1049  82  490  7  ]
      [  40  1  1  6  744  51  8  38  12  3  3  1  1031  82  335  10  ]
      [  25  1  8  -1  -1  -1  -1  -1  14  1  3  2  997  82  445  9  ]
      [  43  1  1  6  531  32  8  38  13  3  3  1  1045  82  460  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  3  3  916  82  399  13  ]
      [  65  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  939  82  420  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1029  82  -1  6  ]
      [  36  2  8  5  780  63  8  45  11  2  3  1  1032  82  329  11  ]
      [  34  2  1  6  304  52  8  38  9  2  3  1  1031  82  276  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1183  82  -1  7  ]
      [  62  2  8  -1  -1  -1  -1  -1  14  1  3  3  1243  82  450  7  ]
      [  26  1  1  5  660  52  8  38  14  1  3  1  1230  82  500  13  ]
      [  33  1  1  5  714  60  1  38  16  1  3  1  1160  82  500  7  ]
      [  65  2  8  -1  -1  -1  -1  -1  10  1  3  3  1198  82  375  7  ]
      [  22  1  1  5  267  45  8  38  13  1  3  1  1197  82  400  8  ]
      [  22  1  1  5  51  1  8  40  13  1  4  1  1291  82  457  7  ]
      [  47  1  8  -1  -1  -1  -1  -1  11  1  3  2  1124  82  387  7  ]
      [  67  2  8  5  784  92  8  15  9  1  3  3  1218  82  280  7  ]
      [  35  2  1  5  772  74  8  20  13  3  4  1  1180  82  455  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  10  1  5  3  1206  82  320  9  ]
      [  40  1  1  1  911  55  8  60  5  5  3  1  1102  82  150  11  ]
      [  39  1  1  6  792  74  8  70  13  3  3  1  1303  82  430  12  ]
      [  25  1  1  5  780  93  8  39  13  5  3  1  1437  82  450  12  ]
      [  34  1  1  6  741  45  8  38  -1  1  3  1  1400  82  -1  13  ]
      [  46  1  1  6  310  28  8  40  14  1  3  1  1436  82  515  11  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1338  82  -1  9  ]
      [  45  1  1  6  323  28  8  35  -1  3  3  1  1323  82  -1  13  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1376  82  -1  9  ]
      [  81  2  8  -1  -1  -1  -1  -1  12  1  3  3  1301  82  359  8  ]
      [  31  2  1  5  853  85  1  40  13  2  6  1  1369  82  465  12  ]
      [  52  1  1  6  225  28  8  35  -1  5  9  1  1643  82  -1  14  ]
      [  46  1  1  6  431  52  8  40  -1  1  3  1  1678  82  -1  12  ]
      [  37  2  1  5  915  55  8  40  12  3  99  1  1627  82  381  9  ]
      [  21  1  1  6  651  28  8  40  18  1  -1  1  1606  82  500  9  ]
      [  44  1  1  5  788  34  8  35  14  1  3  1  1582  82  500  21  ]
      [  53  1  1  5  780  51  8  40  13  5  8  1  1595  82  348  14  ]
      [  41  1  1  5  796  80  1  40  10  3  4  1  1883  82  330  14  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1799  82  -1  11  ]
      [  33  1  1  6  742  51  8  38  12  1  3  1  1757  82  430  10  ]
      [  31  1  1  6  201  27  8  38  14  3  3  1  1865  82  430  10  ]
      [  30  1  1  6  651  28  8  35  8  1  -1  1  1832  82  257  11  ]
      [  43  1  1  6  487  45  8  39  10  1  3  1  1764  82  350  12  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  5  3  1948  82  -1  10  ]
      [  41  1  1  2  911  55  8  70  -1  4  9  1  1917  82  -1  13  ]
      [  43  1  1  6  141  24  8  37  11  1  1  1  1817  82  338  11  ]
      [  38  1  1  6  487  45  8  45  -1  3  3  1  1807  82  -1  11  ]
      [  37  1  1  6  731  64  8  39  -1  2  -1  1  1963  82  -1  14  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2172  82  -1  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2092  82  -1  12  ]
      [  39  1  1  5  912  62  8  48  18  4  8  1  2238  82  615  17  ]
      [  46  1  1  6  651  40  8  38  6  5  5  1  2222  82  200  17  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  4  3  2333  82  -1  13  ]
      [  67  1  1  5  784  29  8  23  -1  1  3  3  2445  82  -1  14  ]
      [  59  2  1  4  872  80  1  40  -1  5  9  1  2563  82  -1  19  ]
      [  62  1  8  -1  -1  -1  -1  -1  11  3  7  3  2320  82  312  12  ]
      [  28  1  1  6  221  29  8  40  14  5  5  1  2327  82  430  13  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2461  82  -1  14  ]
      [  37  1  1  5  780  51  8  38  15  5  3  1  2775  82  530  13  ]
      [  71  1  8  -1  -1  -1  -1  -1  22  5  4  3  2870  82  800  13  ]
      [  41  2  8  -1  -1  -1  -1  -1  13  2  5  2  608  81  423  4  ]
      [  69  1  8  -1  -1  -1  -1  -1  8  1  3  3  868  81  261  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  722  81  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  798  81  -1  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  991  81  -1  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  1001  81  332  6  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1263  81  -1  12  ]
      [  53  1  1  6  231  34  8  40  16  1  99  1  1152  81  520  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1297  81  -1  8  ]
      [  59  2  8  -1  -1  -1  -1  -1  15  1  -1  2  1354  81  500  8  ]
      [  39  1  1  5  254  29  8  38  17  3  3  1  1476  81  480  10  ]
      [  66  2  8  -1  -1  -1  -1  -1  9  1  3  3  1439  81  261  8  ]
      [  49  1  1  6  522  31  8  37  12  1  3  1  1451  81  380  15  ]
      [  69  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1391  81  388  9  ]
      [  28  1  1  6  531  34  8  39  9  1  3  1  1457  81  253  12  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1456  81  -1  13  ]
      [  33  1  1  4  801  75  1  39  -1  5  3  1  1515  81  -1  14  ]
      [  47  1  1  6  471  45  1  38  -1  1  3  1  1673  81  -1  15  ]
      [  47  1  1  2  310  93  8  40  12  2  3  1  1727  81  375  14  ]
      [  37  2  1  5  751  11  8  50  -1  4  8  1  2266  81  -1  11  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2513  81  -1  12  ]
      [  82  1  8  -1  -1  -1  -1  -1  15  5  9  3  3142  81  520  14  ]
      [  23  2  8  -1  -1  -1  -1  -1  12  5  -1  4  13  80  368  9  ]
      [  40  1  1  5  874  80  8  15  14  5  9  1  172  80  350  11  ]
      [  28  2  1  6  901  93  8  15  13  1  3  1  159  80  380  7  ]
      [  49  2  1  5  912  55  8  30  -1  1  -1  1  261  80  -1  3  ]
      [  60  1  8  -1  -1  -1  -1  -1  12  1  3  3  209  80  400  7  ]
      [  39  1  8  -1  -1  -1  -1  -1  -1  -1  -1  4  173  80  -1  2  ]
      [  22  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  252  80  0  10  ]
      [  91  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  417  80  -1  5  ]
      [  36  1  8  -1  -1  -1  -1  -1  12  1  -1  2  458  80  370  10  ]
      [  29  2  8  -1  -1  -1  -1  -1  -1  4  1  4  365  80  -1  3  ]
      [  52  1  8  -1  -1  -1  -1  -1  14  3  3  2  317  80  475  9  ]
      [  57  2  1  5  921  85  8  30  -1  1  -1  2  340  80  -1  3  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  475  80  0  3  ]
      [  74  2  1  2  672  52  8  55  -1  3  8  1  330  80  -1  3  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  -1  -1  4  412  80  -1  8  ]
      [  48  1  8  -1  -1  -1  -1  -1  -1  5  3  4  474  80  -1  3  ]
      [  30  2  1  5  982  74  8  10  -1  5  99  1  349  80  -1  11  ]
      [  42  2  1  5  934  80  1  20  16  1  1  1  454  80  400  13  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  388  80  -1  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  412  80  -1  8  ]
      [  26  1  8  -1  -1  -1  -1  -1  14  5  -1  4  413  80  450  9  ]
      [  46  1  8  -1  -1  -1  -1  -1  7  2  3  2  301  80  220  3  ]
      [  48  2  8  -1  -1  -1  -1  -1  -1  1  3  2  339  80  -1  6  ]
      [  42  2  8  -1  -1  -1  -1  -1  -1  3  3  6  641  80  449  5  ]
      [  44  2  1  5  787  75  1  30  12  3  3  1  581  80  420  13  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  3  3  556  80  -1  4  ]
      [  54  2  1  5  662  52  8  24  -1  1  3  1  508  80  0  4  ]
      [  42  2  1  5  780  92  8  20  7  3  3  1  688  80  180  13  ]
      [  20  2  1  5  772  29  8  40  9  3  3  1  588  80  280  4  ]
      [  23  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  578  80  -1  4  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  629  80  -1  4  ]
      [  91  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  688  80  -1  5  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  664  80  -1  4  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  589  80  0  4  ]
      [  60  1  8  -1  -1  -1  -1  -1  12  1  -1  3  611  80  400  14  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  3  3  2  537  80  -1  4  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  623  80  0  4  ]
      [  73  2  8  3  912  55  8  15  -1  1  -1  3  505  80  -1  4  ]
      [  65  2  8  -1  -1  -1  -1  -1  11  5  -1  6  581  80  365  6  ]
      [  23  1  8  -1  -1  -1  -1  -1  10  3  3  8  565  80  284  4  ]
      [  38  1  1  2  671  51  8  70  10  1  3  1  623  80  350  5  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  519  80  0  4  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  511  80  0  4  ]
      [  27  1  8  -1  -1  -1  -1  -1  11  5  -1  4  539  80  353  10  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  651  80  -1  4  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  629  80  -1  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  622  80  0  4  ]
      [  20  1  8  -1  -1  -1  -1  -1  12  9  3  2  614  80  383  11  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  503  80  0  4  ]
      [  37  2  8  -1  -1  -1  -1  -1  12  5  3  2  503  80  400  9  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  3  3  3  700  80  -1  9  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  657  80  -1  9  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  2  3  2  510  80  -1  4  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  506  80  -1  7  ]
      [  45  1  1  6  912  55  8  40  -1  2  3  1  606  80  -1  10  ]
      [  38  1  1  6  241  28  8  45  -1  2  3  1  589  80  -1  10  ]
      [  47  2  8  -1  -1  -1  -1  -1  7  2  3  8  512  80  200  10  ]
      [  35  2  1  6  660  52  8  20  15  2  3  1  645  80  460  7  ]
      [  40  1  1  1  821  92  8  70  15  3  3  1  701  80  520  11  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  1  3  2  706  80  -1  13  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  728  80  -1  5  ]
      [  32  1  1  6  13  1  8  40  9  1  3  1  886  80  250  5  ]
      [  37  2  1  5  780  45  8  20  -1  3  3  1  868  80  -1  19  ]
      [  47  2  1  5  789  91  8  23  -1  5  4  1  825  80  -1  5  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  779  80  -1  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  724  80  -1  12  ]
      [  24  2  8  5  661  15  8  40  10  3  3  6  868  80  330  5  ]
      [  52  1  1  5  853  85  1  38  11  1  3  1  754  80  380  5  ]
      [  40  1  1  6  935  26  8  38  -1  1  3  1  789  80  -1  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  -1  3  3  730  80  -1  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  4  1  -1  3  874  80  110  5  ]
      [  28  2  1  5  813  75  1  40  -1  5  9  1  851  80  200  5  ]
      [  49  1  8  -1  -1  -1  -1  -1  -1  1  3  3  900  80  -1  5  ]
      [  26  1  1  6  401  15  8  25  -1  1  -1  1  795  80  -1  5  ]
      [  23  1  8  -1  -1  -1  -1  -1  -1  1  3  6  802  80  -1  5  ]
      [  37  1  1  6  531  51  8  40  8  1  -1  1  719  80  250  5  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  864  80  -1  6  ]
      [  73  2  8  -1  -1  -1  -1  -1  7  1  -1  3  742  80  220  5  ]
      [  43  1  1  5  531  28  8  38  13  1  3  1  831  80  440  12  ]
      [  50  1  8  -1  -1  -1  -1  -1  -1  1  3  3  757  80  -1  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  1  -1  3  834  80  250  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  21  1  3  3  899  80  450  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  16  1  -1  3  865  80  500  11  ]
      [  61  2  1  6  923  95  8  13  9  1  3  3  845  80  250  8  ]
      [  34  2  1  6  662  52  8  5  9  1  2  6  892  80  300  5  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  871  80  -1  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  9  3  3  3  790  80  300  5  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  896  80  -1  5  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  5  3  703  80  -1  5  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  884  80  -1  5  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  715  80  -1  5  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  3  3  707  80  -1  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  -1  -1  6  771  80  -1  7  ]
      [  27  2  1  5  780  45  8  22  5  3  3  1  717  80  175  5  ]
      [  41  1  1  6  488  45  8  44  9  1  3  1  706  80  220  5  ]
      [  35  1  8  -1  -1  -1  -1  -1  -1  5  9  2  701  80  -1  5  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  751  80  -1  6  ]
      [  90  2  8  -1  -1  -1  -1  -1  7  1  -1  3  705  80  216  5  ]
      [  32  2  1  5  53  52  8  35  -1  1  3  1  764  80  -1  5  ]
      [  46  1  1  6  441  45  8  40  10  1  3  1  843  80  313  10  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  775  80  -1  7  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  786  80  -1  5  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  797  80  -1  5  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  718  80  250  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  816  80  -1  7  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  780  80  -1  5  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  3  4  3  756  80  -1  5  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  832  80  -1  9  ]
      [  41  1  1  6  935  90  1  40  13  3  -1  1  711  80  400  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  2  756  80  -1  5  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  3  3  877  80  -1  10  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  765  80  -1  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  5  3  794  80  -1  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  2  99  3  888  80  -1  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  890  80  -1  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  817  80  -1  12  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  701  80  -1  9  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1096  80  0  6  ]
      [  39  1  1  1  715  60  8  50  7  -1  1  1  1020  80  250  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1094  80  0  6  ]
      [  42  2  1  5  633  80  1  24  17  3  3  1  967  80  560  12  ]
      [  78  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1052  80  300  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  5  3  3  1086  80  -1  10  ]
      [  55  1  1  6  714  75  1  40  9  1  99  1  945  80  300  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  916  80  -1  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  919  80  -1  6  ]
      [  94  2  8  -1  -1  -1  -1  -1  -1  1  -1  6  971  80  0  6  ]
      [  56  1  1  6  411  99  8  30  -1  1  -1  1  954  80  0  6  ]
      [  42  1  1  6  276  34  8  38  14  1  3  1  1070  80  510  7  ]
      [  29  1  1  1  755  74  8  56  14  3  3  1  1027  80  400  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  908  80  -1  6  ]
      [  37  2  1  6  661  52  8  40  13  1  -1  1  991  80  450  7  ]
      [  79  2  8  -1  -1  -1  -1  -1  7  1  -1  3  1035  80  200  6  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  952  80  -1  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1051  80  -1  8  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  924  80  -1  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  1  3  903  80  -1  8  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1098  80  -1  10  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  3  3  993  80  -1  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  8  3  1070  80  0  9  ]
      [  25  1  1  7  691  65  1  39  18  5  3  1  981  80  600  6  ]
      [  51  2  1  5  787  64  8  25  10  1  3  1  999  80  313  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  983  80  -1  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1032  80  -1  6  ]
      [  51  2  1  5  661  52  8  40  -1  1  -1  1  949  80  -1  6  ]
      [  35  1  1  6  179  22  8  38  15  1  3  1  933  80  444  8  ]
      [  33  2  1  5  861  85  8  38  12  5  8  1  958  80  375  6  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  934  80  -1  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  911  80  -1  6  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1016  80  -1  6  ]
      [  30  1  1  6  221  29  8  35  -1  1  3  1  946  80  -1  10  ]
      [  55  2  1  5  772  63  8  25  -1  1  3  1  945  80  700  12  ]
      [  78  1  8  -1  -1  -1  -1  -1  5  1  -1  3  1049  80  150  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1044  80  -1  10  ]
      [  38  1  1  2  316  52  8  50  -1  3  5  1  1015  80  -1  7  ]
      [  40  2  1  6  178  22  8  35  -1  1  3  1  1008  80  -1  6  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  942  80  -1  6  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  2  945  80  -1  6  ]
      [  48  2  1  6  411  55  8  15  7  1  -1  3  959  80  200  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  8  1  -1  3  936  80  280  6  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  988  80  -1  6  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  957  80  -1  6  ]
      [  59  1  1  5  776  75  1  33  -1  2  8  1  1100  80  -1  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  5  3  953  80  -1  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  3  6  3  1091  80  -1  6  ]
      [  50  2  8  -1  -1  -1  -1  -1  -1  2  6  2  936  80  -1  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1016  80  -1  7  ]
      [  49  1  1  6  24  15  8  40  -1  1  3  1  948  80  -1  12  ]
      [  31  1  1  6  441  45  8  40  6  2  4  1  901  80  180  6  ]
      [  53  1  1  6  310  45  8  37  -1  2  3  1  985  80  -1  9  ]
      [  47  1  1  6  281  63  8  40  -1  2  4  1  1099  80  -1  8  ]
      [  51  1  1  6  269  90  8  40  10  1  3  1  1088  80  300  10  ]
      [  44  1  1  6  714  60  8  40  -1  2  3  1  921  80  -1  11  ]
      [  40  1  1  6  274  1  8  40  -1  1  3  1  1088  80  -1  6  ]
      [  73  2  8  -1  -1  -1  -1  -1  8  1  -1  3  911  80  236  6  ]
      [  29  1  1  6  310  52  8  38  -1  1  3  1  1136  80  -1  11  ]
      [  52  1  1  6  937  60  8  38  13  1  3  1  1140  80  376  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  8  1  -1  3  1112  80  240  13  ]
      [  67  1  8  -1  -1  -1  -1  -1  13  1  3  3  1286  80  450  9  ]
      [  45  2  1  5  867  80  1  40  16  1  5  1  1272  80  500  7  ]
      [  49  2  1  5  521  33  8  30  9  3  3  1  1104  80  300  7  ]
      [  60  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1134  80  346  7  ]
      [  82  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  1252  80  350  8  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1185  80  -1  9  ]
      [  52  1  1  5  692  66  8  38  -1  -1  -1  1  1111  80  -1  12  ]
      [  69  1  8  -1  -1  -1  -1  -1  14  1  -1  3  1196  80  435  7  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  4  -1  3  1279  80  -1  7  ]
      [  60  2  8  -1  -1  -1  -1  -1  13  3  3  8  1265  80  469  7  ]
      [  79  1  8  -1  -1  -1  -1  -1  10  1  4  3  1286  80  300  9  ]
      [  57  1  1  6  742  28  8  35  5  1  3  1  1213  80  153  7  ]
      [  45  2  1  5  863  80  1  33  19  3  4  1  1180  80  600  15  ]
      [  26  2  1  4  813  75  1  55  -1  5  9  1  1295  80  -1  7  ]
      [  51  1  1  5  714  24  8  40  18  3  3  1  1153  80  530  11  ]
      [  80  1  8  -1  -1  -1  -1  -1  9  1  1  3  1158  80  275  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1289  80  -1  7  ]
      [  27  2  1  5  765  74  8  39  8  5  8  1  1125  80  260  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  8  -1  -1  3  1220  80  150  7  ]
      [  48  1  1  6  714  52  8  38  9  1  3  1  1241  80  270  7  ]
      [  29  1  1  6  323  28  8  35  9  1  3  1  1156  80  300  7  ]
      [  26  2  1  5  780  75  1  39  10  3  3  1  1228  80  300  7  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1161  80  0  7  ]
      [  51  1  1  6  540  1  8  38  -1  1  3  1  1144  80  -1  7  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1279  80  -1  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1225  80  -1  10  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1258  80  -1  7  ]
      [  66  1  8  6  51  29  8  7  -1  1  3  3  1273  80  -1  10  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1281  80  -1  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1246  80  -1  7  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1253  80  -1  14  ]
      [  75  1  8  -1  -1  -1  -1  -1  9  1  3  3  1102  80  300  10  ]
      [  49  1  1  6  714  60  8  38  -1  3  3  1  1298  80  -1  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1234  80  -1  12  ]
      [  62  2  8  -1  -1  -1  -1  -1  18  3  5  3  1115  80  600  12  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1161  80  -1  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1156  80  -1  9  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1259  80  -1  7  ]
      [  49  1  1  6  254  21  8  35  -1  1  3  1  1178  80  -1  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1163  80  -1  9  ]
      [  54  1  1  6  131  26  8  40  14  1  99  1  1279  80  480  9  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1116  80  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1269  80  560  10  ]
      [  70  2  8  -1  -1  -1  -1  -1  7  1  -1  3  1226  80  218  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1175  80  -1  7  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1265  80  -1  7  ]
      [  27  1  1  6  441  45  8  40  11  1  3  1  1282  80  380  11  ]
      [  80  2  8  -1  -1  -1  -1  -1  12  3  3  3  1284  80  365  7  ]
      [  68  1  8  -1  -1  -1  -1  -1  10  1  6  3  1238  80  331  10  ]
      [  36  1  1  5  662  50  8  40  -1  2  3  1  1291  80  -1  12  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  6  3  1293  80  -1  7  ]
      [  48  1  1  6  211  28  8  40  -1  2  3  1  1140  80  -1  12  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1206  80  -1  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  4  9  3  1208  80  -1  11  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1255  80  -1  10  ]
      [  24  2  1  5  789  70  8  40  -1  3  3  1  1195  80  100  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1205  80  0  7  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  1  3  1275  80  -1  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  11  5  3  3  1181  80  350  10  ]
      [  57  2  1  5  788  75  1  40  12  1  3  1  1107  80  392  11  ]
      [  42  2  1  6  13  74  8  40  -1  2  3  1  1276  80  -1  7  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  1  3  1251  80  -1  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  4  4  3  1449  80  -1  10  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1487  80  -1  8  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1370  80  -1  8  ]
      [  35  1  1  6  411  55  8  40  -1  1  3  1  1414  80  -1  14  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1334  80  -1  8  ]
      [  74  1  8  -1  -1  -1  -1  -1  7  1  3  3  1494  80  200  9  ]
      [  50  1  1  6  510  45  8  39  19  1  3  1  1302  80  670  8  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1404  80  -1  8  ]
      [  40  2  1  5  633  24  8  35  16  1  -1  1  1322  80  550  13  ]
      [  58  1  1  1  833  92  8  40  16  5  -1  1  1361  80  500  11  ]
      [  58  1  1  6  141  24  8  39  -1  1  3  1  1366  80  -1  13  ]
      [  73  2  8  -1  -1  -1  -1  -1  17  1  -1  3  1384  80  595  8  ]
      [  31  1  1  4  784  75  1  39  12  3  3  1  1308  80  400  10  ]
      [  57  1  1  5  853  85  8  38  -1  4  5  1  1368  80  -1  14  ]
      [  43  2  1  5  787  75  1  40  -1  3  3  1  1430  80  -1  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  19  1  3  3  1478  80  625  12  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1350  80  -1  9  ]
      [  77  1  8  -1  -1  -1  -1  -1  14  3  8  3  1392  80  425  10  ]
      [  48  1  1  5  662  52  8  38  -1  3  -1  1  1367  80  -1  8  ]
      [  31  2  1  5  785  50  8  39  -1  5  3  1  1316  80  -1  14  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1395  80  -1  11  ]
      [  43  1  1  6  101  26  8  40  17  1  3  1  1321  80  600  8  ]
      [  58  1  1  5  751  51  8  45  -1  1  -1  1  1428  80  -1  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1300  80  -1  8  ]
      [  70  1  8  5  771  31  8  1  -1  1  5  3  1390  80  300  8  ]
      [  42  2  1  5  789  34  8  35  -1  5  9  1  1376  80  -1  8  ]
      [  37  1  1  6  269  45  8  40  -1  1  3  1  1405  80  0  8  ]
      [  54  1  1  6  281  34  8  35  14  1  3  1  1491  80  425  11  ]
      [  72  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  1325  80  400  8  ]
      [  37  1  1  6  268  45  8  39  -1  1  1  1  1456  80  -1  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  10  1  5  3  1453  80  322  9  ]
      [  32  1  1  6  726  63  1  38  14  2  3  1  1327  80  500  12  ]
      [  64  1  1  1  692  66  8  50  -1  1  3  1  1498  80  -1  11  ]
      [  35  2  1  5  61  92  8  40  7  5  9  1  1322  80  210  8  ]
      [  35  1  1  6  714  45  8  39  -1  1  3  1  1408  80  169  8  ]
      [  47  1  1  6  550  28  8  36  13  1  3  1  1500  80  396  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1413  80  -1  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1378  80  -1  8  ]
      [  42  1  1  6  993  51  8  38  10  1  1  1  1441  80  300  8  ]
      [  88  2  8  -1  -1  -1  -1  -1  14  1  3  3  1445  80  315  8  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1304  80  -1  13  ]
      [  39  1  1  6  273  29  8  40  13  2  3  1  1358  80  450  11  ]
      [  69  1  8  -1  -1  -1  -1  -1  13  1  6  3  1458  80  440  11  ]
      [  41  1  1  6  441  45  8  40  -1  2  5  1  1436  80  -1  14  ]
      [  43  2  1  5  788  60  8  40  -1  2  3  1  1392  80  -1  15  ]
      [  39  1  1  6  714  60  8  40  -1  2  3  1  1466  80  -1  14  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1438  80  0  11  ]
      [  39  2  1  5  672  52  8  39  6  3  3  1  1508  80  200  9  ]
      [  87  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1669  80  -1  9  ]
      [  58  1  1  6  997  34  8  28  -1  1  3  1  1582  80  -1  11  ]
      [  29  1  1  5  311  75  1  38  13  3  3  1  1645  80  395  11  ]
      [  42  2  1  6  853  85  8  40  -1  1  3  1  1644  80  -1  9  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1652  80  -1  9  ]
      [  37  1  1  5  620  26  8  38  -1  -1  -1  1  1606  80  -1  9  ]
      [  58  1  1  5  521  52  8  38  -1  1  3  1  1540  80  -1  13  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1575  80  -1  9  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  5  3  1679  80  -1  9  ]
      [  51  1  1  5  358  74  8  40  14  1  3  1  1618  80  480  13  ]
      [  33  2  1  5  754  74  8  39  9  4  3  1  1617  80  275  15  ]
      [  37  1  1  5  714  75  1  38  13  1  3  1  1656  80  400  9  ]
      [  39  1  1  5  776  85  8  38  17  3  3  1  1659  80  520  15  ]
      [  30  1  1  5  621  72  8  40  -1  5  3  1  1668  80  710  14  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  9  -1  3  1566  80  -1  13  ]
      [  40  2  1  5  788  52  8  23  -1  3  5  1  1526  80  -1  9  ]
      [  37  1  1  5  714  52  8  38  -1  1  3  1  1502  80  -1  9  ]
      [  42  2  1  2  834  22  8  40  13  5  3  1  1599  80  420  9  ]
      [  52  1  1  6  521  34  8  35  16  1  -1  1  1586  80  500  9  ]
      [  21  1  1  6  270  24  8  38  12  1  3  1  1576  80  400  13  ]
      [  42  1  1  6  741  29  8  38  -1  1  3  1  1644  80  -1  10  ]
      [  30  2  1  5  788  52  8  38  -1  3  5  1  1682  80  -1  16  ]
      [  53  1  1  5  741  52  8  37  -1  1  3  1  1686  80  -1  10  ]
      [  39  1  8  6  411  55  8  7  12  5  3  2  1546  80  430  9  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1511  80  -1  9  ]
      [  53  1  1  5  171  52  8  38  9  1  3  1  1700  80  250  10  ]
      [  31  1  1  5  691  65  8  45  -1  9  -1  1  1665  80  -1  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1550  80  -1  9  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1603  80  -1  11  ]
      [  42  1  1  5  788  28  8  40  -1  5  3  1  1620  80  -1  13  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1595  80  -1  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1667  80  -1  10  ]
      [  28  1  1  6  993  34  8  40  11  1  -1  1  1657  80  400  13  ]
      [  42  2  1  5  853  85  1  19  15  5  3  1  1579  80  460  20  ]
      [  37  2  1  1  687  22  8  45  15  3  3  1  1575  80  510  9  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1631  80  -1  9  ]
      [  48  1  1  5  873  80  8  39  -1  9  99  1  1563  80  -1  14  ]
      [  39  2  1  5  662  52  8  34  -1  3  5  1  1606  80  -1  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1539  80  -1  12  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1566  80  -1  9  ]
      [  60  2  1  2  672  52  8  35  -1  1  3  1  1617  80  -1  9  ]
      [  44  1  1  5  788  52  8  39  -1  1  3  1  1536  80  -1  9  ]
      [  34  1  1  5  601  28  8  40  -1  5  8  1  1572  80  -1  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1648  80  -1  10  ]
      [  57  1  1  6  441  45  8  39  -1  1  3  1  1646  80  -1  18  ]
      [  26  1  1  4  801  75  1  42  16  5  3  1  1566  80  500  15  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1597  80  -1  9  ]
      [  39  1  1  5  861  75  1  39  14  5  8  1  1676  80  460  14  ]
      [  46  1  1  6  531  29  8  35  -1  2  6  1  1657  80  -1  13  ]
      [  59  1  8  -1  -1  -1  -1  -1  13  3  3  3  1539  80  390  16  ]
      [  55  1  1  6  744  29  8  35  -1  1  3  1  1555  80  -1  10  ]
      [  38  2  1  4  870  80  1  17  -1  5  8  1  1690  80  -1  11  ]
      [  27  1  1  5  871  80  1  38  -1  5  9  1  1560  80  400  9  ]
      [  41  1  1  5  780  85  1  40  -1  2  3  1  1598  80  -1  12  ]
      [  59  2  1  5  873  80  1  38  -1  1  6  1  1589  80  -1  15  ]
      [  52  1  1  2  842  85  8  38  -1  -1  -1  1  1651  80  -1  12  ]
      [  27  2  8  -1  -1  -1  -1  -1  12  3  3  2  1526  80  420  14  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1921  80  180  16  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  5  3  1898  80  -1  10  ]
      [  32  1  1  5  620  34  8  40  9  3  3  1  1933  80  300  10  ]
      [  36  1  1  6  401  15  8  50  11  1  3  1  1910  80  200  10  ]
      [  35  1  1  6  626  35  8  38  -1  3  3  1  1991  80  -1  10  ]
      [  87  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1804  80  415  10  ]
      [  73  1  8  -1  -1  -1  -1  -1  11  1  3  3  1870  80  350  13  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1806  80  -1  10  ]
      [  43  1  1  1  777  72  8  40  -1  5  3  1  1856  80  -1  14  ]
      [  31  1  1  5  522  52  8  38  -1  1  4  1  1955  80  -1  12  ]
      [  45  1  1  6  714  63  8  60  10  1  -1  1  1798  80  325  11  ]
      [  52  2  1  5  787  75  1  39  -1  3  3  1  1877  80  -1  10  ]
      [  47  1  1  5  750  55  8  40  16  1  -1  1  1907  80  484  15  ]
      [  44  2  1  5  921  85  1  25  -1  1  3  1  1982  80  -1  14  ]
      [  52  1  1  5  269  20  8  40  -1  1  5  1  1863  80  -1  10  ]
      [  59  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1796  80  550  14  ]
      [  30  1  1  6  269  34  8  35  10  1  3  1  1963  80  320  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1954  80  -1  10  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1737  80  -1  10  ]
      [  64  1  1  6  744  28  8  35  9  1  -1  1  1780  80  320  10  ]
      [  34  2  1  2  315  52  8  60  11  4  5  1  1736  80  360  10  ]
      [  48  1  1  6  540  25  8  38  10  2  3  1  1863  80  350  10  ]
      [  27  1  1  6  742  15  8  40  12  1  3  1  1883  80  380  10  ]
      [  37  1  1  6  290  34  8  35  12  4  3  1  1993  80  400  11  ]
      [  62  1  1  5  676  52  8  40  7  3  3  1  1763  80  220  10  ]
      [  49  1  1  5  751  64  8  39  13  1  3  1  1762  80  350  16  ]
      [  29  1  1  5  411  55  8  40  19  3  3  1  1813  80  650  12  ]
      [  53  1  1  5  620  99  8  38  -1  9  99  1  1945  80  -1  12  ]
      [  49  1  1  5  772  22  8  36  17  3  3  1  1839  80  500  15  ]
      [  46  1  1  6  241  29  8  39  9  1  3  1  1989  80  240  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  13  1  5  3  1797  80  420  10  ]
      [  47  2  1  5  853  85  1  40  13  2  3  1  1939  80  400  10  ]
      [  60  1  1  6  531  24  8  40  16  -1  -1  1  1875  80  530  11  ]
      [  34  1  1  5  771  34  8  45  13  5  9  1  1875  80  450  15  ]
      [  66  1  1  6  269  32  8  10  -1  1  3  3  1710  80  -1  11  ]
      [  38  1  1  2  510  45  8  60  -1  3  3  1  1911  80  -1  13  ]
      [  32  1  1  5  714  60  8  40  -1  3  3  1  1700  80  -1  11  ]
      [  31  1  1  4  651  60  8  39  -1  3  3  1  1786  80  -1  11  ]
      [  51  1  1  6  471  45  8  40  -1  1  -1  1  1788  80  -1  15  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1831  80  -1  11  ]
      [  65  1  1  5  772  52  8  18  -1  5  5  1  1915  80  -1  14  ]
      [  37  1  1  1  511  45  8  60  12  9  5  1  1930  80  330  10  ]
      [  39  1  1  4  801  75  1  40  -1  2  8  1  1949  80  -1  16  ]
      [  60  1  1  5  751  40  8  40  13  -1  -1  1  1903  80  370  12  ]
      [  44  1  1  5  774  73  8  35  12  5  10  1  2271  80  300  11  ]
      [  40  1  1  5  691  65  1  38  -1  3  3  1  2162  80  -1  13  ]
      [  30  1  1  5  841  85  1  40  12  5  9  1  2279  80  370  11  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2016  80  -1  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2220  80  -1  11  ]
      [  47  1  1  1  303  74  8  45  -1  5  99  1  2016  80  -1  13  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2062  80  -1  11  ]
      [  28  1  1  5  622  33  8  38  -1  4  5  1  2226  80  -1  11  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2154  80  -1  12  ]
      [  40  2  1  4  812  75  1  42  -1  5  8  1  2070  80  -1  11  ]
      [  37  2  1  4  765  75  1  40  11  5  8  1  2183  80  350  11  ]
      [  31  1  1  5  677  51  8  38  12  3  3  1  2007  80  390  14  ]
      [  42  2  1  5  780  51  8  25  15  3  3  1  2145  80  460  13  ]
      [  35  1  1  6  531  34  8  38  -1  -1  -1  1  2289  80  -1  11  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2287  80  -1  11  ]
      [  44  1  1  6  714  51  8  38  11  5  1  1  2286  80  375  12  ]
      [  44  1  1  5  756  64  8  38  -1  5  8  1  2239  80  -1  17  ]
      [  39  1  1  5  628  34  8  40  -1  1  5  1  2290  80  -1  11  ]
      [  46  1  1  5  269  45  8  50  -1  2  3  1  2051  80  -1  14  ]
      [  33  1  1  5  281  50  8  39  -1  3  5  1  2400  80  -1  12  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  9  -1  3  2469  80  -1  12  ]
      [  31  1  1  2  750  51  8  80  10  4  5  1  2570  80  330  12  ]
      [  49  1  1  5  673  51  8  50  -1  5  8  1  2429  80  -1  12  ]
      [  36  1  1  5  726  62  8  38  16  1  3  1  2498  80  500  16  ]
      [  31  1  1  2  461  45  8  40  -1  5  5  1  2417  80  -1  12  ]
      [  39  1  1  6  323  28  8  38  -1  1  -1  1  2594  80  -1  15  ]
      [  54  1  1  5  780  63  8  70  12  3  -1  1  2337  80  400  12  ]
      [  42  1  1  5  689  24  8  40  -1  3  3  1  2484  80  -1  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  5  3  2556  80  -1  12  ]
      [  40  1  1  6  269  34  8  38  -1  1  3  1  2555  80  -1  12  ]
      [  53  1  1  4  872  80  1  35  9  5  9  1  2591  80  285  12  ]
      [  28  1  1  5  750  34  8  38  13  1  3  1  2442  80  400  13  ]
      [  31  1  1  5  841  85  1  39  11  5  10  1  2349  80  395  17  ]
      [  53  1  1  5  751  26  8  40  -1  5  9  1  2437  80  -1  14  ]
      [  49  1  1  5  741  74  1  38  11  1  3  1  2853  80  336  19  ]
      [  63  1  8  -1  -1  -1  -1  -1  14  5  9  3  2874  80  500  13  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  5  8  3  2638  80  -1  13  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  2724  80  -1  21  ]
      [  30  1  1  5  757  74  8  40  26  5  3  1  2738  80  860  19  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2743  80  -1  13  ]
      [  38  1  1  5  691  65  8  39  -1  3  8  1  2726  80  -1  13  ]
      [  29  2  1  5  660  51  8  40  -1  4  3  1  3176  80  -1  14  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  3008  80  -1  14  ]
      [  55  1  1  1  692  66  8  50  -1  3  3  1  3071  80  -1  15  ]
      [  36  1  1  5  255  28  8  60  16  4  3  1  3091  80  500  14  ]
      [  54  1  8  -1  -1  -1  -1  -1  12  1  8  3  3093  80  400  15  ]
      [  44  1  1  5  600  10  8  40  9  5  8  1  2951  80  280  14  ]
      [  58  1  1  5  750  45  8  65  11  -1  -1  1  3193  80  336  14  ]
      [  52  1  1  4  765  75  1  40  -1  4  5  1  3098  80  -1  15  ]
      [  31  1  1  5  780  72  8  38  13  1  3  1  3982  80  450  16  ]
      [  41  1  1  1  837  74  8  50  7  1  3  1  4413  80  207  17  ]
      [  41  1  1  9  801  75  1  38  23  4  5  1  4180  80  750  21  ]
      [  62  1  1  4  871  80  1  39  -1  5  9  1  4039  80  -1  17  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  4524  80  -1  21  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  5754  80  0  20  ]
      [  58  1  1  6  791  29  8  14  -1  1  3  4  26  79  250  8  ]
      [  40  1  8  -1  -1  -1  -1  -1  -1  2  3  2  332  79  -1  9  ]
      [  52  2  8  -1  -1  -1  -1  -1  -1  3  4  5  611  79  -1  10  ]
      [  42  2  8  -1  -1  -1  -1  -1  18  4  5  2  642  79  590  8  ]
      [  38  1  1  6  501  74  8  40  12  1  3  1  596  79  340  4  ]
      [  50  2  1  6  934  55  8  20  -1  1  -1  1  814  79  -1  5  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  839  79  -1  5  ]
      [  42  2  8  -1  -1  -1  -1  -1  15  4  3  2  955  79  500  6  ]
      [  39  1  1  6  531  63  8  38  12  -1  -1  1  1055  79  430  8  ]
      [  52  1  1  5  792  74  8  40  11  1  3  1  948  79  390  9  ]
      [  60  2  1  5  856  85  8  20  11  1  3  1  1055  79  370  6  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  4  1155  79  -1  9  ]
      [  68  2  8  -1  -1  -1  -1  -1  10  1  3  3  1240  79  320  7  ]
      [  53  1  1  6  273  29  8  36  16  1  3  1  1166  79  425  7  ]
      [  81  2  8  -1  -1  -1  -1  -1  8  1  3  3  1175  79  225  7  ]
      [  41  1  8  -1  -1  -1  -1  -1  12  5  8  6  1103  79  363  7  ]
      [  52  2  8  -1  -1  -1  -1  -1  13  1  3  3  1214  79  420  13  ]
      [  57  1  8  -1  -1  -1  -1  -1  16  1  -1  3  1294  79  510  11  ]
      [  39  1  8  -1  -1  -1  -1  -1  10  -1  3  2  1212  79  300  7  ]
      [  28  1  1  6  121  26  8  40  12  3  3  1  1395  79  326  9  ]
      [  36  1  1  6  269  30  8  37  11  1  -1  1  1463  79  300  10  ]
      [  29  1  1  2  661  52  8  98  9  5  -1  1  1468  79  250  12  ]
      [  65  1  1  6  323  15  8  5  10  -1  -1  3  1394  79  350  8  ]
      [  41  1  1  6  501  80  1  39  -1  3  3  1  1436  79  -1  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  7  1  8  3  1444  79  215  13  ]
      [  43  1  1  5  312  64  8  38  17  1  3  1  1662  79  530  9  ]
      [  50  1  1  6  512  45  8  39  11  1  3  1  1607  79  379  9  ]
      [  49  1  1  5  780  92  8  38  17  3  3  1  1580  79  525  12  ]
      [  51  1  1  6  273  27  8  40  16  1  3  1  1572  79  550  12  ]
      [  67  2  8  -1  -1  -1  -1  -1  13  1  3  3  1555  79  400  9  ]
      [  43  1  1  6  756  27  8  40  11  1  5  1  1693  79  348  14  ]
      [  33  2  1  5  856  85  8  40  9  2  3  1  1604  79  297  9  ]
      [  61  1  1  5  787  75  1  40  11  2  3  1  1700  79  340  11  ]
      [  57  1  8  -1  -1  -1  -1  -1  15  1  3  3  1714  79  500  16  ]
      [  45  1  1  6  531  32  8  40  8  1  -1  1  1827  79  200  15  ]
      [  36  1  1  6  273  29  8  35  12  3  3  1  1720  79  410  15  ]
      [  49  1  1  1  501  45  8  50  -1  1  5  1  1841  79  -1  15  ]
      [  60  1  8  -1  -1  -1  -1  -1  13  1  3  3  1729  79  348  10  ]
      [  29  1  1  6  270  29  8  50  10  3  3  1  2067  79  310  13  ]
      [  35  1  1  6  741  34  8  40  7  9  -1  1  2193  79  210  11  ]
      [  35  1  1  5  621  29  8  50  17  3  5  1  2503  79  550  16  ]
      [  22  1  1  9  801  75  1  45  14  3  99  1  2544  79  475  14  ]
      [  34  1  1  5  775  32  8  40  16  5  10  1  2305  79  530  12  ]
      [  89  2  8  -1  -1  -1  -1  -1  19  5  9  3  2434  79  635  17  ]
      [  31  1  1  1  813  74  8  80  22  5  9  1  2883  79  675  13  ]
      [  48  2  1  6  934  74  8  20  13  1  3  4  472  78  360  10  ]
      [  45  1  8  -1  -1  -1  -1  -1  10  1  -1  2  642  78  335  8  ]
      [  82  2  8  -1  -1  -1  -1  -1  10  1  -1  3  756  78  307  12  ]
      [  35  1  1  1  483  45  8  48  17  3  3  1  792  78  600  7  ]
      [  34  2  1  6  934  80  8  20  -1  5  5  1  741  78  -1  13  ]
      [  32  2  8  -1  -1  -1  -1  -1  10  3  3  3  738  78  289  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  12  1  -1  3  862  78  351  5  ]
      [  32  1  8  -1  -1  -1  -1  -1  12  3  3  2  749  78  340  6  ]
      [  35  1  1  6  441  45  8  40  13  -1  -1  1  898  78  425  13  ]
      [  30  1  8  -1  -1  -1  -1  -1  -1  5  3  2  776  78  -1  5  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  867  78  -1  9  ]
      [  42  2  1  6  780  52  8  35  -1  2  3  1  702  78  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  935  78  -1  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  10  1  3  3  1072  78  325  7  ]
      [  33  1  8  -1  -1  -1  -1  -1  12  1  -1  4  934  78  330  10  ]
      [  57  2  8  -1  -1  -1  -1  -1  -1  1  3  4  976  78  -1  6  ]
      [  44  1  1  6  531  36  8  40  16  3  3  1  1053  78  480  11  ]
      [  44  1  1  6  145  34  8  40  9  1  3  1  936  78  325  14  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  2  975  78  -1  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  6  3  992  78  -1  6  ]
      [  42  1  1  6  662  50  8  40  -1  5  8  1  912  78  -1  13  ]
      [  42  1  1  6  482  45  8  40  9  2  3  1  1050  78  257  12  ]
      [  22  2  1  5  774  75  1  40  14  3  3  1  1081  78  500  13  ]
      [  25  2  1  5  843  85  8  42  8  5  9  1  1298  78  250  7  ]
      [  34  2  1  1  902  93  8  40  -1  1  3  1  1220  78  -1  7  ]
      [  68  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1242  78  400  7  ]
      [  64  2  8  -1  -1  -1  -1  -1  10  5  9  3  1223  78  279  7  ]
      [  43  2  1  5  868  75  1  39  17  5  9  1  1173  78  500  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1157  78  325  7  ]
      [  53  2  1  5  789  70  8  38  15  3  3  1  1188  78  480  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  13  1  3  3  1276  78  450  7  ]
      [  25  1  1  5  754  74  8  40  8  4  3  1  1197  78  250  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1181  78  -1  8  ]
      [  26  1  1  6  485  45  8  36  13  1  3  1  1127  78  400  12  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1173  78  -1  12  ]
      [  77  2  8  -1  -1  -1  -1  -1  8  1  -1  3  1188  78  255  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  13  1  3  3  1181  78  391  13  ]
      [  62  1  8  -1  -1  -1  -1  -1  14  1  3  3  1282  78  480  10  ]
      [  24  1  1  5  662  50  8  40  10  3  3  1  1198  78  275  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1276  78  -1  10  ]
      [  58  1  8  -1  -1  -1  -1  -1  17  1  3  2  1235  78  550  7  ]
      [  43  2  8  -1  -1  -1  -1  -1  12  5  4  3  1106  78  383  7  ]
      [  54  1  1  6  550  24  8  37  10  1  4  1  1143  78  325  11  ]
      [  52  1  1  6  310  45  8  37  11  9  99  1  1111  78  260  7  ]
      [  40  1  1  6  540  32  8  40  12  1  3  1  1270  78  275  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1375  78  -1  13  ]
      [  31  2  1  5  677  63  8  39  15  5  9  1  1399  78  499  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1432  78  -1  8  ]
      [  52  1  1  5  772  45  8  36  12  1  3  1  1309  78  389  8  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1327  78  -1  8  ]
      [  33  2  1  4  765  75  1  38  20  3  3  1  1376  78  600  14  ]
      [  41  2  1  5  934  80  1  20  8  3  99  1  1329  78  280  8  ]
      [  28  1  1  4  872  80  1  40  9  5  3  1  1364  78  300  10  ]
      [  43  1  1  6  241  29  8  35  13  3  3  1  1469  78  413  8  ]
      [  30  1  1  6  310  51  8  40  13  3  3  1  1377  78  429  10  ]
      [  44  1  1  5  780  52  8  40  16  4  -1  1  1407  78  500  14  ]
      [  25  1  1  5  620  45  8  40  -1  3  3  1  1454  78  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1451  78  -1  8  ]
      [  41  2  1  5  692  66  8  18  17  3  3  1  1438  78  480  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  30  -1  -1  3  1411  78  940  12  ]
      [  23  2  1  5  676  52  8  45  10  9  -1  1  1346  78  325  11  ]
      [  41  2  1  5  780  19  8  40  13  1  3  1  1451  78  400  11  ]
      [  27  1  1  5  269  93  8  40  13  1  99  1  1462  78  414  8  ]
      [  59  1  8  -1  -1  -1  -1  -1  13  -1  -1  2  1491  78  380  12  ]
      [  60  1  8  -1  -1  -1  -1  -1  10  5  8  3  1484  78  240  12  ]
      [  36  1  1  6  546  45  8  40  11  2  4  1  1408  78  306  13  ]
      [  38  1  1  5  775  72  8  40  15  5  8  1  1516  78  450  11  ]
      [  78  2  8  -1  -1  -1  -1  -1  18  1  3  3  1582  78  600  9  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1552  78  -1  9  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1638  78  -1  9  ]
      [  34  1  1  1  225  28  8  35  9  1  3  1  1522  78  267  11  ]
      [  37  2  1  5  780  75  1  20  -1  1  -1  1  1541  78  -1  15  ]
      [  57  1  1  5  814  75  1  40  -1  1  5  1  1654  78  -1  9  ]
      [  35  1  1  5  714  60  8  40  13  1  3  1  1676  78  430  9  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1652  78  400  15  ]
      [  83  1  8  -1  -1  -1  -1  -1  8  3  3  3  1577  78  250  11  ]
      [  42  1  1  6  273  28  8  35  15  2  3  1  1660  78  425  11  ]
      [  38  1  1  5  741  51  8  39  -1  1  3  1  1953  78  -1  12  ]
      [  74  1  8  -1  -1  -1  -1  -1  12  3  3  3  1796  78  375  10  ]
      [  38  1  1  6  540  25  8  40  11  3  -1  1  1803  78  300  10  ]
      [  39  1  1  6  521  24  8  40  13  1  3  1  1935  78  400  10  ]
      [  44  1  1  5  864  85  1  39  11  4  99  1  1750  78  350  15  ]
      [  34  1  1  5  780  70  8  38  13  3  3  1  1748  78  380  13  ]
      [  25  2  8  -1  -1  -1  -1  -1  9  1  -1  6  1756  78  300  10  ]
      [  41  1  1  1  834  74  8  40  16  4  8  1  1834  78  560  17  ]
      [  68  1  8  -1  -1  -1  -1  -1  16  1  3  3  1953  78  457  12  ]
      [  45  1  1  6  273  31  8  35  11  1  3  1  1714  78  288  14  ]
      [  29  2  1  5  755  74  8  40  13  -1  -1  1  1982  78  400  10  ]
      [  33  1  1  2  488  45  8  60  -1  2  5  1  1748  78  -1  10  ]
      [  78  2  8  -1  -1  -1  -1  -1  14  9  -1  3  2188  78  484  13  ]
      [  33  1  1  5  441  45  8  47  11  1  3  1  2204  78  300  15  ]
      [  47  2  1  5  531  18  8  40  7  2  5  1  2244  78  180  17  ]
      [  39  2  1  5  853  85  1  38  12  3  4  1  2054  78  404  17  ]
      [  47  1  1  5  780  51  8  38  -1  4  99  1  2541  78  -1  16  ]
      [  33  1  1  5  788  35  8  40  12  3  3  1  2535  78  345  15  ]
      [  41  1  1  4  801  75  1  40  -1  3  4  1  2408  78  -1  14  ]
      [  57  1  1  5  750  73  8  45  12  2  8  1  2377  78  314  19  ]
      [  33  1  1  4  881  65  1  38  -1  5  8  1  2837  78  -1  13  ]
      [  39  1  1  6  290  34  8  35  15  1  3  1  3167  78  496  14  ]
      [  49  1  1  5  775  65  8  39  13  1  3  1  2904  78  390  14  ]
      [  49  1  1  5  751  33  8  40  -1  3  5  1  3193  78  -1  17  ]
      [  27  1  1  5  757  74  8  40  12  3  -1  1  3004  78  371  14  ]
      [  41  1  1  5  750  70  8  40  18  4  9  1  3234  78  560  15  ]
      [  47  1  1  5  775  64  8  40  -1  5  8  1  3468  78  -1  18  ]
      [  44  1  1  5  774  75  1  40  17  5  9  1  3684  78  570  19  ]
      [  38  1  1  5  611  24  8  38  12  5  9  1  5086  78  400  19  ]
      [  53  2  1  6  934  85  1  10  12  1  -1  1  662  77  388  7  ]
      [  28  1  1  5  775  80  1  19  12  5  3  1  775  77  345  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  11  4  3  3  711  77  325  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  11  5  9  3  711  77  270  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  702  77  -1  8  ]
      [  32  2  8  -1  -1  -1  -1  -1  5  3  3  6  821  77  135  6  ]
      [  69  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1000  77  368  6  ]
      [  34  2  1  6  937  52  8  4  10  4  1  4  963  77  306  6  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  968  77  -1  6  ]
      [  47  1  1  1  886  80  8  6  14  5  9  1  1015  77  411  13  ]
      [  25  2  8  -1  -1  -1  -1  -1  12  1  -1  6  1061  77  300  6  ]
      [  36  1  8  -1  -1  -1  -1  -1  12  1  1  2  1037  77  370  6  ]
      [  68  1  8  -1  -1  -1  -1  -1  12  1  3  3  1293  77  420  10  ]
      [  35  1  8  -1  -1  -1  -1  -1  -1  3  3  2  1104  77  -1  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  17  4  9  3  1108  77  535  11  ]
      [  44  1  1  6  744  51  8  39  15  5  -1  1  1492  77  470  11  ]
      [  50  1  1  5  269  29  8  38  -1  1  3  1  1377  77  -1  13  ]
      [  30  1  1  5  660  50  8  38  17  4  3  1  1489  77  489  12  ]
      [  50  1  1  6  269  34  8  35  12  3  99  1  1538  77  350  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  11  1  3  2  1654  77  305  9  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1585  77  -1  9  ]
      [  47  1  1  2  701  63  8  65  17  2  3  1  1607  77  555  11  ]
      [  52  1  1  6  273  60  8  40  -1  9  99  1  1984  77  -1  10  ]
      [  72  1  8  -1  -1  -1  -1  -1  10  1  3  3  1950  77  330  11  ]
      [  42  2  1  5  751  32  8  38  23  5  4  1  1905  77  750  15  ]
      [  30  2  1  5  873  80  1  38  16  5  9  1  2192  77  520  11  ]
      [  58  1  1  5  633  25  8  40  13  1  3  1  2204  77  400  11  ]
      [  42  1  1  4  801  75  1  40  11  5  7  1  2118  77  350  17  ]
      [  60  1  1  6  254  34  8  37  11  1  3  1  2189  77  350  11  ]
      [  52  1  1  4  784  60  8  40  8  1  3  1  2129  77  250  14  ]
      [  52  1  1  5  602  26  8  37  -1  3  3  1  2095  77  600  16  ]
      [  53  2  1  4  874  80  1  30  8  5  5  1  2551  77  230  12  ]
      [  44  1  1  6  281  50  8  40  12  1  3  1  3094  77  349  14  ]
      [  39  1  1  2  670  74  8  60  23  1  3  1  3142  77  700  14  ]
      [  41  1  1  5  861  85  8  39  19  5  8  1  3353  77  700  21  ]
      [  61  1  8  -1  -1  -1  -1  -1  9  3  3  3  3516  77  227  15  ]
      [  48  2  8  -1  -1  -1  -1  -1  12  5  9  4  20  76  350  8  ]
      [  24  1  8  -1  -1  -1  -1  -1  -1  9  3  4  270  76  -1  2  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  385  76  0  3  ]
      [  23  2  8  -1  -1  -1  -1  -1  7  5  3  4  497  76  210  3  ]
      [  20  2  8  -1  -1  -1  -1  -1  -1  -1  -1  8  379  76  -1  3  ]
      [  35  2  8  -1  -1  -1  -1  -1  -1  2  3  2  418  76  -1  6  ]
      [  60  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  646  76  325  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  14  -1  -1  6  600  76  400  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  9  -1  -1  2  625  76  230  4  ]
      [  21  2  8  -1  -1  -1  -1  -1  12  5  -1  4  530  76  333  4  ]
      [  23  1  1  5  997  80  1  10  -1  5  -1  1  616  76  -1  4  ]
      [  34  1  8  -1  -1  -1  -1  -1  8  2  3  8  526  76  240  10  ]
      [  37  1  1  5  714  93  8  40  14  2  3  1  653  76  435  6  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  4  3  737  76  0  6  ]
      [  56  1  1  5  714  60  8  20  10  1  -1  2  712  76  250  9  ]
      [  39  1  1  5  780  80  1  19  15  5  3  1  876  76  464  5  ]
      [  35  2  8  -1  -1  -1  -1  -1  10  3  3  2  750  76  300  6  ]
      [  52  1  8  -1  -1  -1  -1  -1  8  -1  -1  2  873  76  220  6  ]
      [  24  1  8  -1  -1  -1  -1  -1  10  1  3  2  833  76  300  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  777  76  -1  8  ]
      [  33  2  1  5  431  52  8  20  -1  2  3  1  899  76  -1  13  ]
      [  52  1  8  -1  -1  -1  -1  -1  14  1  3  2  866  76  330  5  ]
      [  69  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  726  76  285  5  ]
      [  33  2  1  5  853  85  1  39  -1  3  3  1  932  76  460  6  ]
      [  52  1  8  -1  -1  -1  -1  -1  9  4  5  2  951  76  237  10  ]
      [  21  2  1  5  786  74  8  38  14  3  3  1  1078  76  400  6  ]
      [  32  2  1  5  660  52  8  18  12  1  3  1  1036  76  375  6  ]
      [  41  1  1  6  401  51  8  40  10  3  99  1  901  76  270  12  ]
      [  47  1  1  6  153  25  8  38  11  3  3  1  902  76  330  12  ]
      [  58  2  8  -1  -1  -1  -1  -1  -1  1  3  4  990  76  -1  13  ]
      [  26  1  1  6  281  50  8  45  10  2  3  1  1082  76  307  10  ]
      [  51  1  1  6  662  52  8  39  8  2  3  1  945  76  193  11  ]
      [  70  2  8  -1  -1  -1  -1  -1  13  3  3  3  1134  76  349  7  ]
      [  26  1  1  6  241  28  8  40  9  1  -1  1  1240  76  310  9  ]
      [  54  1  1  6  268  45  8  38  13  1  3  1  1143  76  405  15  ]
      [  43  1  1  6  997  50  8  38  -1  1  3  1  1108  76  -1  7  ]
      [  34  2  1  5  857  91  1  32  -1  3  3  1  1253  76  -1  14  ]
      [  45  1  1  6  51  1  8  42  12  3  3  1  1257  76  375  9  ]
      [  81  2  8  -1  -1  -1  -1  -1  17  1  3  3  1150  76  600  7  ]
      [  25  1  8  -1  -1  -1  -1  -1  -1  4  3  8  1117  76  -1  7  ]
      [  41  2  8  -1  -1  -1  -1  -1  13  5  8  6  1142  76  337  11  ]
      [  65  2  8  -1  -1  -1  -1  -1  11  2  4  3  1112  76  298  7  ]
      [  53  1  8  -1  -1  -1  -1  -1  10  5  10  2  1235  76  274  7  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  1  3  1286  76  -1  7  ]
      [  26  1  1  6  742  10  8  40  15  1  -1  1  1415  76  480  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  15  1  3  3  1325  76  500  12  ]
      [  34  1  1  6  281  34  8  39  14  1  -1  1  1400  76  410  8  ]
      [  42  2  1  5  633  74  1  38  16  5  3  1  1479  76  500  13  ]
      [  27  1  1  5  510  45  8  40  16  3  3  1  1493  76  500  10  ]
      [  58  2  1  5  853  85  1  39  -1  1  3  1  1459  76  -1  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  10  1  3  3  1304  76  240  8  ]
      [  52  1  1  5  791  74  8  48  -1  3  3  1  1337  76  -1  17  ]
      [  39  1  1  5  714  51  8  45  12  1  -1  1  1401  76  356  18  ]
      [  32  1  1  6  171  22  8  40  12  3  3  1  1384  76  400  10  ]
      [  32  1  1  5  751  52  8  38  -1  1  3  1  1413  76  -1  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1476  76  -1  15  ]
      [  67  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1356  76  420  8  ]
      [  32  1  1  6  711  60  8  47  14  1  -1  1  1452  76  439  8  ]
      [  30  1  1  6  501  52  8  38  12  1  3  1  1338  76  370  13  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1365  76  -1  8  ]
      [  29  1  1  6  270  29  8  36  -1  1  3  1  1434  76  -1  8  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1489  76  -1  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1554  76  -1  9  ]
      [  27  1  1  6  521  63  8  40  10  1  3  1  1585  76  290  9  ]
      [  31  1  1  6  488  45  8  39  14  1  3  1  1559  76  425  14  ]
      [  38  2  1  5  858  85  8  20  11  5  5  1  1511  76  310  9  ]
      [  60  1  1  6  273  36  8  35  12  1  3  1  1549  76  340  9  ]
      [  38  2  1  5  853  85  1  27  11  3  3  1  1665  76  350  9  ]
      [  47  1  8  -1  -1  -1  -1  -1  12  5  -1  4  1529  76  363  12  ]
      [  47  1  1  6  268  45  8  39  14  1  1  1  1618  76  360  11  ]
      [  44  1  1  6  250  34  8  40  -1  3  3  1  1624  76  -1  11  ]
      [  36  1  1  6  481  45  8  38  13  3  3  1  1541  76  450  10  ]
      [  31  1  1  6  461  45  8  40  -1  1  99  1  1666  76  -1  12  ]
      [  43  2  1  5  789  85  1  39  -1  3  3  1  1602  76  -1  9  ]
      [  60  1  8  -1  -1  -1  -1  -1  16  1  3  8  1514  76  535  14  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  3  8  3  1509  76  -1  9  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1674  76  -1  9  ]
      [  37  2  1  5  823  91  8  38  10  2  3  1  1577  76  310  10  ]
      [  51  1  1  6  711  75  1  38  12  1  -1  1  1712  76  341  14  ]
      [  40  2  1  5  821  92  8  38  14  5  3  1  1818  76  500  10  ]
      [  48  1  1  5  671  51  8  38  13  1  3  1  1977  76  394  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  17  1  3  3  1947  76  525  14  ]
      [  50  1  1  6  550  21  8  35  12  1  -1  1  1944  76  400  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1940  76  -1  16  ]
      [  46  1  1  6  471  93  1  40  18  3  -1  1  1717  76  525  13  ]
      [  62  1  1  5  316  31  8  39  11  1  3  1  1857  76  350  11  ]
      [  53  1  1  4  801  75  1  38  17  2  8  1  1948  76  560  13  ]
      [  36  1  1  6  714  63  8  55  10  1  3  1  2230  76  256  11  ]
      [  53  1  1  5  689  51  8  40  16  1  3  1  2135  76  500  11  ]
      [  44  1  1  9  801  75  1  39  12  3  5  1  2066  76  342  14  ]
      [  35  1  1  5  776  72  8  40  17  9  99  1  2115  76  515  11  ]
      [  48  1  1  6  671  51  8  40  15  1  1  1  2057  76  440  13  ]
      [  39  1  1  6  201  34  8  39  15  3  3  1  2240  76  450  13  ]
      [  52  1  1  5  628  28  8  35  -1  1  5  1  2007  76  -1  16  ]
      [  42  1  1  6  731  64  8  39  15  1  3  1  2199  76  490  11  ]
      [  34  2  1  5  677  52  8  46  15  5  9  1  2458  76  484  19  ]
      [  51  1  1  5  863  85  1  38  -1  3  3  1  2303  76  560  13  ]
      [  35  1  1  6  273  40  8  60  -1  2  3  1  2489  76  -1  16  ]
      [  29  1  1  5  780  45  8  40  15  5  9  1  2839  76  465  19  ]
      [  33  1  1  5  602  31  8  35  -1  5  9  1  2899  76  -1  18  ]
      [  35  1  1  5  601  29  8  35  -1  5  8  1  3098  76  -1  14  ]
      [  43  1  1  2  268  45  8  50  -1  2  5  1  2920  76  -1  14  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  5  99  3  3543  76  -1  15  ]
      [  38  1  1  5  607  33  8  50  18  5  9  1  4077  76  600  17  ]
      [  40  1  8  1  937  74  8  20  10  3  3  5  139  75  320  6  ]
      [  20  2  1  8  773  52  8  37  -1  3  -1  4  196  75  200  12  ]
      [  48  1  8  -1  -1  -1  -1  -1  12  1  4  6  276  75  400  4  ]
      [  29  1  1  6  934  74  8  20  14  -1  -1  4  495  75  430  11  ]
      [  53  1  8  -1  -1  -1  -1  -1  9  1  -1  2  387  75  245  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  411  75  320  10  ]
      [  92  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  377  75  -1  3  ]
      [  23  1  8  -1  -1  -1  -1  -1  9  5  3  6  356  75  270  3  ]
      [  21  1  8  -1  -1  -1  -1  -1  -1  5  -1  6  499  75  -1  3  ]
      [  24  1  8  -1  -1  -1  -1  -1  -1  5  3  6  420  75  -1  3  ]
      [  36  2  8  -1  -1  -1  -1  -1  13  -1  -1  6  391  75  330  5  ]
      [  40  1  8  -1  -1  -1  -1  -1  10  2  3  2  315  75  318  8  ]
      [  54  1  8  -1  -1  -1  -1  -1  8  1  -1  2  601  75  270  5  ]
      [  26  1  8  -1  -1  -1  -1  -1  -1  1  3  2  648  75  -1  10  ]
      [  40  1  8  -1  -1  -1  -1  -1  12  1  3  6  622  75  330  8  ]
      [  44  1  8  -1  -1  -1  -1  -1  15  1  -1  2  691  75  464  7  ]
      [  37  1  8  -1  -1  -1  -1  -1  9  1  -1  2  598  75  305  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  10  1  3  3  624  75  300  8  ]
      [  40  2  8  -1  -1  -1  -1  -1  50  5  7  2  633  75  -1  4  ]
      [  32  2  8  5  853  85  1  56  12  5  5  1  568  75  328  10  ]
      [  66  1  1  6  934  74  8  6  12  1  3  3  674  75  380  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  681  75  -1  4  ]
      [  49  1  8  -1  -1  -1  -1  -1  15  5  5  6  543  75  445  12  ]
      [  21  1  8  -1  -1  -1  -1  -1  11  3  -1  4  643  75  303  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  689  75  -1  4  ]
      [  20  1  1  7  852  85  8  37  7  3  -1  1  574  75  215  5  ]
      [  71  1  8  -1  -1  -1  -1  -1  14  1  3  3  544  75  399  6  ]
      [  31  1  8  -1  -1  -1  -1  -1  11  2  3  2  501  75  325  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  11  3  4  2  833  75  216  12  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  734  75  -1  5  ]
      [  74  2  8  -1  -1  -1  -1  -1  10  1  -1  3  714  75  310  5  ]
      [  36  2  8  -1  -1  -1  -1  -1  11  3  -1  8  879  75  350  5  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  3  3  838  75  0  5  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  881  75  -1  6  ]
      [  29  1  1  1  757  74  8  50  7  5  3  1  890  75  230  5  ]
      [  34  2  8  -1  -1  -1  -1  -1  13  3  3  2  880  75  400  5  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  799  75  -1  5  ]
      [  33  2  1  5  853  85  1  7  18  5  5  1  802  75  570  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  9  1  3  3  737  75  300  7  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  732  75  -1  7  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  1  3  3  736  75  0  5  ]
      [  55  1  8  -1  -1  -1  -1  -1  19  -1  3  4  711  75  600  15  ]
      [  25  2  8  -1  -1  -1  -1  -1  8  1  3  6  744  75  260  5  ]
      [  95  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  771  75  0  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  7  -1  -1  3  795  75  208  8  ]
      [  52  2  8  -1  -1  -1  -1  -1  10  3  3  2  710  75  302  10  ]
      [  56  1  8  -1  -1  -1  -1  -1  18  1  3  3  852  75  540  13  ]
      [  59  1  8  -1  -1  -1  -1  -1  14  1  3  3  853  75  455  13  ]
      [  50  1  1  3  411  55  8  60  -1  1  3  1  732  75  -1  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  779  75  -1  5  ]
      [  51  2  1  5  772  74  8  30  13  2  6  1  823  75  375  12  ]
      [  41  1  8  -1  -1  -1  -1  -1  17  2  99  8  710  75  500  11  ]
      [  24  1  1  6  485  45  8  40  8  3  -1  1  823  75  251  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  841  75  0  9  ]
      [  55  1  1  6  792  74  8  55  -1  -1  -1  1  781  75  -1  5  ]
      [  50  1  1  1  603  28  8  80  -1  4  8  1  803  75  -1  12  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  827  75  -1  5  ]
      [  63  1  1  6  660  52  8  3  6  1  3  3  860  75  150  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  10  3  3  3  1062  75  307  7  ]
      [  23  1  1  5  411  55  8  60  31  3  -1  1  1088  75  940  10  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  3  3  983  75  0  6  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1083  75  -1  6  ]
      [  60  2  1  5  411  55  8  30  12  3  3  1  926  75  400  6  ]
      [  25  2  1  5  689  71  8  20  8  5  -1  1  1050  75  235  8  ]
      [  60  1  8  -1  -1  -1  -1  -1  9  1  -1  3  1029  75  270  10  ]
      [  54  2  1  5  780  74  8  39  10  1  3  1  1082  75  325  6  ]
      [  53  2  1  5  863  85  1  35  -1  5  99  1  990  75  -1  13  ]
      [  36  1  1  5  741  30  8  38  17  1  3  1  1088  75  500  15  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1017  75  -1  6  ]
      [  65  2  8  -1  -1  -1  -1  -1  8  1  -1  3  1029  75  200  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1085  75  -1  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  10  1  3  3  990  75  300  6  ]
      [  48  1  8  5  522  52  8  12  8  -1  -1  3  962  75  250  6  ]
      [  42  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1006  75  -1  6  ]
      [  23  2  1  5  786  74  8  38  -1  -1  -1  1  1044  75  -1  6  ]
      [  37  2  1  6  863  85  8  39  13  1  3  1  1066  75  380  6  ]
      [  75  2  8  -1  -1  -1  -1  -1  8  1  -1  3  1089  75  250  6  ]
      [  89  1  8  -1  -1  -1  -1  -1  -1  1  1  3  996  75  -1  6  ]
      [  27  2  1  5  53  52  8  35  13  1  3  1  936  75  421  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  8  1  3  3  1072  75  256  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1020  75  -1  10  ]
      [  65  2  8  -1  -1  -1  -1  -1  11  1  -1  3  906  75  305  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1042  75  -1  8  ]
      [  48  2  1  6  411  55  8  20  13  3  3  3  1001  75  350  6  ]
      [  37  1  1  1  834  92  8  30  11  5  9  1  1087  75  295  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  963  75  -1  9  ]
      [  43  1  1  6  331  17  8  40  -1  2  3  1  920  75  352  12  ]
      [  50  2  1  6  934  80  1  40  -1  2  3  1  1058  75  -1  10  ]
      [  52  1  1  6  310  70  8  37  12  2  3  1  965  75  200  11  ]
      [  44  1  1  6  270  45  8  40  -1  5  -1  1  1027  75  -1  11  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1090  75  -1  6  ]
      [  35  1  1  5  714  52  8  38  8  -1  -1  1  1141  75  250  7  ]
      [  63  2  8  1  852  85  8  3  -1  3  4  3  1268  75  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  13  1  3  3  1257  75  420  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1104  75  480  8  ]
      [  31  1  1  6  714  63  8  40  10  3  3  1  1101  75  325  11  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1144  75  -1  7  ]
      [  42  1  1  6  937  74  8  40  16  -1  -1  1  1140  75  500  8  ]
      [  87  2  8  -1  -1  -1  -1  -1  9  1  1  3  1154  75  220  7  ]
      [  33  1  8  -1  -1  -1  -1  -1  12  1  3  2  1154  75  401  7  ]
      [  42  2  1  5  660  52  8  39  -1  1  3  1  1290  75  -1  9  ]
      [  49  1  1  6  512  36  8  39  13  -1  -1  1  1111  75  320  16  ]
      [  36  2  1  6  660  64  8  39  13  1  3  1  1266  75  425  15  ]
      [  53  2  1  5  789  74  8  40  18  3  -1  1  1167  75  495  10  ]
      [  83  1  8  -1  -1  -1  -1  -1  10  1  3  3  1255  75  315  7  ]
      [  48  1  1  5  876  1  8  45  11  1  -1  1  1148  75  330  11  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1231  75  -1  7  ]
      [  55  2  1  5  672  52  8  38  14  1  3  1  1254  75  470  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  11  1  5  3  1293  75  330  7  ]
      [  41  1  1  6  531  29  8  37  -1  3  5  1  1167  75  -1  12  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1112  75  -1  7  ]
      [  68  1  8  -1  -1  -1  -1  -1  14  1  3  3  1245  75  345  11  ]
      [  27  1  1  5  774  72  8  39  12  3  3  1  1140  75  400  11  ]
      [  33  2  1  5  703  72  8  30  -1  5  -1  1  1280  75  -1  7  ]
      [  34  2  1  5  662  45  8  39  11  1  5  1  1224  75  324  8  ]
      [  81  2  8  -1  -1  -1  -1  -1  6  -1  -1  3  1214  75  180  7  ]
      [  66  1  8  5  796  52  8  12  -1  3  -1  3  1262  75  -1  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  9  1  3  3  1105  75  275  8  ]
      [  42  2  1  5  780  80  1  10  11  5  3  1  1166  75  280  10  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1254  75  -1  7  ]
      [  58  1  1  5  805  93  8  40  18  1  3  1  1233  75  600  11  ]
      [  46  1  8  -1  -1  -1  -1  -1  13  3  3  8  1246  75  350  8  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1143  75  -1  10  ]
      [  74  2  8  -1  -1  -1  -1  -1  10  3  6  3  1249  75  300  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  12  2  3  3  1290  75  398  12  ]
      [  33  1  1  6  194  28  8  40  -1  2  3  1  1185  75  -1  9  ]
      [  33  1  1  6  501  45  8  38  -1  2  3  1  1136  75  0  7  ]
      [  54  1  1  6  626  24  8  38  13  1  3  1  1340  75  375  8  ]
      [  40  2  8  -1  -1  -1  -1  -1  13  3  99  6  1447  75  327  8  ]
      [  36  2  1  5  772  71  8  36  18  5  -1  1  1366  75  580  13  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1422  75  -1  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1491  75  -1  8  ]
      [  47  1  1  5  703  64  8  39  12  3  3  1  1466  75  375  11  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1408  75  -1  8  ]
      [  53  2  8  -1  -1  -1  -1  -1  12  1  3  4  1348  75  345  13  ]
      [  53  1  8  -1  -1  -1  -1  -1  9  1  4  3  1403  75  206  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1426  75  -1  8  ]
      [  34  1  1  1  750  70  8  40  -1  3  3  1  1336  75  -1  10  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1388  75  0  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  11  1  3  3  1327  75  340  9  ]
      [  59  1  1  6  531  34  8  37  -1  -1  -1  1  1357  75  -1  17  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1483  75  0  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1449  75  -1  10  ]
      [  42  1  1  6  550  45  8  38  -1  1  3  1  1484  75  -1  14  ]
      [  60  1  1  5  784  65  8  37  -1  1  -1  1  1398  75  -1  11  ]
      [  39  1  1  6  714  63  8  40  16  2  3  1  1445  75  490  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1446  75  -1  8  ]
      [  21  1  1  6  791  74  8  40  17  1  -1  1  1307  75  480  11  ]
      [  20  1  1  6  441  45  8  42  12  1  3  1  1419  75  325  12  ]
      [  51  2  1  5  784  85  8  38  7  1  3  1  1371  75  200  8  ]
      [  93  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1310  75  -1  8  ]
      [  53  1  1  6  141  24  8  37  15  -1  -1  1  1329  75  400  11  ]
      [  30  1  1  5  401  15  8  40  -1  1  3  1  1381  75  -1  10  ]
      [  58  1  1  5  491  45  8  39  10  1  3  1  1399  75  320  17  ]
      [  49  1  1  5  787  64  8  38  -1  1  -1  1  1317  75  0  13  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1496  75  -1  9  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1491  75  -1  8  ]
      [  33  1  1  5  600  74  8  40  -1  4  8  1  1388  75  -1  8  ]
      [  34  1  8  -1  -1  -1  -1  -1  -1  1  5  2  1404  75  -1  8  ]
      [  71  2  8  -1  -1  -1  -1  -1  14  1  3  3  1435  75  353  8  ]
      [  53  2  1  5  787  75  1  40  13  -1  -1  1  1447  75  380  8  ]
      [  46  2  1  5  853  85  8  24  10  3  3  1  1381  75  240  8  ]
      [  48  1  1  5  651  85  1  40  -1  2  5  1  1440  75  -1  13  ]
      [  45  1  1  5  692  67  8  38  9  4  3  1  1576  75  200  14  ]
      [  48  2  1  5  787  91  8  38  -1  3  3  1  1552  75  -1  9  ]
      [  40  1  1  6  442  45  8  40  15  1  5  1  1578  75  450  10  ]
      [  45  1  1  6  501  36  8  38  -1  3  1  1  1610  75  -1  12  ]
      [  52  1  1  5  912  55  8  70  -1  1  3  1  1514  75  -1  9  ]
      [  42  1  8  -1  -1  -1  -1  -1  15  3  3  2  1526  75  480  9  ]
      [  29  1  1  6  411  55  1  40  -1  9  -1  1  1595  75  -1  11  ]
      [  43  1  1  5  660  52  8  37  -1  4  3  1  1631  75  -1  15  ]
      [  37  1  1  6  540  27  8  40  -1  1  99  1  1586  75  347  9  ]
      [  28  1  1  6  267  45  8  38  -1  1  3  1  1595  75  0  10  ]
      [  44  2  1  6  269  31  8  38  15  1  -1  1  1568  75  400  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1631  75  0  9  ]
      [  36  2  1  5  863  80  1  32  11  3  3  1  1605  75  350  9  ]
      [  77  2  8  -1  -1  -1  -1  -1  17  1  3  3  1596  75  570  9  ]
      [  51  1  1  6  241  28  8  38  10  3  3  1  1668  75  304  11  ]
      [  58  1  1  5  692  66  8  38  -1  1  3  1  1642  75  -1  11  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1514  75  -1  11  ]
      [  62  1  1  5  311  32  8  35  -1  1  3  1  1576  75  -1  12  ]
      [  57  1  1  4  801  75  1  40  -1  3  3  1  1594  75  -1  17  ]
      [  41  2  1  6  854  85  1  30  14  1  3  1  1525  75  434  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1687  75  -1  11  ]
      [  30  1  1  9  801  75  1  39  9  1  3  1  1633  75  250  13  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1621  75  -1  9  ]
      [  45  2  1  5  787  75  1  38  11  4  3  1  1557  75  341  13  ]
      [  60  1  1  5  620  60  8  40  14  5  9  1  1587  75  435  13  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  5  3  1500  75  0  9  ]
      [  39  2  1  5  787  75  1  40  12  2  3  1  1584  75  350  14  ]
      [  39  1  1  6  310  45  8  40  8  2  3  1  1667  75  228  15  ]
      [  33  1  1  1  703  92  8  60  5  5  -1  1  1737  75  60  10  ]
      [  77  1  8  -1  -1  -1  -1  -1  14  5  3  3  1793  75  400  10  ]
      [  51  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1829  75  -1  12  ]
      [  43  1  1  6  274  10  8  40  -1  1  3  1  1962  75  -1  13  ]
      [  42  1  1  5  787  75  1  39  13  3  3  1  1850  75  424  12  ]
      [  55  1  1  5  174  22  8  38  11  1  3  1  1881  75  360  13  ]
      [  41  1  1  5  502  32  8  35  -1  3  3  1  1999  75  -1  10  ]
      [  62  1  1  6  269  28  8  40  -1  3  3  1  1910  75  -1  10  ]
      [  37  1  1  5  750  74  8  50  18  5  5  1  1797  75  580  15  ]
      [  48  1  1  5  678  51  8  40  18  1  3  1  1893  75  620  13  ]
      [  35  2  1  5  786  74  8  40  -1  3  3  1  1935  75  -1  12  ]
      [  57  1  1  6  540  29  8  35  -1  1  -1  1  1790  75  -1  11  ]
      [  35  2  1  5  876  80  8  40  13  4  4  1  1800  75  350  10  ]
      [  51  1  1  6  744  34  8  35  10  -1  -1  1  1713  75  312  13  ]
      [  36  2  1  1  689  17  8  40  19  3  3  1  1945  75  585  15  ]
      [  34  1  1  5  873  80  1  40  10  5  9  1  1753  75  300  10  ]
      [  29  1  1  5  672  52  8  45  -1  4  8  1  1876  75  -1  10  ]
      [  42  1  1  4  878  75  1  40  -1  5  7  1  1837  75  -1  15  ]
      [  31  1  1  5  689  51  8  40  13  1  -1  1  1972  75  383  10  ]
      [  46  1  1  6  310  29  8  36  4  1  3  1  1829  75  100  12  ]
      [  62  1  1  5  663  51  8  45  -1  1  3  1  1850  75  -1  14  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1753  75  -1  10  ]
      [  58  1  1  6  270  31  8  35  14  1  3  1  1803  75  382  10  ]
      [  58  1  1  5  863  85  1  39  -1  3  4  1  1850  75  -1  12  ]
      [  35  1  1  1  662  52  8  35  10  1  1  1  1756  75  255  10  ]
      [  55  1  1  6  714  63  8  40  6  1  3  1  1788  75  163  14  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1900  75  -1  14  ]
      [  60  1  8  1  714  50  8  15  -1  3  3  3  2105  75  -1  13  ]
      [  36  1  1  5  603  35  8  30  14  5  4  1  2128  75  400  11  ]
      [  43  1  1  6  141  24  8  37  -1  1  3  1  2300  75  -1  11  ]
      [  40  1  1  5  714  93  1  38  12  1  3  1  2211  75  400  11  ]
      [  41  1  1  6  174  22  8  38  5  1  3  1  2001  75  100  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2168  75  -1  14  ]
      [  55  1  1  6  796  85  8  40  12  5  3  1  2149  75  380  17  ]
      [  64  1  1  5  778  62  8  38  11  3  3  1  2267  75  300  11  ]
      [  40  1  1  5  677  34  8  40  -1  3  5  1  2298  75  -1  15  ]
      [  50  1  1  6  482  34  8  35  -1  3  5  1  2092  75  -1  16  ]
      [  32  1  1  6  174  22  8  40  12  3  3  1  2026  75  370  11  ]
      [  38  2  1  4  873  80  1  29  -1  5  9  1  2233  75  -1  11  ]
      [  38  1  1  5  785  60  8  40  -1  3  5  1  2245  75  -1  13  ]
      [  29  1  1  6  254  33  8  40  9  3  3  1  2289  75  250  11  ]
      [  38  1  1  5  777  93  8  40  -1  5  9  1  2170  75  -1  15  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  6  2  2172  75  -1  13  ]
      [  37  1  1  5  678  64  8  38  11  3  4  1  2347  75  315  14  ]
      [  64  1  8  -1  -1  -1  -1  -1  9  1  8  3  2418  75  240  12  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2555  75  -1  12  ]
      [  47  2  1  4  784  75  1  39  -1  5  9  1  2504  75  -1  12  ]
      [  33  1  1  2  852  85  8  42  8  5  3  1  2515  75  238  15  ]
      [  39  1  1  1  609  74  8  40  12  5  9  1  2550  75  400  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  8  3  2385  75  -1  15  ]
      [  31  1  1  5  785  29  8  40  13  1  3  1  2524  75  375  16  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  4  4  3  2376  75  -1  12  ]
      [  39  1  1  5  627  22  8  40  -1  4  4  1  2520  75  -1  12  ]
      [  36  1  1  4  765  75  1  40  -1  -1  -1  1  2319  75  -1  12  ]
      [  56  2  1  5  841  85  1  38  -1  5  9  1  2761  75  -1  13  ]
      [  87  1  8  -1  -1  -1  -1  -1  11  1  3  3  2840  75  320  13  ]
      [  33  1  1  5  601  34  8  40  12  5  8  1  2755  75  409  14  ]
      [  44  1  1  4  813  74  1  40  -1  5  7  1  2629  75  -1  13  ]
      [  46  1  1  5  622  74  8  50  23  5  9  1  2722  75  720  17  ]
      [  40  1  1  4  765  75  1  39  11  5  6  1  3167  75  324  16  ]
      [  55  1  1  6  265  28  8  37  -1  1  3  1  3075  75  -1  14  ]
      [  51  2  1  5  772  91  8  38  -1  1  3  1  2950  75  -1  14  ]
      [  32  2  1  4  801  75  1  38  -1  5  7  1  3888  75  -1  16  ]
      [  29  1  1  5  780  24  8  37  18  5  8  1  3765  75  525  17  ]
      [  34  1  1  6  714  63  8  60  10  1  -1  1  3786  75  291  16  ]
      [  44  1  1  4  764  75  1  39  10  5  9  1  3927  75  300  16  ]
      [  62  1  1  5  823  66  8  39  -1  3  3  1  4352  75  -1  21  ]
      [  37  1  1  2  670  50  8  35  -1  1  -1  1  4215  75  -1  17  ]
      [  47  1  1  1  833  92  8  80  7  4  9  1  5332  75  200  19  ]
      [  44  1  1  5  628  31  8  40  -1  1  3  1  5479  75  -1  19  ]
      [  31  2  1  1  834  74  8  50  13  5  -1  1  5937  75  375  22  ]
      [  38  1  1  1  833  92  8  40  50  5  -1  1  304  74  -1  3  ]
      [  22  1  1  7  267  45  8  36  13  3  -1  1  470  74  350  5  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  1  3  3  351  74  236  3  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  370  74  -1  3  ]
      [  17  2  8  -1  -1  -1  -1  -1  -1  -1  -1  4  424  74  -1  3  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  353  74  -1  3  ]
      [  37  2  1  6  934  74  8  15  14  1  1  1  377  74  420  12  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  573  74  -1  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  577  74  0  4  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  599  74  -1  4  ]
      [  38  2  1  5  934  91  8  13  15  1  3  1  695  74  400  4  ]
      [  61  2  8  -1  -1  -1  -1  -1  14  2  -1  6  656  74  300  6  ]
      [  30  1  1  1  750  22  8  40  10  2  5  1  681  74  240  13  ]
      [  46  2  1  1  670  55  8  80  -1  1  3  1  703  74  290  8  ]
      [  58  1  8  -1  -1  -1  -1  -1  15  1  3  3  880  74  450  7  ]
      [  65  2  8  -1  -1  -1  -1  -1  10  1  -1  3  842  74  252  5  ]
      [  73  1  8  -1  -1  -1  -1  -1  13  1  -1  3  893  74  409  8  ]
      [  51  1  8  -1  -1  -1  -1  -1  14  1  3  2  876  74  375  5  ]
      [  51  2  1  5  662  52  8  15  -1  1  -1  4  803  74  -1  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  7  3  3  3  820  74  203  10  ]
      [  32  2  1  5  853  85  1  40  -1  2  6  1  740  74  -1  13  ]
      [  91  2  8  -1  -1  -1  -1  -1  12  3  -1  3  1092  74  328  13  ]
      [  44  1  8  -1  -1  -1  -1  -1  15  1  -1  2  935  74  450  6  ]
      [  29  1  1  5  621  29  8  38  13  5  5  1  946  74  404  11  ]
      [  39  2  8  5  780  85  8  10  11  1  3  1  1053  74  330  6  ]
      [  57  1  1  6  401  51  8  48  12  1  3  1  924  74  375  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  9  1  3  3  942  74  240  6  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1099  74  -1  6  ]
      [  36  2  1  5  391  15  8  25  15  3  4  1  905  74  480  7  ]
      [  57  2  8  -1  -1  -1  -1  -1  -1  1  3  2  1062  74  -1  6  ]
      [  60  1  1  6  714  75  1  40  9  1  5  1  1006  74  252  11  ]
      [  37  1  1  5  281  50  8  37  13  1  1  1  1202  74  360  11  ]
      [  31  2  1  6  934  74  8  3  10  1  -1  2  1192  74  240  7  ]
      [  42  2  1  5  780  93  8  36  -1  4  8  1  1234  74  -1  8  ]
      [  55  2  8  -1  -1  -1  -1  -1  12  1  3  3  1189  74  384  7  ]
      [  55  2  1  5  660  52  8  24  -1  3  3  1  1149  74  -1  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  14  1  3  3  1226  74  419  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  11  1  3  3  1285  74  320  9  ]
      [  49  2  1  5  853  85  1  38  8  1  3  1  1157  74  220  7  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1228  74  -1  7  ]
      [  81  1  8  -1  -1  -1  -1  -1  11  1  3  3  1257  74  335  10  ]
      [  55  1  1  6  254  63  8  40  13  1  -1  1  1176  74  350  11  ]
      [  89  2  8  -1  -1  -1  -1  -1  21  1  3  3  1149  74  730  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  12  1  3  3  1236  74  293  13  ]
      [  39  2  1  5  863  80  1  39  10  3  3  1  1144  74  280  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  12  1  4  3  1144  74  339  13  ]
      [  40  1  1  6  310  45  8  40  11  2  8  1  1297  74  282  12  ]
      [  43  1  1  6  744  63  8  30  17  2  3  1  1268  74  500  12  ]
      [  48  2  1  6  13  1  8  40  9  2  3  1  1157  74  210  7  ]
      [  29  1  1  5  316  45  8  40  18  1  3  1  1395  74  530  11  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1450  74  -1  14  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1342  74  0  9  ]
      [  32  1  1  6  269  45  8  40  16  1  3  1  1350  74  500  13  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1306  74  -1  10  ]
      [  47  2  1  5  777  72  8  40  13  5  9  1  1436  74  317  10  ]
      [  36  2  1  5  780  64  8  38  9  2  3  1  1436  74  220  8  ]
      [  32  1  1  6  222  34  8  35  -1  3  3  1  1506  74  -1  13  ]
      [  30  1  1  5  741  25  8  39  10  1  3  1  1617  74  290  9  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1602  74  -1  14  ]
      [  42  2  1  5  864  85  8  40  10  1  -1  1  1570  74  340  9  ]
      [  38  2  8  -1  -1  -1  -1  -1  17  3  3  2  1556  74  520  9  ]
      [  61  1  1  5  861  85  1  39  16  3  7  1  1500  74  450  9  ]
      [  51  1  1  6  254  45  8  40  -1  -1  -1  1  1674  74  -1  10  ]
      [  39  1  1  6  714  15  8  38  10  1  -1  1  1537  74  290  10  ]
      [  47  2  1  5  788  34  8  35  -1  1  3  1  1549  74  -1  9  ]
      [  38  1  1  6  488  45  8  40  9  2  3  1  1586  74  200  9  ]
      [  57  1  1  6  201  27  8  40  14  -1  3  1  1877  74  429  10  ]
      [  26  2  1  5  755  22  8  40  18  5  9  1  1974  74  615  10  ]
      [  42  1  1  6  622  45  8  38  -1  1  -1  1  1853  74  -1  10  ]
      [  43  2  1  5  633  24  8  38  17  3  5  1  1791  74  550  10  ]
      [  37  1  1  6  744  27  8  38  12  1  3  1  1745  74  325  11  ]
      [  53  1  1  4  787  75  1  39  11  3  3  1  2093  74  350  15  ]
      [  40  1  1  5  775  72  8  43  -1  4  8  1  2108  74  -1  11  ]
      [  29  1  1  6  268  45  8  45  12  1  3  1  2131  74  370  12  ]
      [  42  1  1  6  487  45  8  40  -1  2  3  1  2233  74  -1  11  ]
      [  40  2  1  6  934  80  1  19  14  1  -1  1  2723  74  426  13  ]
      [  43  1  1  5  780  32  8  35  11  3  3  1  2634  74  348  19  ]
      [  57  1  1  5  787  75  1  39  9  3  3  1  2874  74  269  13  ]
      [  50  1  1  5  602  31  8  40  -1  4  8  1  3725  74  -1  20  ]
      [  40  2  8  -1  -1  -1  -1  -1  11  4  -1  3  691  73  250  7  ]
      [  48  1  8  -1  -1  -1  -1  -1  16  1  -1  2  599  73  500  8  ]
      [  32  1  8  -1  -1  -1  -1  -1  11  4  5  2  601  73  320  6  ]
      [  58  1  1  6  792  74  8  50  9  1  3  1  681  73  259  10  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  874  73  -1  6  ]
      [  29  2  1  5  633  24  8  20  -1  3  3  1  876  73  -1  14  ]
      [  62  2  1  6  411  55  1  40  -1  1  -1  1  788  73  -1  5  ]
      [  56  1  1  6  531  22  8  30  10  -1  -1  1  707  73  320  8  ]
      [  61  2  1  1  833  92  8  30  10  3  8  1  799  73  264  5  ]
      [  29  2  1  4  764  80  1  35  14  5  9  1  1022  73  440  6  ]
      [  69  2  8  -1  -1  -1  -1  -1  11  1  3  3  938  73  325  6  ]
      [  49  1  1  6  744  60  8  30  16  -1  -1  1  989  73  400  10  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  3  1  3  979  73  0  6  ]
      [  43  1  1  6  152  25  8  40  11  1  -1  1  944  73  312  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  10  1  3  3  985  73  305  9  ]
      [  44  2  8  -1  -1  -1  -1  -1  10  2  4  6  945  73  292  6  ]
      [  22  1  1  6  511  45  8  39  11  3  3  1  1118  73  310  10  ]
      [  44  2  1  5  662  51  8  38  17  1  3  1  1254  73  500  7  ]
      [  27  1  8  -1  -1  -1  -1  -1  12  3  3  6  1167  73  360  7  ]
      [  29  1  8  6  997  90  8  10  13  3  5  2  1236  73  400  9  ]
      [  48  2  1  5  875  80  8  25  -1  3  99  1  1154  73  -1  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  11  1  3  3  1131  73  350  8  ]
      [  74  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  1200  73  303  8  ]
      [  69  1  8  -1  -1  -1  -1  -1  9  1  -1  3  1179  73  240  10  ]
      [  84  2  8  -1  -1  -1  -1  -1  12  1  4  3  1214  73  400  7  ]
      [  28  2  1  5  788  34  8  20  13  3  1  1  1300  73  388  9  ]
      [  24  2  1  5  731  64  8  39  13  1  3  1  1283  73  430  13  ]
      [  37  1  1  6  273  29  8  40  11  2  3  1  1293  73  365  12  ]
      [  55  2  1  1  869  85  8  38  -1  3  3  1  1480  73  -1  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  10  1  3  3  1413  73  300  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  13  1  3  3  1465  73  380  8  ]
      [  61  2  8  -1  -1  -1  -1  -1  10  1  3  3  1349  73  224  8  ]
      [  43  1  1  6  510  45  8  39  17  1  3  1  1379  73  500  11  ]
      [  59  1  1  6  714  45  8  45  11  1  -1  1  1326  73  350  11  ]
      [  47  2  1  5  856  85  8  40  13  1  5  1  1455  73  340  8  ]
      [  52  1  1  5  316  31  8  40  12  2  5  1  1300  73  321  13  ]
      [  43  1  1  6  281  50  8  40  11  2  3  1  1427  73  300  12  ]
      [  51  1  1  6  274  74  8  38  11  1  3  1  1582  73  360  9  ]
      [  25  1  1  9  801  75  1  39  7  3  5  1  1649  73  193  10  ]
      [  56  2  1  3  934  29  8  4  -1  -1  3  1  1698  73  -1  9  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1610  73  318  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  8  5  9  3  1633  73  200  10  ]
      [  27  1  1  6  492  34  8  35  13  3  3  1  1818  73  350  11  ]
      [  36  1  1  5  267  40  8  38  -1  4  5  1  1779  73  -1  10  ]
      [  55  2  1  5  885  85  1  38  17  5  9  1  1960  73  480  10  ]
      [  50  1  1  5  780  52  8  38  12  1  3  1  1890  73  297  11  ]
      [  41  2  1  5  704  70  8  40  12  3  4  1  1954  73  370  10  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1890  73  -1  13  ]
      [  42  1  1  5  304  52  8  40  9  3  3  1  1713  73  208  14  ]
      [  61  1  1  4  784  75  1  39  12  1  3  1  2179  73  326  12  ]
      [  41  1  1  6  461  45  8  40  9  2  3  1  2025  73  239  11  ]
      [  41  1  1  4  874  80  1  45  14  5  9  1  2573  73  419  21  ]
      [  35  1  1  6  273  29  8  38  18  1  3  1  2443  73  530  14  ]
      [  43  1  1  4  811  75  1  35  12  5  9  1  2359  73  335  12  ]
      [  41  1  1  1  269  45  8  40  16  3  3  1  2682  73  500  13  ]
      [  19  2  1  5  703  74  8  40  -1  5  -1  1  172  72  -1  2  ]
      [  55  1  8  -1  -1  -1  -1  -1  8  1  -1  2  218  72  206  11  ]
      [  54  1  8  -1  -1  -1  -1  -1  11  2  3  2  190  72  300  6  ]
      [  23  1  1  5  714  93  8  10  -1  5  -1  1  358  72  -1  3  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  5  -1  3  423  72  -1  3  ]
      [  49  2  1  5  934  93  8  10  9  1  -1  4  417  72  264  11  ]
      [  41  2  8  -1  -1  -1  -1  -1  5  2  -1  2  384  72  130  3  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  481  72  -1  3  ]
      [  44  1  8  -1  -1  -1  -1  -1  6  3  3  2  693  72  190  4  ]
      [  79  1  8  -1  -1  -1  -1  -1  13  1  3  3  671  72  360  6  ]
      [  36  2  1  5  642  32  8  18  -1  3  3  1  597  72  -1  11  ]
      [  53  1  1  6  254  28  8  40  -1  1  -1  1  679  72  400  10  ]
      [  46  1  8  -1  -1  -1  -1  -1  11  1  3  2  653  72  300  16  ]
      [  32  1  8  -1  -1  -1  -1  -1  11  1  3  4  572  72  350  4  ]
      [  27  1  1  5  660  55  8  40  12  -1  -1  1  696  72  360  6  ]
      [  35  2  8  -1  -1  -1  -1  -1  13  5  -1  8  675  72  350  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  6  1  3  3  667  72  140  4  ]
      [  60  1  8  -1  -1  -1  -1  -1  11  1  3  3  666  72  339  10  ]
      [  35  1  1  6  150  25  8  40  11  2  3  1  594  72  338  10  ]
      [  20  2  1  5  661  52  8  10  20  5  -1  1  727  72  585  5  ]
      [  54  1  8  -1  -1  -1  -1  -1  12  1  3  2  826  72  337  5  ]
      [  70  2  8  -1  -1  -1  -1  -1  8  1  3  3  877  72  200  5  ]
      [  56  1  1  5  712  60  8  40  16  3  -1  1  888  72  470  5  ]
      [  57  1  8  -1  -1  -1  -1  -1  9  1  -1  3  811  72  270  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  881  72  274  12  ]
      [  53  1  8  -1  -1  -1  -1  -1  9  1  3  2  795  72  276  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  744  72  -1  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  10  1  4  3  886  72  250  10  ]
      [  42  1  1  6  505  20  8  40  -1  2  3  1  711  72  -1  11  ]
      [  84  1  8  -1  -1  -1  -1  -1  15  3  4  3  710  72  370  8  ]
      [  71  2  8  -1  -1  -1  -1  -1  4  1  -1  3  859  72  108  5  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  5  8  3  759  72  -1  11  ]
      [  40  2  1  5  303  85  8  40  11  2  3  1  889  72  275  10  ]
      [  24  2  8  -1  -1  -1  -1  -1  17  1  -1  6  963  72  492  8  ]
      [  48  1  1  5  744  50  8  38  14  1  -1  1  927  72  460  12  ]
      [  24  2  1  5  411  55  8  30  9  5  -1  1  1076  72  223  8  ]
      [  61  1  1  6  714  15  8  40  -1  1  -1  1  914  72  0  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  9  1  3  3  998  72  300  6  ]
      [  51  2  1  5  660  52  8  35  -1  1  3  1  915  72  -1  6  ]
      [  27  2  1  5  871  80  1  39  14  5  9  1  1002  72  430  13  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1070  72  -1  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  920  72  -1  13  ]
      [  73  2  8  -1  -1  -1  -1  -1  10  1  -1  3  937  72  300  6  ]
      [  88  2  8  -1  -1  -1  -1  -1  12  1  3  3  921  72  264  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  5  3  929  72  -1  9  ]
      [  62  2  8  -1  -1  -1  -1  -1  7  1  6  3  1095  72  202  6  ]
      [  34  2  1  5  912  55  8  40  9  1  4  1  1029  72  280  6  ]
      [  46  2  1  5  865  85  8  40  8  2  3  1  1020  72  248  6  ]
      [  46  1  8  -1  -1  -1  -1  -1  9  3  -1  2  1034  72  219  10  ]
      [  28  2  8  -1  -1  -1  -1  -1  11  5  3  6  981  72  275  6  ]
      [  61  1  8  -1  -1  -1  -1  -1  11  9  -1  3  1237  72  250  12  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1198  72  -1  7  ]
      [  34  1  1  6  310  63  1  38  8  3  3  1  1245  72  200  12  ]
      [  22  1  1  8  511  45  8  37  10  -1  -1  1  1178  72  290  7  ]
      [  82  1  8  -1  -1  -1  -1  -1  13  1  3  3  1202  72  410  9  ]
      [  47  2  1  5  780  52  8  38  9  1  3  1  1283  72  250  12  ]
      [  61  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1263  72  288  7  ]
      [  56  1  1  6  742  24  8  36  13  1  3  1  1169  72  400  12  ]
      [  81  1  8  -1  -1  -1  -1  -1  13  1  3  3  1296  72  330  12  ]
      [  34  1  1  5  783  72  8  15  18  1  1  1  1113  72  590  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1212  72  294  7  ]
      [  32  2  8  6  660  52  8  7  13  3  3  6  1229  72  400  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  18  -1  -1  3  1297  72  510  7  ]
      [  57  1  8  -1  -1  -1  -1  -1  11  1  3  2  1279  72  330  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  16  1  3  3  1294  72  465  10  ]
      [  47  1  1  1  835  92  8  40  13  5  3  1  1116  72  370  7  ]
      [  66  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1101  72  240  7  ]
      [  21  1  1  9  801  75  1  39  10  3  3  1  1239  72  300  7  ]
      [  66  2  8  -1  -1  -1  -1  -1  7  1  3  3  1194  72  208  7  ]
      [  38  2  1  5  864  85  8  40  13  2  3  1  1204  72  350  7  ]
      [  56  1  1  5  620  25  8  50  -1  -1  -1  1  1446  72  -1  8  ]
      [  44  1  1  6  540  28  8  38  -1  1  3  1  1397  72  -1  8  ]
      [  51  1  1  6  714  63  8  40  11  1  3  1  1348  72  330  10  ]
      [  36  1  1  6  531  28  8  35  11  1  -1  1  1443  72  330  20  ]
      [  61  1  8  -1  -1  -1  -1  -1  8  1  3  3  1457  72  230  12  ]
      [  72  1  8  -1  -1  -1  -1  -1  9  3  3  3  1494  72  268  9  ]
      [  82  1  8  -1  -1  -1  -1  -1  11  1  3  3  1465  72  315  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  9  1  3  3  1372  72  220  8  ]
      [  67  1  8  -1  -1  -1  -1  -1  14  1  3  3  1419  72  432  8  ]
      [  39  2  1  5  863  80  1  36  8  3  3  1  1348  72  245  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1423  72  -1  11  ]
      [  35  2  1  5  853  85  8  39  7  5  9  1  1396  72  200  8  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1436  72  -1  8  ]
      [  60  1  8  -1  -1  -1  -1  -1  9  1  3  3  1346  72  226  8  ]
      [  37  2  1  6  934  45  8  30  14  1  -1  1  1315  72  450  8  ]
      [  42  2  1  5  852  85  8  25  11  5  5  1  1428  72  254  9  ]
      [  37  2  8  -1  -1  -1  -1  -1  8  5  9  2  1419  72  220  8  ]
      [  48  2  1  5  772  40  8  40  -1  2  6  1  1365  72  -1  15  ]
      [  37  1  1  6  316  31  8  38  -1  3  5  1  1540  72  -1  9  ]
      [  58  1  8  6  997  52  8  10  9  1  3  3  1615  72  242  12  ]
      [  41  1  1  5  741  75  1  40  11  1  3  1  1697  72  300  13  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1538  72  -1  9  ]
      [  48  1  1  1  757  93  8  40  12  5  8  1  1643  72  280  11  ]
      [  34  1  1  6  269  28  8  35  12  1  4  1  1637  72  320  9  ]
      [  35  1  1  5  780  51  8  40  13  4  3  1  1501  72  385  12  ]
      [  38  1  1  6  51  75  1  38  14  3  3  1  1586  72  370  9  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  4  8  3  1694  72  -1  9  ]
      [  45  2  1  5  778  64  8  39  12  1  -1  1  1581  72  300  14  ]
      [  54  1  1  6  401  15  8  38  12  1  3  1  1605  72  320  9  ]
      [  66  2  8  -1  -1  -1  -1  -1  5  1  3  3  1676  72  125  9  ]
      [  40  1  1  6  531  34  8  35  11  1  -1  1  1666  72  324  11  ]
      [  32  1  1  5  777  72  8  40  14  -1  -1  1  1691  72  379  13  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1589  72  -1  9  ]
      [  27  2  1  5  789  74  8  40  19  3  3  1  1752  72  550  14  ]
      [  79  1  8  -1  -1  -1  -1  -1  12  -1  -1  3  1960  72  315  10  ]
      [  45  1  1  6  311  31  8  38  14  1  99  1  1799  72  350  12  ]
      [  36  1  1  6  540  36  8  36  9  1  -1  1  1962  72  260  10  ]
      [  36  2  1  5  662  52  8  38  19  3  3  1  1929  72  595  12  ]
      [  88  2  8  -1  -1  -1  -1  -1  12  1  5  3  1959  72  300  10  ]
      [  38  2  1  5  789  65  8  45  10  3  -1  1  1792  72  300  10  ]
      [  37  1  1  6  141  24  8  40  26  1  3  1  1933  72  500  10  ]
      [  55  1  1  6  550  28  8  38  12  1  3  1  1735  72  350  13  ]
      [  58  2  1  5  780  66  8  40  24  3  3  1  1951  72  700  10  ]
      [  47  2  1  4  812  75  1  39  -1  3  7  1  2157  72  -1  11  ]
      [  52  1  1  5  620  75  1  38  -1  4  5  1  2009  72  -1  14  ]
      [  56  1  1  5  812  66  8  50  -1  1  -1  1  2145  72  -1  14  ]
      [  49  1  1  6  121  26  8  40  11  1  -1  1  2025  72  275  11  ]
      [  45  1  1  4  801  75  1  40  13  2  3  1  2202  72  340  14  ]
      [  45  1  1  1  687  65  8  48  21  1  4  1  2450  72  655  12  ]
      [  36  1  1  4  765  75  1  39  9  4  5  1  2460  72  248  14  ]
      [  35  2  1  4  764  75  1  38  19  5  9  1  2534  72  600  12  ]
      [  48  1  1  5  713  60  8  38  7  4  5  1  2720  72  200  18  ]
      [  58  1  1  4  801  75  1  40  11  2  3  1  2680  72  350  15  ]
      [  65  1  1  4  873  80  1  45  -1  5  9  1  2959  72  -1  14  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  3  5  3  3051  72  -1  14  ]
      [  61  1  1  2  608  45  8  45  15  2  8  1  3591  72  450  18  ]
      [  33  1  1  5  777  72  8  40  -1  5  9  1  4308  72  -1  17  ]
      [  47  1  8  5  879  80  8  3  13  4  9  4  164  71  400  9  ]
      [  25  2  1  6  934  74  8  10  13  1  -1  4  353  71  420  9  ]
      [  28  2  1  6  934  52  8  10  12  1  3  1  309  71  335  10  ]
      [  23  1  1  5  912  55  8  10  10  5  -1  3  301  71  220  3  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  574  71  428  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  12  1  3  3  509  71  335  6  ]
      [  25  2  1  5  879  80  8  16  -1  5  9  1  695  71  -1  4  ]
      [  28  2  1  5  780  50  8  37  15  3  3  1  822  71  430  13  ]
      [  60  1  8  -1  -1  -1  -1  -1  13  1  3  3  824  71  367  9  ]
      [  41  1  8  -1  -1  -1  -1  -1  11  2  -1  2  773  71  299  9  ]
      [  40  2  8  -1  -1  -1  -1  -1  11  1  -1  6  992  71  360  6  ]
      [  57  1  8  -1  -1  -1  -1  -1  11  -1  -1  2  992  71  300  8  ]
      [  59  1  1  5  788  51  8  37  15  3  3  1  949  71  347  10  ]
      [  80  2  8  -1  -1  -1  -1  -1  13  1  -1  3  992  71  387  6  ]
      [  51  1  1  6  714  45  8  39  10  -1  -1  1  1081  71  250  11  ]
      [  73  2  8  -1  -1  -1  -1  -1  11  1  -1  3  948  71  370  6  ]
      [  22  2  8  -1  -1  -1  -1  -1  8  5  -1  8  1032  71  250  6  ]
      [  41  1  1  6  292  29  8  40  10  2  3  1  904  71  292  11  ]
      [  54  2  1  5  864  85  8  30  11  1  3  1  1272  71  320  7  ]
      [  69  1  8  -1  -1  -1  -1  -1  16  1  3  3  1152  71  459  10  ]
      [  30  1  1  5  411  55  8  45  11  1  3  1  1268  71  320  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  11  1  3  3  1155  71  279  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  1  3  3  1290  71  328  7  ]
      [  37  2  8  5  775  75  1  39  13  5  9  1  1120  71  378  7  ]
      [  31  1  1  1  750  52  8  40  9  1  3  1  1190  71  160  7  ]
      [  61  2  8  -1  -1  -1  -1  -1  11  1  3  3  1289  71  295  10  ]
      [  69  2  8  -1  -1  -1  -1  -1  11  1  3  3  1154  71  336  9  ]
      [  34  2  8  -1  -1  -1  -1  -1  12  4  6  8  1200  71  350  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  17  -1  -1  3  1366  71  450  11  ]
      [  36  1  1  5  854  85  1  39  11  5  3  1  1382  71  292  12  ]
      [  70  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1434  71  454  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  10  3  3  3  1392  71  265  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1500  71  420  8  ]
      [  29  1  1  5  175  22  8  40  12  5  3  1  1407  71  360  8  ]
      [  47  2  1  6  211  33  8  40  11  1  3  1  1446  71  280  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  9  1  3  3  1526  71  245  10  ]
      [  41  1  1  6  714  63  8  50  12  1  3  1  1635  71  307  12  ]
      [  68  1  8  -1  -1  -1  -1  -1  11  1  3  3  1544  71  292  9  ]
      [  60  1  8  -1  -1  -1  -1  -1  13  1  3  3  1688  71  400  9  ]
      [  34  1  1  5  750  65  8  40  18  5  8  1  1696  71  550  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  12  4  6  3  1561  71  340  11  ]
      [  78  1  8  -1  -1  -1  -1  -1  17  4  8  3  1762  71  398  10  ]
      [  39  1  1  6  273  29  8  40  15  3  3  1  1996  71  440  12  ]
      [  37  1  1  5  744  40  8  39  14  1  3  1  1994  71  437  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1729  71  -1  10  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  3  4  3  1743  71  -1  10  ]
      [  34  1  8  -1  -1  -1  -1  -1  18  5  3  5  1892  71  442  10  ]
      [  28  2  1  5  704  70  8  40  13  5  99  1  1940  71  383  10  ]
      [  59  1  1  5  788  72  8  38  13  5  10  1  2153  71  403  13  ]
      [  44  1  1  4  765  75  1  40  -1  3  3  1  2372  71  -1  16  ]
      [  52  1  8  -1  -1  -1  -1  -1  9  5  3  4  101  70  250  9  ]
      [  45  1  8  -1  -1  -1  -1  -1  -1  5  3  4  138  70  -1  1  ]
      [  33  1  8  -1  -1  -1  -1  -1  50  1  -1  6  238  70  -1  4  ]
      [  30  2  8  -1  -1  -1  -1  -1  50  1  -1  6  194  70  -1  3  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  280  70  -1  2  ]
      [  30  1  8  -1  -1  -1  -1  -1  12  1  -1  6  223  70  385  3  ]
      [  34  2  8  -1  -1  -1  -1  -1  6  3  3  2  430  70  150  13  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  337  70  0  3  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  405  70  0  3  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  371  70  -1  4  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  500  70  -1  6  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  3  3  366  70  -1  3  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  412  70  -1  3  ]
      [  41  1  8  -1  -1  -1  -1  -1  9  1  3  2  337  70  250  3  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  400  70  -1  3  ]
      [  67  1  8  -1  -1  -1  -1  -1  15  -1  -1  3  415  70  300  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  6  488  70  0  3  ]
      [  35  1  8  -1  -1  -1  -1  -1  11  5  -1  4  429  70  250  3  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  421  70  0  5  ]
      [  95  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  440  70  0  3  ]
      [  43  2  1  6  923  85  8  20  -1  1  4  1  485  70  -1  3  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  1  3  472  70  -1  4  ]
      [  29  1  8  -1  -1  -1  -1  -1  -1  2  3  2  380  70  -1  3  ]
      [  48  1  8  -1  -1  -1  -1  -1  15  2  6  2  428  70  415  8  ]
      [  26  1  1  5  835  92  8  14  12  5  -1  1  449  70  330  3  ]
      [  26  1  1  5  861  80  8  16  11  4  -1  1  690  70  344  4  ]
      [  27  2  8  -1  -1  -1  -1  -1  -1  5  -1  8  537  70  -1  4  ]
      [  20  1  1  5  784  91  1  8  -1  4  -1  1  644  70  -1  4  ]
      [  42  1  8  -1  -1  -1  -1  -1  8  1  -1  2  523  70  200  4  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  4  568  70  -1  4  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  687  70  -1  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  8  1  -1  3  546  70  259  4  ]
      [  34  1  1  7  641  74  8  38  10  3  3  1  502  70  290  4  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  540  70  -1  4  ]
      [  53  2  1  5  714  55  8  40  -1  1  3  1  579  70  -1  4  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  557  70  -1  6  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  3  3  592  70  -1  4  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  514  70  0  4  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  3  3  3  651  70  0  5  ]
      [  28  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  666  70  -1  4  ]
      [  71  1  8  -1  -1  -1  -1  -1  13  -1  3  3  658  70  336  7  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  685  70  0  4  ]
      [  33  1  8  -1  -1  -1  -1  -1  16  5  9  4  589  70  500  13  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  673  70  -1  4  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  541  70  -1  4  ]
      [  48  1  8  -1  -1  -1  -1  -1  8  5  3  4  580  70  240  4  ]
      [  77  2  8  -1  -1  -1  -1  -1  7  1  3  3  562  70  200  4  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  531  70  -1  4  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  554  70  -1  4  ]
      [  61  2  1  6  934  80  1  21  11  3  6  1  524  70  325  4  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  588  70  -1  12  ]
      [  45  2  8  -1  -1  -1  -1  -1  17  1  3  2  603  70  479  4  ]
      [  52  1  8  -1  -1  -1  -1  -1  12  1  4  2  508  70  318  11  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  558  70  -1  4  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  636  70  0  4  ]
      [  23  2  8  -1  -1  -1  -1  -1  10  5  -1  8  585  70  290  4  ]
      [  28  2  8  -1  -1  -1  -1  -1  10  1  1  4  523  70  256  4  ]
      [  49  1  8  -1  -1  -1  -1  -1  9  2  5  2  528  70  250  6  ]
      [  45  2  1  5  853  85  8  30  -1  2  3  1  666  70  -1  9  ]
      [  46  1  1  1  522  11  8  40  -1  2  5  1  525  70  -1  4  ]
      [  50  2  1  6  937  74  8  32  7  2  -1  1  548  70  190  11  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  643  70  -1  4  ]
      [  67  2  8  -1  -1  -1  -1  -1  9  1  3  3  605  70  205  8  ]
      [  46  1  8  -1  -1  -1  -1  -1  8  2  3  2  652  70  200  12  ]
      [  58  1  8  -1  -1  -1  -1  -1  9  1  3  2  645  70  230  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  7  1  1  3  667  70  150  4  ]
      [  39  2  1  6  937  93  8  3  9  2  3  2  564  70  220  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  600  70  0  10  ]
      [  45  2  1  5  660  15  8  27  13  2  -1  1  542  70  300  10  ]
      [  53  2  1  6  358  52  8  14  9  1  3  3  769  70  247  5  ]
      [  25  2  1  5  853  85  8  20  15  3  3  1  853  70  450  12  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  876  70  0  5  ]
      [  40  1  8  -1  -1  -1  -1  -1  15  1  3  2  843  70  400  7  ]
      [  54  1  1  1  714  60  8  60  10  -1  -1  1  752  70  276  5  ]
      [  58  2  1  5  661  15  8  35  7  1  3  1  847  70  209  10  ]
      [  37  1  1  6  11  1  8  40  13  1  3  1  758  70  400  9  ]
      [  29  1  8  -1  -1  -1  -1  -1  13  3  -1  2  732  70  351  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  732  70  -1  5  ]
      [  33  2  1  5  660  52  8  18  12  1  3  1  726  70  358  11  ]
      [  61  2  8  -1  -1  -1  -1  -1  12  1  -1  4  852  70  350  5  ]
      [  21  1  1  7  692  75  1  39  13  5  -1  1  771  70  300  5  ]
      [  69  1  1  6  934  74  8  9  10  1  3  3  751  70  290  9  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  3  99  3  767  70  -1  5  ]
      [  44  2  8  -1  -1  -1  -1  -1  12  1  -1  3  885  70  300  5  ]
      [  38  2  1  1  859  93  8  60  -1  4  6  1  881  70  -1  5  ]
      [  48  2  1  6  181  20  8  38  11  1  -1  1  812  70  300  9  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  719  70  -1  5  ]
      [  27  1  1  6  441  45  8  40  10  1  3  1  876  70  300  6  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  709  70  -1  5  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  1  3  3  752  70  -1  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  781  70  -1  5  ]
      [  38  2  1  5  854  85  8  20  7  3  3  1  787  70  187  5  ]
      [  81  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  823  70  174  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  791  70  -1  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  851  70  -1  5  ]
      [  23  1  8  -1  -1  -1  -1  -1  22  5  1  4  723  70  720  10  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  894  70  -1  5  ]
      [  23  1  8  -1  -1  -1  -1  -1  10  3  1  8  784  70  266  5  ]
      [  28  1  8  -1  -1  -1  -1  -1  21  5  8  2  899  70  500  9  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  709  70  0  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  5  1  1  3  883  70  130  5  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  711  70  -1  5  ]
      [  70  2  8  -1  -1  -1  -1  -1  8  1  -1  3  808  70  237  5  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  751  70  -1  5  ]
      [  28  1  1  5  813  75  1  45  13  5  9  1  718  70  360  5  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  707  70  -1  8  ]
      [  54  1  1  6  254  45  8  40  9  1  3  1  827  70  214  11  ]
      [  58  2  8  -1  -1  -1  -1  -1  11  -1  -1  2  822  70  290  5  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  772  70  -1  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  813  70  -1  10  ]
      [  47  2  1  5  856  85  8  30  11  1  1  1  889  70  300  7  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  5  3  810  70  -1  7  ]
      [  54  1  1  6  471  93  8  35  -1  1  3  1  793  70  -1  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  5  3  885  70  -1  8  ]
      [  45  1  1  6  744  35  8  40  11  2  3  1  881  70  288  10  ]
      [  40  1  1  6  540  28  8  40  12  2  3  1  730  70  299  11  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  761  70  -1  8  ]
      [  61  1  8  6  934  74  8  12  -1  1  3  3  762  70  -1  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  809  70  -1  7  ]
      [  28  1  1  5  854  85  8  20  20  5  1  1  940  70  595  9  ]
      [  43  1  1  1  714  60  8  98  12  5  9  1  1004  70  390  6  ]
      [  60  1  1  1  359  17  8  60  15  3  3  1  1037  70  375  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  9  -1  -1  4  912  70  250  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  11  1  5  3  959  70  300  12  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  3  3  2  973  70  -1  6  ]
      [  33  1  1  5  631  15  8  30  -1  2  5  1  1066  70  -1  8  ]
      [  42  2  1  6  923  95  8  38  10  1  -1  1  1039  70  295  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  7  1  -1  2  1043  70  180  12  ]
      [  26  2  1  5  870  80  1  18  9  5  9  1  1025  70  250  6  ]
      [  45  2  1  6  359  74  8  40  14  1  3  1  1007  70  401  11  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  1  3  3  971  70  -1  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  10  1  3  3  1081  70  270  6  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1052  70  -1  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  998  70  -1  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1078  70  380  6  ]
      [  42  2  1  5  691  65  8  25  -1  3  3  1  949  70  -1  6  ]
      [  44  1  1  6  51  75  1  40  -1  1  -1  1  984  70  0  10  ]
      [  20  1  8  6  531  29  8  35  14  1  -1  6  1031  70  355  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  1035  70  250  6  ]
      [  45  1  8  -1  -1  -1  -1  -1  14  1  3  3  933  70  400  12  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  920  70  -1  6  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  5  6  3  1070  70  -1  13  ]
      [  71  1  8  -1  -1  -1  -1  -1  6  -1  -1  3  903  70  170  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1095  70  0  6  ]
      [  37  1  8  -1  -1  -1  -1  -1  13  3  -1  2  1024  70  400  6  ]
      [  73  1  8  -1  -1  -1  -1  -1  12  -1  -1  3  1027  70  325  10  ]
      [  84  2  8  -1  -1  -1  -1  -1  19  3  -1  3  997  70  495  6  ]
      [  50  2  1  5  911  15  8  40  -1  3  4  1  1067  70  -1  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  3  3  943  70  -1  6  ]
      [  89  2  8  -1  -1  -1  -1  -1  6  1  3  3  969  70  144  6  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1033  70  -1  15  ]
      [  54  1  1  1  788  74  8  3  12  1  3  3  1099  70  375  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  11  1  -1  3  940  70  300  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  978  70  -1  6  ]
      [  63  1  8  -1  -1  -1  -1  -1  4  1  -1  3  964  70  50  6  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  1  3  3  943  70  -1  9  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  987  70  -1  6  ]
      [  70  2  8  -1  -1  -1  -1  -1  10  1  -1  3  975  70  305  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  923  70  -1  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1069  70  -1  13  ]
      [  47  1  1  6  522  52  8  40  12  1  -1  1  1033  70  350  9  ]
      [  30  1  1  6  311  60  8  19  -1  3  3  1  1071  70  -1  15  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  942  70  0  6  ]
      [  22  2  1  5  853  85  8  39  14  4  3  1  938  70  425  12  ]
      [  76  2  8  -1  -1  -1  -1  -1  19  -1  -1  3  976  70  400  6  ]
      [  64  2  8  -1  -1  -1  -1  -1  15  2  -1  3  933  70  472  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  8  1  1  3  922  70  230  6  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1062  70  0  6  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  954  70  -1  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  9  1  6  3  1046  70  217  10  ]
      [  25  2  1  5  672  52  8  30  11  3  3  1  1012  70  297  11  ]
      [  45  1  1  6  281  50  8  40  12  2  3  1  1038  70  340  13  ]
      [  65  2  8  -1  -1  -1  -1  -1  11  1  3  3  1002  70  315  6  ]
      [  44  1  1  6  511  45  8  40  13  2  3  1  976  70  359  10  ]
      [  51  1  1  6  441  45  8  35  -1  2  3  1  937  70  -1  6  ]
      [  47  1  1  6  471  45  8  40  9  3  3  6  1089  70  217  6  ]
      [  35  1  1  6  540  45  8  42  -1  2  3  1  1004  70  -1  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1002  70  -1  6  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  5  3  957  70  -1  10  ]
      [  35  2  8  -1  -1  -1  -1  -1  11  5  5  6  1055  70  325  14  ]
      [  43  1  8  -1  -1  -1  -1  -1  -1  2  3  2  1037  70  0  12  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  2  3  3  1039  70  -1  6  ]
      [  32  1  1  6  804  74  8  40  12  2  3  1  966  70  350  11  ]
      [  55  1  1  6  714  60  1  40  10  2  3  1  1050  70  300  13  ]
      [  61  2  8  -1  -1  -1  -1  -1  16  1  3  3  1042  70  461  6  ]
      [  40  2  8  -1  -1  -1  -1  -1  -1  2  3  2  1032  70  -1  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1038  70  -1  8  ]
      [  29  1  1  6  281  50  8  40  -1  -1  -1  1  953  70  -1  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  16  1  -1  3  1267  70  480  7  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1223  70  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1125  70  0  7  ]
      [  64  2  1  6  934  80  1  10  11  1  -1  3  1170  70  247  7  ]
      [  37  2  1  5  902  93  8  32  12  3  3  1  1202  70  370  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1175  70  0  7  ]
      [  32  2  1  5  856  85  8  35  -1  3  3  1  1222  70  -1  13  ]
      [  23  2  1  4  801  75  1  40  17  5  3  1  1218  70  455  13  ]
      [  33  1  1  6  273  29  8  37  10  3  3  1  1121  70  240  7  ]
      [  34  1  1  5  776  72  8  32  11  5  5  1  1298  70  310  7  ]
      [  42  1  1  6  441  45  8  38  10  -1  -1  1  1268  70  260  11  ]
      [  38  1  1  5  281  74  8  38  5  1  3  1  1202  70  115  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  8  1  -1  3  1296  70  235  8  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1149  70  -1  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1115  70  -1  7  ]
      [  56  1  1  6  194  27  8  40  6  1  1  1  1216  70  150  7  ]
      [  59  2  1  4  870  80  1  13  9  5  9  1  1131  70  266  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  14  -1  -1  3  1156  70  358  7  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1118  70  -1  10  ]
      [  24  2  1  5  780  40  1  38  -1  3  3  1  1297  70  0  13  ]
      [  73  1  8  -1  -1  -1  -1  -1  13  1  3  3  1209  70  350  9  ]
      [  40  1  1  5  671  51  8  38  16  2  3  1  1264  70  450  7  ]
      [  31  2  1  5  788  66  8  38  11  3  -1  1  1122  70  226  7  ]
      [  48  1  1  6  701  63  8  40  12  -1  -1  1  1147  70  350  9  ]
      [  70  1  8  -1  -1  -1  -1  -1  7  1  3  3  1119  70  190  7  ]
      [  39  1  1  6  550  25  8  40  13  3  8  1  1120  70  400  12  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1256  70  -1  15  ]
      [  86  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1239  70  300  10  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1256  70  -1  7  ]
      [  86  2  8  -1  -1  -1  -1  -1  15  1  3  3  1285  70  400  7  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1253  70  250  14  ]
      [  31  2  1  5  789  29  8  40  -1  3  1  1  1126  70  -1  7  ]
      [  35  1  1  5  711  60  8  40  11  3  5  1  1146  70  350  7  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1246  70  -1  7  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1277  70  -1  7  ]
      [  73  2  8  -1  -1  -1  -1  -1  8  1  -1  3  1107  70  241  7  ]
      [  73  2  8  -1  -1  -1  -1  -1  16  1  -1  3  1240  70  500  7  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1139  70  -1  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1121  70  -1  7  ]
      [  48  1  8  -1  -1  -1  -1  -1  13  1  -1  2  1268  70  400  9  ]
      [  74  1  8  -1  -1  -1  -1  -1  13  3  3  3  1288  70  244  10  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1241  70  -1  10  ]
      [  59  1  1  6  741  21  8  38  -1  -1  -1  1  1144  70  -1  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1243  70  -1  8  ]
      [  43  1  1  6  531  34  8  35  -1  1  3  1  1274  70  -1  7  ]
      [  48  1  1  5  660  52  8  38  -1  -1  -1  1  1217  70  -1  12  ]
      [  61  1  1  6  51  75  1  39  11  1  3  1  1106  70  287  9  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1167  70  -1  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1104  70  250  7  ]
      [  40  1  1  1  671  51  8  49  -1  1  -1  1  1131  70  0  7  ]
      [  83  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1276  70  360  7  ]
      [  82  1  8  -1  -1  -1  -1  -1  10  1  3  3  1270  70  285  8  ]
      [  81  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1145  70  290  7  ]
      [  81  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  1167  70  190  7  ]
      [  25  1  1  6  714  24  8  40  11  1  -1  1  1171  70  230  9  ]
      [  49  1  1  6  282  35  8  39  -1  2  5  1  1177  70  -1  15  ]
      [  32  1  1  6  461  45  8  40  9  2  1  1  1200  70  236  11  ]
      [  87  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  1118  70  350  7  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1163  70  -1  7  ]
      [  40  1  1  6  491  45  8  40  9  2  3  1  1254  70  280  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  8  3  6  3  1110  70  228  10  ]
      [  45  2  1  5  834  17  8  40  9  2  6  1  1191  70  262  7  ]
      [  55  1  1  5  787  75  1  38  10  2  3  1  1191  70  300  12  ]
      [  44  1  1  6  312  64  8  40  -1  2  3  1  1207  70  -1  10  ]
      [  53  1  1  6  993  29  8  40  -1  2  3  1  1229  70  -1  11  ]
      [  52  2  8  -1  -1  -1  -1  -1  12  2  3  2  1121  70  346  8  ]
      [  21  2  1  6  141  24  8  40  9  5  3  1  1265  70  201  7  ]
      [  62  1  8  6  11  1  8  15  -1  1  6  3  1119  70  -1  10  ]
      [  54  1  1  5  608  52  8  39  12  2  8  1  1226  70  335  14  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1167  70  -1  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1402  70  -1  12  ]
      [  62  2  8  -1  -1  -1  -1  -1  18  -1  -1  3  1416  70  487  8  ]
      [  49  1  1  6  273  29  8  40  -1  4  8  1  1375  70  505  10  ]
      [  37  2  1  5  857  85  1  39  12  3  5  1  1344  70  350  8  ]
      [  49  1  1  6  796  95  8  38  -1  1  3  1  1490  70  -1  12  ]
      [  83  1  8  -1  -1  -1  -1  -1  9  1  -1  3  1411  70  241  8  ]
      [  60  1  1  6  276  28  8  37  -1  1  -1  1  1365  70  -1  8  ]
      [  57  2  1  5  660  50  8  40  -1  3  3  1  1371  70  -1  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  14  1  3  3  1488  70  400  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1307  70  -1  13  ]
      [  76  1  8  -1  -1  -1  -1  -1  10  1  3  3  1331  70  250  8  ]
      [  27  2  1  5  870  80  1  35  12  5  9  1  1426  70  350  8  ]
      [  29  1  1  5  756  74  8  40  23  5  -1  1  1310  70  600  8  ]
      [  25  1  1  5  773  45  8  40  5  4  5  1  1333  70  130  10  ]
      [  35  1  1  6  511  93  8  39  -1  1  3  1  1450  70  -1  12  ]
      [  22  1  1  5  270  22  8  40  11  3  3  1  1408  70  250  8  ]
      [  40  2  1  5  788  65  8  40  20  1  3  1  1389  70  585  8  ]
      [  65  2  8  -1  -1  -1  -1  -1  18  -1  -1  3  1302  70  530  8  ]
      [  28  2  1  5  757  65  8  39  12  5  3  1  1307  70  307  8  ]
      [  31  1  1  5  671  51  8  40  -1  3  4  1  1353  70  -1  8  ]
      [  34  1  1  6  254  25  8  40  9  2  3  1  1369  70  250  8  ]
      [  27  1  1  5  609  45  8  45  18  4  8  1  1410  70  560  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  1  3  3  1490  70  170  12  ]
      [  33  2  1  5  861  85  8  39  -1  4  8  1  1489  70  -1  8  ]
      [  52  1  1  1  714  63  8  60  -1  1  3  1  1389  70  -1  8  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1454  70  -1  10  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  3  5  3  1389  70  -1  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1315  70  -1  9  ]
      [  32  2  1  5  600  22  8  37  -1  5  9  1  1457  70  -1  8  ]
      [  29  2  8  -1  -1  -1  -1  -1  15  1  -1  6  1438  70  490  8  ]
      [  57  1  1  6  174  74  8  39  -1  1  1  1  1406  70  -1  13  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1344  70  -1  10  ]
      [  36  1  1  5  787  75  1  39  6  3  3  1  1319  70  155  8  ]
      [  31  2  1  5  993  52  8  38  13  1  3  1  1470  70  358  8  ]
      [  33  1  1  6  222  29  8  35  10  1  3  1  1379  70  290  10  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1322  70  -1  8  ]
      [  25  1  1  5  662  50  8  38  11  5  3  1  1377  70  340  8  ]
      [  21  1  1  6  714  51  8  45  9  3  3  1  1421  70  275  8  ]
      [  52  1  1  6  441  45  8  40  17  1  -1  1  1323  70  500  8  ]
      [  34  1  1  6  501  36  8  40  11  2  3  1  1350  70  271  8  ]
      [  75  1  8  -1  -1  -1  -1  -1  11  5  9  3  1481  70  297  8  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1371  70  -1  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  12  5  9  3  1390  70  297  12  ]
      [  52  1  1  6  250  27  8  38  13  1  3  1  1494  70  330  13  ]
      [  74  2  8  -1  -1  -1  -1  -1  9  -1  -1  3  1441  70  236  8  ]
      [  84  2  8  -1  -1  -1  -1  -1  12  5  6  3  1403  70  350  8  ]
      [  61  1  1  1  254  28  8  40  10  2  5  1  1340  70  290  10  ]
      [  46  1  1  5  776  75  1  40  9  2  3  1  1355  70  260  15  ]
      [  24  1  1  6  714  50  8  50  5  3  3  1  1427  70  80  8  ]
      [  27  1  1  6  391  15  8  39  -1  1  3  1  1660  70  -1  10  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1610  70  -1  9  ]
      [  86  2  8  -1  -1  -1  -1  -1  5  1  -1  3  1631  70  125  9  ]
      [  54  2  1  5  792  85  8  35  13  3  3  1  1507  70  357  9  ]
      [  32  1  1  5  779  66  8  38  18  4  8  1  1507  70  525  16  ]
      [  71  2  8  -1  -1  -1  -1  -1  13  1  1  3  1530  70  316  9  ]
      [  55  1  1  6  721  61  8  39  14  3  4  1  1617  70  380  9  ]
      [  46  2  1  6  269  45  8  38  11  1  -1  1  1534  70  288  11  ]
      [  77  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  1568  70  300  11  ]
      [  45  1  1  5  785  18  8  38  11  1  3  1  1624  70  300  9  ]
      [  30  2  1  5  780  21  8  35  21  4  3  1  1615  70  500  14  ]
      [  54  1  1  6  254  34  8  38  11  1  3  1  1648  70  315  9  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1665  70  238  13  ]
      [  45  1  1  6  540  34  8  37  13  -1  -1  1  1689  70  411  16  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1625  70  -1  9  ]
      [  47  1  1  5  540  21  8  38  16  1  3  1  1642  70  400  12  ]
      [  33  1  1  6  441  45  8  40  12  1  3  1  1541  70  330  9  ]
      [  38  1  1  5  861  91  1  39  16  5  8  1  1561  70  470  14  ]
      [  33  2  1  5  852  85  8  20  20  5  4  1  1699  70  620  9  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1692  70  -1  12  ]
      [  53  1  1  6  622  40  1  39  9  1  3  1  1500  70  240  11  ]
      [  38  1  1  6  714  60  1  40  14  1  -1  1  1535  70  450  9  ]
      [  31  1  1  5  772  92  8  40  -1  5  3  1  1529  70  0  9  ]
      [  26  1  1  6  461  45  8  50  14  1  -1  1  1655  70  400  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1568  70  -1  9  ]
      [  31  1  1  5  775  75  1  39  -1  3  3  1  1677  70  -1  9  ]
      [  57  1  1  6  633  24  8  38  9  1  3  1  1669  70  250  11  ]
      [  51  2  1  5  856  85  1  39  -1  3  -1  1  1566  70  320  9  ]
      [  81  2  8  -1  -1  -1  -1  -1  15  1  -1  3  1625  70  450  9  ]
      [  55  1  1  6  531  32  8  40  -1  1  3  1  1549  70  -1  17  ]
      [  44  2  1  5  789  75  1  39  16  5  9  1  1584  70  500  9  ]
      [  33  1  8  -1  -1  -1  -1  -1  11  1  3  2  1530  70  340  9  ]
      [  53  2  1  5  689  33  8  38  9  3  5  1  1545  70  240  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  16  1  3  3  1623  70  432  9  ]
      [  95  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1596  70  -1  9  ]
      [  33  2  1  5  751  71  8  39  15  1  3  1  1644  70  500  9  ]
      [  51  1  1  6  273  28  8  40  -1  1  3  1  1645  70  -1  12  ]
      [  59  1  8  -1  -1  -1  -1  -1  16  1  3  2  1501  70  440  9  ]
      [  39  2  1  5  788  28  8  28  14  5  3  1  1604  70  400  9  ]
      [  42  1  1  4  787  64  8  38  -1  3  1  1  1699  70  -1  16  ]
      [  37  1  1  5  993  32  8  38  7  1  3  1  1668  70  180  9  ]
      [  54  1  1  6  290  29  8  35  -1  1  3  1  1539  70  -1  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1500  70  -1  15  ]
      [  67  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1668  70  242  9  ]
      [  78  1  8  -1  -1  -1  -1  -1  11  1  3  3  1627  70  300  10  ]
      [  56  2  1  5  788  75  1  40  7  -1  -1  1  1533  70  185  11  ]
      [  52  2  1  5  873  80  1  16  9  2  6  1  1505  70  225  9  ]
      [  47  1  1  5  600  32  8  40  11  5  9  1  1659  70  332  12  ]
      [  39  1  1  5  620  40  1  39  11  3  3  1  1797  70  270  13  ]
      [  65  2  8  -1  -1  -1  -1  -1  14  3  3  3  1768  70  425  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1973  70  -1  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1885  70  -1  10  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1872  70  -1  10  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1968  70  -1  10  ]
      [  40  1  1  5  633  75  1  38  7  3  3  1  1855  70  184  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  1892  70  280  10  ]
      [  51  1  1  5  793  74  8  40  12  1  3  1  1705  70  330  16  ]
      [  50  1  1  5  676  52  8  42  15  1  3  1  1872  70  450  14  ]
      [  23  1  1  5  935  41  1  38  19  3  3  1  1856  70  600  10  ]
      [  45  1  1  5  672  51  8  40  11  1  3  1  1975  70  275  16  ]
      [  33  1  1  5  174  74  8  38  -1  1  3  1  1970  70  227  10  ]
      [  40  2  1  5  775  75  1  40  13  5  9  1  1893  70  341  10  ]
      [  51  1  1  6  633  28  8  38  -1  1  3  1  1739  70  -1  11  ]
      [  33  1  1  6  273  29  8  37  -1  3  3  1  1979  70  -1  11  ]
      [  41  1  1  5  312  32  8  39  -1  3  3  1  1737  70  0  10  ]
      [  74  1  8  -1  -1  -1  -1  -1  10  4  3  3  1916  70  244  11  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1871  70  -1  10  ]
      [  34  2  1  5  521  24  8  40  -1  5  9  1  1950  70  -1  10  ]
      [  56  1  1  6  510  29  8  35  13  1  -1  1  1974  70  400  11  ]
      [  24  1  1  5  686  50  8  40  9  1  3  1  1902  70  250  11  ]
      [  77  2  8  -1  -1  -1  -1  -1  6  1  -1  3  1895  70  168  18  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1968  70  -1  11  ]
      [  78  2  8  -1  -1  -1  -1  -1  9  1  3  3  1948  70  300  10  ]
      [  87  1  8  -1  -1  -1  -1  -1  12  3  3  3  1827  70  350  10  ]
      [  49  2  1  5  672  52  8  50  -1  1  3  1  1954  70  -1  10  ]
      [  57  1  1  5  608  64  8  39  11  5  9  1  1715  70  243  12  ]
      [  47  1  1  5  714  29  1  40  -1  2  3  1  1853  70  -1  12  ]
      [  32  2  1  5  676  52  8  40  -1  3  99  1  1916  70  340  10  ]
      [  61  1  1  4  787  75  1  40  -1  3  3  1  2252  70  -1  11  ]
      [  43  1  1  5  622  74  1  37  -1  1  3  1  2228  70  -1  11  ]
      [  44  1  1  6  221  28  8  35  15  1  3  1  2178  70  485  12  ]
      [  52  1  1  6  310  40  8  38  12  1  3  1  2215  70  345  12  ]
      [  38  1  1  6  254  34  8  35  12  1  3  1  2088  70  300  11  ]
      [  41  2  1  5  862  85  8  70  -1  5  8  1  2272  70  -1  11  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  5  7  3  2254  70  -1  11  ]
      [  48  1  1  5  254  27  8  40  -1  1  5  1  2041  70  -1  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  2000  70  285  11  ]
      [  32  1  1  5  612  80  1  45  15  5  10  1  2022  70  410  11  ]
      [  59  1  8  -1  -1  -1  -1  -1  10  3  3  3  2036  70  307  11  ]
      [  29  1  1  6  161  21  8  39  -1  1  3  1  2257  70  0  13  ]
      [  34  1  1  6  540  28  8  35  19  1  3  1  2079  70  550  13  ]
      [  30  1  1  6  221  28  8  48  15  1  3  1  2145  70  470  11  ]
      [  29  1  1  5  834  18  8  39  11  5  8  1  2113  70  288  11  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  5  5  3  2162  70  -1  11  ]
      [  40  1  1  4  603  75  1  40  15  5  9  1  2302  70  396  17  ]
      [  37  2  1  5  692  66  8  38  -1  5  3  1  2314  70  -1  12  ]
      [  26  2  1  5  620  75  1  39  11  5  3  1  2393  70  300  12  ]
      [  88  1  8  -1  -1  -1  -1  -1  15  5  8  3  2418  70  446  12  ]
      [  37  1  1  5  864  85  8  39  13  3  3  1  2409  70  400  18  ]
      [  33  1  1  5  757  72  8  40  20  4  10  1  2428  70  540  16  ]
      [  38  2  1  5  780  92  8  50  25  5  9  1  2398  70  700  12  ]
      [  36  1  1  5  993  25  8  60  16  1  3  1  2304  70  470  16  ]
      [  36  1  1  5  780  70  8  50  -1  -1  -1  1  2413  70  -1  12  ]
      [  33  1  1  5  874  80  8  40  12  5  8  1  2459  70  305  12  ]
      [  78  1  8  -1  -1  -1  -1  -1  10  3  3  3  2521  70  200  14  ]
      [  57  2  1  5  870  80  1  40  11  5  6  1  2480  70  314  12  ]
      [  37  1  1  2  912  55  8  40  13  1  3  1  2681  70  380  16  ]
      [  38  1  1  4  801  75  1  38  -1  3  3  1  2732  70  0  13  ]
      [  51  2  1  4  870  80  1  40  11  5  9  1  2697  70  307  18  ]
      [  37  1  1  5  691  67  8  40  -1  3  99  1  2899  70  -1  13  ]
      [  37  1  1  5  774  72  8  40  -1  5  9  1  2640  70  600  13  ]
      [  25  1  1  5  821  22  8  36  -1  5  8  1  2727  70  -1  18  ]
      [  55  1  1  5  604  75  1  39  13  3  8  1  3151  70  294  14  ]
      [  32  1  1  2  704  70  8  38  12  5  4  1  3174  70  330  14  ]
      [  56  2  1  5  692  66  8  38  12  1  -1  1  3067  70  340  14  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  5  10  3  2994  70  -1  14  ]
      [  21  1  1  6  480  45  8  36  5  -1  1  1  3089  70  110  15  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  3093  70  -1  14  ]
      [  33  1  1  5  603  45  8  39  16  5  9  1  3200  70  479  17  ]
      [  60  1  1  5  873  80  1  40  -1  5  9  1  3109  70  -1  19  ]
      [  34  1  1  5  600  27  8  40  8  4  8  1  3550  70  190  17  ]
      [  44  1  1  2  750  45  8  85  16  5  8  1  3881  70  450  16  ]
      [  34  1  1  5  672  52  8  37  15  5  3  1  4386  70  448  19  ]
      [  45  1  1  1  621  45  8  40  -1  3  3  1  5068  70  -1  20  ]
      [  59  1  1  5  692  66  8  50  27  5  -1  1  5697  70  860  20  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  5  10  3  5903  70  -1  21  ]
      [  81  2  8  -1  -1  -1  -1  -1  9  1  -1  3  7270  70  255  21  ]
      [  55  1  1  5  603  45  8  45  -1  4  8  1  6620  70  -1  21  ]
      [  30  1  1  1  836  45  8  25  13  5  3  1  7060  70  384  21  ]
      [  48  1  1  5  662  24  8  37  9  1  5  1  18479  70  250  24  ]
      [  24  1  8  6  660  52  8  6  14  1  3  2  340  69  376  4  ]
      [  45  1  8  -1  -1  -1  -1  -1  -1  1  3  2  561  69  -1  4  ]
      [  22  2  8  -1  -1  -1  -1  -1  12  1  3  6  695  69  283  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  10  1  -1  3  689  69  292  4  ]
      [  23  2  1  7  780  63  8  40  -1  3  -1  1  536  69  -1  4  ]
      [  21  2  8  -1  -1  -1  -1  -1  11  1  -1  6  644  69  278  7  ]
      [  58  1  8  -1  -1  -1  -1  -1  8  1  3  2  614  69  200  9  ]
      [  32  2  1  5  853  85  8  20  12  2  5  1  680  69  375  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  10  1  3  3  707  69  310  8  ]
      [  56  2  1  5  864  85  8  40  13  5  4  1  793  69  309  7  ]
      [  27  2  1  5  784  80  1  4  11  5  3  8  822  69  288  13  ]
      [  25  2  8  7  780  52  8  40  14  -1  3  8  834  69  373  9  ]
      [  54  2  1  5  864  85  8  40  8  3  1  1  1056  69  240  10  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  906  69  400  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1005  69  280  6  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  -1  -1  2  1059  69  -1  8  ]
      [  56  1  8  -1  -1  -1  -1  -1  21  1  3  3  1024  69  600  11  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  1  3  3  1068  69  340  6  ]
      [  25  1  1  6  281  50  8  17  11  1  3  1  938  69  281  6  ]
      [  67  1  1  5  744  22  8  2  13  9  -1  3  930  69  240  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1056  69  400  6  ]
      [  26  1  1  6  501  45  8  40  11  2  3  1  923  69  277  9  ]
      [  47  2  1  4  852  85  1  40  11  2  4  1  1086  69  254  6  ]
      [  41  2  1  5  856  85  8  40  12  2  3  1  998  69  251  11  ]
      [  73  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1065  69  257  9  ]
      [  39  2  8  -1  -1  -1  -1  -1  10  2  3  2  1083  69  259  10  ]
      [  39  1  1  6  254  28  8  40  10  2  3  1  935  69  315  11  ]
      [  80  2  8  -1  -1  -1  -1  -1  12  3  3  3  923  69  353  6  ]
      [  43  1  1  5  602  40  8  40  -1  2  8  1  1073  69  -1  10  ]
      [  37  1  1  6  741  31  8  40  9  2  3  1  1031  69  210  11  ]
      [  57  2  1  5  735  85  8  38  15  1  3  1  1215  69  360  12  ]
      [  47  1  1  5  672  93  8  39  19  1  4  1  1236  69  450  13  ]
      [  75  2  8  -1  -1  -1  -1  -1  11  1  1  3  1199  69  300  10  ]
      [  72  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1211  69  234  7  ]
      [  27  1  1  6  267  45  8  40  -1  1  -1  1  1179  69  325  7  ]
      [  61  2  8  -1  -1  -1  -1  -1  16  -1  -1  3  1178  69  480  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1182  69  -1  9  ]
      [  55  2  1  5  864  85  8  39  11  3  4  1  1117  69  302  14  ]
      [  36  2  1  5  863  80  1  30  13  2  5  1  1286  69  250  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  11  5  9  3  1235  69  323  10  ]
      [  60  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1131  69  268  12  ]
      [  49  1  8  -1  -1  -1  -1  -1  10  5  9  2  1273  69  242  11  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  2  8  3  1291  69  -1  11  ]
      [  45  1  1  6  71  36  8  40  -1  1  3  1  1159  69  -1  10  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  3  8  3  1496  69  -1  10  ]
      [  30  2  1  5  750  74  8  40  15  5  3  1  1408  69  375  8  ]
      [  87  1  8  -1  -1  -1  -1  -1  13  5  7  3  1361  69  385  11  ]
      [  37  2  1  5  864  85  8  38  11  3  4  1  1501  69  343  9  ]
      [  21  1  1  6  512  50  8  55  -1  1  3  1  1594  69  -1  10  ]
      [  48  2  1  5  676  52  8  37  13  1  3  1  1611  69  400  9  ]
      [  54  2  1  5  691  65  8  39  11  3  3  1  1649  69  310  15  ]
      [  37  2  1  5  691  65  8  39  -1  3  99  1  1661  69  -1  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  13  1  3  3  1593  69  400  11  ]
      [  67  2  8  -1  -1  -1  -1  -1  14  5  6  3  1598  69  352  9  ]
      [  40  1  1  5  268  45  8  40  8  2  5  1  1614  69  215  11  ]
      [  43  1  1  5  441  45  8  39  -1  3  3  1  1726  69  -1  15  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  3  8  5  1950  69  -1  10  ]
      [  34  1  1  5  775  72  8  40  13  3  3  1  1816  69  395  10  ]
      [  78  2  8  -1  -1  -1  -1  -1  14  3  8  3  2000  69  400  10  ]
      [  79  1  8  -1  -1  -1  -1  -1  9  1  3  3  1926  69  227  12  ]
      [  51  1  1  5  600  29  8  40  10  5  9  1  1955  69  236  14  ]
      [  43  1  1  2  914  55  8  60  16  5  3  1  2081  69  500  17  ]
      [  28  1  1  5  676  52  8  40  11  2  3  1  2005  69  268  14  ]
      [  50  1  1  6  269  34  8  35  19  -1  5  1  2584  69  400  16  ]
      [  57  1  1  6  741  28  8  43  12  1  3  1  2490  69  300  19  ]
      [  49  1  1  5  787  75  1  39  20  4  8  1  3419  69  580  16  ]
      [  32  2  1  5  744  22  8  2  12  1  -1  1  101  68  290  9  ]
      [  53  2  1  5  660  52  8  8  13  1  3  4  264  68  380  12  ]
      [  63  1  8  -1  -1  -1  -1  -1  8  1  -1  3  259  68  220  3  ]
      [  47  2  1  6  660  52  8  20  11  -1  -1  1  166  68  282  12  ]
      [  82  2  8  -1  -1  -1  -1  -1  10  1  99  3  338  68  300  3  ]
      [  73  2  8  -1  -1  -1  -1  -1  10  1  -1  3  445  68  280  3  ]
      [  25  1  8  -1  -1  -1  -1  -1  13  5  -1  8  378  68  330  3  ]
      [  31  2  8  -1  -1  -1  -1  -1  13  1  3  6  598  68  345  4  ]
      [  77  1  8  -1  -1  -1  -1  -1  6  1  -1  3  697  68  100  4  ]
      [  64  2  8  -1  -1  -1  -1  -1  8  1  3  3  647  68  200  4  ]
      [  27  1  1  5  997  80  8  18  22  5  -1  1  608  68  680  11  ]
      [  53  1  8  -1  -1  -1  -1  -1  11  4  99  2  671  68  273  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  12  1  -1  3  686  68  350  4  ]
      [  37  2  1  5  662  52  8  4  11  5  -1  1  585  68  301  4  ]
      [  42  1  1  6  531  74  8  40  14  1  -1  1  675  68  410  10  ]
      [  37  2  1  1  851  85  8  20  22  5  3  1  623  68  610  5  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  5  3  609  68  272  4  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  4  3  636  68  -1  4  ]
      [  68  2  8  -1  -1  -1  -1  -1  9  1  -1  3  697  68  245  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  9  1  5  3  520  68  235  9  ]
      [  62  2  8  -1  -1  -1  -1  -1  14  1  3  3  792  68  346  5  ]
      [  58  2  1  6  411  34  8  23  10  1  -1  1  825  68  259  5  ]
      [  29  2  1  6  823  45  8  40  9  5  3  1  793  68  240  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  12  1  3  3  897  68  305  9  ]
      [  50  2  8  -1  -1  -1  -1  -1  12  3  3  2  835  68  290  8  ]
      [  58  2  1  5  787  75  1  40  11  1  3  1  856  68  300  9  ]
      [  54  1  1  6  714  50  8  12  14  2  3  2  871  68  382  7  ]
      [  32  2  1  5  864  85  8  20  21  5  3  1  904  68  550  18  ]
      [  67  1  8  -1  -1  -1  -1  -1  9  1  3  3  1006  68  200  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  8  1  3  3  1086  68  260  8  ]
      [  44  2  8  -1  -1  -1  -1  -1  11  3  3  3  956  68  320  6  ]
      [  43  2  1  6  780  64  8  24  13  3  3  1  982  68  330  6  ]
      [  33  2  1  5  780  63  8  25  9  3  3  1  945  68  217  7  ]
      [  47  1  8  -1  -1  -1  -1  -1  12  1  -1  2  1045  68  325  9  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1000  68  -1  12  ]
      [  71  2  8  -1  -1  -1  -1  -1  15  1  -1  3  967  68  490  6  ]
      [  32  1  1  5  789  45  8  25  14  3  4  1  958  68  375  16  ]
      [  70  1  8  -1  -1  -1  -1  -1  14  1  3  3  922  68  400  9  ]
      [  48  1  8  -1  -1  -1  -1  -1  11  2  3  3  957  68  280  11  ]
      [  52  1  1  5  273  60  8  40  9  2  3  1  901  68  240  12  ]
      [  39  1  1  6  744  15  8  40  9  2  3  1  984  68  196  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  8  3  4  3  1091  68  196  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  11  1  5  3  1033  68  305  6  ]
      [  22  1  1  6  441  45  8  40  11  3  3  1  1003  68  290  11  ]
      [  41  1  8  -1  -1  -1  -1  -1  -1  2  3  2  1076  68  -1  7  ]
      [  38  2  1  5  788  74  8  40  10  2  3  1  1085  68  260  7  ]
      [  56  2  1  6  854  85  1  20  -1  5  6  1  1062  68  -1  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  8  1  3  3  1220  68  200  12  ]
      [  48  2  1  6  531  34  8  40  18  1  4  1  1121  68  560  15  ]
      [  22  2  1  5  641  74  8  38  12  3  3  1  1260  68  300  10  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1109  68  -1  8  ]
      [  44  2  1  6  411  80  1  39  11  1  3  1  1260  68  300  13  ]
      [  63  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  1272  68  400  7  ]
      [  27  1  1  6  741  45  8  36  12  3  3  1  1241  68  330  7  ]
      [  55  2  1  5  780  75  1  25  16  1  4  1  1267  68  500  12  ]
      [  59  1  8  -1  -1  -1  -1  -1  11  1  3  2  1228  68  282  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  12  1  3  3  1271  68  350  9  ]
      [  56  2  1  6  915  45  1  39  14  1  3  1  1224  68  394  7  ]
      [  48  1  1  6  234  25  8  38  10  1  -1  1  1116  68  250  16  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  4  3  1222  68  -1  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  1  3  3  1214  68  330  7  ]
      [  46  2  1  6  854  85  8  35  16  1  -1  1  1283  68  450  9  ]
      [  70  2  8  -1  -1  -1  -1  -1  12  1  3  3  1290  68  340  7  ]
      [  81  1  8  -1  -1  -1  -1  -1  10  1  3  3  1268  68  239  7  ]
      [  38  1  1  6  221  28  8  40  10  2  6  1  1245  68  216  13  ]
      [  54  1  1  6  269  45  8  35  14  1  3  1  1180  68  360  12  ]
      [  51  1  1  1  482  45  8  50  13  1  3  1  1290  68  325  15  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  5  9  3  1290  68  295  10  ]
      [  31  1  1  5  853  85  8  35  10  5  5  1  1153  68  253  8  ]
      [  34  2  1  5  780  74  8  39  8  2  3  1  1197  68  165  8  ]
      [  39  1  1  6  742  15  8  39  8  2  3  1  1186  68  200  10  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1212  68  -1  7  ]
      [  60  1  1  6  935  90  1  40  13  1  3  1  1153  68  365  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  4  9  3  1168  68  -1  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  3  8  3  1377  68  -1  13  ]
      [  29  1  1  5  785  31  8  35  10  4  -1  1  1425  68  276  8  ]
      [  36  1  1  6  714  63  8  39  13  4  3  1  1497  68  350  10  ]
      [  31  1  1  9  801  75  1  39  15  5  3  1  1459  68  410  12  ]
      [  38  1  1  6  401  15  8  40  12  1  3  1  1323  68  350  8  ]
      [  67  1  8  -1  -1  -1  -1  -1  7  -1  -1  3  1319  68  200  8  ]
      [  33  2  1  5  789  25  8  38  13  3  3  1  1487  68  325  8  ]
      [  38  1  1  5  254  28  8  38  11  1  3  1  1443  68  312  10  ]
      [  30  1  1  6  540  29  1  39  10  1  -1  1  1382  68  310  13  ]
      [  41  1  1  6  522  29  8  40  -1  3  3  1  1460  68  -1  14  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1399  68  -1  10  ]
      [  36  1  1  1  750  28  8  40  24  3  -1  1  1438  68  750  8  ]
      [  72  1  8  -1  -1  -1  -1  -1  11  1  3  3  1387  68  312  8  ]
      [  37  2  1  5  853  85  1  45  14  3  1  1  1380  68  363  8  ]
      [  38  1  1  4  814  75  1  40  14  3  3  1  1383  68  326  8  ]
      [  37  1  1  1  875  80  8  11  10  5  9  1  1444  68  224  15  ]
      [  31  2  1  1  821  22  8  20  12  5  9  1  1328  68  325  8  ]
      [  50  2  1  5  765  75  1  40  10  5  9  1  1309  68  216  12  ]
      [  26  1  1  6  511  45  8  39  10  2  3  1  1420  68  294  8  ]
      [  72  1  8  -1  -1  -1  -1  -1  16  5  8  3  1408  68  495  11  ]
      [  82  2  8  -1  -1  -1  -1  -1  11  1  6  3  1483  68  300  8  ]
      [  33  1  1  6  268  45  8  40  -1  2  3  1  1370  68  -1  12  ]
      [  60  2  8  -1  -1  -1  -1  -1  10  3  6  3  1352  68  281  8  ]
      [  73  1  8  -1  -1  -1  -1  -1  13  1  3  3  1612  68  298  11  ]
      [  69  2  8  -1  -1  -1  -1  -1  14  3  4  3  1533  68  374  9  ]
      [  82  1  8  -1  -1  -1  -1  -1  14  1  3  3  1642  68  400  9  ]
      [  51  1  1  5  744  52  8  38  11  1  -1  1  1605  68  250  9  ]
      [  35  1  1  5  854  85  8  45  13  3  3  1  1545  68  360  9  ]
      [  50  2  1  5  885  80  8  30  12  5  9  1  1689  68  290  10  ]
      [  51  1  1  6  651  28  8  39  -1  1  3  1  1507  68  -1  16  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1514  68  -1  9  ]
      [  33  1  1  1  911  55  8  80  -1  4  8  1  1642  68  -1  9  ]
      [  31  1  1  6  744  34  8  35  10  1  -1  1  1689  68  300  12  ]
      [  83  1  8  -1  -1  -1  -1  -1  12  5  8  3  1648  68  308  13  ]
      [  34  1  1  5  611  24  8  40  16  5  9  1  1567  68  425  15  ]
      [  28  1  1  5  755  15  8  49  11  5  9  1  1664  68  270  9  ]
      [  42  1  1  6  241  27  8  50  12  1  3  1  1933  68  330  12  ]
      [  49  1  8  -1  -1  -1  -1  -1  10  1  3  3  1710  68  235  15  ]
      [  77  1  8  -1  -1  -1  -1  -1  24  5  3  3  1834  68  600  11  ]
      [  31  1  1  6  391  15  8  37  13  1  -1  1  2000  68  392  11  ]
      [  43  1  1  5  852  85  8  38  -1  3  3  1  1896  68  -1  11  ]
      [  33  2  1  5  778  72  8  38  9  3  3  1  1711  68  215  10  ]
      [  41  1  1  6  550  34  8  40  -1  1  3  1  1924  68  -1  10  ]
      [  36  1  1  6  273  29  8  40  -1  1  3  1  1741  68  -1  12  ]
      [  35  1  1  5  281  34  8  38  14  1  5  1  1874  68  430  10  ]
      [  36  2  1  4  872  80  1  60  12  5  10  1  1899  68  338  10  ]
      [  35  1  1  5  607  29  8  37  15  5  9  1  1744  68  408  10  ]
      [  35  1  1  4  802  75  1  39  11  3  3  1  2247  68  300  12  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  1  3  2254  68  -1  11  ]
      [  34  1  1  6  141  24  8  37  5  1  3  1  2032  68  100  11  ]
      [  33  1  1  6  501  92  1  39  8  1  3  1  2180  68  206  13  ]
      [  85  1  8  -1  -1  -1  -1  -1  8  5  9  3  2154  68  200  11  ]
      [  63  1  8  -1  -1  -1  -1  -1  9  1  3  3  2005  68  280  13  ]
      [  30  1  1  5  764  75  1  40  15  5  9  1  2032  68  438  11  ]
      [  26  1  1  5  780  51  8  40  -1  -1  -1  1  2528  68  -1  12  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2489  68  -1  12  ]
      [  50  1  1  5  620  28  8  50  11  1  -1  1  2487  68  280  13  ]
      [  57  1  1  5  779  72  8  39  17  3  3  1  2452  68  459  12  ]
      [  67  1  8  -1  -1  -1  -1  -1  11  5  9  3  2649  68  273  17  ]
      [  43  1  1  5  788  72  8  40  -1  5  9  1  2689  68  -1  13  ]
      [  86  1  8  -1  -1  -1  -1  -1  -1  3  5  3  2826  68  -1  14  ]
      [  34  1  1  5  651  34  8  40  11  4  3  1  2608  68  300  13  ]
      [  52  1  1  5  600  36  8  38  18  1  3  1  3048  68  550  15  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  5  8  3  3872  68  -1  18  ]
      [  42  1  8  -1  -1  -1  -1  -1  12  1  -1  6  3  67  340  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  213  67  -1  9  ]
      [  42  1  8  -1  -1  -1  -1  -1  9  4  8  6  290  67  256  5  ]
      [  34  2  1  5  660  52  8  20  12  -1  -1  1  310  67  265  10  ]
      [  32  1  1  5  702  63  8  44  16  1  3  1  693  67  450  7  ]
      [  40  1  8  -1  -1  -1  -1  -1  11  1  3  2  664  67  319  6  ]
      [  61  1  8  -1  -1  -1  -1  -1  13  1  -1  3  527  67  370  6  ]
      [  51  1  1  5  785  73  8  36  14  5  9  1  679  67  362  11  ]
      [  63  1  8  -1  -1  -1  -1  -1  14  1  3  3  573  67  385  8  ]
      [  56  1  8  -1  -1  -1  -1  -1  9  1  3  2  577  67  247  7  ]
      [  45  2  8  -1  -1  -1  -1  -1  10  3  -1  2  732  67  262  5  ]
      [  47  1  1  2  750  52  8  50  11  1  -1  1  756  67  302  6  ]
      [  28  1  1  6  310  40  8  39  9  3  3  1  840  67  253  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  964  67  -1  11  ]
      [  40  1  1  5  754  74  8  40  12  5  9  1  925  67  286  6  ]
      [  57  1  1  6  793  80  1  39  14  1  3  1  943  67  300  11  ]
      [  45  2  1  5  787  75  1  20  12  1  3  1  1004  67  297  6  ]
      [  69  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  935  67  270  6  ]
      [  24  2  1  5  789  74  8  40  -1  3  -1  1  1006  67  -1  6  ]
      [  33  2  8  5  780  55  8  39  -1  3  3  1  1068  67  -1  6  ]
      [  45  2  1  5  661  52  8  24  12  3  4  1  915  67  291  8  ]
      [  60  1  1  6  441  45  8  40  6  3  5  1  1014  67  151  10  ]
      [  53  1  1  6  511  45  8  39  9  2  3  1  1086  67  218  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  12  1  3  3  912  67  364  9  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1299  67  -1  7  ]
      [  82  2  8  -1  -1  -1  -1  -1  12  3  -1  3  1168  67  348  7  ]
      [  49  1  1  6  179  22  8  35  12  1  -1  1  1150  67  307  13  ]
      [  43  1  8  -1  -1  -1  -1  -1  13  3  3  3  1146  67  320  7  ]
      [  29  1  1  6  51  1  8  39  17  3  3  1  1219  67  460  9  ]
      [  24  1  1  6  997  21  8  16  14  1  -1  6  1253  67  400  7  ]
      [  31  1  1  6  731  64  8  38  11  5  9  1  1168  67  330  11  ]
      [  28  2  1  5  856  85  8  40  15  1  99  1  1193  67  281  7  ]
      [  31  2  1  5  661  52  8  38  -1  1  -1  1  1269  67  -1  7  ]
      [  51  2  1  5  780  52  8  38  13  3  3  1  1124  67  380  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  10  1  3  3  1248  67  253  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  15  1  -1  3  1296  67  410  8  ]
      [  25  1  1  5  660  52  8  40  12  -1  -1  1  1208  67  250  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  -1  3  1112  67  235  12  ]
      [  34  2  1  5  661  52  8  40  10  3  3  1  1185  67  220  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  10  1  5  3  1179  67  248  11  ]
      [  44  2  1  5  863  80  8  30  13  5  4  1  1232  67  311  7  ]
      [  31  2  1  4  735  64  8  38  16  3  3  1  1304  67  424  13  ]
      [  50  2  1  5  750  52  8  37  8  3  3  1  1416  67  229  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  11  1  3  3  1452  67  300  9  ]
      [  35  2  1  5  863  85  1  38  12  3  4  1  1314  67  350  8  ]
      [  61  2  1  5  772  51  8  9  12  3  3  3  1324  67  297  8  ]
      [  62  1  1  5  787  92  8  40  12  1  3  1  1354  67  321  8  ]
      [  32  2  1  8  864  85  1  40  12  5  -1  1  1475  67  350  12  ]
      [  34  1  1  6  714  45  8  45  10  1  1  1  1376  67  250  8  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  4  5  3  1327  67  -1  12  ]
      [  73  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1462  67  280  14  ]
      [  43  1  1  1  831  92  8  20  11  5  99  2  1435  67  270  8  ]
      [  47  1  1  6  145  25  8  40  9  2  3  1  1390  67  189  10  ]
      [  78  1  8  -1  -1  -1  -1  -1  14  1  5  3  1646  67  380  10  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1580  67  -1  9  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1654  67  -1  13  ]
      [  58  1  8  -1  -1  -1  -1  -1  14  3  3  2  1558  67  351  14  ]
      [  67  1  1  1  714  60  8  50  8  1  3  1  1511  67  170  13  ]
      [  54  2  1  5  780  28  8  30  10  3  3  1  1511  67  250  12  ]
      [  40  2  1  5  863  80  8  34  9  2  4  1  1542  67  213  9  ]
      [  33  1  1  6  714  75  1  39  15  1  3  1  1738  67  420  10  ]
      [  27  1  1  5  311  28  8  40  3  4  3  1  1765  67  60  10  ]
      [  46  1  1  5  622  72  1  39  11  5  -1  1  1873  67  290  10  ]
      [  40  1  1  5  620  25  8  38  12  1  5  1  1714  67  325  10  ]
      [  25  2  1  5  914  55  8  50  14  5  99  1  1976  67  400  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1959  67  300  10  ]
      [  31  1  1  5  672  55  8  40  19  3  3  1  1745  67  510  10  ]
      [  35  1  1  5  622  75  1  38  13  1  -1  1  1931  67  353  11  ]
      [  69  2  8  -1  -1  -1  -1  -1  13  1  3  3  2110  67  363  11  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2031  67  -1  11  ]
      [  46  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2176  67  -1  15  ]
      [  48  1  1  5  861  75  1  39  12  4  6  1  2124  67  330  11  ]
      [  54  1  1  5  772  29  8  36  -1  3  3  1  2414  67  -1  16  ]
      [  71  2  8  -1  -1  -1  -1  -1  12  5  9  3  2561  67  314  12  ]
      [  54  1  1  5  837  92  8  38  13  3  8  1  2624  67  350  19  ]
      [  35  1  1  5  835  92  8  45  20  5  8  1  3522  67  570  15  ]
      [  37  1  1  5  600  25  8  38  -1  5  8  1  3394  67  500  15  ]
      [  27  1  1  5  750  51  8  38  19  5  -1  1  3497  67  505  15  ]
      [  29  1  8  -1  -1  -1  -1  -1  -1  3  3  2  273  66  -1  2  ]
      [  44  1  8  -1  -1  -1  -1  -1  15  1  3  2  369  66  430  10  ]
      [  70  1  8  -1  -1  -1  -1  -1  10  -1  -1  6  431  66  274  3  ]
      [  20  1  8  -1  -1  -1  -1  -1  5  5  -1  8  357  66  136  3  ]
      [  20  1  8  -1  -1  -1  -1  -1  -1  5  -1  8  307  66  -1  3  ]
      [  41  1  8  -1  -1  -1  -1  -1  9  1  -1  2  695  66  250  4  ]
      [  60  2  8  -1  -1  -1  -1  -1  9  1  -1  4  577  66  212  4  ]
      [  24  1  8  -1  -1  -1  -1  -1  13  3  -1  2  583  66  300  11  ]
      [  54  1  8  -1  -1  -1  -1  -1  8  2  3  2  610  66  216  10  ]
      [  55  1  8  -1  -1  -1  -1  -1  -1  1  3  3  661  66  -1  10  ]
      [  46  1  1  5  259  36  8  40  14  1  3  1  775  66  357  10  ]
      [  80  2  8  -1  -1  -1  -1  -1  10  1  -1  3  881  66  277  5  ]
      [  60  2  8  -1  -1  -1  -1  -1  9  -1  -1  6  727  66  215  5  ]
      [  88  2  8  -1  -1  -1  -1  -1  11  1  3  3  843  66  268  5  ]
      [  40  2  8  -1  -1  -1  -1  -1  11  1  3  2  898  66  260  5  ]
      [  56  1  8  -1  -1  -1  -1  -1  9  1  3  3  847  66  230  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  8  2  3  3  833  66  194  8  ]
      [  45  2  1  5  861  55  8  40  -1  2  6  1  891  66  -1  9  ]
      [  70  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1057  66  329  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  -1  1  5  3  921  66  -1  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  979  66  -1  6  ]
      [  79  1  8  -1  -1  -1  -1  -1  8  1  3  3  1100  66  201  9  ]
      [  42  2  1  5  789  91  8  38  11  3  99  1  936  66  325  8  ]
      [  30  1  1  6  997  34  8  40  11  1  -1  1  909  66  325  10  ]
      [  58  2  8  -1  -1  -1  -1  -1  13  1  3  3  960  66  280  6  ]
      [  66  2  8  -1  -1  -1  -1  -1  10  9  -1  3  946  66  267  6  ]
      [  39  1  1  6  796  45  8  40  11  2  3  1  970  66  279  10  ]
      [  80  1  8  -1  -1  -1  -1  -1  12  5  9  3  944  66  308  15  ]
      [  66  1  8  -1  -1  -1  -1  -1  13  1  3  3  1072  66  363  9  ]
      [  48  2  1  6  864  85  8  38  13  5  8  1  1297  66  330  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  15  -1  -1  3  1133  66  410  11  ]
      [  43  2  1  5  660  52  8  40  11  3  3  1  1150  66  340  7  ]
      [  39  1  1  6  741  29  8  40  12  1  -1  1  1268  66  345  7  ]
      [  50  1  1  6  714  60  8  40  -1  3  4  1  1182  66  -1  7  ]
      [  53  2  1  6  322  29  8  35  11  1  -1  1  1171  66  235  8  ]
      [  63  2  8  -1  -1  -1  -1  -1  11  1  3  3  1287  66  276  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1466  66  -1  11  ]
      [  85  1  8  -1  -1  -1  -1  -1  15  1  3  3  1396  66  440  9  ]
      [  51  1  8  -1  -1  -1  -1  -1  7  -1  -1  2  1377  66  150  8  ]
      [  37  1  1  5  316  30  8  40  10  1  3  1  1638  66  260  12  ]
      [  55  1  1  6  993  29  8  39  9  3  3  1  1617  66  245  10  ]
      [  43  1  1  6  269  45  8  38  9  1  -1  1  1504  66  252  9  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  1  5  3  1590  66  -1  13  ]
      [  80  1  8  -1  -1  -1  -1  -1  12  1  3  3  1692  66  275  10  ]
      [  73  2  8  -1  -1  -1  -1  -1  9  5  -1  3  1554  66  219  9  ]
      [  38  1  1  6  269  34  8  40  11  2  3  1  1667  66  330  9  ]
      [  33  2  1  5  677  51  8  38  11  4  3  1  1954  66  300  10  ]
      [  43  1  1  5  788  24  8  39  10  4  5  1  1757  66  300  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  12  1  3  3  1789  66  300  13  ]
      [  61  1  1  5  622  32  8  40  -1  1  5  1  1988  66  -1  15  ]
      [  38  1  1  6  714  90  8  45  9  3  3  1  2004  66  242  15  ]
      [  22  1  8  -1  -1  -1  -1  -1  -1  -1  -1  6  8  65  -1  1  ]
      [  53  1  8  -1  -1  -1  -1  -1  14  1  3  3  232  65  400  14  ]
      [  19  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  182  65  -1  2  ]
      [  22  2  8  -1  -1  -1  -1  -1  9  3  3  2  379  65  250  3  ]
      [  23  1  8  -1  -1  -1  -1  -1  12  5  3  4  390  65  350  5  ]
      [  23  2  8  -1  -1  -1  -1  -1  -1  -1  -1  6  436  65  305  5  ]
      [  23  1  8  -1  -1  -1  -1  -1  13  1  3  2  395  65  350  3  ]
      [  24  1  1  5  522  63  8  8  -1  5  -1  1  477  65  0  3  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  1  3  320  65  -1  3  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  426  65  134  3  ]
      [  51  1  8  -1  -1  -1  -1  -1  7  1  -1  2  401  65  210  3  ]
      [  50  2  8  -1  -1  -1  -1  -1  -1  2  3  2  394  65  -1  9  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  447  65  -1  3  ]
      [  56  2  8  -1  -1  -1  -1  -1  13  1  3  2  407  65  380  5  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  316  65  550  10  ]
      [  48  1  8  -1  -1  -1  -1  -1  -1  2  -1  2  320  65  -1  10  ]
      [  49  1  8  -1  -1  -1  -1  -1  12  2  5  2  449  65  260  8  ]
      [  62  1  1  1  662  52  8  20  -1  1  5  1  417  65  -1  3  ]
      [  67  2  8  -1  -1  -1  -1  -1  11  1  3  3  690  65  273  4  ]
      [  22  1  8  -1  -1  -1  -1  -1  16  1  99  2  674  65  410  6  ]
      [  57  2  1  6  869  85  8  36  -1  1  -1  1  521  65  -1  4  ]
      [  71  2  8  -1  -1  -1  -1  -1  11  1  -1  3  522  65  300  4  ]
      [  57  1  8  -1  -1  -1  -1  -1  14  1  3  2  666  65  300  13  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  697  65  -1  4  ]
      [  54  1  8  -1  -1  -1  -1  -1  11  1  3  3  556  65  261  11  ]
      [  72  2  8  -1  -1  -1  -1  -1  19  1  3  3  572  65  585  6  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  687  65  -1  4  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  4  693  65  -1  7  ]
      [  25  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  597  65  400  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  14  1  3  3  658  65  338  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  2  656  65  -1  6  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  575  65  -1  8  ]
      [  56  2  1  5  660  52  8  40  10  3  3  1  700  65  238  12  ]
      [  80  2  8  -1  -1  -1  -1  -1  9  1  3  3  735  65  220  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  766  65  0  5  ]
      [  72  2  8  -1  -1  -1  -1  -1  12  1  -1  3  894  65  325  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  -1  3  747  65  250  5  ]
      [  61  2  8  -1  -1  -1  -1  -1  11  -1  -1  2  887  65  300  5  ]
      [  63  2  8  -1  -1  -1  -1  -1  12  1  -1  3  707  65  264  5  ]
      [  41  1  8  -1  -1  -1  -1  -1  10  1  3  2  839  65  272  5  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  867  65  -1  5  ]
      [  36  1  8  -1  -1  -1  -1  -1  21  5  -1  2  790  65  550  9  ]
      [  82  1  8  -1  -1  -1  -1  -1  8  1  -1  3  898  65  200  6  ]
      [  43  2  1  6  912  55  8  15  14  3  3  1  719  65  400  6  ]
      [  24  2  8  -1  -1  -1  -1  -1  8  5  -1  4  899  65  200  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  11  1  -1  3  767  65  300  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  848  65  -1  5  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  777  65  -1  5  ]
      [  42  1  8  -1  -1  -1  -1  -1  7  1  3  2  704  65  175  5  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  897  65  -1  5  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  888  65  -1  5  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  5  3  704  65  -1  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  11  1  -1  3  809  65  300  5  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  849  65  0  5  ]
      [  23  1  1  5  703  22  8  38  20  5  -1  1  823  65  179  5  ]
      [  23  2  1  5  755  74  8  40  -1  5  -1  1  801  65  -1  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  21  -1  -1  3  705  65  428  5  ]
      [  83  2  8  -1  -1  -1  -1  -1  10  1  -1  3  857  65  281  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  3  3  740  65  -1  5  ]
      [  28  1  8  -1  -1  -1  -1  -1  12  1  3  2  718  65  320  5  ]
      [  59  1  8  -1  -1  -1  -1  -1  9  1  3  2  785  65  225  8  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  755  65  -1  8  ]
      [  41  2  1  6  322  34  8  40  7  2  3  1  743  65  175  11  ]
      [  40  2  1  5  912  55  8  55  -1  2  6  1  790  65  -1  5  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  3  3  2  949  65  0  6  ]
      [  44  1  1  6  141  24  8  38  13  1  -1  1  904  65  299  10  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  977  65  0  6  ]
      [  81  2  8  -1  -1  -1  -1  -1  11  1  -1  3  966  65  248  6  ]
      [  53  2  1  5  863  95  8  38  14  9  -1  1  1030  65  380  6  ]
      [  19  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  1009  65  -1  6  ]
      [  44  1  1  5  270  85  8  37  -1  1  99  1  965  65  -1  6  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1000  65  -1  6  ]
      [  36  1  1  5  672  52  8  38  -1  3  3  1  935  65  240  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1020  65  -1  6  ]
      [  33  2  1  6  705  52  8  40  11  1  -1  1  958  65  305  6  ]
      [  55  1  1  6  744  22  8  12  10  1  3  3  924  65  263  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  979  65  -1  6  ]
      [  45  2  8  -1  -1  -1  -1  -1  13  3  4  2  938  65  352  6  ]
      [  53  1  1  6  714  55  8  15  -1  1  3  1  1086  65  -1  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  904  65  -1  12  ]
      [  32  1  1  5  714  60  8  45  9  1  -1  1  912  65  255  9  ]
      [  41  2  1  5  661  15  8  36  6  1  3  1  1078  65  169  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  978  65  -1  11  ]
      [  65  2  8  -1  -1  -1  -1  -1  17  1  -1  3  1065  65  374  11  ]
      [  56  1  1  6  270  75  1  39  12  1  3  1  1096  65  325  8  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1002  65  -1  10  ]
      [  81  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1042  65  285  6  ]
      [  37  2  1  6  531  15  8  40  9  -1  -1  1  930  65  235  6  ]
      [  22  1  1  5  512  62  8  35  10  2  3  1  900  65  260  10  ]
      [  59  1  8  -1  -1  -1  -1  -1  10  1  -1  2  973  65  248  8  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1064  65  -1  6  ]
      [  60  2  1  5  832  92  8  40  11  5  4  1  1042  65  292  6  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  978  65  0  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  11  1  3  3  1045  65  225  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  9  1  3  3  1124  65  225  10  ]
      [  77  2  8  -1  -1  -1  -1  -1  7  1  -1  3  1172  65  175  7  ]
      [  41  2  8  -1  -1  -1  -1  -1  10  5  -1  4  1266  65  258  7  ]
      [  28  2  1  5  785  25  8  40  12  3  3  1  1174  65  345  12  ]
      [  57  2  1  5  788  80  1  38  12  3  3  1  1266  65  290  7  ]
      [  81  2  8  -1  -1  -1  -1  -1  12  1  3  3  1275  65  350  7  ]
      [  29  2  8  -1  -1  -1  -1  -1  11  3  -1  8  1223  65  240  7  ]
      [  62  2  1  5  672  15  8  7  14  1  3  1  1160  65  400  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  1212  65  300  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1127  65  280  9  ]
      [  76  2  8  -1  -1  -1  -1  -1  14  1  3  3  1287  65  330  7  ]
      [  55  1  1  6  714  63  8  38  15  1  -1  1  1277  65  420  10  ]
      [  47  1  1  6  741  24  8  40  -1  1  3  1  1261  65  -1  17  ]
      [  29  1  1  6  997  75  1  40  13  9  5  1  1112  65  325  12  ]
      [  23  1  1  5  785  36  8  40  12  4  3  1  1261  65  285  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  13  1  3  3  1290  65  365  9  ]
      [  74  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  1185  65  300  7  ]
      [  48  1  1  6  773  50  8  40  19  1  -1  1  1183  65  545  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1249  65  -1  7  ]
      [  35  2  1  5  660  52  8  40  22  3  -1  1  1174  65  625  14  ]
      [  26  1  1  6  716  90  1  39  9  1  3  1  1140  65  260  12  ]
      [  28  1  1  6  531  26  8  40  13  1  -1  1  1268  65  350  8  ]
      [  44  1  1  6  255  45  8  40  16  1  3  1  1108  65  397  7  ]
      [  31  2  1  5  787  75  1  38  13  2  3  1  1265  65  383  7  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  4  3  1139  65  0  7  ]
      [  32  1  1  6  323  29  8  40  -1  -1  -1  1  1271  65  -1  10  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1187  65  -1  7  ]
      [  27  2  1  5  780  52  8  39  -1  1  3  1  1211  65  -1  15  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1193  65  -1  7  ]
      [  81  1  8  -1  -1  -1  -1  -1  13  1  -1  3  1127  65  380  8  ]
      [  34  1  1  5  921  99  8  60  50  3  4  1  1265  65  -1  7  ]
      [  26  1  1  6  310  45  8  36  10  1  -1  1  1199  65  265  7  ]
      [  39  2  1  6  322  74  8  30  14  1  -1  1  1277  65  420  8  ]
      [  35  1  1  6  540  34  8  36  7  3  4  1  1202  65  190  7  ]
      [  41  2  1  6  531  36  8  35  11  3  -1  1  1156  65  270  7  ]
      [  21  1  1  6  290  28  8  40  9  1  3  1  1154  65  255  9  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1222  65  0  11  ]
      [  79  1  8  -1  -1  -1  -1  -1  15  3  3  3  1144  65  394  7  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1121  65  -1  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  5  3  3  1174  65  -1  10  ]
      [  53  1  1  6  274  25  8  38  -1  1  3  1  1260  65  -1  11  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1375  65  -1  8  ]
      [  25  1  1  4  787  75  1  39  23  3  3  1  1372  65  650  11  ]
      [  60  2  1  6  934  80  1  24  -1  1  3  1  1430  65  -1  8  ]
      [  78  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1310  65  320  8  ]
      [  32  1  1  6  714  63  1  40  14  3  3  1  1444  65  325  8  ]
      [  26  2  1  5  751  31  8  40  14  5  5  1  1368  65  310  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1322  65  330  12  ]
      [  40  2  1  6  864  85  1  35  12  1  -1  1  1453  65  300  8  ]
      [  81  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  1461  65  240  10  ]
      [  47  2  1  5  861  85  8  25  -1  4  7  1  1394  65  -1  8  ]
      [  32  1  1  6  934  45  8  40  12  1  5  1  1449  65  310  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  14  1  3  3  1483  65  380  9  ]
      [  30  1  1  6  492  36  8  40  10  1  -1  1  1407  65  230  9  ]
      [  26  1  1  6  741  28  8  40  7  1  3  1  1394  65  155  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  9  1  3  3  1490  65  245  9  ]
      [  71  2  8  -1  -1  -1  -1  -1  13  4  3  3  1407  65  380  8  ]
      [  23  2  1  5  692  66  8  40  14  5  3  1  1377  65  400  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1429  65  -1  13  ]
      [  36  1  1  5  788  64  8  50  -1  3  3  1  1324  65  -1  8  ]
      [  46  2  1  5  661  15  8  65  -1  1  3  1  1446  65  -1  8  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1487  65  -1  8  ]
      [  38  1  1  6  153  45  8  40  16  -1  3  1  1470  65  460  9  ]
      [  60  2  1  5  660  55  8  40  8  1  3  1  1468  65  202  8  ]
      [  28  1  1  6  714  63  8  50  10  1  -1  1  1347  65  250  8  ]
      [  51  1  1  6  714  51  8  38  -1  1  3  1  1431  65  -1  14  ]
      [  40  1  1  5  787  85  8  39  -1  4  99  1  1388  65  -1  9  ]
      [  35  1  1  5  662  50  8  38  -1  4  3  1  1451  65  300  8  ]
      [  36  2  1  5  660  52  8  27  10  3  3  1  1427  65  250  8  ]
      [  59  2  8  -1  -1  -1  -1  -1  14  3  -1  3  1427  65  283  8  ]
      [  35  2  1  1  821  92  8  45  10  5  8  1  1308  65  229  8  ]
      [  26  1  1  6  421  15  8  40  11  2  3  1  1486  65  300  8  ]
      [  39  2  1  5  863  80  1  30  14  2  5  1  1425  65  390  8  ]
      [  33  2  1  5  662  52  8  45  13  5  9  1  1308  65  337  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  5  8  3  1358  65  -1  10  ]
      [  40  2  1  6  512  34  8  39  10  2  3  1  1392  65  281  8  ]
      [  58  1  1  6  549  71  8  40  11  1  3  1  1539  65  222  12  ]
      [  49  2  1  5  703  92  8  38  11  3  3  1  1699  65  300  9  ]
      [  46  2  1  4  787  60  8  39  13  3  3  1  1565  65  320  9  ]
      [  40  1  1  5  735  72  8  40  10  1  3  1  1510  65  250  9  ]
      [  31  1  1  6  391  15  8  50  -1  3  3  1  1676  65  -1  9  ]
      [  34  1  1  6  714  60  1  39  12  1  3  1  1699  65  328  10  ]
      [  31  2  1  5  821  92  8  40  14  5  9  1  1674  65  360  9  ]
      [  48  1  1  6  254  24  8  38  10  1  -1  1  1561  65  235  17  ]
      [  40  1  1  6  744  85  1  39  12  1  4  1  1515  65  294  10  ]
      [  31  1  1  5  714  93  8  40  37  1  1  1  1694  65  800  9  ]
      [  29  1  1  4  802  75  1  48  13  3  3  1  1663  65  375  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1532  65  -1  9  ]
      [  36  1  1  6  997  26  8  37  9  1  3  1  1531  65  216  12  ]
      [  46  1  1  6  222  29  8  38  12  1  3  1  1692  65  320  11  ]
      [  41  1  1  6  521  62  8  38  -1  3  3  1  1537  65  -1  9  ]
      [  73  2  8  -1  -1  -1  -1  -1  11  1  3  3  1662  65  303  9  ]
      [  44  1  1  5  671  51  8  38  -1  1  3  1  1661  65  -1  9  ]
      [  64  1  1  6  936  63  8  38  15  1  -1  1  1562  65  406  9  ]
      [  24  1  1  6  222  90  8  40  50  2  3  1  1517  65  -1  11  ]
      [  34  1  1  6  622  32  8  35  10  1  3  1  1692  65  300  9  ]
      [  47  2  1  5  787  75  1  30  9  4  -1  1  1698  65  240  11  ]
      [  54  2  1  5  780  33  8  40  14  3  3  1  1586  65  383  9  ]
      [  49  1  1  6  269  34  8  35  11  1  3  1  1617  65  310  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  13  1  3  3  1688  65  306  10  ]
      [  49  1  1  5  788  64  8  38  11  2  4  1  1539  65  241  14  ]
      [  43  1  1  5  609  45  8  40  -1  5  9  1  1651  65  -1  9  ]
      [  34  2  1  4  757  75  1  40  8  2  3  1  1563  65  209  9  ]
      [  39  1  1  6  712  60  8  40  -1  2  3  1  1505  65  -1  9  ]
      [  34  1  1  6  714  60  8  40  7  2  3  1  1694  65  200  10  ]
      [  74  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1894  65  300  10  ]
      [  32  1  1  5  756  63  8  39  14  5  8  1  1970  65  330  10  ]
      [  32  1  1  5  785  35  8  35  12  5  3  1  1941  65  325  10  ]
      [  35  1  1  5  796  72  8  50  10  3  3  1  1734  65  290  10  ]
      [  30  2  1  5  780  74  8  39  11  4  3  1  1721  65  300  10  ]
      [  49  1  1  4  787  63  1  39  -1  1  3  1  1850  65  -1  12  ]
      [  44  1  1  5  780  72  1  39  -1  5  3  1  1993  65  400  13  ]
      [  30  1  1  6  270  10  8  40  12  5  3  1  1783  65  300  13  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  3  4  3  1995  65  350  10  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1855  65  -1  15  ]
      [  36  2  1  5  601  34  8  40  14  5  9  1  1793  65  377  10  ]
      [  28  1  1  4  787  75  1  39  11  5  7  1  1757  65  300  16  ]
      [  29  1  1  5  620  64  8  38  13  3  5  1  1804  65  350  14  ]
      [  93  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1759  65  -1  10  ]
      [  45  1  1  6  511  45  8  35  13  1  -1  1  1886  65  360  15  ]
      [  58  2  1  5  676  52  8  45  -1  1  4  1  1961  65  -1  10  ]
      [  93  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1846  65  -1  10  ]
      [  37  2  1  6  714  60  1  40  -1  3  3  1  1781  65  -1  10  ]
      [  24  2  1  4  801  75  1  39  10  3  3  1  1742  65  280  10  ]
      [  77  1  8  -1  -1  -1  -1  -1  14  5  3  3  1823  65  340  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  1  3  3  1993  65  241  11  ]
      [  64  2  8  -1  -1  -1  -1  -1  21  5  3  3  1709  65  575  10  ]
      [  37  1  1  4  801  75  1  40  -1  5  9  1  1788  65  -1  16  ]
      [  46  1  1  6  714  63  8  40  -1  2  3  1  1962  65  -1  12  ]
      [  33  2  1  5  856  85  8  37  14  3  3  1  2081  65  360  11  ]
      [  45  1  1  6  274  60  8  40  14  1  3  1  2170  65  350  13  ]
      [  39  1  1  4  787  64  8  39  14  3  3  1  2033  65  282  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2294  65  -1  12  ]
      [  55  1  1  5  701  11  8  37  17  -1  -1  1  2111  65  500  13  ]
      [  58  1  1  6  993  15  8  40  16  1  3  1  2057  65  425  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  3  3  3  2179  65  -1  11  ]
      [  26  2  1  5  785  24  8  39  15  4  7  1  2223  65  400  11  ]
      [  37  2  1  5  871  80  1  38  17  5  10  1  2102  65  485  11  ]
      [  30  1  1  5  831  92  1  70  11  4  9  1  2200  65  288  11  ]
      [  38  1  1  6  273  29  8  35  14  -1  -1  1  2007  65  380  11  ]
      [  55  2  1  5  677  52  8  50  13  1  3  1  2222  65  324  11  ]
      [  36  1  1  4  813  75  1  38  -1  5  9  1  2473  65  -1  12  ]
      [  53  1  1  1  779  72  8  32  11  5  3  1  2409  65  300  14  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2454  65  -1  12  ]
      [  49  1  1  5  775  65  8  40  17  5  9  1  2471  65  430  12  ]
      [  35  1  1  1  836  74  8  40  10  1  3  1  2589  65  256  12  ]
      [  37  2  1  1  821  22  8  50  16  5  9  1  2574  65  400  12  ]
      [  34  1  1  5  772  64  8  50  18  1  3  1  2885  65  450  13  ]
      [  44  1  1  5  771  45  8  39  -1  4  8  1  2683  65  -1  13  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  3196  65  -1  15  ]
      [  36  1  1  5  751  45  8  35  18  9  -1  1  3287  65  500  15  ]
      [  50  1  1  5  611  24  8  40  -1  5  8  1  3242  65  -1  15  ]
      [  53  2  1  5  841  75  1  40  22  5  10  1  3346  65  570  15  ]
      [  30  2  1  5  692  67  8  38  -1  3  3  1  3877  65  -1  16  ]
      [  37  1  1  5  996  72  8  40  19  5  9  1  5044  65  500  19  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  5  3  4  262  64  -1  9  ]
      [  55  1  8  -1  -1  -1  -1  -1  9  1  3  2  298  64  240  5  ]
      [  84  2  8  -1  -1  -1  -1  -1  11  1  -1  3  382  64  222  3  ]
      [  62  2  8  -1  -1  -1  -1  -1  12  1  3  6  354  64  291  3  ]
      [  30  2  8  -1  -1  -1  -1  -1  16  3  3  8  432  64  360  3  ]
      [  70  2  8  -1  -1  -1  -1  -1  11  1  -1  3  389  64  311  3  ]
      [  39  1  8  -1  -1  -1  -1  -1  11  1  -1  6  330  64  290  5  ]
      [  24  2  8  -1  -1  -1  -1  -1  6  5  -1  8  308  64  151  9  ]
      [  43  2  8  -1  -1  -1  -1  -1  8  -1  -1  2  366  64  192  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  337  64  -1  3  ]
      [  19  2  8  -1  -1  -1  -1  -1  9  -1  -1  6  554  64  240  4  ]
      [  19  1  8  -1  -1  -1  -1  -1  13  3  -1  8  637  64  347  6  ]
      [  21  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  569  64  -1  4  ]
      [  21  1  8  -1  -1  -1  -1  -1  14  5  -1  4  575  64  402  4  ]
      [  54  1  8  -1  -1  -1  -1  -1  11  3  3  2  538  64  275  7  ]
      [  63  2  8  -1  -1  -1  -1  -1  9  1  -1  3  682  64  250  4  ]
      [  37  1  8  6  531  36  8  10  13  5  3  1  533  64  339  4  ]
      [  30  1  8  -1  -1  -1  -1  -1  15  2  3  2  692  64  360  4  ]
      [  48  2  1  5  780  1  8  30  9  1  3  1  870  64  245  11  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  875  64  -1  8  ]
      [  63  2  8  -1  -1  -1  -1  -1  14  3  3  3  877  64  390  5  ]
      [  60  2  8  -1  -1  -1  -1  -1  12  1  -1  3  703  64  295  5  ]
      [  34  1  8  -1  -1  -1  -1  -1  12  3  3  2  778  64  271  7  ]
      [  25  1  1  1  775  72  8  15  11  4  3  1  867  64  245  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  845  64  -1  7  ]
      [  68  1  8  -1  -1  -1  -1  -1  12  1  4  3  786  64  314  8  ]
      [  79  2  8  -1  -1  -1  -1  -1  10  3  3  3  737  64  186  5  ]
      [  69  1  8  -1  -1  -1  -1  -1  50  3  3  3  828  64  -1  5  ]
      [  31  2  1  6  997  93  8  40  -1  9  -1  1  899  64  -1  5  ]
      [  53  1  8  -1  -1  -1  -1  -1  12  1  5  2  909  64  260  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1066  64  311  6  ]
      [  31  2  1  6  934  85  8  10  12  1  -1  6  945  64  300  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  9  1  3  3  1012  64  217  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  9  1  -1  3  918  64  240  6  ]
      [  40  1  1  5  273  29  8  40  16  1  3  1  959  64  402  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  10  3  3  3  931  64  245  6  ]
      [  48  1  1  6  267  45  8  38  17  1  3  1  916  64  432  6  ]
      [  54  1  8  -1  -1  -1  -1  -1  18  1  5  3  981  64  461  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  3  3  966  64  -1  6  ]
      [  64  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  941  64  300  6  ]
      [  59  1  8  -1  -1  -1  -1  -1  12  1  3  3  1064  64  310  11  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  946  64  -1  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  11  1  -1  3  945  64  270  6  ]
      [  83  1  8  -1  -1  -1  -1  -1  9  1  -1  3  1031  64  169  9  ]
      [  59  2  8  -1  -1  -1  -1  -1  10  1  3  3  931  64  241  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  1  3  3  984  64  300  11  ]
      [  35  2  1  5  864  85  8  40  12  2  5  1  985  64  285  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  904  64  -1  8  ]
      [  40  2  1  5  782  75  1  42  19  -1  -1  1  1062  64  500  6  ]
      [  33  1  1  6  391  15  8  40  -1  2  4  1  995  64  -1  6  ]
      [  45  2  1  5  662  52  8  40  13  3  3  1  1286  64  350  7  ]
      [  52  2  1  5  789  74  8  39  14  1  3  1  1125  64  385  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1242  64  310  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1278  64  -1  10  ]
      [  27  2  1  6  660  52  8  20  14  3  3  4  1190  64  330  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  20  1  -1  3  1138  64  580  7  ]
      [  22  1  1  6  254  28  8  38  -1  1  3  1  1124  64  0  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  10  3  3  3  1281  64  248  11  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1270  64  -1  11  ]
      [  66  1  8  -1  -1  -1  -1  -1  13  1  3  3  1286  64  350  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  14  1  3  3  1204  64  364  7  ]
      [  40  1  1  5  662  52  8  40  16  2  5  1  1181  64  435  7  ]
      [  41  2  1  5  864  85  8  38  9  3  3  1  1298  64  250  7  ]
      [  27  1  1  6  744  34  8  38  15  1  3  1  1241  64  420  11  ]
      [  75  2  8  -1  -1  -1  -1  -1  11  1  3  3  1196  64  250  7  ]
      [  86  1  8  -1  -1  -1  -1  -1  13  1  5  3  1235  64  276  10  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1122  64  -1  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  11  1  -1  3  1298  64  244  13  ]
      [  73  1  8  -1  -1  -1  -1  -1  12  1  3  3  1224  64  300  9  ]
      [  68  2  1  6  792  92  8  15  13  1  5  3  1108  64  314  7  ]
      [  47  2  1  5  853  85  8  37  13  2  3  1  1239  64  261  11  ]
      [  56  1  1  6  52  1  8  40  -1  2  5  1  1111  64  -1  9  ]
      [  77  1  8  -1  -1  -1  -1  -1  11  1  3  3  1282  64  270  9  ]
      [  65  2  8  -1  -1  -1  -1  -1  15  -1  -1  4  1348  64  415  8  ]
      [  33  1  1  6  741  75  1  38  11  1  -1  1  1409  64  300  8  ]
      [  46  1  1  5  701  63  8  38  12  3  3  1  1479  64  310  8  ]
      [  64  2  8  -1  -1  -1  -1  -1  13  1  3  3  1493  64  350  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  16  1  3  3  1369  64  400  11  ]
      [  44  1  1  6  281  50  8  35  18  1  3  1  1312  64  500  12  ]
      [  27  1  1  5  678  51  8  39  11  3  3  1  1413  64  330  8  ]
      [  27  1  1  5  531  28  8  40  10  1  -1  1  1309  64  280  8  ]
      [  36  2  1  6  322  31  8  35  9  3  5  1  1354  64  250  8  ]
      [  74  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1331  64  235  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1430  64  -1  8  ]
      [  40  2  1  5  853  85  1  39  12  3  5  1  1352  64  235  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1394  64  -1  11  ]
      [  32  2  1  5  689  51  8  38  9  2  3  1  1452  64  208  8  ]
      [  40  1  1  6  316  32  8  39  13  2  3  1  1417  64  330  12  ]
      [  51  1  1  6  744  51  8  45  11  2  3  1  1427  64  290  14  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  1675  64  273  11  ]
      [  37  2  1  6  411  80  1  38  -1  1  -1  1  1581  64  -1  9  ]
      [  34  1  1  6  488  45  8  40  10  1  3  1  1507  64  164  10  ]
      [  31  1  1  5  600  33  8  38  10  5  8  1  1643  64  275  9  ]
      [  71  1  8  -1  -1  -1  -1  -1  10  3  3  3  1503  64  219  10  ]
      [  67  2  8  -1  -1  -1  -1  -1  25  1  3  3  1779  64  700  10  ]
      [  43  1  1  5  756  74  1  60  15  1  3  1  1901  64  360  16  ]
      [  34  1  1  6  281  35  8  35  13  3  -1  1  1742  64  340  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1973  64  -1  10  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1767  64  -1  10  ]
      [  40  1  1  6  714  15  8  46  10  2  3  1  1879  64  260  11  ]
      [  46  2  1  2  911  55  8  50  -1  1  -1  1  2244  64  -1  11  ]
      [  32  1  1  5  813  74  8  50  13  5  10  1  2156  64  260  11  ]
      [  38  2  1  5  841  24  8  40  9  5  10  1  2040  64  250  17  ]
      [  22  1  1  6  220  29  8  38  11  3  3  1  2073  64  300  13  ]
      [  33  1  1  5  777  52  8  45  -1  1  99  1  2355  64  -1  15  ]
      [  39  1  1  6  512  34  8  35  10  1  -1  1  2345  64  232  13  ]
      [  47  1  1  4  873  80  1  38  -1  5  9  1  2411  64  462  12  ]
      [  41  1  1  1  601  74  8  50  12  4  8  1  2376  64  306  15  ]
      [  28  1  1  5  775  17  8  37  12  3  4  1  3111  64  345  14  ]
      [  20  1  1  9  801  75  1  40  12  3  3  1  218  63  315  4  ]
      [  68  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  429  63  229  6  ]
      [  36  1  8  -1  -1  -1  -1  -1  -1  2  3  2  337  63  -1  6  ]
      [  22  2  8  -1  -1  -1  -1  -1  12  1  3  6  516  63  350  4  ]
      [  86  2  8  -1  -1  -1  -1  -1  10  1  -1  3  643  63  200  4  ]
      [  23  2  1  5  311  92  8  6  14  5  -1  4  565  63  370  10  ]
      [  39  2  1  5  780  51  8  27  -1  5  4  1  548  63  -1  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  15  1  -1  3  620  63  406  4  ]
      [  66  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  605  63  261  4  ]
      [  52  1  8  -1  -1  -1  -1  -1  10  2  5  2  576  63  232  9  ]
      [  30  2  8  -1  -1  -1  -1  -1  13  2  3  2  543  63  354  10  ]
      [  67  2  8  -1  -1  -1  -1  -1  9  1  3  3  596  63  224  8  ]
      [  78  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  760  63  250  5  ]
      [  40  2  8  -1  -1  -1  -1  -1  9  5  1  2  776  63  216  5  ]
      [  49  2  8  -1  -1  -1  -1  -1  12  1  3  6  797  63  291  5  ]
      [  83  1  8  -1  -1  -1  -1  -1  10  1  3  3  743  63  216  5  ]
      [  41  1  1  6  316  31  8  35  13  1  3  1  716  63  300  5  ]
      [  74  1  8  -1  -1  -1  -1  -1  14  -1  -1  3  724  63  360  9  ]
      [  41  1  8  -1  -1  -1  -1  -1  4  1  -1  2  794  63  90  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  9  1  -1  3  760  63  216  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  11  1  3  3  729  63  300  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  8  1  3  3  707  63  184  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  11  1  5  3  855  63  293  8  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  750  63  -1  7  ]
      [  47  1  1  5  787  74  1  36  12  2  3  1  821  63  340  8  ]
      [  78  1  8  -1  -1  -1  -1  -1  9  1  3  3  815  63  220  7  ]
      [  22  1  8  -1  -1  -1  -1  -1  9  1  -1  3  986  63  225  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  11  1  -1  3  931  63  300  6  ]
      [  21  1  1  6  997  55  8  39  11  1  -1  1  1078  63  300  6  ]
      [  52  2  1  6  522  19  8  40  -1  1  -1  1  1031  63  -1  6  ]
      [  47  1  1  6  741  29  8  35  9  3  3  1  921  63  235  11  ]
      [  55  1  8  -1  -1  -1  -1  -1  14  1  3  3  1089  63  400  11  ]
      [  52  2  1  5  661  15  8  38  12  3  3  1  1077  63  350  6  ]
      [  70  1  8  -1  -1  -1  -1  -1  9  1  3  3  979  63  244  8  ]
      [  29  2  1  6  431  15  8  30  8  3  3  1  983  63  176  6  ]
      [  31  2  1  5  784  18  8  37  11  3  3  1  925  63  306  6  ]
      [  49  2  8  -1  -1  -1  -1  -1  12  2  3  2  1017  63  250  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  7  1  -1  3  930  63  156  9  ]
      [  66  2  8  -1  -1  -1  -1  -1  9  1  3  3  1009  63  210  6  ]
      [  33  2  1  5  864  85  8  25  16  4  5  1  1007  63  430  6  ]
      [  58  1  8  -1  -1  -1  -1  -1  13  1  3  3  960  63  347  7  ]
      [  59  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  985  63  260  7  ]
      [  43  2  1  5  864  85  1  37  -1  4  3  1  1185  63  240  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  1155  63  363  7  ]
      [  25  1  1  5  712  60  8  38  9  3  3  1  1298  63  220  7  ]
      [  53  1  1  6  714  60  8  12  11  1  5  1  1151  63  320  8  ]
      [  74  2  8  -1  -1  -1  -1  -1  11  3  -1  3  1164  63  269  7  ]
      [  50  1  1  6  310  40  1  40  13  1  3  1  1107  63  311  7  ]
      [  31  2  1  5  641  51  8  35  11  5  3  1  1299  63  300  7  ]
      [  39  2  1  5  411  80  1  19  10  3  3  1  1289  63  250  9  ]
      [  33  1  1  6  276  29  8  37  9  1  3  1  1273  63  240  13  ]
      [  27  1  1  6  373  19  8  39  13  1  3  1  1108  63  350  12  ]
      [  79  1  8  -1  -1  -1  -1  -1  10  3  3  3  1122  63  237  9  ]
      [  41  1  1  5  502  27  8  35  11  1  5  1  1206  63  280  7  ]
      [  27  2  1  5  784  92  8  20  10  5  -1  1  1132  63  228  7  ]
      [  52  1  1  6  141  24  8  40  12  1  3  1  1225  63  289  9  ]
      [  22  1  8  -1  -1  -1  -1  -1  -1  1  -1  6  1221  63  -1  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1416  63  -1  8  ]
      [  34  1  1  6  510  34  8  29  14  1  -1  1  1382  63  380  8  ]
      [  40  2  1  6  531  22  8  35  12  1  -1  1  1353  63  303  8  ]
      [  32  1  1  6  511  45  8  39  14  1  3  1  1310  63  333  8  ]
      [  34  2  1  5  642  29  8  35  11  4  3  1  1319  63  300  14  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1340  63  398  8  ]
      [  32  1  1  6  72  28  8  36  11  3  3  1  1406  63  300  8  ]
      [  38  1  1  5  273  29  8  40  19  3  3  1  1376  63  450  8  ]
      [  60  1  1  1  911  55  8  75  9  1  3  1  1342  63  190  8  ]
      [  54  2  8  -1  -1  -1  -1  -1  -1  1  3  2  1397  63  -1  8  ]
      [  79  2  8  -1  -1  -1  -1  -1  14  3  3  3  1453  63  295  8  ]
      [  45  1  1  5  627  15  8  39  -1  1  3  1  1597  63  -1  9  ]
      [  83  2  8  -1  -1  -1  -1  -1  11  3  4  3  1500  63  295  9  ]
      [  68  1  8  -1  -1  -1  -1  -1  10  1  3  3  1659  63  260  9  ]
      [  82  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  1604  63  250  9  ]
      [  51  1  1  6  531  27  8  40  12  1  1  1  1556  63  277  11  ]
      [  63  1  1  6  316  32  8  35  17  1  -1  1  1609  63  450  9  ]
      [  33  2  1  5  774  60  8  40  21  5  9  1  1597  63  555  9  ]
      [  27  1  1  6  712  60  8  38  8  2  3  1  1528  63  200  9  ]
      [  39  1  1  5  712  60  8  40  14  1  3  1  1634  63  358  11  ]
      [  81  1  8  -1  -1  -1  -1  -1  12  3  6  3  1665  63  305  13  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  3  3  1828  63  290  10  ]
      [  27  1  1  1  441  45  8  40  12  1  -1  1  1786  63  320  11  ]
      [  24  2  1  5  833  74  8  40  13  5  5  1  1939  63  330  14  ]
      [  70  1  8  -1  -1  -1  -1  -1  10  1  3  3  1866  63  200  12  ]
      [  84  1  8  -1  -1  -1  -1  -1  10  1  5  3  1794  63  251  14  ]
      [  44  1  1  5  641  16  8  40  12  5  6  1  1719  63  260  11  ]
      [  53  1  1  4  801  75  1  40  7  1  3  1  1834  63  200  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  7  1  3  3  1735  63  200  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  3  3  3  1980  63  -1  14  ]
      [  63  1  1  5  683  52  8  40  12  3  3  1  1975  63  290  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  16  3  5  3  1841  63  442  10  ]
      [  64  1  1  5  273  29  8  37  11  1  3  1  2270  63  251  11  ]
      [  72  2  8  -1  -1  -1  -1  -1  12  5  9  3  2281  63  250  11  ]
      [  32  1  1  5  813  74  8  50  15  5  9  1  2207  63  450  11  ]
      [  25  1  1  6  270  28  8  35  9  3  3  1  2138  63  180  11  ]
      [  54  1  1  5  601  35  8  40  13  5  8  1  2072  63  300  11  ]
      [  30  1  1  6  225  34  8  38  16  1  3  1  2387  63  450  13  ]
      [  44  1  1  5  872  80  1  38  13  5  9  1  2515  63  362  12  ]
      [  42  1  1  5  780  65  8  40  15  5  3  1  2774  63  330  13  ]
      [  52  1  1  2  491  45  8  60  16  1  1  1  3012  63  400  16  ]
      [  21  1  1  1  756  92  8  40  12  1  3  1  3413  63  300  15  ]
      [  62  2  1  3  780  45  8  14  -1  -1  -1  3  4372  63  -1  17  ]
      [  21  1  8  -1  -1  -1  -1  -1  12  1  -1  6  275  62  263  3  ]
      [  90  2  8  -1  -1  -1  -1  -1  50  1  -1  3  201  62  -1  2  ]
      [  46  1  8  -1  -1  -1  -1  -1  -1  5  9  6  282  62  0  6  ]
      [  25  1  1  6  411  55  8  10  12  3  -1  6  309  62  285  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  14  1  3  6  456  62  330  5  ]
      [  36  1  8  -1  -1  -1  -1  -1  11  3  3  2  465  62  300  3  ]
      [  28  2  8  -1  -1  -1  -1  -1  -1  1  -1  6  376  62  -1  3  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  447  62  255  3  ]
      [  21  2  8  -1  -1  -1  -1  -1  -1  4  -1  4  478  62  -1  3  ]
      [  34  1  8  -1  -1  -1  -1  -1  16  5  -1  2  500  62  378  7  ]
      [  52  1  8  -1  -1  -1  -1  -1  12  1  3  3  580  62  260  4  ]
      [  84  2  8  -1  -1  -1  -1  -1  6  1  3  3  533  62  158  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  17  1  -1  3  672  62  460  10  ]
      [  71  2  8  -1  -1  -1  -1  -1  9  1  -1  3  584  62  220  4  ]
      [  66  1  8  -1  -1  -1  -1  -1  10  1  3  3  576  62  228  6  ]
      [  58  2  8  -1  -1  -1  -1  -1  11  2  6  3  508  62  229  10  ]
      [  23  2  1  6  912  55  8  18  11  5  -1  1  531  62  286  8  ]
      [  85  2  8  -1  -1  -1  -1  -1  12  1  -1  3  664  62  275  4  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  707  62  260  8  ]
      [  75  2  8  -1  -1  -1  -1  -1  9  1  -1  3  860  62  225  5  ]
      [  70  2  8  -1  -1  -1  -1  -1  8  1  -1  3  889  62  199  5  ]
      [  82  1  8  -1  -1  -1  -1  -1  12  1  3  3  822  62  242  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  837  62  305  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  12  1  3  3  790  62  310  5  ]
      [  63  1  8  6  714  60  8  20  15  1  3  3  831  62  404  10  ]
      [  85  2  8  -1  -1  -1  -1  -1  13  3  3  3  809  62  315  5  ]
      [  51  2  8  -1  -1  -1  -1  -1  12  1  3  2  740  62  331  7  ]
      [  60  2  8  -1  -1  -1  -1  -1  8  1  3  3  790  62  172  5  ]
      [  20  2  1  8  481  45  8  38  7  4  -1  1  700  62  131  5  ]
      [  35  1  1  6  461  45  8  40  10  4  8  1  747  62  243  7  ]
      [  55  1  8  -1  -1  -1  -1  -1  6  2  3  3  814  62  101  5  ]
      [  68  2  8  -1  -1  -1  -1  -1  7  1  5  3  855  62  100  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1002  62  306  6  ]
      [  68  2  8  -1  -1  -1  -1  -1  11  1  -1  3  987  62  305  6  ]
      [  87  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  926  62  -1  6  ]
      [  75  1  8  -1  -1  -1  -1  -1  9  1  -1  3  1096  62  225  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  979  62  -1  8  ]
      [  65  2  8  -1  -1  -1  -1  -1  8  1  -1  3  918  62  210  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  15  -1  -1  3  1084  62  290  9  ]
      [  23  2  1  5  856  85  8  39  15  3  3  1  1066  62  420  6  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  912  62  0  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1073  62  -1  6  ]
      [  66  2  8  -1  -1  -1  -1  -1  20  1  -1  3  906  62  500  6  ]
      [  39  1  8  -1  -1  -1  -1  -1  14  1  1  2  1057  62  380  13  ]
      [  71  2  8  -1  -1  -1  -1  -1  13  3  3  3  1092  62  289  6  ]
      [  34  1  1  6  796  70  8  40  12  2  3  1  981  62  250  8  ]
      [  47  1  1  7  981  52  8  40  -1  2  6  1  1093  62  -1  11  ]
      [  32  1  1  6  270  29  8  40  11  2  3  1  1007  62  287  11  ]
      [  80  2  8  -1  -1  -1  -1  -1  17  1  -1  3  945  62  450  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  13  1  3  3  1028  62  350  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  8  1  3  3  968  62  195  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  1  3  3  1186  62  299  10  ]
      [  68  2  8  -1  -1  -1  -1  -1  11  1  4  3  1201  62  296  7  ]
      [  89  2  8  -1  -1  -1  -1  -1  10  1  3  3  1290  62  250  7  ]
      [  48  1  1  6  411  75  1  39  10  1  -1  1  1255  62  259  7  ]
      [  84  1  8  -1  -1  -1  -1  -1  11  1  3  3  1286  62  250  7  ]
      [  79  2  8  -1  -1  -1  -1  -1  23  1  -1  3  1123  62  630  7  ]
      [  46  1  8  -1  -1  -1  -1  -1  13  1  3  2  1118  62  284  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  12  1  3  3  1220  62  250  7  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1300  62  -1  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  11  1  3  3  1223  62  250  7  ]
      [  37  1  8  -1  -1  -1  -1  -1  -1  5  9  4  1253  62  407  9  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1230  62  -1  11  ]
      [  47  1  1  2  852  85  8  40  -1  5  5  1  1100  62  434  14  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1159  62  -1  7  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  5  3  1290  62  -1  7  ]
      [  37  1  1  6  471  45  8  37  11  3  3  1  1279  62  270  10  ]
      [  54  2  1  6  531  29  8  35  12  -1  -1  1  1189  62  261  13  ]
      [  25  1  1  6  268  45  8  37  9  3  3  1  1136  62  155  8  ]
      [  37  1  1  6  281  50  8  40  12  2  3  1  1139  62  281  11  ]
      [  46  2  1  6  522  52  8  38  8  2  3  1  1230  62  167  11  ]
      [  44  2  1  5  861  85  8  40  16  5  9  1  1233  62  425  7  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1247  62  -1  11  ]
      [  70  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  1430  62  230  8  ]
      [  58  1  1  2  911  55  8  70  21  1  3  1  1317  62  600  11  ]
      [  65  1  8  -1  -1  -1  -1  -1  8  1  -1  3  1393  62  200  8  ]
      [  29  2  8  -1  -1  -1  -1  -1  17  1  -1  4  1312  62  440  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1308  62  480  8  ]
      [  30  2  1  5  834  92  8  38  13  5  8  1  1313  62  320  8  ]
      [  69  1  8  -1  -1  -1  -1  -1  9  1  3  3  1389  62  200  8  ]
      [  80  2  8  -1  -1  -1  -1  -1  14  -1  -1  6  1347  62  334  8  ]
      [  24  2  1  5  853  85  8  39  16  5  3  1  1431  62  389  12  ]
      [  58  1  1  6  267  45  8  38  15  1  3  1  1361  62  336  14  ]
      [  73  1  8  -1  -1  -1  -1  -1  8  1  3  3  1424  62  181  12  ]
      [  57  1  1  5  620  29  8  35  12  1  5  1  1473  62  250  8  ]
      [  36  1  1  5  853  85  1  39  10  3  3  1  1301  62  192  13  ]
      [  25  2  1  5  861  80  8  40  14  5  8  1  1500  62  290  8  ]
      [  58  2  1  5  692  66  8  40  13  3  6  1  1381  62  250  8  ]
      [  44  1  1  6  796  70  8  40  9  2  3  1  1490  62  218  13  ]
      [  48  1  1  6  714  26  8  40  13  2  3  1  1390  62  343  9  ]
      [  24  1  1  5  753  74  8  40  10  5  7  1  1600  62  250  9  ]
      [  47  2  1  5  677  41  8  35  17  1  3  1  1696  62  330  9  ]
      [  29  2  1  4  787  75  1  39  11  3  3  1  1620  62  290  9  ]
      [  45  2  1  5  780  64  8  38  -1  1  5  1  1527  62  -1  9  ]
      [  51  2  8  -1  -1  -1  -1  -1  23  3  -1  4  1646  62  580  9  ]
      [  55  1  1  4  801  75  1  40  11  2  3  1  1504  62  271  14  ]
      [  66  1  8  -1  -1  -1  -1  -1  11  1  3  3  1564  62  260  16  ]
      [  87  2  8  -1  -1  -1  -1  -1  12  5  5  3  1513  62  318  9  ]
      [  50  2  1  5  863  80  1  30  13  1  3  1  1959  62  250  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  16  5  9  3  1714  62  375  10  ]
      [  95  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1700  62  -1  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  11  1  3  3  1815  62  271  10  ]
      [  27  1  1  6  651  25  8  40  13  1  -1  1  1787  62  350  12  ]
      [  30  2  1  5  691  65  8  38  -1  3  3  1  1966  62  380  10  ]
      [  53  1  1  6  505  36  8  40  10  2  5  1  1952  62  268  12  ]
      [  32  1  1  5  775  72  8  38  9  5  4  1  2140  62  215  13  ]
      [  34  1  1  6  491  45  8  37  18  1  3  1  2078  62  470  11  ]
      [  36  1  1  4  801  75  1  40  12  3  7  1  2244  62  236  11  ]
      [  48  1  1  6  531  22  8  42  15  1  -1  1  2313  62  360  12  ]
      [  33  2  1  5  813  32  8  40  17  5  9  1  2407  62  429  12  ]
      [  49  1  8  -1  -1  -1  -1  -1  10  1  3  3  2891  62  229  13  ]
      [  70  1  8  -1  -1  -1  -1  -1  10  5  8  3  2680  62  239  14  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  3  4  3  3186  62  -1  14  ]
      [  57  1  1  5  780  45  8  60  12  5  9  1  3737  62  275  16  ]
      [  27  1  1  6  483  45  8  40  11  3  -1  1  285  61  247  6  ]
      [  47  1  8  -1  -1  -1  -1  -1  13  3  8  6  167  61  300  4  ]
      [  80  2  8  -1  -1  -1  -1  -1  50  4  8  6  485  61  -1  3  ]
      [  22  2  8  -1  -1  -1  -1  -1  13  1  -1  8  367  61  330  3  ]
      [  43  2  8  -1  -1  -1  -1  -1  9  -1  -1  6  453  61  198  4  ]
      [  22  2  8  -1  -1  -1  -1  -1  10  5  -1  8  477  61  211  3  ]
      [  26  2  1  5  854  85  8  20  -1  5  -1  1  410  61  -1  3  ]
      [  45  1  8  -1  -1  -1  -1  -1  10  1  3  2  375  61  265  7  ]
      [  24  1  1  7  701  63  8  40  15  5  -1  1  526  61  379  9  ]
      [  75  2  8  -1  -1  -1  -1  -1  8  1  -1  3  523  61  180  4  ]
      [  88  2  8  -1  -1  -1  -1  -1  18  1  -1  3  548  61  480  4  ]
      [  23  1  1  6  714  52  8  40  9  2  3  1  666  61  219  8  ]
      [  35  1  1  6  51  75  1  30  16  2  3  1  597  61  381  8  ]
      [  24  1  8  -1  -1  -1  -1  -1  13  3  3  2  632  61  310  4  ]
      [  72  1  8  -1  -1  -1  -1  -1  10  1  3  3  552  61  267  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  3  3  629  61  282  8  ]
      [  92  1  8  -1  -1  -1  -1  -1  12  1  3  3  853  61  310  5  ]
      [  54  2  8  -1  -1  -1  -1  -1  12  1  3  6  716  61  300  7  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  782  61  -1  8  ]
      [  52  2  1  6  411  80  1  30  8  1  3  1  776  61  183  5  ]
      [  42  2  1  5  358  91  8  38  8  2  3  1  870  61  190  7  ]
      [  48  2  1  5  787  64  8  38  -1  3  3  1  978  61  -1  6  ]
      [  42  1  8  -1  -1  -1  -1  -1  15  1  3  2  921  61  357  6  ]
      [  57  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1044  61  -1  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  20  1  3  3  971  61  420  6  ]
      [  49  1  1  5  832  92  8  45  -1  5  9  1  942  61  -1  6  ]
      [  36  1  8  6  522  52  8  6  15  2  3  2  993  61  377  6  ]
      [  68  1  8  -1  -1  -1  -1  -1  13  2  5  3  1037  61  342  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  12  3  3  3  1080  61  315  9  ]
      [  86  1  8  -1  -1  -1  -1  -1  7  1  3  3  956  61  183  9  ]
      [  72  2  8  -1  -1  -1  -1  -1  11  1  4  3  924  61  280  6  ]
      [  84  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1290  61  270  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1217  61  280  7  ]
      [  31  1  1  5  832  92  8  60  24  5  9  1  1180  61  615  7  ]
      [  36  2  1  5  771  29  8  20  12  3  3  1  1276  61  253  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1228  61  218  7  ]
      [  67  1  1  6  744  22  8  12  13  3  6  3  1287  61  310  9  ]
      [  68  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  1153  61  260  10  ]
      [  57  2  1  6  11  1  8  40  12  2  3  1  1162  61  310  7  ]
      [  45  1  1  6  181  20  8  37  11  2  3  1  1216  61  245  9  ]
      [  80  1  8  -1  -1  -1  -1  -1  11  1  3  3  1236  61  290  8  ]
      [  36  2  1  5  856  85  8  40  9  2  5  1  1110  61  214  7  ]
      [  46  1  1  6  540  24  8  38  13  5  8  1  1386  61  310  8  ]
      [  34  1  1  5  661  52  8  38  12  9  -1  1  1434  61  294  11  ]
      [  23  1  1  5  714  63  8  42  15  1  3  1  1497  61  297  15  ]
      [  76  1  8  -1  -1  -1  -1  -1  11  1  3  3  1368  61  281  11  ]
      [  56  1  1  6  802  27  8  40  10  2  5  1  1413  61  240  11  ]
      [  48  1  1  6  241  35  8  38  -1  2  3  1  1337  61  -1  11  ]
      [  88  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1383  61  277  8  ]
      [  87  1  8  -1  -1  -1  -1  -1  10  3  3  3  1309  61  250  8  ]
      [  55  1  1  6  471  45  8  40  13  1  -1  1  1629  61  310  9  ]
      [  29  1  1  4  787  75  1  39  15  3  3  1  1586  61  400  13  ]
      [  59  1  1  6  742  63  8  40  14  1  -1  1  1609  61  272  9  ]
      [  36  2  1  5  751  74  8  35  13  3  3  1  1516  61  250  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  10  3  3  3  1564  61  209  12  ]
      [  31  2  1  4  801  75  1  42  11  3  3  1  1653  61  264  15  ]
      [  42  1  1  6  714  60  1  40  14  2  3  1  1632  61  300  15  ]
      [  43  2  1  6  51  1  8  36  12  2  3  1  1581  61  280  9  ]
      [  49  2  8  -1  -1  -1  -1  -1  14  3  3  3  1778  61  313  13  ]
      [  61  1  8  -1  -1  -1  -1  -1  11  1  3  3  1990  61  204  10  ]
      [  45  2  1  5  787  75  1  38  11  2  3  1  1820  61  260  12  ]
      [  28  2  1  1  835  92  8  50  15  2  5  1  1879  61  373  17  ]
      [  63  1  8  -1  -1  -1  -1  -1  14  5  8  3  2286  61  334  11  ]
      [  34  2  1  5  841  85  1  39  25  5  9  1  2000  61  635  11  ]
      [  44  2  1  5  751  85  1  40  17  3  3  1  2533  61  400  12  ]
      [  42  2  1  5  780  40  8  37  9  4  3  1  2534  61  210  12  ]
      [  39  1  1  5  841  85  1  39  19  5  10  1  2394  61  430  12  ]
      [  34  2  1  5  841  85  1  40  9  5  8  1  3470  61  167  15  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  5  145  60  -1  1  ]
      [  42  1  1  2  268  45  8  40  -1  5  9  1  30  60  -1  8  ]
      [  47  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  182  60  -1  2  ]
      [  38  1  1  5  775  72  8  40  -1  5  -1  1  242  60  0  2  ]
      [  92  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  197  60  -1  2  ]
      [  60  1  1  6  714  55  8  20  12  5  9  1  181  60  300  4  ]
      [  56  2  8  -1  -1  -1  -1  -1  8  5  9  6  215  60  183  3  ]
      [  19  1  1  5  411  55  8  12  14  3  -1  4  488  60  350  3  ]
      [  23  1  8  -1  -1  -1  -1  -1  13  5  -1  8  320  60  330  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  15  5  99  6  394  60  300  5  ]
      [  32  1  8  -1  -1  -1  -1  -1  15  -1  -1  2  302  60  400  3  ]
      [  22  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  351  60  0  3  ]
      [  50  2  8  -1  -1  -1  -1  -1  8  -1  -1  3  478  60  206  6  ]
      [  34  1  8  -1  -1  -1  -1  -1  10  3  3  2  377  60  250  5  ]
      [  50  1  1  6  268  45  8  40  50  1  3  1  405  60  -1  3  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  353  60  -1  3  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  457  60  -1  3  ]
      [  31  1  8  -1  -1  -1  -1  -1  -1  5  3  4  366  60  -1  3  ]
      [  23  2  8  -1  -1  -1  -1  -1  -1  5  3  4  331  60  -1  3  ]
      [  61  1  8  -1  -1  -1  -1  -1  6  -1  -1  3  436  60  160  6  ]
      [  51  1  8  -1  -1  -1  -1  -1  9  2  3  2  475  60  204  11  ]
      [  52  2  8  -1  -1  -1  -1  -1  -1  2  3  2  418  60  -1  7  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  1  3  308  60  0  3  ]
      [  62  1  8  5  53  52  8  15  -1  -1  -1  3  556  60  -1  11  ]
      [  92  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  506  60  -1  4  ]
      [  53  2  8  -1  -1  -1  -1  -1  -1  1  -1  2  652  60  340  4  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  3  3  3  571  60  0  4  ]
      [  19  1  8  -1  -1  -1  -1  -1  -1  -1  3  4  677  60  0  4  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  592  60  -1  4  ]
      [  66  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  513  60  248  4  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  4  507  60  -1  4  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  -1  3  3  663  60  -1  4  ]
      [  50  2  1  5  923  73  8  20  12  -1  -1  1  687  60  270  4  ]
      [  22  2  1  6  912  55  8  12  15  3  -1  1  540  60  360  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  3  3  529  60  -1  4  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  -1  -1  2  540  60  -1  4  ]
      [  55  2  8  -1  -1  -1  -1  -1  11  1  -1  2  571  60  255  4  ]
      [  27  2  8  5  912  55  8  10  11  4  3  1  628  60  250  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  3  3  660  60  -1  8  ]
      [  61  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  698  60  270  7  ]
      [  22  1  8  -1  -1  -1  -1  -1  15  5  -1  8  675  60  400  8  ]
      [  75  2  8  -1  -1  -1  -1  -1  11  1  -1  3  554  60  266  4  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  507  60  -1  6  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  652  60  -1  4  ]
      [  23  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  552  60  -1  4  ]
      [  23  1  8  -1  -1  -1  -1  -1  16  5  -1  4  550  60  348  4  ]
      [  62  2  8  -1  -1  -1  -1  -1  8  1  -1  3  539  60  205  4  ]
      [  23  2  8  -1  -1  -1  -1  -1  11  -1  -1  6  561  60  261  4  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  532  60  0  4  ]
      [  60  2  8  -1  -1  -1  -1  -1  8  1  -1  3  539  60  200  4  ]
      [  81  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  517  60  250  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  657  60  -1  5  ]
      [  61  1  1  1  670  52  8  46  -1  1  3  1  618  60  0  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  4  5  3  672  60  -1  7  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  700  60  -1  4  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  620  60  0  4  ]
      [  25  2  8  -1  -1  -1  -1  -1  10  2  3  2  629  60  231  7  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  1  3  3  621  60  -1  4  ]
      [  34  1  8  -1  -1  -1  -1  -1  -1  2  3  2  514  60  -1  7  ]
      [  25  2  1  5  853  85  8  6  -1  3  3  2  662  60  -1  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  14  1  -1  3  567  60  334  4  ]
      [  22  2  1  6  662  52  8  40  9  3  3  1  621  60  225  5  ]
      [  43  1  8  5  879  80  1  8  12  5  9  2  564  60  300  11  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  578  60  -1  4  ]
      [  54  2  8  -1  -1  -1  -1  -1  11  1  5  3  513  60  275  4  ]
      [  46  2  8  -1  -1  -1  -1  -1  11  2  3  2  618  60  244  8  ]
      [  49  1  8  -1  -1  -1  -1  -1  -1  2  5  3  587  60  -1  15  ]
      [  63  1  8  -1  -1  -1  -1  -1  8  1  3  3  519  60  200  7  ]
      [  20  2  8  -1  -1  -1  -1  -1  10  -1  5  8  536  60  210  4  ]
      [  23  2  8  5  912  55  8  40  17  3  3  1  851  60  400  5  ]
      [  58  1  1  5  997  51  8  4  10  -1  -1  1  797  60  240  9  ]
      [  69  2  8  -1  -1  -1  -1  -1  13  3  3  3  863  60  298  5  ]
      [  25  2  1  5  867  95  8  25  11  3  5  1  869  60  245  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  863  60  -1  5  ]
      [  42  1  8  -1  -1  -1  -1  -1  17  1  3  6  870  60  408  13  ]
      [  68  1  8  -1  -1  -1  -1  -1  12  1  3  3  803  60  300  6  ]
      [  38  2  1  5  702  66  8  20  16  1  3  1  783  60  375  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  19  1  -1  3  783  60  499  5  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  702  60  0  8  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  788  60  -1  5  ]
      [  43  1  8  -1  -1  -1  -1  -1  15  1  3  2  893  60  300  5  ]
      [  88  2  8  -1  -1  -1  -1  -1  14  1  -1  3  895  60  320  5  ]
      [  60  1  1  1  934  45  8  30  -1  1  3  1  770  60  -1  7  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  739  60  -1  5  ]
      [  90  1  8  -1  -1  -1  -1  -1  13  1  -1  3  717  60  300  5  ]
      [  87  2  8  -1  -1  -1  -1  -1  17  1  -1  3  882  60  280  5  ]
      [  26  2  8  -1  -1  -1  -1  -1  -1  1  3  2  704  60  -1  5  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  3  3  888  60  -1  5  ]
      [  58  1  8  -1  -1  -1  -1  -1  9  5  9  2  822  60  245  11  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  856  60  -1  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  10  1  -1  3  786  60  204  5  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  9  -1  3  744  60  350  5  ]
      [  57  1  8  -1  -1  -1  -1  -1  11  1  3  8  766  60  270  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  14  -1  -1  2  717  60  300  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  773  60  260  5  ]
      [  58  1  8  -1  -1  -1  -1  -1  12  1  3  3  758  60  279  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  11  1  -1  3  867  60  300  7  ]
      [  50  1  1  6  546  45  8  45  10  9  4  1  771  60  231  5  ]
      [  26  1  1  6  531  34  8  40  10  1  3  1  786  60  238  5  ]
      [  69  2  8  -1  -1  -1  -1  -1  11  1  -1  3  851  60  250  5  ]
      [  41  1  8  -1  -1  -1  -1  -1  8  -1  -1  6  860  60  190  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  792  60  -1  5  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  4  3  763  60  0  5  ]
      [  57  1  8  -1  -1  -1  -1  -1  13  1  5  3  730  60  300  11  ]
      [  88  2  8  -1  -1  -1  -1  -1  9  1  -1  3  731  60  216  5  ]
      [  91  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  758  60  -1  5  ]
      [  30  1  1  6  661  55  8  48  16  -1  -1  1  881  60  400  6  ]
      [  69  1  8  3  11  1  8  15  -1  1  1  3  860  60  -1  9  ]
      [  72  2  1  6  992  28  8  25  10  1  3  1  735  60  240  5  ]
      [  60  1  8  -1  -1  -1  -1  -1  8  1  3  2  900  60  170  5  ]
      [  26  1  8  -1  -1  -1  -1  -1  15  4  8  4  802  60  400  11  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  782  60  0  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  841  60  0  5  ]
      [  67  1  8  -1  -1  -1  -1  -1  10  1  -1  3  758  60  190  6  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  767  60  -1  5  ]
      [  23  2  1  5  853  85  8  5  15  5  -1  8  792  60  375  5  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  777  60  -1  5  ]
      [  48  1  1  6  281  50  8  40  11  3  5  1  789  60  250  5  ]
      [  44  1  1  6  51  95  8  22  10  1  3  1  859  60  210  5  ]
      [  68  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  711  60  324  8  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  805  60  -1  5  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  832  60  203  5  ]
      [  70  2  8  -1  -1  -1  -1  -1  8  1  -1  3  762  60  180  5  ]
      [  48  1  1  6  391  15  8  50  -1  2  3  1  867  60  -1  5  ]
      [  48  2  8  -1  -1  -1  -1  -1  10  -1  -1  2  727  60  200  5  ]
      [  46  1  1  6  915  55  8  40  13  2  3  1  770  60  284  11  ]
      [  29  1  1  5  662  52  8  40  16  2  3  1  705  60  382  5  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  1  3  3  724  60  300  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  10  -1  1  3  731  60  243  7  ]
      [  71  2  8  -1  -1  -1  -1  -1  10  1  3  3  728  60  248  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  13  1  3  3  767  60  305  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  896  60  -1  7  ]
      [  69  1  8  -1  -1  -1  -1  -1  12  1  3  3  710  60  288  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  13  1  3  3  841  60  332  8  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  3  3  726  60  -1  5  ]
      [  59  1  8  -1  -1  -1  -1  -1  19  4  9  2  707  60  400  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  3  3  728  60  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  10  1  3  3  786  60  240  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  892  60  -1  8  ]
      [  54  1  1  5  689  52  8  40  13  3  3  1  769  60  300  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  861  60  186  5  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  3  3  834  60  -1  5  ]
      [  66  1  8  -1  -1  -1  -1  -1  15  1  -1  3  795  60  400  9  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  747  60  -1  9  ]
      [  46  2  1  5  911  55  8  40  12  2  3  1  878  60  274  5  ]
      [  45  1  1  6  531  50  8  20  -1  -1  -1  1  844  60  -1  5  ]
      [  45  2  1  5  863  80  1  22  -1  2  6  1  870  60  -1  6  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  743  60  -1  5  ]
      [  29  2  1  6  51  74  8  40  9  2  -1  1  749  60  230  13  ]
      [  24  1  1  6  269  50  8  38  -1  2  3  1  737  60  -1  5  ]
      [  66  1  8  -1  -1  -1  -1  -1  6  2  3  3  782  60  160  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1051  60  -1  6  ]
      [  36  2  1  5  912  55  8  50  -1  3  3  1  1097  60  -1  6  ]
      [  88  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  971  60  -1  6  ]
      [  34  2  1  5  786  74  8  40  12  3  3  1  976  60  250  6  ]
      [  50  2  1  5  854  85  8  20  13  3  3  1  933  60  330  6  ]
      [  80  1  8  -1  -1  -1  -1  -1  15  -1  -1  3  1031  60  340  9  ]
      [  82  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  961  60  320  6  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1053  60  -1  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  915  60  -1  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  9  1  3  3  995  60  200  7  ]
      [  78  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  910  60  216  6  ]
      [  46  1  1  6  488  45  8  40  -1  1  3  1  1061  60  -1  11  ]
      [  53  2  1  6  997  93  8  20  12  1  3  1  1073  60  250  12  ]
      [  26  2  1  5  787  75  1  38  13  3  3  1  920  60  306  10  ]
      [  85  2  8  -1  -1  -1  -1  -1  13  1  -1  3  982  60  350  6  ]
      [  34  2  1  5  714  64  8  18  12  1  3  1  1034  60  300  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1058  60  226  6  ]
      [  30  1  1  5  911  55  8  60  15  5  3  1  925  60  400  7  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  960  60  -1  6  ]
      [  45  1  1  6  531  28  8  38  6  1  -1  1  974  60  110  9  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1100  60  170  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1053  60  325  9  ]
      [  45  2  1  6  269  28  8  37  9  1  -1  1  1058  60  229  6  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1059  60  -1  6  ]
      [  78  2  8  -1  -1  -1  -1  -1  10  3  3  3  1071  60  220  6  ]
      [  43  1  8  -1  -1  -1  -1  -1  14  1  3  6  913  60  304  6  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1022  60  225  7  ]
      [  33  1  8  6  481  45  8  20  12  1  3  1  900  60  300  6  ]
      [  35  2  1  6  391  15  8  30  7  -1  -1  1  1075  60  160  6  ]
      [  49  2  1  5  876  92  8  25  13  1  3  1  1002  60  330  6  ]
      [  74  2  8  -1  -1  -1  -1  -1  18  1  3  3  937  60  480  6  ]
      [  57  2  1  2  753  74  8  70  31  -1  -1  1  951  60  800  6  ]
      [  95  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1040  60  -1  6  ]
      [  31  1  1  5  780  15  8  60  -1  9  -1  1  1058  60  -1  10  ]
      [  38  1  1  6  411  55  8  40  13  1  3  1  1005  60  306  6  ]
      [  42  1  1  1  871  80  8  20  -1  3  5  1  965  60  0  10  ]
      [  78  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1012  60  210  6  ]
      [  37  2  1  6  540  33  8  35  -1  4  3  1  1052  60  -1  6  ]
      [  20  1  1  5  712  60  8  38  9  3  4  1  1085  60  223  6  ]
      [  78  1  8  -1  -1  -1  -1  -1  11  1  3  3  967  60  275  6  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  5  9  3  939  60  -1  6  ]
      [  63  1  1  6  254  28  8  4  -1  1  4  3  928  60  -1  11  ]
      [  82  2  8  -1  -1  -1  -1  -1  8  1  -1  3  1093  60  185  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1029  60  -1  6  ]
      [  34  1  1  6  401  15  8  45  11  2  3  1  982  60  238  6  ]
      [  45  2  1  5  671  51  8  30  11  2  3  1  1018  60  270  6  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  1  3  1063  60  -1  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  16  3  3  3  991  60  414  6  ]
      [  37  1  1  5  863  85  8  36  9  3  3  1  901  60  214  9  ]
      [  70  1  8  -1  -1  -1  -1  -1  9  1  3  3  1047  60  215  9  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  968  60  0  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  7  1  3  3  1037  60  180  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  1  3  3  947  60  315  10  ]
      [  68  1  8  -1  -1  -1  -1  -1  9  1  3  3  985  60  210  10  ]
      [  42  2  1  5  642  74  8  40  9  2  3  1  941  60  230  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  5  9  3  1014  60  -1  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1026  60  0  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  8  1  3  3  1017  60  146  10  ]
      [  87  2  8  -1  -1  -1  -1  -1  11  1  3  3  1036  60  300  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  955  60  -1  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  4  3  918  60  0  6  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  932  60  -1  9  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1057  60  240  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  15  1  1  3  1006  60  300  10  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  961  60  -1  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  9  1  3  3  1015  60  195  9  ]
      [  66  2  8  -1  -1  -1  -1  -1  12  2  6  3  1095  60  302  6  ]
      [  24  1  1  6  255  28  8  40  12  3  3  1  1068  60  290  6  ]
      [  51  1  1  6  441  1  8  40  10  1  3  1  1057  60  223  9  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  904  60  -1  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  12  1  3  3  1254  60  300  10  ]
      [  30  1  1  6  742  51  8  38  12  1  99  1  1225  60  330  7  ]
      [  63  1  8  6  796  70  8  5  -1  1  3  3  1276  60  200  11  ]
      [  41  1  1  6  460  45  8  40  9  1  1  1  1260  60  200  7  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1286  60  -1  7  ]
      [  71  2  8  -1  -1  -1  -1  -1  15  1  3  3  1278  60  404  7  ]
      [  27  2  1  5  642  45  8  40  13  5  3  1  1103  60  305  7  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1298  60  -1  7  ]
      [  30  2  1  5  863  80  8  30  -1  5  8  1  1271  60  -1  12  ]
      [  90  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1146  60  260  11  ]
      [  51  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1204  60  -1  7  ]
      [  32  1  1  5  853  85  8  39  -1  1  3  1  1138  60  -1  12  ]
      [  48  2  1  5  863  80  8  25  -1  5  5  1  1203  60  -1  14  ]
      [  79  2  8  -1  -1  -1  -1  -1  12  1  1  3  1156  60  260  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  17  3  3  3  1282  60  350  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  14  1  3  3  1262  60  360  7  ]
      [  59  1  1  5  714  63  8  65  14  1  3  1  1177  60  350  7  ]
      [  34  2  1  5  701  63  8  30  15  5  9  1  1191  60  330  10  ]
      [  51  1  1  6  488  45  8  45  16  1  3  1  1114  60  400  7  ]
      [  35  1  8  -1  -1  -1  -1  -1  12  5  9  2  1259  60  300  8  ]
      [  28  1  1  6  511  45  8  38  19  3  3  1  1150  60  400  7  ]
      [  58  2  1  5  691  65  1  37  -1  1  3  1  1268  60  -1  7  ]
      [  36  1  1  6  997  45  8  40  34  1  -1  1  1209  60  900  7  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1145  60  -1  7  ]
      [  51  1  1  6  152  25  8  40  11  1  3  1  1161  60  270  7  ]
      [  49  1  1  6  531  36  8  40  11  1  -1  1  1188  60  250  7  ]
      [  56  1  1  6  290  29  8  35  16  3  3  1  1140  60  350  7  ]
      [  64  2  1  5  772  74  8  12  -1  1  3  3  1116  60  -1  7  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1211  60  -1  7  ]
      [  24  2  1  5  703  22  8  38  12  3  3  1  1229  60  307  7  ]
      [  25  1  1  6  550  35  8  44  9  -1  -1  1  1279  60  220  14  ]
      [  61  1  8  -1  -1  -1  -1  -1  19  3  3  3  1228  60  500  13  ]
      [  64  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  1245  60  250  7  ]
      [  54  1  1  5  620  74  8  40  23  1  99  1  1196  60  475  12  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1181  60  -1  10  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1176  60  -1  7  ]
      [  25  1  1  6  835  92  8  42  -1  3  3  1  1165  60  -1  9  ]
      [  46  2  1  5  789  80  1  39  -1  3  3  1  1205  60  -1  13  ]
      [  65  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  1159  60  230  7  ]
      [  58  1  1  6  714  99  8  38  9  1  3  1  1220  60  200  9  ]
      [  31  1  1  5  780  51  8  38  10  3  3  1  1122  60  250  12  ]
      [  31  1  1  6  726  62  8  39  8  1  -1  1  1267  60  190  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1167  60  -1  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  1  3  1292  60  0  7  ]
      [  48  2  1  5  787  91  1  31  -1  1  3  1  1103  60  -1  9  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1229  60  280  7  ]
      [  81  2  8  -1  -1  -1  -1  -1  12  3  3  3  1202  60  299  7  ]
      [  53  2  1  5  923  95  8  39  10  5  99  1  1160  60  225  7  ]
      [  57  2  1  5  823  92  1  39  13  -1  99  1  1115  60  305  7  ]
      [  33  1  1  5  662  52  8  40  -1  1  3  1  1130  60  -1  9  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1196  60  -1  10  ]
      [  73  2  8  -1  -1  -1  -1  -1  16  1  -1  3  1299  60  400  15  ]
      [  68  1  8  -1  -1  -1  -1  -1  17  -1  -1  3  1127  60  465  11  ]
      [  26  2  1  5  673  52  8  40  13  3  99  1  1208  60  295  7  ]
      [  82  1  8  -1  -1  -1  -1  -1  6  1  3  3  1243  60  155  7  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1112  60  336  7  ]
      [  60  1  1  6  803  45  8  40  -1  -1  -1  1  1154  60  -1  7  ]
      [  39  1  1  6  540  45  8  38  16  1  3  1  1195  60  450  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  9  1  1  3  1154  60  210  7  ]
      [  47  1  1  5  521  51  8  39  -1  5  5  1  1152  60  -1  7  ]
      [  53  2  1  6  531  24  8  40  10  1  -1  1  1258  60  200  11  ]
      [  20  2  1  5  785  72  8  38  6  3  4  1  1277  60  150  7  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1181  60  -1  7  ]
      [  57  1  1  6  522  26  8  38  10  1  3  1  1243  60  280  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1215  60  -1  11  ]
      [  26  1  1  6  714  64  8  37  -1  1  -1  1  1296  60  -1  7  ]
      [  44  2  1  6  522  34  8  35  11  1  3  1  1282  60  270  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1173  60  -1  7  ]
      [  28  1  1  5  788  85  1  39  6  5  3  1  1225  60  150  11  ]
      [  71  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  1229  60  325  7  ]
      [  64  2  8  -1  -1  -1  -1  -1  8  1  3  3  1257  60  200  7  ]
      [  92  1  8  -1  -1  -1  -1  -1  9  1  3  3  1222  60  160  7  ]
      [  37  2  1  2  852  85  8  40  12  5  5  1  1238  60  280  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  12  1  3  3  1175  60  282  7  ]
      [  71  2  8  -1  -1  -1  -1  -1  12  5  9  3  1153  60  219  13  ]
      [  68  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1258  60  281  7  ]
      [  49  1  1  6  313  29  8  39  -1  2  3  1  1244  60  -1  7  ]
      [  29  1  1  5  673  52  8  40  13  2  3  1  1114  60  325  11  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  6  3  1278  60  -1  9  ]
      [  46  2  1  5  823  92  1  40  13  5  9  1  1251  60  221  7  ]
      [  36  1  1  5  691  67  8  40  -1  2  4  1  1248  60  -1  7  ]
      [  67  1  1  5  792  74  8  15  12  9  99  3  1283  60  287  12  ]
      [  65  1  8  -1  -1  -1  -1  -1  17  -1  -1  3  1202  60  341  10  ]
      [  49  1  1  5  787  75  1  39  15  5  3  1  1114  60  354  10  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1186  60  -1  7  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  6  3  1154  60  232  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  12  1  1  3  1134  60  282  10  ]
      [  37  1  1  6  313  31  8  38  10  2  3  1  1280  60  231  12  ]
      [  83  2  8  -1  -1  -1  -1  -1  8  1  3  3  1203  60  180  7  ]
      [  24  2  1  5  858  85  8  40  12  3  5  1  1272  60  320  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  10  1  8  3  1279  60  252  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1127  60  -1  10  ]
      [  51  1  1  6  62  1  1  40  -1  1  -1  1  1148  60  250  10  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1260  60  -1  7  ]
      [  62  2  8  -1  -1  -1  -1  -1  10  1  3  3  1290  60  230  7  ]
      [  74  2  8  -1  -1  -1  -1  -1  8  5  9  3  1293  60  183  7  ]
      [  27  1  1  5  780  45  8  40  9  3  3  1  1143  60  186  9  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  1  6  3  1296  60  290  7  ]
      [  30  1  1  6  274  35  8  38  10  2  3  1  1217  60  243  9  ]
      [  44  1  1  6  465  75  1  39  11  1  -1  1  1496  60  253  9  ]
      [  38  2  1  5  856  85  8  39  19  3  3  1  1400  60  505  8  ]
      [  58  2  1  5  787  75  1  38  16  1  3  1  1309  60  369  8  ]
      [  94  2  8  -1  -1  -1  -1  -1  12  4  7  3  1431  60  300  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  9  -1  3  1380  60  0  8  ]
      [  46  1  1  5  622  80  1  37  -1  1  5  1  1315  60  300  8  ]
      [  43  1  1  6  312  64  8  39  -1  1  3  1  1350  60  -1  14  ]
      [  46  2  1  5  788  99  8  38  15  3  5  1  1354  60  310  8  ]
      [  25  1  1  9  801  75  1  45  12  1  3  1  1467  60  285  10  ]
      [  48  1  1  6  541  52  8  40  11  3  -1  1  1346  60  300  12  ]
      [  54  1  8  -1  -1  -1  -1  -1  11  1  99  2  1470  60  250  13  ]
      [  33  2  1  5  780  74  8  38  16  5  99  1  1424  60  385  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  12  1  3  3  1434  60  262  8  ]
      [  32  1  8  -1  -1  -1  -1  -1  13  3  3  2  1323  60  320  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1444  60  -1  8  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1476  60  -1  8  ]
      [  31  1  1  6  511  45  8  37  -1  1  3  1  1372  60  0  14  ]
      [  70  2  8  -1  -1  -1  -1  -1  9  1  3  3  1390  60  210  8  ]
      [  43  2  1  5  609  74  8  40  15  5  8  1  1388  60  330  8  ]
      [  35  1  1  6  201  27  8  37  14  1  3  1  1446  60  300  8  ]
      [  43  1  1  6  142  74  8  38  -1  -1  1  1  1461  60  -1  13  ]
      [  40  2  1  5  912  55  8  40  21  3  3  1  1455  60  550  8  ]
      [  57  1  1  5  521  24  8  38  15  3  3  1  1349  60  400  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1468  60  -1  14  ]
      [  40  2  1  5  677  62  8  30  17  1  3  1  1454  60  304  9  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1466  60  -1  9  ]
      [  49  2  1  5  853  85  1  38  12  3  3  1  1374  60  270  8  ]
      [  27  1  1  1  702  63  8  70  -1  5  -1  1  1436  60  -1  14  ]
      [  32  2  1  5  691  65  8  40  16  5  9  1  1326  60  440  8  ]
      [  33  1  1  5  701  63  8  40  13  1  3  1  1405  60  280  8  ]
      [  28  1  1  6  540  28  8  38  18  1  3  1  1436  60  425  12  ]
      [  27  1  1  5  267  45  8  39  8  1  3  1  1425  60  190  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1489  60  -1  8  ]
      [  28  2  8  5  672  52  8  38  14  3  3  8  1352  60  302  8  ]
      [  69  2  8  -1  -1  -1  -1  -1  10  1  3  3  1452  60  244  8  ]
      [  28  1  1  6  744  52  8  40  -1  -1  -1  1  1477  60  400  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  13  1  3  3  1334  60  350  8  ]
      [  37  1  1  4  731  64  8  39  12  1  3  1  1397  60  300  13  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  4  3  1330  60  -1  12  ]
      [  30  1  1  5  785  18  8  37  15  5  3  1  1358  60  385  8  ]
      [  43  1  1  5  270  28  8  35  12  3  5  1  1498  60  250  8  ]
      [  57  1  1  6  714  75  1  39  -1  1  3  1  1332  60  -1  13  ]
      [  70  1  8  -1  -1  -1  -1  -1  15  1  3  3  1478  60  400  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1478  60  238  12  ]
      [  33  1  1  6  274  20  8  36  8  2  3  1  1308  60  200  8  ]
      [  37  1  1  5  789  74  1  38  7  1  4  1  1444  60  153  8  ]
      [  54  1  1  6  714  60  8  40  -1  9  3  1  1448  60  -1  8  ]
      [  30  2  1  5  780  25  8  39  13  3  4  1  1447  60  260  8  ]
      [  37  1  1  6  714  60  8  40  12  1  3  1  1483  60  300  11  ]
      [  76  1  8  -1  -1  -1  -1  -1  11  1  3  3  1355  60  255  8  ]
      [  60  2  1  5  881  63  8  37  15  1  4  1  1377  60  353  8  ]
      [  73  2  8  -1  -1  -1  -1  -1  10  1  3  3  1354  60  240  8  ]
      [  47  1  1  6  741  15  8  40  11  1  3  1  1427  60  250  9  ]
      [  49  2  1  5  861  80  8  38  14  5  8  1  1478  60  360  8  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  99  3  1428  60  -1  8  ]
      [  33  1  1  5  620  91  8  35  -1  5  -1  1  1358  60  -1  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  14  3  -1  3  1331  60  380  8  ]
      [  54  1  1  6  371  19  8  38  11  1  -1  1  1461  60  255  11  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1474  60  -1  10  ]
      [  80  2  8  -1  -1  -1  -1  -1  10  3  3  3  1426  60  250  8  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1486  60  -1  9  ]
      [  60  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1473  60  207  8  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1409  60  0  8  ]
      [  39  1  1  6  311  40  8  40  12  2  3  1  1440  60  280  11  ]
      [  28  1  1  4  801  75  1  40  8  5  3  1  1475  60  174  12  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  4  8  3  1458  60  -1  13  ]
      [  37  1  1  5  441  45  8  40  8  2  3  1  1334  60  174  12  ]
      [  61  1  8  -1  -1  -1  -1  -1  9  4  9  3  1435  60  181  13  ]
      [  62  1  1  6  273  40  1  40  12  1  3  1  1414  60  275  11  ]
      [  71  1  8  -1  -1  -1  -1  -1  10  2  6  3  1464  60  250  12  ]
      [  69  1  8  -1  -1  -1  -1  -1  10  1  3  3  1537  60  231  9  ]
      [  32  1  1  6  549  15  8  39  -1  3  3  1  1506  60  0  9  ]
      [  44  1  1  5  854  85  1  38  12  4  6  1  1573  60  280  12  ]
      [  25  1  1  9  801  75  1  40  12  3  3  1  1648  60  330  13  ]
      [  43  1  1  6  501  36  8  35  11  1  3  1  1602  60  257  9  ]
      [  34  2  1  5  780  29  8  35  9  1  3  1  1656  60  207  9  ]
      [  41  1  1  6  231  34  8  38  15  1  3  1  1591  60  375  9  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  5  3  3  1696  60  0  9  ]
      [  76  2  8  -1  -1  -1  -1  -1  9  -1  -1  3  1684  60  200  9  ]
      [  44  1  1  6  273  29  8  39  -1  3  5  1  1565  60  -1  9  ]
      [  53  1  1  5  741  29  8  35  21  5  -1  1  1596  60  550  13  ]
      [  34  1  1  5  757  65  8  16  -1  5  9  1  1600  60  -1  9  ]
      [  47  1  1  6  620  34  8  40  -1  5  3  1  1525  60  -1  9  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  3  -1  3  1543  60  -1  9  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1511  60  -1  11  ]
      [  40  1  1  6  713  93  8  40  11  1  3  1  1540  60  250  14  ]
      [  28  2  1  5  881  65  8  39  13  5  8  1  1577  60  325  9  ]
      [  42  1  1  5  785  52  8  39  11  5  3  1  1562  60  263  9  ]
      [  29  1  1  5  703  92  8  40  17  3  3  1  1523  60  420  9  ]
      [  31  1  1  5  676  52  8  40  13  1  5  1  1582  60  330  9  ]
      [  48  1  1  5  780  74  8  39  11  1  3  1  1570  60  245  14  ]
      [  95  2  8  -1  -1  -1  -1  -1  16  3  3  3  1527  60  322  9  ]
      [  80  2  8  -1  -1  -1  -1  -1  13  5  -1  3  1665  60  300  9  ]
      [  54  1  1  5  765  75  1  40  15  2  8  1  1607  60  354  13  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1630  60  -1  9  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1662  60  250  9  ]
      [  29  1  1  4  801  75  1  40  -1  2  4  1  1669  60  -1  15  ]
      [  66  2  8  -1  -1  -1  -1  -1  10  1  3  3  1527  60  180  11  ]
      [  37  1  1  6  241  45  8  40  10  2  3  1  1641  60  250  11  ]
      [  28  2  1  4  765  75  1  40  11  5  7  1  1681  60  250  14  ]
      [  39  1  1  1  442  45  8  38  13  1  3  1  1824  60  350  10  ]
      [  32  1  1  4  801  75  1  40  23  4  8  1  1930  60  600  10  ]
      [  72  2  8  -1  -1  -1  -1  -1  24  3  4  3  1904  60  600  10  ]
      [  74  2  8  -1  -1  -1  -1  -1  13  1  3  3  1955  60  281  10  ]
      [  32  1  1  5  603  45  8  39  11  5  8  1  1785  60  240  13  ]
      [  68  2  8  -1  -1  -1  -1  -1  11  1  3  3  1885  60  250  11  ]
      [  58  1  1  5  721  61  8  48  -1  3  5  1  1753  60  -1  10  ]
      [  44  1  1  5  751  24  8  70  -1  1  3  1  1976  60  -1  14  ]
      [  49  1  1  5  521  27  8  35  -1  4  3  1  1886  60  -1  13  ]
      [  39  2  1  5  764  75  1  45  19  4  9  1  1818  60  460  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  11  1  -1  3  1930  60  270  10  ]
      [  56  1  1  6  714  71  8  48  13  -1  -1  1  1730  60  320  10  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1914  60  -1  10  ]
      [  44  1  1  5  411  80  1  38  -1  1  3  1  1713  60  -1  10  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1754  60  0  10  ]
      [  27  1  1  5  775  33  8  38  17  5  8  1  1807  60  485  10  ]
      [  66  1  1  6  714  60  8  12  -1  1  3  1  1848  60  0  18  ]
      [  49  2  1  5  789  66  8  38  21  4  8  1  1823  60  445  10  ]
      [  24  2  1  4  765  75  1  38  13  5  8  1  1820  60  320  10  ]
      [  57  1  1  5  714  60  8  43  12  -1  -1  1  1792  60  250  11  ]
      [  77  2  8  -1  -1  -1  -1  -1  7  3  3  3  1804  60  155  10  ]
      [  44  2  1  5  788  75  1  40  12  5  7  1  1911  60  257  10  ]
      [  45  1  1  5  600  29  8  40  -1  5  9  1  1807  60  -1  14  ]
      [  48  2  1  5  789  74  8  40  -1  1  3  1  2163  60  -1  11  ]
      [  21  1  1  6  141  28  8  38  11  3  3  1  2201  60  230  11  ]
      [  40  1  1  5  750  50  8  50  18  5  3  1  2240  60  436  11  ]
      [  30  2  1  5  881  64  8  40  18  5  8  1  2078  60  500  15  ]
      [  48  1  1  4  787  60  8  39  10  3  5  1  2220  60  250  15  ]
      [  29  1  1  6  540  28  8  40  13  1  -1  1  2232  60  297  11  ]
      [  44  1  1  4  801  75  1  39  11  3  3  1  2078  60  250  11  ]
      [  25  1  1  5  750  55  8  40  14  3  -1  1  2162  60  325  11  ]
      [  35  1  1  5  785  60  8  39  13  3  3  1  2098  60  300  14  ]
      [  58  1  8  5  714  85  8  15  12  1  3  3  2235  60  290  13  ]
      [  46  1  1  6  290  34  8  35  -1  1  3  1  2067  60  400  14  ]
      [  54  1  1  1  757  74  8  60  11  1  3  1  2089  60  252  11  ]
      [  28  2  1  5  813  70  8  40  -1  5  9  1  2006  60  -1  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  2234  60  400  11  ]
      [  48  1  1  6  310  40  8  38  -1  1  3  1  2014  60  -1  16  ]
      [  34  1  1  5  751  33  8  40  18  4  8  1  2295  60  350  11  ]
      [  39  1  1  6  487  45  8  40  13  1  3  1  2126  60  320  14  ]
      [  86  1  8  -1  -1  -1  -1  -1  7  1  -1  3  2168  60  130  11  ]
      [  37  1  1  4  811  75  1  40  18  5  9  1  2416  60  450  12  ]
      [  56  1  1  4  870  80  1  39  -1  5  7  1  2412  60  -1  12  ]
      [  48  1  1  4  801  75  1  39  13  4  5  1  2398  60  297  16  ]
      [  54  1  1  5  692  66  8  38  -1  -1  -1  1  2349  60  -1  12  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  9  99  3  2574  60  -1  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  15  1  -1  3  2428  60  370  14  ]
      [  29  1  1  5  612  66  8  40  19  5  9  1  2301  60  540  14  ]
      [  40  1  1  6  254  45  8  38  -1  2  3  1  2549  60  -1  16  ]
      [  79  2  8  -1  -1  -1  -1  -1  23  5  10  3  2891  60  600  13  ]
      [  31  1  1  5  142  80  1  38  20  5  9  1  2660  60  545  13  ]
      [  68  1  1  2  794  55  8  50  -1  1  -1  1  2945  60  -1  15  ]
      [  54  1  1  1  174  22  8  60  9  1  3  1  3008  60  208  14  ]
      [  36  1  1  1  774  74  8  90  9  4  8  1  3074  60  204  14  ]
      [  55  1  1  5  622  33  8  40  -1  1  5  1  3492  60  -1  15  ]
      [  38  1  1  5  691  65  8  57  23  5  3  1  3358  60  630  20  ]
      [  38  2  1  5  750  29  8  35  -1  5  9  1  3585  60  -1  15  ]
      [  48  2  1  5  772  29  8  40  -1  3  3  1  3976  60  0  16  ]
      [  35  1  1  5  622  45  8  39  6  4  5  1  4489  60  100  17  ]
      [  34  1  1  5  753  74  8  40  7  5  5  1  4129  60  150  17  ]
      [  50  2  1  1  834  74  8  50  37  3  99  1  5317  60  960  19  ]
      [  57  1  1  5  841  85  8  60  -1  5  10  1  7819  60  -1  23  ]
      [  40  2  1  1  609  22  8  40  -1  5  8  1  8644  60  -1  23  ]
      [  35  2  8  -1  -1  -1  -1  -1  9  5  -1  6  167  59  180  4  ]
      [  19  2  8  -1  -1  -1  -1  -1  10  5  -1  8  219  59  260  3  ]
      [  33  1  8  -1  -1  -1  -1  -1  12  1  1  2  346  59  291  3  ]
      [  49  2  8  -1  -1  -1  -1  -1  13  1  3  6  410  59  300  8  ]
      [  39  2  8  -1  -1  -1  -1  -1  10  2  3  2  489  59  212  3  ]
      [  26  1  8  -1  -1  -1  -1  -1  -1  1  4  2  535  59  -1  4  ]
      [  69  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  573  59  275  4  ]
      [  25  1  8  -1  -1  -1  -1  -1  11  3  3  2  558  59  205  4  ]
      [  47  2  8  -1  -1  -1  -1  -1  10  1  -1  3  507  59  200  4  ]
      [  65  1  8  -1  -1  -1  -1  -1  13  1  -1  3  616  59  314  9  ]
      [  58  2  8  -1  -1  -1  -1  -1  12  1  3  3  550  59  250  4  ]
      [  62  2  8  -1  -1  -1  -1  -1  17  1  3  3  726  59  390  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  21  -1  -1  3  880  59  500  5  ]
      [  51  2  8  -1  -1  -1  -1  -1  13  1  3  2  803  59  275  9  ]
      [  67  2  8  -1  -1  -1  -1  -1  16  1  -1  3  758  59  384  5  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  716  59  -1  5  ]
      [  64  2  8  -1  -1  -1  -1  -1  12  1  3  3  893  59  270  5  ]
      [  69  1  8  -1  -1  -1  -1  -1  9  1  3  3  774  59  230  7  ]
      [  71  2  8  -1  -1  -1  -1  -1  11  1  -1  3  781  59  259  5  ]
      [  72  1  8  -1  -1  -1  -1  -1  9  1  3  3  762  59  210  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  1  3  3  869  59  268  8  ]
      [  70  2  8  -1  -1  -1  -1  -1  11  1  6  3  884  59  255  8  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  1  5  3  744  59  201  9  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  1  3  3  778  59  266  7  ]
      [  83  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1098  59  -1  10  ]
      [  53  1  1  6  522  22  8  40  13  1  -1  1  935  59  300  6  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  927  59  332  6  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  969  59  -1  6  ]
      [  31  2  1  5  870  80  1  24  -1  5  9  1  940  59  415  12  ]
      [  75  2  8  -1  -1  -1  -1  -1  10  1  -1  3  953  59  223  9  ]
      [  55  1  8  -1  -1  -1  -1  -1  15  3  -1  3  933  59  380  10  ]
      [  84  1  8  -1  -1  -1  -1  -1  11  1  3  3  1063  59  226  6  ]
      [  86  2  8  -1  -1  -1  -1  -1  8  1  3  3  1086  59  165  6  ]
      [  70  2  8  -1  -1  -1  -1  -1  10  3  6  3  1084  59  190  6  ]
      [  33  1  1  6  461  1  8  40  12  2  3  1  982  59  175  10  ]
      [  80  1  8  -1  -1  -1  -1  -1  8  3  3  3  1096  59  169  10  ]
      [  51  1  8  5  677  51  8  5  8  5  6  2  1047  59  171  11  ]
      [  26  2  1  5  691  65  8  40  8  5  3  1  981  59  179  6  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  5  9  3  940  59  238  9  ]
      [  68  1  8  -1  -1  -1  -1  -1  10  1  6  3  1034  59  233  10  ]
      [  67  2  8  -1  -1  -1  -1  -1  11  1  3  3  910  59  249  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  12  1  5  3  996  59  270  9  ]
      [  67  1  8  -1  -1  -1  -1  -1  11  1  3  3  993  59  260  8  ]
      [  31  1  1  5  863  80  1  38  23  2  6  1  1199  59  450  7  ]
      [  73  2  8  -1  -1  -1  -1  -1  11  3  5  3  1143  59  250  7  ]
      [  86  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1170  59  200  7  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  5  5  3  1237  59  -1  11  ]
      [  47  2  1  5  856  85  8  32  12  3  4  1  1284  59  307  7  ]
      [  22  2  1  5  692  67  8  39  5  5  3  1  1137  59  95  12  ]
      [  42  1  1  1  411  55  8  45  15  3  3  1  1105  59  305  7  ]
      [  61  2  8  -1  -1  -1  -1  -1  10  1  3  3  1206  59  208  7  ]
      [  41  1  8  -1  -1  -1  -1  -1  13  5  8  2  1205  59  301  7  ]
      [  53  1  1  5  772  33  8  35  14  9  9  1  1239  59  362  10  ]
      [  55  2  1  5  812  75  1  40  16  2  3  1  1214  59  378  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1100  59  210  7  ]
      [  43  2  8  -1  -1  -1  -1  -1  11  2  3  6  1249  59  231  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  12  1  5  3  1258  59  292  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  12  2  6  3  1181  59  260  11  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1285  59  -1  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1232  59  357  10  ]
      [  35  2  1  5  780  74  8  40  19  3  3  1  1362  59  450  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1469  59  300  8  ]
      [  69  1  8  -1  -1  -1  -1  -1  11  1  3  3  1304  59  225  8  ]
      [  27  1  1  5  51  1  8  40  15  1  3  1  1388  59  225  9  ]
      [  46  1  1  5  411  55  8  36  12  2  3  1  1414  59  273  8  ]
      [  35  1  1  6  255  35  8  38  8  2  4  1  1457  59  190  10  ]
      [  31  1  1  6  141  24  8  40  10  5  3  1  1407  59  212  11  ]
      [  46  1  1  6  141  24  8  40  11  2  3  1  1473  59  271  8  ]
      [  68  2  8  -1  -1  -1  -1  -1  9  1  3  3  1355  59  217  8  ]
      [  69  1  1  5  702  75  1  3  -1  3  3  3  1558  59  -1  13  ]
      [  75  1  8  -1  -1  -1  -1  -1  12  1  3  3  1573  59  315  10  ]
      [  31  1  1  5  788  34  8  35  14  3  5  1  1524  59  350  9  ]
      [  55  1  1  5  791  92  8  38  16  1  3  1  1676  59  442  10  ]
      [  47  1  1  5  611  24  8  38  15  3  5  1  1552  59  315  9  ]
      [  27  1  1  9  801  75  1  60  12  4  5  1  1663  59  300  9  ]
      [  95  1  8  -1  -1  -1  -1  -1  12  1  3  3  1608  59  301  9  ]
      [  32  1  1  6  714  60  8  40  10  2  3  1  1641  59  238  16  ]
      [  46  1  1  5  620  75  1  40  12  2  8  1  1571  59  295  14  ]
      [  49  1  1  4  764  75  1  40  12  2  6  1  2224  59  275  16  ]
      [  51  2  1  5  870  80  1  40  8  5  9  1  2306  59  186  12  ]
      [  18  1  8  -1  -1  -1  -1  -1  8  1  -1  8  223  58  190  5  ]
      [  29  1  8  -1  -1  -1  -1  -1  12  5  3  4  489  58  300  9  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  -1  -1  6  416  58  -1  3  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  413  58  -1  3  ]
      [  50  2  1  6  901  93  8  30  11  -1  -1  1  441  58  252  5  ]
      [  37  1  8  -1  -1  -1  -1  -1  10  2  3  3  389  58  240  6  ]
      [  91  2  8  -1  -1  -1  -1  -1  11  1  3  3  433  58  260  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  9  1  3  3  532  58  210  4  ]
      [  70  2  8  -1  -1  -1  -1  -1  12  1  5  3  636  58  280  4  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  -1  -1  3  516  58  276  12  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  671  58  -1  4  ]
      [  58  2  8  -1  -1  -1  -1  -1  10  1  3  3  573  58  211  11  ]
      [  67  2  8  -1  -1  -1  -1  -1  14  1  3  3  514  58  300  10  ]
      [  37  2  1  2  750  45  8  40  18  5  8  8  685  58  405  4  ]
      [  45  2  1  5  704  75  1  40  11  2  3  1  685  58  200  5  ]
      [  38  1  8  -1  -1  -1  -1  -1  7  2  1  2  669  58  134  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  10  1  4  3  665  58  207  4  ]
      [  32  2  1  6  411  55  8  45  14  2  3  1  612  58  350  10  ]
      [  24  2  8  -1  -1  -1  -1  -1  11  3  -1  6  837  58  255  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  763  58  230  5  ]
      [  63  2  1  6  934  74  8  12  9  1  -1  1  834  58  202  5  ]
      [  61  2  8  -1  -1  -1  -1  -1  14  1  3  3  871  58  350  5  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  844  58  -1  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  8  1  -1  3  715  58  200  5  ]
      [  83  2  8  -1  -1  -1  -1  -1  10  1  4  3  841  58  200  5  ]
      [  68  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  861  58  230  8  ]
      [  47  1  8  -1  -1  -1  -1  -1  7  1  3  3  890  58  175  6  ]
      [  57  2  1  6  934  80  1  24  6  1  3  1  848  58  100  5  ]
      [  55  1  8  -1  -1  -1  -1  -1  8  5  8  5  801  58  166  5  ]
      [  34  1  1  6  505  45  8  40  13  2  3  1  747  58  260  12  ]
      [  38  2  1  6  661  52  8  30  11  2  3  1  722  58  242  5  ]
      [  55  1  1  6  714  60  8  40  11  2  -1  1  737  58  250  7  ]
      [  35  1  8  -1  -1  -1  -1  -1  13  2  3  2  793  58  294  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  1  3  3  900  58  251  9  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  2  809  58  0  6  ]
      [  36  1  1  6  714  51  8  40  12  2  3  1  707  58  226  8  ]
      [  38  2  1  6  934  55  8  10  12  2  3  2  701  58  281  5  ]
      [  55  1  1  6  997  75  1  36  13  1  3  1  780  58  300  10  ]
      [  28  2  8  -1  -1  -1  -1  -1  12  3  3  2  880  58  255  5  ]
      [  71  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  1070  58  275  8  ]
      [  30  2  1  5  856  85  8  38  13  3  3  1  1022  58  220  6  ]
      [  28  1  8  -1  -1  -1  -1  -1  11  1  3  2  989  58  260  7  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  1  -1  3  980  58  310  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1020  58  230  6  ]
      [  24  2  1  5  863  75  1  39  13  3  4  1  1077  58  300  12  ]
      [  29  1  1  5  672  52  8  38  13  1  3  1  1004  58  310  8  ]
      [  28  2  1  5  863  85  8  19  12  5  3  1  950  58  290  6  ]
      [  24  2  1  5  302  36  8  40  13  5  3  1  1023  58  310  6  ]
      [  32  2  8  -1  -1  -1  -1  -1  15  3  3  8  1026  58  350  7  ]
      [  24  2  1  5  787  75  1  40  12  5  3  1  945  58  260  6  ]
      [  36  1  1  1  995  51  8  80  8  4  99  1  999  58  183  6  ]
      [  61  1  8  -1  -1  -1  -1  -1  12  1  5  3  932  58  280  10  ]
      [  55  1  1  6  310  45  8  40  -1  2  3  1  1097  58  -1  8  ]
      [  73  1  8  -1  -1  -1  -1  -1  11  1  3  3  926  58  259  8  ]
      [  25  1  1  6  441  45  8  40  6  3  3  1  1085  58  150  6  ]
      [  59  1  1  5  879  80  1  40  11  2  5  1  982  58  238  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  1  3  3  1061  58  285  13  ]
      [  70  1  8  -1  -1  -1  -1  -1  8  5  6  3  1027  58  177  10  ]
      [  37  1  8  -1  -1  -1  -1  -1  12  1  3  3  1270  58  240  7  ]
      [  25  1  1  5  735  74  8  38  12  4  5  1  1235  58  260  7  ]
      [  46  1  1  6  241  25  8  39  13  9  3  1  1274  58  330  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1116  58  -1  7  ]
      [  59  1  8  -1  -1  -1  -1  -1  14  1  3  2  1126  58  300  7  ]
      [  64  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1180  58  170  7  ]
      [  49  1  1  5  834  92  8  40  -1  3  4  1  1204  58  -1  7  ]
      [  73  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1139  58  210  7  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  1  4  3  1199  58  257  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  11  1  -1  3  1257  58  250  10  ]
      [  33  1  1  6  281  50  8  40  13  1  3  1  1110  58  300  7  ]
      [  61  2  1  5  859  85  8  39  -1  3  5  1  1148  58  -1  7  ]
      [  39  2  1  1  851  74  8  55  -1  3  99  1  1153  58  -1  7  ]
      [  47  1  1  6  281  75  1  38  -1  1  3  1  1206  58  -1  11  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1153  58  0  7  ]
      [  53  1  1  6  714  63  8  60  12  1  3  1  1182  58  300  7  ]
      [  26  2  8  -1  -1  -1  -1  -1  11  -1  -1  6  1237  58  223  8  ]
      [  67  1  8  -1  -1  -1  -1  -1  14  2  4  3  1146  58  357  11  ]
      [  57  1  1  6  714  60  8  40  9  1  3  1  1241  58  200  7  ]
      [  47  1  1  6  274  80  1  40  10  1  3  1  1141  58  231  10  ]
      [  51  2  1  5  787  75  1  40  12  2  6  1  1150  58  268  7  ]
      [  62  1  1  1  687  51  8  60  9  1  3  8  1300  58  208  10  ]
      [  70  1  8  -1  -1  -1  -1  -1  12  1  3  3  1144  58  286  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  14  1  8  3  1261  58  350  7  ]
      [  59  2  8  -1  -1  -1  -1  -1  8  2  3  2  1290  58  156  7  ]
      [  73  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  1409  58  363  8  ]
      [  51  1  1  4  814  75  1  38  15  1  3  1  1411  58  380  8  ]
      [  54  2  8  -1  -1  -1  -1  -1  7  1  3  3  1317  58  175  13  ]
      [  82  1  1  5  676  52  8  48  14  4  5  1  1416  58  330  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1322  58  -1  8  ]
      [  38  1  1  5  622  74  1  40  18  9  99  1  1430  58  432  9  ]
      [  68  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1403  58  250  8  ]
      [  75  1  8  -1  -1  -1  -1  -1  12  1  3  3  1457  58  270  8  ]
      [  35  2  1  5  853  85  1  38  -1  5  3  1  1395  58  -1  8  ]
      [  46  1  1  6  254  28  8  40  10  -1  -1  1  1307  58  152  15  ]
      [  77  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  1433  58  152  8  ]
      [  70  2  8  -1  -1  -1  -1  -1  9  1  6  3  1499  58  193  8  ]
      [  43  1  1  6  401  15  8  38  12  1  99  1  1533  58  250  12  ]
      [  52  1  1  6  411  55  8  60  9  3  3  1  1624  58  180  9  ]
      [  54  1  1  6  714  60  1  39  -1  1  3  1  1582  58  -1  11  ]
      [  54  2  1  5  634  85  1  38  14  5  3  1  1700  58  350  9  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1599  58  -1  17  ]
      [  39  1  1  2  911  55  8  60  13  1  -1  1  1595  58  310  12  ]
      [  55  1  1  6  300  29  8  40  13  1  -1  1  1541  58  325  9  ]
      [  51  2  1  6  321  34  8  35  16  1  2  1  1507  58  415  9  ]
      [  35  1  1  2  392  55  8  90  14  4  3  1  1668  58  300  11  ]
      [  44  1  1  6  540  26  8  44  9  4  8  1  1632  58  160  9  ]
      [  79  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  1602  58  171  9  ]
      [  31  2  1  5  775  72  8  45  14  5  9  1  1624  58  338  9  ]
      [  47  2  1  5  789  75  1  38  10  2  3  1  1558  58  234  10  ]
      [  32  2  1  5  789  51  8  39  24  1  3  1  1714  58  515  10  ]
      [  42  1  1  5  795  92  1  39  15  3  5  1  2036  58  315  11  ]
      [  69  1  8  -1  -1  -1  -1  -1  14  1  3  3  2197  58  258  12  ]
      [  35  2  1  5  993  66  8  38  28  5  99  1  2274  58  650  17  ]
      [  81  1  8  -1  -1  -1  -1  -1  15  3  3  3  2008  58  356  13  ]
      [  31  1  1  5  601  34  8  40  -1  5  9  1  2402  58  -1  12  ]
      [  35  1  1  5  821  22  8  36  16  5  3  1  2795  58  400  13  ]
      [  50  2  1  5  872  80  1  38  11  5  9  1  2766  58  250  13  ]
      [  54  1  1  5  780  29  8  60  15  3  3  1  3221  58  360  23  ]
      [  33  1  1  5  813  74  8  75  29  5  9  1  3522  58  730  15  ]
      [  53  1  8  -1  -1  -1  -1  -1  12  3  -1  2  435  57  270  8  ]
      [  59  2  8  -1  -1  -1  -1  -1  9  -1  -1  3  437  57  220  11  ]
      [  63  2  8  -1  -1  -1  -1  -1  13  -1  -1  6  458  57  320  3  ]
      [  46  2  8  -1  -1  -1  -1  -1  9  2  3  2  359  57  155  3  ]
      [  36  1  8  -1  -1  -1  -1  -1  -1  2  3  2  446  57  288  4  ]
      [  43  1  8  -1  -1  -1  -1  -1  14  2  3  2  449  57  338  6  ]
      [  62  2  8  -1  -1  -1  -1  -1  9  1  -1  3  390  57  188  3  ]
      [  49  2  8  -1  -1  -1  -1  -1  12  2  3  2  343  57  302  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  11  1  3  3  557  57  267  6  ]
      [  63  2  8  -1  -1  -1  -1  -1  14  1  -1  3  604  57  323  4  ]
      [  73  1  8  -1  -1  -1  -1  -1  13  1  3  3  555  57  300  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  11  1  -1  3  538  57  280  6  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  1  3  3  560  57  -1  4  ]
      [  36  1  8  -1  -1  -1  -1  -1  13  3  5  3  645  57  317  4  ]
      [  40  2  8  -1  -1  -1  -1  -1  10  3  3  2  636  57  200  4  ]
      [  60  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  557  57  250  8  ]
      [  78  2  8  -1  -1  -1  -1  -1  9  1  -1  3  653  57  192  4  ]
      [  42  1  8  -1  -1  -1  -1  -1  11  2  3  2  564  57  257  13  ]
      [  66  1  8  -1  -1  -1  -1  -1  9  1  3  3  515  57  162  8  ]
      [  39  2  1  5  662  52  8  18  9  2  3  1  598  57  181  4  ]
      [  38  1  1  6  934  74  8  40  12  2  3  1  550  57  276  4  ]
      [  65  2  8  -1  -1  -1  -1  -1  10  1  3  3  586  57  223  10  ]
      [  67  1  8  -1  -1  -1  -1  -1  15  1  3  3  709  57  320  8  ]
      [  29  2  1  5  856  85  8  20  12  3  3  1  757  57  260  5  ]
      [  40  2  1  6  411  80  1  40  12  2  1  1  872  57  209  5  ]
      [  21  2  1  6  863  80  1  40  11  3  4  1  887  57  223  5  ]
      [  29  2  8  5  642  45  8  40  11  2  4  1  867  57  264  5  ]
      [  60  1  8  -1  -1  -1  -1  -1  10  1  3  3  801  57  244  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  3  3  779  57  239  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  10  1  3  3  735  57  241  8  ]
      [  41  1  1  6  51  75  1  40  10  2  5  1  756  57  210  7  ]
      [  59  1  1  6  997  92  8  40  -1  1  3  1  723  57  -1  8  ]
      [  34  2  1  5  787  75  1  32  -1  3  5  1  1023  57  315  8  ]
      [  70  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1012  57  305  6  ]
      [  24  1  8  -1  -1  -1  -1  -1  13  3  3  2  955  57  280  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  17  2  3  3  935  57  420  6  ]
      [  28  1  1  6  225  27  8  40  -1  3  99  1  935  57  -1  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  -1  3  930  57  228  6  ]
      [  58  1  1  6  744  63  8  40  11  1  3  1  931  57  242  7  ]
      [  25  1  1  7  779  72  8  40  15  4  -1  1  1014  57  320  6  ]
      [  76  1  8  -1  -1  -1  -1  -1  12  1  -1  3  975  57  240  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  12  1  -1  3  911  57  227  9  ]
      [  51  2  1  5  863  80  1  33  -1  2  6  1  955  57  0  6  ]
      [  25  2  1  5  792  92  8  40  8  3  -1  1  980  57  180  13  ]
      [  70  2  8  -1  -1  -1  -1  -1  5  1  -1  3  929  57  113  6  ]
      [  57  2  8  -1  -1  -1  -1  -1  11  1  3  3  987  57  220  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  14  1  3  3  967  57  341  10  ]
      [  18  2  8  -1  -1  -1  -1  -1  8  -1  -1  6  1087  57  160  7  ]
      [  33  1  1  5  714  60  8  60  13  5  8  1  1107  57  307  11  ]
      [  30  1  1  5  852  85  8  35  19  3  4  1  1165  57  480  7  ]
      [  33  1  1  6  51  1  1  39  9  1  -1  1  1256  57  180  7  ]
      [  21  1  1  11  994  85  8  38  6  3  -1  1  1160  57  140  7  ]
      [  62  2  8  -1  -1  -1  -1  -1  12  1  3  3  1103  57  273  12  ]
      [  73  2  8  -1  -1  -1  -1  -1  9  1  3  3  1208  57  203  7  ]
      [  46  1  1  5  602  40  8  40  11  4  8  1  1287  57  234  12  ]
      [  34  2  1  5  676  52  8  40  13  2  3  1  1195  57  283  7  ]
      [  36  1  1  5  273  40  8  38  14  2  3  1  1298  57  302  12  ]
      [  39  1  1  6  269  32  8  40  11  4  3  1  1458  57  284  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  13  3  3  3  1374  57  265  8  ]
      [  63  2  8  -1  -1  -1  -1  -1  13  3  -1  3  1381  57  350  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  1407  57  300  8  ]
      [  81  1  8  -1  -1  -1  -1  -1  16  3  3  3  1458  57  350  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1491  57  208  8  ]
      [  45  1  1  6  714  60  8  50  15  1  3  1  1480  57  350  12  ]
      [  47  1  1  1  692  67  8  40  11  4  9  1  1304  57  215  13  ]
      [  69  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1351  57  307  8  ]
      [  68  2  8  -1  -1  -1  -1  -1  10  1  4  3  1406  57  255  8  ]
      [  34  1  1  5  691  65  8  38  9  2  3  1  1304  57  206  8  ]
      [  62  1  1  5  874  80  1  38  -1  5  8  1  1445  57  -1  11  ]
      [  36  1  1  6  442  45  8  40  10  2  3  1  1449  57  205  11  ]
      [  28  1  1  6  152  25  8  40  10  2  3  1  1339  57  203  8  ]
      [  50  2  1  6  731  75  1  40  -1  1  5  1  1362  57  -1  8  ]
      [  66  2  8  -1  -1  -1  -1  -1  11  1  4  3  1395  57  277  8  ]
      [  62  2  1  6  934  74  8  10  13  1  3  3  1627  57  276  9  ]
      [  27  1  1  5  777  40  8  36  15  5  5  1  1573  57  300  10  ]
      [  39  1  1  5  841  85  8  31  13  5  10  1  1677  57  291  9  ]
      [  29  2  1  5  780  52  8  40  11  5  3  1  1908  57  270  10  ]
      [  56  2  1  5  691  65  1  38  -1  1  3  1  1860  57  -1  15  ]
      [  39  1  1  6  792  24  8  37  -1  -1  -1  1  1719  57  341  10  ]
      [  41  1  1  6  70  10  8  38  -1  1  3  1  1869  57  285  12  ]
      [  38  1  1  5  751  51  8  50  14  5  9  1  1775  57  350  10  ]
      [  31  1  1  9  801  75  1  40  10  5  4  1  1825  57  210  13  ]
      [  46  1  1  5  777  24  8  40  11  4  3  1  2270  57  250  14  ]
      [  49  1  1  5  772  31  8  35  -1  3  3  1  2452  57  -1  14  ]
      [  32  1  1  5  692  66  8  40  -1  1  3  1  2583  57  -1  12  ]
      [  32  1  1  5  634  29  8  40  -1  4  -1  1  3188  57  470  14  ]
      [  39  2  1  4  787  75  1  38  20  3  3  1  3530  57  480  15  ]
      [  26  2  1  5  788  51  8  45  24  5  9  1  3913  57  560  16  ]
      [  34  1  1  5  612  73  1  50  7  5  9  1  8554  57  155  22  ]
      [  52  2  8  -1  -1  -1  -1  -1  7  2  3  2  182  56  153  10  ]
      [  22  1  8  -1  -1  -1  -1  -1  11  -1  -1  6  186  56  240  8  ]
      [  23  1  8  -1  -1  -1  -1  -1  14  -1  -1  6  446  56  250  7  ]
      [  67  2  8  -1  -1  -1  -1  -1  11  1  -1  3  438  56  229  3  ]
      [  68  1  8  -1  -1  -1  -1  -1  14  1  5  3  356  56  300  7  ]
      [  57  1  8  -1  -1  -1  -1  -1  7  1  3  3  378  56  150  13  ]
      [  49  1  8  -1  -1  -1  -1  -1  11  1  3  2  437  56  210  11  ]
      [  37  1  8  -1  -1  -1  -1  -1  -1  5  3  2  679  56  -1  4  ]
      [  38  1  1  5  861  91  8  10  17  5  -1  4  566  56  413  4  ]
      [  60  2  8  -1  -1  -1  -1  -1  14  1  3  6  660  56  320  4  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  645  56  250  7  ]
      [  84  2  8  -1  -1  -1  -1  -1  12  1  -1  3  555  56  260  4  ]
      [  36  2  8  -1  -1  -1  -1  -1  14  1  -1  6  573  56  360  5  ]
      [  67  1  1  5  997  74  8  20  11  1  -1  3  637  56  245  4  ]
      [  43  2  1  6  934  80  1  20  13  1  -1  1  546  56  324  11  ]
      [  84  2  8  -1  -1  -1  -1  -1  6  1  -1  3  523  56  140  4  ]
      [  66  1  8  -1  -1  -1  -1  -1  15  1  -1  3  546  56  382  6  ]
      [  49  1  8  -1  -1  -1  -1  -1  9  1  3  2  654  56  230  4  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  662  56  -1  10  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  611  56  -1  4  ]
      [  90  2  8  -1  -1  -1  -1  -1  7  1  -1  3  567  56  160  4  ]
      [  57  2  8  -1  -1  -1  -1  -1  13  1  3  3  546  56  256  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  5  1  3  3  594  56  100  4  ]
      [  75  2  8  -1  -1  -1  -1  -1  10  1  3  3  540  56  210  8  ]
      [  26  2  8  -1  -1  -1  -1  -1  9  1  3  2  544  56  168  4  ]
      [  44  1  8  -1  -1  -1  -1  -1  7  2  3  3  507  56  142  4  ]
      [  42  1  8  -1  -1  -1  -1  -1  -1  5  3  2  540  56  -1  4  ]
      [  56  1  8  -1  -1  -1  -1  -1  17  2  3  2  531  56  200  5  ]
      [  21  2  8  -1  -1  -1  -1  -1  13  5  -1  8  627  56  300  7  ]
      [  73  1  8  -1  -1  -1  -1  -1  13  1  3  3  769  56  297  7  ]
      [  48  1  1  6  997  45  8  20  -1  1  -1  1  789  56  -1  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  9  3  -1  3  741  56  200  5  ]
      [  54  2  1  5  675  52  8  23  8  1  3  1  870  56  200  5  ]
      [  68  2  8  -1  -1  -1  -1  -1  8  1  -1  3  864  56  180  5  ]
      [  65  2  8  6  934  75  1  14  11  1  3  1  858  56  236  5  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  3  3  729  56  -1  5  ]
      [  69  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  803  56  300  5  ]
      [  28  1  8  -1  -1  -1  -1  -1  12  9  5  2  733  56  245  8  ]
      [  27  1  1  5  982  72  8  38  9  5  8  1  754  56  225  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  14  1  -1  3  892  56  300  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  13  3  6  3  900  56  288  5  ]
      [  62  2  8  -1  -1  -1  -1  -1  12  1  3  3  753  56  238  5  ]
      [  47  1  8  -1  -1  -1  -1  -1  9  2  6  3  798  56  200  7  ]
      [  40  1  1  8  774  80  8  40  13  2  5  1  774  56  294  9  ]
      [  78  2  8  -1  -1  -1  -1  -1  12  3  3  3  772  56  289  5  ]
      [  69  1  8  -1  -1  -1  -1  -1  11  1  3  3  877  56  280  9  ]
      [  65  1  8  -1  -1  -1  -1  -1  14  1  3  3  701  56  334  6  ]
      [  62  2  8  -1  -1  -1  -1  -1  12  1  3  3  868  56  256  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  8  -1  -1  3  836  56  163  9  ]
      [  74  2  8  -1  -1  -1  -1  -1  12  1  -1  3  762  56  265  5  ]
      [  74  2  8  -1  -1  -1  -1  -1  11  1  3  3  721  56  220  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  11  9  -1  3  810  56  232  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  7  2  3  2  871  56  160  9  ]
      [  40  2  8  -1  -1  -1  -1  -1  9  2  3  2  856  56  200  6  ]
      [  50  2  8  -1  -1  -1  -1  -1  15  3  3  3  1099  56  317  8  ]
      [  40  1  8  -1  -1  -1  -1  -1  12  1  3  3  1049  56  244  7  ]
      [  61  2  1  5  660  52  8  10  14  1  -1  3  912  56  310  6  ]
      [  29  1  1  7  764  75  1  38  11  5  8  8  950  56  286  6  ]
      [  28  1  1  6  281  50  8  40  11  3  3  1  1017  56  210  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  13  1  -1  3  935  56  295  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  13  1  4  3  989  56  300  6  ]
      [  21  2  1  5  863  80  8  40  13  3  4  1  924  56  303  6  ]
      [  31  1  1  5  780  22  8  37  18  5  9  1  904  56  425  13  ]
      [  82  1  8  -1  -1  -1  -1  -1  15  1  1  3  1054  56  352  6  ]
      [  67  2  8  -1  -1  -1  -1  -1  17  1  -1  3  984  56  364  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  13  1  -1  3  980  56  275  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  3  3  3  954  56  -1  6  ]
      [  89  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  1089  56  285  9  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1079  56  -1  7  ]
      [  63  2  8  -1  -1  -1  -1  -1  13  1  -1  3  900  56  292  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  13  1  4  3  1075  56  288  6  ]
      [  31  2  1  5  787  75  1  39  -1  3  3  1  1077  56  -1  6  ]
      [  68  2  8  -1  -1  -1  -1  -1  11  1  3  3  1057  56  224  11  ]
      [  73  1  8  -1  -1  -1  -1  -1  15  1  3  3  1027  56  298  11  ]
      [  47  1  1  5  861  85  1  36  10  2  3  1  1046  56  210  11  ]
      [  41  1  1  5  802  45  8  40  11  2  3  1  994  56  236  12  ]
      [  60  1  1  5  792  74  8  40  8  1  3  1  923  56  147  10  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1016  56  0  7  ]
      [  26  1  1  6  501  52  8  40  9  2  3  1  1018  56  145  9  ]
      [  72  2  8  -1  -1  -1  -1  -1  15  1  -1  3  970  56  334  6  ]
      [  39  1  1  6  792  92  8  40  10  2  3  1  1005  56  215  11  ]
      [  54  1  1  6  792  74  8  60  17  5  9  1  1098  56  388  9  ]
      [  79  1  8  -1  -1  -1  -1  -1  15  1  3  3  1045  56  334  9  ]
      [  84  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1079  56  257  6  ]
      [  29  2  1  1  704  74  8  40  11  2  3  1  954  56  243  15  ]
      [  38  1  1  5  731  64  8  38  11  2  3  1  1008  56  228  6  ]
      [  39  1  1  6  254  29  8  40  12  2  3  1  1056  56  253  11  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1088  56  -1  6  ]
      [  41  2  1  5  788  93  8  25  -1  3  3  1  1171  56  -1  7  ]
      [  82  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1293  56  200  7  ]
      [  31  2  1  5  661  15  8  42  12  1  3  1  1126  56  260  7  ]
      [  37  1  1  5  662  52  8  38  -1  3  3  1  1113  56  200  7  ]
      [  38  1  1  6  212  29  8  35  20  3  2  1  1223  56  430  7  ]
      [  22  2  1  5  914  55  8  45  13  3  3  1  1109  56  295  7  ]
      [  26  2  1  5  780  74  8  40  12  4  3  1  1296  56  249  7  ]
      [  73  1  8  -1  -1  -1  -1  -1  10  1  3  3  1283  56  236  11  ]
      [  26  1  1  5  838  45  8  40  15  1  3  1  1278  56  390  12  ]
      [  24  1  1  6  511  45  8  40  11  1  3  1  1194  56  280  7  ]
      [  45  2  1  5  853  85  1  39  13  1  3  1  1199  56  292  11  ]
      [  63  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1244  56  290  7  ]
      [  34  1  1  5  629  74  8  40  13  1  3  1  1241  56  299  7  ]
      [  34  1  1  5  391  15  8  40  9  3  3  1  1219  56  180  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  12  1  3  3  1278  56  263  11  ]
      [  42  2  1  6  411  85  1  39  12  1  -1  1  1135  56  229  8  ]
      [  66  2  8  -1  -1  -1  -1  -1  12  5  9  3  1127  56  220  7  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  4  9  3  1135  56  -1  9  ]
      [  69  1  8  -1  -1  -1  -1  -1  14  1  3  3  1225  56  308  10  ]
      [  50  2  1  5  782  75  1  40  12  2  3  1  1114  56  269  10  ]
      [  89  1  8  -1  -1  -1  -1  -1  16  1  3  3  1141  56  407  9  ]
      [  37  2  1  5  702  74  8  36  8  2  3  1  1216  56  122  7  ]
      [  50  1  1  6  796  93  8  40  12  2  3  1  1272  56  234  10  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1257  56  -1  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  15  1  -1  3  1354  56  379  12  ]
      [  41  2  1  5  856  85  1  39  14  4  4  1  1374  56  340  8  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1344  56  344  10  ]
      [  52  2  8  -1  -1  -1  -1  -1  -1  5  9  3  1418  56  -1  8  ]
      [  81  1  8  -1  -1  -1  -1  -1  11  1  3  3  1318  56  270  8  ]
      [  64  1  8  -1  -1  -1  -1  -1  10  1  3  3  1388  56  211  8  ]
      [  40  1  1  6  241  20  8  40  -1  1  -1  1  1317  56  -1  14  ]
      [  54  1  1  6  741  29  8  37  -1  1  3  1  1381  56  -1  13  ]
      [  82  1  8  -1  -1  -1  -1  -1  16  1  3  3  1368  56  350  8  ]
      [  86  2  8  -1  -1  -1  -1  -1  9  1  3  3  1392  56  200  8  ]
      [  48  2  1  5  853  85  1  39  15  3  6  1  1418  56  330  13  ]
      [  37  1  1  5  310  31  8  37  14  1  3  1  1304  56  320  10  ]
      [  36  2  1  5  853  85  1  29  13  3  3  1  1411  56  251  12  ]
      [  28  2  1  5  854  85  8  39  13  1  3  1  1376  56  226  8  ]
      [  74  2  8  -1  -1  -1  -1  -1  12  1  4  3  1332  56  230  8  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  3  5  3  1512  56  -1  9  ]
      [  90  1  8  -1  -1  -1  -1  -1  15  1  3  3  1531  56  340  11  ]
      [  35  2  1  5  788  65  8  40  16  5  99  1  1555  56  400  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1623  56  291  10  ]
      [  49  1  1  6  141  24  8  38  -1  1  3  1  1625  56  -1  9  ]
      [  27  1  1  5  283  35  8  38  22  3  3  1  1766  56  500  14  ]
      [  76  2  8  -1  -1  -1  -1  -1  10  1  3  3  1914  56  244  10  ]
      [  80  1  8  -1  -1  -1  -1  -1  11  1  -1  3  1781  56  252  10  ]
      [  25  1  1  4  802  80  1  60  18  3  3  1  1775  56  400  10  ]
      [  51  1  1  6  141  24  8  38  19  1  3  1  1938  56  430  13  ]
      [  57  1  1  2  602  33  8  40  22  -1  -1  1  1859  56  442  10  ]
      [  64  2  8  -1  -1  -1  -1  -1  11  1  8  3  1906  56  233  10  ]
      [  34  1  1  5  691  75  1  40  13  5  5  1  1855  56  310  10  ]
      [  55  1  1  5  780  75  1  38  13  1  3  1  2123  56  277  13  ]
      [  68  1  8  -1  -1  -1  -1  -1  9  1  3  3  2097  56  171  14  ]
      [  52  2  1  5  832  92  1  50  24  9  -1  1  2048  56  600  15  ]
      [  66  1  8  -1  -1  -1  -1  -1  14  1  3  3  2255  56  287  13  ]
      [  67  1  8  -1  -1  -1  -1  -1  11  1  8  3  2004  56  223  14  ]
      [  42  1  1  4  841  85  1  40  16  5  7  1  2498  56  396  12  ]
      [  67  2  8  -1  -1  -1  -1  -1  21  5  9  3  2347  56  470  12  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2316  56  -1  15  ]
      [  76  2  8  -1  -1  -1  -1  -1  8  3  5  3  2884  56  175  13  ]
      [  30  2  1  5  757  74  8  40  15  5  9  1  2632  56  358  13  ]
      [  32  2  1  5  676  52  8  60  -1  3  99  1  3113  56  -1  14  ]
      [  43  2  1  5  861  85  8  32  30  5  8  1  3063  56  700  14  ]
      [  35  2  1  5  780  93  8  45  -1  4  8  1  4861  56  -1  18  ]
      [  23  1  8  -1  -1  -1  -1  -1  -1  3  -1  4  79  55  -1  1  ]
      [  24  2  1  1  692  66  8  12  17  3  4  5  115  55  375  7  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  18  55  -1  1  ]
      [  21  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  173  55  -1  2  ]
      [  21  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  214  55  -1  2  ]
      [  28  2  8  -1  -1  -1  -1  -1  -1  1  -1  6  456  55  -1  3  ]
      [  25  1  1  5  714  63  8  8  13  5  -1  1  468  55  300  9  ]
      [  47  2  1  1  931  93  8  53  -1  2  3  1  305  55  -1  12  ]
      [  35  1  8  -1  -1  -1  -1  -1  7  2  3  2  397  55  138  5  ]
      [  47  1  1  1  308  52  8  40  10  2  5  1  428  55  200  3  ]
      [  47  1  1  3  11  1  8  60  -1  1  -1  1  549  55  0  4  ]
      [  70  2  8  -1  -1  -1  -1  -1  13  1  3  3  537  55  300  4  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  5  9  2  626  55  290  6  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  5  -1  8  526  55  380  4  ]
      [  30  1  1  5  872  80  1  18  10  5  7  1  636  55  225  4  ]
      [  49  1  8  1  831  92  8  50  12  5  8  6  644  55  276  4  ]
      [  34  1  8  -1  -1  -1  -1  -1  11  1  -1  2  585  55  240  4  ]
      [  81  2  8  -1  -1  -1  -1  -1  11  1  -1  3  543  55  279  4  ]
      [  25  1  8  -1  -1  -1  -1  -1  10  5  -1  4  694  55  250  4  ]
      [  31  1  8  -1  -1  -1  -1  -1  10  5  5  8  659  55  250  4  ]
      [  71  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  514  55  300  4  ]
      [  41  1  8  -1  -1  -1  -1  -1  9  2  3  6  560  55  190  4  ]
      [  48  1  8  -1  -1  -1  -1  -1  8  2  3  2  656  55  150  6  ]
      [  63  1  8  -1  -1  -1  -1  -1  12  1  4  3  570  55  260  7  ]
      [  21  1  8  -1  -1  -1  -1  -1  8  5  -1  4  640  55  165  4  ]
      [  36  2  1  6  660  52  8  25  -1  2  99  1  617  55  -1  4  ]
      [  83  2  8  -1  -1  -1  -1  -1  9  1  -1  3  739  55  200  5  ]
      [  56  1  1  6  934  52  8  12  11  1  -1  6  899  55  185  5  ]
      [  22  1  1  5  310  33  8  38  11  1  -1  8  784  55  231  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  869  55  -1  5  ]
      [  86  2  8  -1  -1  -1  -1  -1  14  1  3  3  753  55  300  5  ]
      [  77  2  8  -1  -1  -1  -1  -1  10  1  3  3  809  55  197  5  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  864  55  0  5  ]
      [  88  2  8  -1  -1  -1  -1  -1  8  1  3  3  836  55  168  5  ]
      [  24  1  1  8  254  28  8  35  9  1  3  1  897  55  200  5  ]
      [  78  2  8  -1  -1  -1  -1  -1  8  1  3  3  882  55  160  5  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  1  3  709  55  -1  5  ]
      [  55  2  8  -1  -1  -1  -1  -1  10  1  -1  6  840  55  208  5  ]
      [  22  2  1  5  997  85  8  12  13  4  3  4  744  55  300  8  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  790  55  -1  6  ]
      [  90  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  733  55  -1  5  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  1  3  740  55  0  10  ]
      [  51  1  8  -1  -1  -1  -1  -1  10  1  3  3  888  55  197  6  ]
      [  22  2  1  7  671  51  8  38  12  3  3  1  822  55  240  5  ]
      [  43  1  8  1  603  45  8  50  14  5  8  5  792  55  316  5  ]
      [  59  2  1  5  661  52  8  30  11  1  3  1  889  55  227  11  ]
      [  57  1  1  6  796  50  8  3  11  1  3  3  727  55  221  10  ]
      [  43  2  1  6  269  28  8  40  9  1  3  1  794  55  204  8  ]
      [  61  1  8  6  522  22  8  12  9  2  3  1  832  55  212  11  ]
      [  23  2  1  5  780  28  8  40  15  3  3  1  701  55  299  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  7  2  6  3  737  55  132  8  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  3  3  995  55  0  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  984  55  -1  7  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  99  3  935  55  0  10  ]
      [  22  1  1  6  731  64  8  39  -1  1  3  1  1054  55  -1  6  ]
      [  29  2  8  -1  -1  -1  -1  -1  15  5  -1  4  1020  55  340  6  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1060  55  0  6  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1045  55  -1  6  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1043  55  0  6  ]
      [  52  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  918  55  285  9  ]
      [  21  1  1  11  994  85  1  39  12  3  3  1  1069  55  215  6  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1008  55  0  7  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1002  55  -1  12  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1094  55  -1  6  ]
      [  36  1  1  5  780  50  8  35  11  -1  -1  1  984  55  230  6  ]
      [  52  2  1  5  789  74  8  40  13  2  3  1  1000  55  228  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  11  1  3  3  1047  55  207  6  ]
      [  53  1  8  -1  -1  -1  -1  -1  4  2  3  2  932  55  70  8  ]
      [  58  1  8  -1  -1  -1  -1  -1  -1  4  8  3  909  55  -1  10  ]
      [  62  2  8  -1  -1  -1  -1  -1  13  3  6  3  911  55  310  12  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1069  55  -1  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1141  55  340  7  ]
      [  24  1  1  5  864  85  1  38  9  1  99  1  1108  55  190  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  12  1  -1  3  1132  55  260  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  11  1  3  3  1139  55  252  7  ]
      [  44  2  1  5  773  50  8  39  15  3  3  1  1182  55  370  10  ]
      [  74  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1262  55  270  7  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1206  55  -1  7  ]
      [  23  2  1  5  662  52  8  38  12  1  3  1  1192  55  293  7  ]
      [  35  1  1  6  744  27  8  40  8  -1  -1  1  1117  55  173  7  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1246  55  -1  7  ]
      [  27  1  1  6  443  45  8  40  11  3  99  1  1130  55  250  7  ]
      [  27  2  1  5  662  52  8  40  15  3  3  1  1200  55  310  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  14  1  3  3  1218  55  328  7  ]
      [  29  2  1  6  269  32  8  35  15  1  3  1  1122  55  350  12  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1209  55  0  7  ]
      [  24  1  1  5  741  29  8  40  24  5  -1  1  1183  55  550  12  ]
      [  84  1  8  -1  -1  -1  -1  -1  13  1  3  3  1190  55  300  11  ]
      [  67  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  1278  55  333  7  ]
      [  53  2  8  -1  -1  -1  -1  -1  14  1  4  3  1112  55  313  7  ]
      [  90  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1235  55  -1  7  ]
      [  48  1  8  -1  -1  -1  -1  -1  13  1  3  3  1130  55  255  9  ]
      [  31  1  1  6  741  34  8  38  13  1  3  1  1227  55  318  7  ]
      [  39  1  1  6  521  28  8  35  11  3  3  1  1189  55  215  7  ]
      [  56  1  1  5  796  70  8  40  13  2  3  1  1100  55  268  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  10  3  6  3  1150  55  191  13  ]
      [  51  2  1  6  741  51  8  40  14  1  3  1  1465  55  300  10  ]
      [  33  1  1  5  620  73  8  38  13  5  8  1  1460  55  291  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  16  1  3  3  1313  55  351  11  ]
      [  31  1  1  5  273  51  8  38  14  3  3  1  1388  55  340  8  ]
      [  44  1  1  6  254  29  8  40  14  3  3  1  1446  55  310  8  ]
      [  31  2  1  6  912  85  1  38  14  3  -1  1  1412  55  300  8  ]
      [  70  1  8  -1  -1  -1  -1  -1  13  3  8  3  1321  55  267  10  ]
      [  51  1  1  5  814  75  1  38  12  1  3  1  1361  55  275  8  ]
      [  78  2  8  -1  -1  -1  -1  -1  11  1  3  3  1465  55  250  8  ]
      [  45  2  1  6  522  17  8  38  12  1  3  1  1385  55  250  11  ]
      [  57  1  1  5  633  24  8  37  13  1  3  1  1313  55  300  11  ]
      [  29  1  1  2  51  1  8  57  11  5  3  1  1427  55  256  8  ]
      [  26  1  1  4  802  75  1  40  18  3  3  1  1400  55  425  8  ]
      [  49  1  1  5  832  92  1  42  11  5  5  1  1333  55  221  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1393  55  -1  8  ]
      [  45  2  1  5  784  32  8  39  12  1  3  1  1450  55  215  14  ]
      [  87  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1350  55  -1  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  5  4  3  1304  55  -1  9  ]
      [  22  2  1  5  786  74  8  40  22  3  3  1  1366  55  520  8  ]
      [  41  2  1  5  751  36  8  44  15  5  9  1  1409  55  350  8  ]
      [  22  1  1  6  267  45  8  42  12  -1  -1  1  1416  55  278  11  ]
      [  80  2  8  -1  -1  -1  -1  -1  17  1  -1  3  1356  55  440  8  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1307  55  0  8  ]
      [  56  1  1  5  623  75  1  40  -1  2  5  1  1455  55  -1  10  ]
      [  51  1  1  5  772  45  8  39  -1  3  3  1  1625  55  -1  9  ]
      [  29  1  1  6  441  45  8  40  14  2  3  1  1687  55  345  10  ]
      [  24  2  1  5  776  24  8  37  13  3  3  1  1632  55  300  11  ]
      [  29  2  1  5  853  85  1  40  -1  3  4  1  1523  55  -1  16  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1515  55  -1  12  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1548  55  0  9  ]
      [  46  2  1  5  788  52  8  33  -1  3  3  1  1504  55  -1  10  ]
      [  31  1  1  6  269  34  8  35  12  5  8  1  1529  55  240  9  ]
      [  81  1  8  -1  -1  -1  -1  -1  13  5  8  3  1611  55  320  9  ]
      [  57  1  1  4  801  75  1  40  15  3  6  1  1644  55  355  9  ]
      [  59  2  8  -1  -1  -1  -1  -1  12  3  3  8  1642  55  254  9  ]
      [  26  1  1  5  780  51  8  40  -1  4  3  1  1911  55  -1  10  ]
      [  27  1  1  6  391  15  8  45  16  3  3  1  1723  55  355  10  ]
      [  27  1  1  5  726  62  8  38  24  5  9  1  1819  55  605  14  ]
      [  67  1  8  -1  -1  -1  -1  -1  16  3  3  3  1946  55  320  10  ]
      [  26  1  1  5  145  25  8  38  18  1  3  1  1965  55  400  14  ]
      [  48  1  1  2  841  85  8  70  18  5  9  1  1729  55  380  14  ]
      [  94  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1799  55  -1  10  ]
      [  30  2  1  5  835  92  8  40  16  5  3  1  1717  55  342  10  ]
      [  28  2  1  4  801  75  1  40  -1  -1  -1  1  1773  55  -1  10  ]
      [  75  2  8  -1  -1  -1  -1  -1  17  1  3  3  1976  55  360  10  ]
      [  31  1  1  5  880  80  1  40  13  5  9  1  1834  55  267  12  ]
      [  55  1  1  6  550  34  8  29  -1  1  3  1  2079  55  -1  13  ]
      [  29  1  1  5  757  74  8  40  14  5  9  1  2298  55  287  11  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2308  55  -1  12  ]
      [  37  1  1  5  600  34  8  40  11  4  8  1  2595  55  230  12  ]
      [  34  2  1  4  787  75  1  39  23  5  9  1  2364  55  600  12  ]
      [  36  1  1  5  836  52  8  39  15  9  3  1  2385  55  358  12  ]
      [  29  1  1  6  310  34  8  35  -1  2  3  1  2486  55  -1  12  ]
      [  30  1  1  4  801  75  1  40  15  3  5  1  2414  55  350  17  ]
      [  33  1  1  5  996  72  8  40  23  5  9  1  2636  55  510  13  ]
      [  30  1  1  5  283  62  8  39  17  4  3  1  2969  55  350  14  ]
      [  35  1  1  5  316  32  8  40  -1  3  3  1  3061  55  0  14  ]
      [  52  1  1  4  870  80  1  39  -1  5  9  1  3041  55  -1  16  ]
      [  48  2  1  2  869  85  8  60  25  4  9  1  4296  55  497  17  ]
      [  64  1  8  -1  -1  -1  -1  -1  50  4  99  6  298  54  -1  3  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  -1  -1  6  240  54  0  4  ]
      [  38  1  1  6  501  85  8  30  9  -1  -1  6  460  54  200  5  ]
      [  39  1  8  -1  -1  -1  -1  -1  11  1  3  2  358  54  240  5  ]
      [  43  1  8  -1  -1  -1  -1  -1  8  2  3  2  381  54  159  6  ]
      [  26  2  8  -1  -1  -1  -1  -1  13  1  3  8  648  54  250  4  ]
      [  36  2  1  1  751  74  8  50  17  5  3  1  640  54  375  4  ]
      [  40  1  8  -1  -1  -1  -1  -1  12  3  3  8  695  54  275  4  ]
      [  33  2  8  -1  -1  -1  -1  -1  26  3  -1  4  504  54  500  4  ]
      [  69  1  8  -1  -1  -1  -1  -1  11  1  -1  3  589  54  250  4  ]
      [  28  2  8  6  660  52  8  10  21  1  3  1  649  54  452  4  ]
      [  64  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  652  54  250  7  ]
      [  21  2  8  -1  -1  -1  -1  -1  14  3  -1  2  580  54  288  4  ]
      [  45  1  8  -1  -1  -1  -1  -1  8  2  3  2  587  54  140  6  ]
      [  51  1  8  -1  -1  -1  -1  -1  9  2  3  2  540  54  190  4  ]
      [  43  1  8  -1  -1  -1  -1  -1  9  5  10  2  508  54  201  4  ]
      [  65  2  8  -1  -1  -1  -1  -1  12  1  3  3  555  54  234  4  ]
      [  28  1  8  6  997  52  8  8  9  5  3  8  552  54  150  4  ]
      [  48  1  8  -1  -1  -1  -1  -1  -1  1  1  2  579  54  -1  4  ]
      [  56  2  1  5  921  85  8  30  14  2  3  1  642  54  342  4  ]
      [  28  2  1  6  531  93  8  40  15  5  3  1  857  54  300  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  12  1  -1  3  804  54  253  9  ]
      [  72  1  8  -1  -1  -1  -1  -1  9  1  3  3  847  54  190  5  ]
      [  73  1  8  -1  -1  -1  -1  -1  11  1  -1  3  840  54  210  5  ]
      [  50  1  8  -1  -1  -1  -1  -1  12  1  3  3  722  54  220  7  ]
      [  65  2  8  -1  -1  -1  -1  -1  15  1  3  3  713  54  350  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  12  1  -1  3  755  54  240  8  ]
      [  34  1  1  5  662  52  8  38  11  1  3  1  834  54  230  5  ]
      [  74  2  8  -1  -1  -1  -1  -1  10  1  -1  3  746  54  230  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  13  1  -1  3  727  54  280  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  6  1  3  3  808  54  112  5  ]
      [  76  2  8  -1  -1  -1  -1  -1  12  1  3  3  891  54  300  5  ]
      [  45  2  8  -1  -1  -1  -1  -1  -1  5  9  8  830  54  250  6  ]
      [  38  2  1  6  934  74  8  40  12  1  1  1  757  54  215  5  ]
      [  78  1  8  -1  -1  -1  -1  -1  12  1  3  3  791  54  164  7  ]
      [  50  1  8  -1  -1  -1  -1  -1  11  5  9  6  785  54  194  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  9  3  4  3  737  54  164  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  10  1  -1  3  821  54  233  5  ]
      [  61  2  8  -1  -1  -1  -1  -1  8  1  5  3  874  54  180  5  ]
      [  33  2  1  6  662  52  8  40  10  2  1  1  717  54  181  5  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  847  54  -1  5  ]
      [  72  1  8  -1  -1  -1  -1  -1  7  1  3  3  700  54  153  10  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  806  54  -1  5  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  891  54  -1  5  ]
      [  51  2  8  -1  -1  -1  -1  -1  16  3  3  3  1056  54  384  6  ]
      [  65  2  8  -1  -1  -1  -1  -1  9  1  -1  3  979  54  180  6  ]
      [  45  2  1  6  531  36  8  39  15  1  -1  1  963  54  319  6  ]
      [  26  2  1  5  856  85  8  38  15  3  3  1  1016  54  370  6  ]
      [  66  2  8  -1  -1  -1  -1  -1  15  1  -1  3  976  54  320  6  ]
      [  80  1  8  -1  -1  -1  -1  -1  13  1  3  3  921  54  272  6  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1029  54  271  6  ]
      [  25  1  1  9  801  75  1  42  13  3  4  1  919  54  300  12  ]
      [  74  2  8  -1  -1  -1  -1  -1  14  1  -1  3  1087  54  289  6  ]
      [  63  1  1  6  794  92  8  40  -1  1  3  1  980  54  0  11  ]
      [  25  1  1  6  281  50  8  45  14  1  1  1  1078  54  300  6  ]
      [  50  1  1  5  267  45  8  40  16  1  3  1  1056  54  325  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  13  1  3  3  1034  54  230  6  ]
      [  58  2  8  -1  -1  -1  -1  -1  17  1  -1  3  903  54  416  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  17  -1  -1  3  1097  54  365  9  ]
      [  63  2  1  6  923  95  8  8  16  1  3  3  909  54  300  9  ]
      [  23  2  1  6  321  31  8  35  13  1  3  1  987  54  270  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  911  54  -1  6  ]
      [  27  1  1  6  531  45  8  40  10  1  3  1  1089  54  230  6  ]
      [  36  1  8  -1  -1  -1  -1  -1  8  1  -1  2  1009  54  122  9  ]
      [  69  2  8  5  870  80  8  7  14  3  6  3  975  54  293  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  13  3  4  3  1081  54  325  6  ]
      [  74  2  8  -1  -1  -1  -1  -1  13  1  6  3  1079  54  280  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  10  1  3  3  993  54  190  6  ]
      [  59  2  1  5  662  52  8  22  15  1  3  1  1274  54  358  7  ]
      [  32  1  1  6  741  52  8  38  16  -1  -1  1  1269  54  314  10  ]
      [  30  2  1  5  853  85  1  28  15  3  3  1  1234  54  330  7  ]
      [  67  1  1  6  744  74  8  8  25  1  3  1  1197  54  600  12  ]
      [  33  1  1  6  741  51  8  36  13  1  3  1  1133  54  300  7  ]
      [  88  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1229  54  220  7  ]
      [  31  2  1  5  678  51  8  20  22  5  -1  1  1184  54  500  7  ]
      [  89  2  8  -1  -1  -1  -1  -1  16  1  -1  3  1210  54  350  7  ]
      [  30  2  1  5  856  85  8  38  -1  3  3  1  1300  54  250  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  11  1  -1  3  1106  54  260  10  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1243  54  -1  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  11  1  3  3  1208  54  220  7  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1106  54  -1  7  ]
      [  51  1  1  6  255  45  8  40  12  2  3  1  1282  54  216  10  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1111  54  -1  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  11  1  3  3  1181  54  250  7  ]
      [  52  1  1  6  714  60  8  40  10  2  3  1  1141  54  160  9  ]
      [  53  2  8  -1  -1  -1  -1  -1  13  2  3  3  1206  54  304  7  ]
      [  83  1  8  -1  -1  -1  -1  -1  11  1  3  3  1268  54  248  7  ]
      [  78  2  8  -1  -1  -1  -1  -1  11  4  7  3  1254  54  235  7  ]
      [  60  2  8  -1  -1  -1  -1  -1  8  1  6  3  1163  54  169  7  ]
      [  43  1  1  5  861  80  8  40  11  5  8  1  1221  54  252  7  ]
      [  26  1  1  5  267  45  8  37  10  1  3  1  1311  54  180  12  ]
      [  38  1  1  5  861  85  1  39  12  5  8  1  1492  54  250  8  ]
      [  27  1  1  6  512  50  8  36  13  1  3  1  1468  54  315  8  ]
      [  68  2  8  -1  -1  -1  -1  -1  20  1  1  3  1449  54  360  8  ]
      [  37  1  1  6  531  36  8  35  19  1  3  1  1439  54  400  8  ]
      [  36  1  1  6  540  25  8  36  12  1  3  1  1391  54  300  8  ]
      [  53  2  1  5  853  85  1  39  11  1  3  1  1484  54  250  8  ]
      [  76  1  1  6  512  15  8  40  15  -1  -1  1  1439  54  323  8  ]
      [  33  1  1  6  550  34  8  39  12  4  4  1  1316  54  248  10  ]
      [  35  2  1  5  609  74  8  40  11  5  9  1  1639  54  240  9  ]
      [  59  1  1  6  714  63  8  55  12  1  3  1  1516  54  250  10  ]
      [  28  2  1  5  750  74  8  38  14  4  9  1  1605  54  320  9  ]
      [  33  1  1  6  290  34  8  35  10  1  3  1  1609  54  180  9  ]
      [  23  1  1  5  780  52  8  36  14  4  -1  1  1571  54  310  9  ]
      [  76  1  8  -1  -1  -1  -1  -1  13  5  9  3  1695  54  286  11  ]
      [  57  2  1  5  702  63  8  38  9  4  8  1  1531  54  185  9  ]
      [  22  1  1  6  487  45  8  40  12  1  3  1  1501  54  259  9  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1614  54  -1  9  ]
      [  51  1  1  5  868  75  1  39  15  1  3  1  1731  54  300  12  ]
      [  43  1  1  5  662  52  8  37  11  1  4  1  1802  54  250  11  ]
      [  32  1  1  6  521  32  8  36  16  1  -1  1  1983  54  320  10  ]
      [  38  2  1  5  862  85  8  40  13  2  6  1  1746  54  235  10  ]
      [  64  1  1  6  531  92  8  7  -1  3  5  3  2062  54  410  11  ]
      [  35  1  1  6  791  74  8  40  13  2  -1  1  2258  54  300  11  ]
      [  32  1  1  5  270  32  8  35  19  1  3  1  2314  54  450  14  ]
      [  28  1  1  5  660  93  8  45  16  4  8  1  2692  54  340  16  ]
      [  38  2  1  4  765  75  1  40  15  5  5  1  2820  54  315  13  ]
      [  35  1  1  5  750  34  8  50  -1  5  8  1  2968  54  -1  14  ]
      [  24  1  1  2  691  65  8  60  -1  3  3  1  2910  54  -1  14  ]
      [  35  1  1  5  880  75  1  40  20  5  9  1  3272  54  479  15  ]
      [  55  1  1  4  764  75  1  39  11  5  8  1  3894  54  240  16  ]
      [  39  2  8  -1  -1  -1  -1  -1  7  3  3  6  179  53  134  3  ]
      [  54  2  8  -1  -1  -1  -1  -1  12  1  -1  6  484  53  240  5  ]
      [  24  1  8  -1  -1  -1  -1  -1  15  5  -1  4  406  53  330  6  ]
      [  20  1  8  -1  -1  -1  -1  -1  13  5  -1  4  461  53  275  9  ]
      [  60  1  1  6  796  70  8  12  11  1  3  1  487  53  180  8  ]
      [  26  2  8  5  982  92  8  15  8  5  -1  4  409  53  150  5  ]
      [  61  2  8  -1  -1  -1  -1  -1  12  1  -1  3  422  53  260  3  ]
      [  38  1  8  -1  -1  -1  -1  -1  9  2  3  3  437  53  193  3  ]
      [  54  1  8  -1  -1  -1  -1  -1  11  3  3  2  395  53  260  3  ]
      [  81  2  8  -1  -1  -1  -1  -1  14  1  -1  3  518  53  285  4  ]
      [  28  1  8  -1  -1  -1  -1  -1  20  5  -1  4  642  53  450  4  ]
      [  22  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  650  53  -1  4  ]
      [  45  1  8  -1  -1  -1  -1  -1  10  4  5  2  654  53  220  4  ]
      [  18  1  1  7  461  45  8  38  6  1  -1  1  613  53  126  4  ]
      [  23  2  1  8  853  85  1  40  13  3  -1  1  504  53  297  8  ]
      [  20  2  8  -1  -1  -1  -1  -1  12  5  -1  4  674  53  235  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  11  1  -1  3  503  53  249  4  ]
      [  38  2  1  5  774  72  8  40  10  2  4  1  680  53  196  4  ]
      [  43  1  1  6  714  93  8  12  12  1  3  2  882  53  240  5  ]
      [  78  2  8  -1  -1  -1  -1  -1  12  1  -1  3  745  53  250  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  745  53  330  5  ]
      [  57  2  8  -1  -1  -1  -1  -1  -1  -1  -1  4  723  53  -1  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  13  1  -1  3  833  53  300  5  ]
      [  85  2  8  -1  -1  -1  -1  -1  11  1  -1  3  853  53  240  5  ]
      [  81  2  8  -1  -1  -1  -1  -1  6  1  -1  3  812  53  125  5  ]
      [  86  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  801  53  0  6  ]
      [  29  1  1  6  391  15  8  40  9  1  3  1  730  53  228  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  11  3  -1  3  895  53  209  5  ]
      [  18  1  8  -1  -1  -1  -1  -1  13  -1  -1  6  869  53  260  5  ]
      [  41  1  1  6  316  31  8  40  -1  2  3  1  739  53  -1  5  ]
      [  76  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  815  53  298  8  ]
      [  29  1  8  -1  -1  -1  -1  -1  10  3  -1  6  838  53  230  5  ]
      [  62  2  8  -1  -1  -1  -1  -1  10  4  8  3  782  53  155  5  ]
      [  34  1  1  6  281  91  8  38  14  3  5  1  987  53  280  9  ]
      [  35  2  1  1  821  22  8  5  -1  5  7  1  927  53  -1  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  8  1  3  3  1074  53  160  6  ]
      [  70  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1078  53  200  6  ]
      [  44  2  1  5  864  85  1  40  13  1  3  1  1061  53  273  8  ]
      [  57  2  1  5  765  75  1  40  11  2  3  1  1037  53  223  11  ]
      [  68  1  8  -1  -1  -1  -1  -1  12  1  3  3  1032  53  245  9  ]
      [  72  2  8  -1  -1  -1  -1  -1  13  1  3  3  1211  53  300  7  ]
      [  76  1  8  -1  -1  -1  -1  -1  13  1  -1  3  1279  53  245  7  ]
      [  23  1  1  6  481  45  8  40  11  1  3  1  1180  53  204  7  ]
      [  69  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1229  53  190  7  ]
      [  74  2  8  -1  -1  -1  -1  -1  14  1  -1  3  1238  53  260  7  ]
      [  48  2  1  5  857  85  1  30  12  1  3  1  1277  53  274  7  ]
      [  73  1  8  -1  -1  -1  -1  -1  11  1  3  3  1106  53  237  8  ]
      [  35  2  1  5  676  52  8  50  12  2  3  1  1296  53  242  7  ]
      [  24  1  1  5  712  60  8  39  14  3  3  1  1497  53  300  8  ]
      [  31  2  1  5  701  63  8  39  21  5  3  1  1405  53  500  8  ]
      [  44  2  1  5  411  85  1  39  17  3  3  1  1323  53  347  8  ]
      [  24  2  1  5  662  52  8  9  -1  5  -1  4  1448  53  -1  8  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1466  53  -1  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  6  1  -1  3  1407  53  99  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  13  1  3  3  1451  53  280  10  ]
      [  36  1  1  5  620  75  1  39  8  3  3  1  1408  53  124  8  ]
      [  47  1  1  6  222  29  8  38  15  2  3  1  1442  53  340  11  ]
      [  44  1  1  6  300  33  8  35  13  1  3  1  1608  53  280  9  ]
      [  57  2  1  5  861  91  8  39  17  4  8  1  1657  53  430  9  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1570  53  -1  9  ]
      [  81  2  8  -1  -1  -1  -1  -1  7  1  -1  3  1669  53  150  9  ]
      [  22  2  1  5  785  29  8  37  14  5  3  1  1565  53  303  9  ]
      [  33  1  1  6  255  28  8  35  11  1  3  1  1867  53  222  10  ]
      [  25  1  1  5  778  72  8  40  30  4  -1  1  1926  53  700  10  ]
      [  33  1  1  6  281  34  8  40  16  2  3  1  1721  53  330  12  ]
      [  37  1  1  5  841  85  8  40  15  5  9  1  1904  53  350  10  ]
      [  68  2  8  -1  -1  -1  -1  -1  11  1  1  3  2141  53  225  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2002  53  -1  11  ]
      [  21  1  1  1  714  64  8  60  11  3  3  1  2715  53  250  13  ]
      [  60  1  1  5  612  35  8  39  -1  5  10  1  2885  53  -1  13  ]
      [  95  2  8  -1  -1  -1  -1  -1  -1  5  -1  3  3357  53  -1  15  ]
      [  25  1  1  5  997  80  1  8  19  -1  -1  4  242  52  430  6  ]
      [  21  2  1  7  786  74  8  40  -1  5  -1  1  168  52  0  2  ]
      [  25  1  8  -1  -1  -1  -1  -1  15  -1  -1  2  437  52  329  8  ]
      [  42  1  8  -1  -1  -1  -1  -1  -1  2  3  2  469  52  -1  8  ]
      [  26  2  8  -1  -1  -1  -1  -1  14  2  3  2  373  52  290  3  ]
      [  19  2  1  8  853  85  1  38  17  4  -1  1  563  52  358  11  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  512  52  220  4  ]
      [  61  2  8  -1  -1  -1  -1  -1  13  1  3  2  629  52  274  4  ]
      [  35  2  8  -1  -1  -1  -1  -1  11  4  3  2  694  52  226  4  ]
      [  43  1  8  -1  -1  -1  -1  -1  14  1  3  2  610  52  300  4  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  523  52  -1  4  ]
      [  75  2  8  -1  -1  -1  -1  -1  11  1  -1  3  527  52  200  4  ]
      [  63  2  8  -1  -1  -1  -1  -1  14  1  3  3  680  52  265  6  ]
      [  78  2  8  -1  -1  -1  -1  -1  10  4  6  3  645  52  202  4  ]
      [  54  1  8  6  24  1  8  4  11  1  3  2  694  52  240  5  ]
      [  48  2  8  5  853  85  1  38  16  3  3  1  737  52  350  5  ]
      [  83  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  784  52  300  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  14  1  -1  3  891  52  300  7  ]
      [  29  1  1  5  997  66  8  15  17  4  3  1  753  52  409  5  ]
      [  46  1  1  6  714  60  8  35  12  1  3  1  871  52  243  5  ]
      [  49  1  8  -1  -1  -1  -1  -1  16  5  4  2  821  52  250  5  ]
      [  22  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  787  52  333  5  ]
      [  69  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  862  52  224  5  ]
      [  40  2  1  6  914  55  8  25  11  1  3  1  841  52  227  5  ]
      [  83  2  8  -1  -1  -1  -1  -1  14  1  -1  3  755  52  310  5  ]
      [  63  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  881  52  230  5  ]
      [  37  2  1  5  923  85  8  22  13  2  3  1  737  52  293  5  ]
      [  49  2  1  5  864  85  8  40  21  3  3  1  949  52  500  14  ]
      [  77  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  910  52  260  6  ]
      [  58  2  8  -1  -1  -1  -1  -1  13  3  3  4  1010  52  320  14  ]
      [  31  1  1  6  997  93  8  40  17  -1  -1  1  917  52  390  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1080  52  -1  6  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  909  52  -1  6  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  909  52  250  6  ]
      [  38  2  8  -1  -1  -1  -1  -1  9  1  -1  2  1100  52  152  7  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  958  52  -1  6  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  980  52  325  8  ]
      [  75  2  8  -1  -1  -1  -1  -1  12  1  -1  3  987  52  253  6  ]
      [  29  1  1  5  622  52  8  40  16  4  3  1  1099  52  348  6  ]
      [  87  2  8  -1  -1  -1  -1  -1  12  1  -1  3  974  52  215  6  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  3  3  3  1097  52  -1  6  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  915  52  -1  9  ]
      [  50  1  1  6  540  25  8  37  16  1  -1  1  1011  52  320  11  ]
      [  39  2  1  5  834  74  8  30  -1  1  3  1  1005  52  220  6  ]
      [  20  2  1  5  864  85  1  30  -1  1  4  1  1044  52  -1  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  1  3  977  52  -1  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  12  1  3  3  983  52  252  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  14  1  3  3  975  52  280  6  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1089  52  -1  10  ]
      [  21  1  1  9  801  75  1  37  11  3  3  1  1223  52  250  7  ]
      [  63  2  8  -1  -1  -1  -1  -1  16  1  3  2  1182  52  349  7  ]
      [  36  1  1  5  780  51  8  37  18  3  3  1  1122  52  420  7  ]
      [  35  1  1  6  254  75  1  39  14  1  3  1  1162  52  300  7  ]
      [  24  2  1  5  642  75  1  38  15  5  3  1  1164  52  330  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  10  1  3  3  1251  52  174  12  ]
      [  26  1  1  6  273  28  8  40  14  1  3  1  1250  52  307  7  ]
      [  53  2  1  5  773  52  8  25  11  1  3  3  1282  52  228  7  ]
      [  40  1  1  6  150  25  8  40  -1  5  5  1  1172  52  -1  8  ]
      [  72  1  8  -1  -1  -1  -1  -1  10  3  3  3  1130  52  180  7  ]
      [  56  2  8  -1  -1  -1  -1  -1  13  1  3  3  1295  52  258  7  ]
      [  41  2  1  5  660  52  8  38  13  1  -1  1  1196  52  275  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  14  1  -1  3  1174  52  249  7  ]
      [  26  1  1  5  689  70  8  37  13  5  99  1  1272  52  301  9  ]
      [  24  1  1  6  303  33  8  40  12  3  3  1  1242  52  280  7  ]
      [  59  2  1  6  741  75  1  40  11  4  6  1  1254  52  234  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  11  4  6  3  1224  52  245  11  ]
      [  34  2  1  5  885  92  8  50  17  5  9  1  1158  52  372  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  13  1  3  3  1352  52  300  9  ]
      [  61  1  1  6  463  45  8  45  -1  1  3  1  1300  52  -1  8  ]
      [  50  1  1  5  714  15  8  40  22  -1  -1  1  1435  52  489  8  ]
      [  68  1  8  -1  -1  -1  -1  -1  10  1  3  3  1370  52  210  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1413  52  147  8  ]
      [  52  2  1  5  853  85  1  35  -1  4  3  1  1350  52  -1  8  ]
      [  42  1  1  5  787  75  1  39  11  3  3  1  1432  52  250  8  ]
      [  41  2  1  5  787  75  1  39  17  3  3  1  1399  52  350  8  ]
      [  58  1  1  5  796  70  8  39  17  1  3  1  1403  52  330  8  ]
      [  28  2  1  6  521  28  8  40  -1  1  -1  1  1442  52  -1  8  ]
      [  28  1  1  6  269  34  8  35  -1  1  3  1  1496  52  383  8  ]
      [  49  2  1  5  788  85  8  35  13  5  9  1  1302  52  266  8  ]
      [  41  2  1  5  857  85  8  38  16  5  9  1  1449  52  338  8  ]
      [  59  2  1  5  787  64  8  38  -1  3  4  1  1330  52  -1  8  ]
      [  29  2  1  5  678  52  8  39  18  5  8  1  1656  52  399  9  ]
      [  53  2  1  5  787  75  1  38  10  1  3  1  1674  52  193  9  ]
      [  62  1  8  -1  -1  -1  -1  -1  11  1  3  3  1555  52  222  9  ]
      [  34  1  1  9  801  75  1  40  17  4  3  1  1564  52  380  14  ]
      [  62  2  8  -1  -1  -1  -1  -1  22  1  -1  3  1566  52  380  9  ]
      [  28  2  1  5  626  33  8  40  18  5  4  1  1562  52  371  9  ]
      [  77  2  8  -1  -1  -1  -1  -1  9  1  6  3  1549  52  157  9  ]
      [  51  1  1  6  323  34  8  36  11  1  3  1  1931  52  202  14  ]
      [  32  1  1  6  714  45  8  44  13  1  3  1  1718  52  280  10  ]
      [  46  2  1  5  863  80  1  40  10  2  6  1  1807  52  220  10  ]
      [  50  1  1  5  721  63  8  50  11  3  5  1  2009  52  200  11  ]
      [  64  2  8  -1  -1  -1  -1  -1  11  4  8  3  2185  52  210  11  ]
      [  31  1  1  5  691  65  8  39  11  3  4  1  2286  52  181  11  ]
      [  53  2  1  2  911  55  8  40  -1  3  -1  5  2406  52  -1  17  ]
      [  44  1  1  4  872  80  1  40  23  5  10  1  2551  52  500  12  ]
      [  35  1  1  5  607  29  8  40  12  4  8  1  2339  52  235  13  ]
      [  82  2  8  -1  -1  -1  -1  -1  22  5  5  3  2528  52  510  12  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  5  7  3  3018  52  -1  14  ]
      [  31  1  1  5  757  74  8  50  13  5  9  1  4059  52  269  17  ]
      [  78  1  8  -1  -1  -1  -1  -1  34  -1  -1  3  67  51  432  6  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  171  51  -1  4  ]
      [  30  1  8  5  874  80  8  2  11  5  3  4  310  51  198  3  ]
      [  46  1  8  -1  -1  -1  -1  -1  -1  -1  -1  2  424  51  391  3  ]
      [  62  1  8  -1  -1  -1  -1  -1  13  1  -1  3  408  51  250  5  ]
      [  22  1  8  -1  -1  -1  -1  -1  10  5  -1  4  458  51  194  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  20  1  3  2  395  51  402  8  ]
      [  41  2  8  -1  -1  -1  -1  -1  19  1  -1  6  654  51  420  6  ]
      [  32  1  1  7  774  72  8  40  10  5  -1  8  595  51  196  4  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  696  51  -1  4  ]
      [  73  2  8  -1  -1  -1  -1  -1  11  1  3  3  603  51  190  4  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  1  -1  3  553  51  250  4  ]
      [  83  2  8  -1  -1  -1  -1  -1  13  3  3  3  611  51  313  4  ]
      [  41  2  8  -1  -1  -1  -1  -1  13  2  3  2  662  51  270  5  ]
      [  45  2  8  -1  -1  -1  -1  -1  11  2  6  2  516  51  220  4  ]
      [  68  2  8  -1  -1  -1  -1  -1  11  1  -1  3  813  51  213  5  ]
      [  60  2  8  -1  -1  -1  -1  -1  14  1  4  6  791  51  241  5  ]
      [  54  2  8  -1  -1  -1  -1  -1  10  3  3  3  787  51  220  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  788  51  -1  5  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  1  3  3  841  51  281  5  ]
      [  37  2  8  -1  -1  -1  -1  -1  -1  4  99  4  786  51  -1  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  8  1  -1  3  844  51  145  9  ]
      [  25  1  8  -1  -1  -1  -1  -1  12  1  3  2  841  51  240  10  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  869  51  -1  10  ]
      [  63  2  1  6  934  80  1  20  12  -1  -1  1  793  51  235  5  ]
      [  83  2  8  -1  -1  -1  -1  -1  8  3  4  3  752  51  145  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  2  3  3  854  51  180  8  ]
      [  75  1  8  -1  -1  -1  -1  -1  13  1  3  3  900  51  311  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  10  1  3  3  1081  51  202  6  ]
      [  73  1  8  -1  -1  -1  -1  -1  8  1  -1  3  972  51  144  9  ]
      [  35  1  1  6  491  45  8  40  11  2  3  1  999  51  211  6  ]
      [  75  2  8  -1  -1  -1  -1  -1  10  3  8  3  1078  51  200  6  ]
      [  81  2  8  -1  -1  -1  -1  -1  11  1  -1  3  955  51  220  6  ]
      [  60  1  1  4  712  65  8  38  12  1  3  1  1125  51  180  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  10  1  3  3  1186  51  227  7  ]
      [  89  2  8  -1  -1  -1  -1  -1  7  1  1  3  1241  51  120  7  ]
      [  67  2  8  -1  -1  -1  -1  -1  17  1  -1  3  1104  51  354  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  18  1  3  3  1430  51  408  8  ]
      [  47  1  1  6  540  24  8  40  15  1  3  1  1462  51  270  12  ]
      [  46  1  1  6  171  22  8  40  10  2  3  1  1389  51  165  8  ]
      [  74  2  8  -1  -1  -1  -1  -1  10  3  6  3  1383  51  214  8  ]
      [  82  1  8  -1  -1  -1  -1  -1  25  1  3  3  1693  51  550  10  ]
      [  39  1  1  6  221  33  8  38  -1  2  3  1  1594  51  -1  9  ]
      [  52  1  1  6  255  27  8  37  19  1  3  1  1803  51  400  11  ]
      [  28  1  1  5  521  72  8  40  21  5  9  1  1843  51  450  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  21  1  3  3  1803  51  432  13  ]
      [  47  2  1  4  872  80  1  38  16  5  9  1  2226  51  340  11  ]
      [  54  2  1  5  776  74  8  36  16  5  9  1  2448  51  320  12  ]
      [  36  1  1  5  875  80  1  20  -1  2  4  1  2350  51  -1  12  ]
      [  35  2  8  -1  -1  -1  -1  -1  -1  3  3  4  86  50  -1  11  ]
      [  25  1  8  -1  -1  -1  -1  -1  50  4  -1  3  297  50  -1  2  ]
      [  57  2  8  -1  -1  -1  -1  -1  11  9  -1  6  255  50  202  5  ]
      [  71  2  8  -1  -1  -1  -1  -1  5  -1  -1  3  309  50  80  3  ]
      [  54  2  1  2  673  52  8  60  8  1  3  1  343  50  141  3  ]
      [  63  2  8  -1  -1  -1  -1  -1  12  1  1  3  338  50  240  10  ]
      [  58  2  8  5  901  93  8  10  11  1  3  1  372  50  199  3  ]
      [  57  2  8  -1  -1  -1  -1  -1  8  1  3  2  342  50  145  3  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  5  359  50  -1  6  ]
      [  35  1  1  6  705  51  8  16  14  1  -1  1  452  50  240  3  ]
      [  65  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  341  50  400  3  ]
      [  71  2  8  -1  -1  -1  -1  -1  6  1  -1  3  463  50  108  3  ]
      [  64  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  440  50  0  3  ]
      [  19  2  1  8  864  85  8  40  10  3  -1  1  382  50  210  3  ]
      [  40  2  1  5  780  52  8  20  16  4  -1  1  394  50  340  4  ]
      [  33  1  1  1  11  45  8  50  12  1  3  1  323  50  250  3  ]
      [  53  1  1  6  522  85  8  38  11  -1  -1  1  327  50  200  3  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  3  3  319  50  -1  3  ]
      [  58  1  8  -1  -1  -1  -1  -1  9  1  3  2  375  50  175  9  ]
      [  27  1  1  5  780  92  8  12  -1  5  -1  1  398  50  0  3  ]
      [  43  2  8  -1  -1  -1  -1  -1  50  2  3  2  471  50  -1  3  ]
      [  46  1  8  -1  -1  -1  -1  -1  -1  2  3  2  415  50  -1  3  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  3  3  668  50  240  4  ]
      [  34  1  8  -1  -1  -1  -1  -1  8  1  -1  2  520  50  147  9  ]
      [  77  2  8  -1  -1  -1  -1  -1  7  -1  -1  3  681  50  110  4  ]
      [  59  2  1  5  744  51  8  13  21  1  -1  1  650  50  400  4  ]
      [  23  1  1  10  801  75  1  38  11  3  3  1  544  50  228  4  ]
      [  39  2  8  -1  -1  -1  -1  -1  10  1  3  8  537  50  195  4  ]
      [  41  1  8  -1  -1  -1  -1  -1  9  1  3  2  657  50  175  4  ]
      [  33  2  8  5  714  60  8  6  13  5  3  2  650  50  265  10  ]
      [  91  2  8  -1  -1  -1  -1  -1  -1  1  -1  7  510  50  0  4  ]
      [  68  1  8  -1  -1  -1  -1  -1  10  -1  -1  6  601  50  200  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  671  50  0  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  3  3  599  50  -1  4  ]
      [  64  1  8  -1  -1  -1  -1  -1  12  1  3  3  668  50  250  4  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  592  50  -1  4  ]
      [  76  2  8  -1  -1  -1  -1  -1  21  -1  -1  3  684  50  400  4  ]
      [  37  1  1  6  731  64  8  38  11  1  3  1  523  50  200  4  ]
      [  49  1  8  -1  -1  -1  -1  -1  10  1  -1  3  628  50  201  4  ]
      [  61  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  569  50  200  4  ]
      [  47  1  8  -1  -1  -1  -1  -1  16  3  3  5  601  50  333  4  ]
      [  50  1  8  6  411  55  8  9  11  3  -1  6  610  50  194  4  ]
      [  31  2  8  -1  -1  -1  -1  -1  10  3  3  2  602  50  153  4  ]
      [  49  1  8  -1  -1  -1  -1  -1  12  2  3  6  643  50  240  4  ]
      [  41  1  8  -1  -1  -1  -1  -1  16  1  4  2  651  50  280  7  ]
      [  87  2  8  -1  -1  -1  -1  -1  8  1  3  3  680  50  139  4  ]
      [  54  2  1  5  661  15  8  40  8  2  3  1  600  50  141  4  ]
      [  61  1  8  -1  -1  -1  -1  -1  10  2  3  3  698  50  190  4  ]
      [  84  1  8  -1  -1  -1  -1  -1  -1  1  5  3  513  50  -1  8  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  523  50  0  4  ]
      [  21  2  1  7  691  65  8  39  10  5  -1  1  620  50  194  7  ]
      [  34  2  8  -1  -1  -1  -1  -1  13  2  3  8  591  50  200  4  ]
      [  43  1  8  -1  -1  -1  -1  -1  8  1  3  3  678  50  149  4  ]
      [  75  2  8  -1  -1  -1  -1  -1  13  1  6  3  667  50  270  4  ]
      [  58  1  8  -1  -1  -1  -1  -1  13  1  1  3  542  50  280  8  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  2  5  2  572  50  -1  6  ]
      [  25  1  8  -1  -1  -1  -1  -1  14  1  -1  2  874  50  256  7  ]
      [  83  2  8  -1  -1  -1  -1  -1  10  1  3  3  792  50  194  5  ]
      [  23  1  1  7  780  28  8  38  18  5  -1  1  722  50  387  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  23  1  -1  3  884  50  430  5  ]
      [  48  2  8  -1  -1  -1  -1  -1  -1  3  6  2  829  50  -1  5  ]
      [  77  1  8  -1  -1  -1  -1  -1  12  1  -1  3  801  50  250  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  10  1  -1  3  731  50  200  5  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  863  50  0  5  ]
      [  50  2  8  -1  -1  -1  -1  -1  12  -1  -1  6  848  50  240  5  ]
      [  46  2  8  -1  -1  -1  -1  -1  13  3  3  6  719  50  260  5  ]
      [  81  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  738  50  150  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  789  50  -1  5  ]
      [  29  1  1  5  778  64  8  42  18  1  3  1  885  50  385  9  ]
      [  85  1  8  -1  -1  -1  -1  -1  -1  1  3  3  807  50  -1  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  887  50  162  5  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  3  3  860  50  -1  5  ]
      [  46  2  8  -1  -1  -1  -1  -1  -1  1  -1  6  840  50  -1  5  ]
      [  40  1  1  5  997  85  1  37  13  1  -1  1  892  50  300  5  ]
      [  41  2  8  -1  -1  -1  -1  -1  -1  1  3  3  700  50  237  5  ]
      [  38  2  1  5  674  52  8  8  -1  5  3  2  811  50  0  5  ]
      [  66  1  8  -1  -1  -1  -1  -1  14  1  3  3  702  50  290  5  ]
      [  48  2  8  -1  -1  -1  -1  -1  14  4  4  3  719  50  250  5  ]
      [  21  2  8  -1  -1  -1  -1  -1  -1  1  3  4  728  50  0  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  703  50  -1  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  785  50  0  9  ]
      [  84  2  8  -1  -1  -1  -1  -1  17  1  3  3  897  50  350  5  ]
      [  23  1  1  6  501  75  1  40  11  1  -1  6  888  50  200  5  ]
      [  67  1  8  -1  -1  -1  -1  -1  9  1  3  3  760  50  130  5  ]
      [  58  1  8  -1  -1  -1  -1  -1  12  -1  -1  3  749  50  230  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  2  5  3  845  50  0  8  ]
      [  83  2  8  -1  -1  -1  -1  -1  8  1  -1  3  711  50  132  5  ]
      [  33  2  1  5  912  55  8  40  14  2  3  1  758  50  262  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  6  1  3  3  722  50  120  5  ]
      [  59  2  1  5  788  50  8  37  11  1  3  1  780  50  219  5  ]
      [  39  1  1  6  411  55  8  40  17  1  3  1  702  50  290  5  ]
      [  55  1  8  -1  -1  -1  -1  -1  10  4  8  2  890  50  204  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  11  1  3  3  702  50  193  5  ]
      [  77  1  8  -1  -1  -1  -1  -1  9  1  3  3  822  50  183  5  ]
      [  68  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  883  50  -1  5  ]
      [  25  1  1  5  391  15  8  40  7  1  3  1  781  50  135  5  ]
      [  43  2  8  -1  -1  -1  -1  -1  14  5  9  2  1009  50  307  13  ]
      [  32  1  8  -1  -1  -1  -1  -1  13  2  -1  2  951  50  248  6  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  3  3  961  50  -1  6  ]
      [  37  2  1  7  671  51  8  38  10  5  5  1  908  50  150  6  ]
      [  68  2  8  -1  -1  -1  -1  -1  17  -1  -1  3  1017  50  300  6  ]
      [  48  2  1  1  834  92  8  60  18  3  3  1  1089  50  370  6  ]
      [  32  1  1  6  181  20  8  38  6  3  3  1  960  50  105  6  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  968  50  -1  6  ]
      [  81  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1057  50  -1  8  ]
      [  31  1  1  6  51  1  8  38  6  1  3  1  1018  50  100  6  ]
      [  70  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1049  50  200  6  ]
      [  19  1  1  6  997  64  8  39  14  3  3  1  1097  50  303  9  ]
      [  79  2  8  -1  -1  -1  -1  -1  14  1  -1  3  909  50  250  6  ]
      [  22  1  1  5  267  45  8  40  15  3  3  1  941  50  300  6  ]
      [  21  1  1  6  281  34  8  40  13  1  -1  1  1058  50  250  6  ]
      [  78  2  8  -1  -1  -1  -1  -1  11  1  -1  3  973  50  220  6  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  1  1  3  969  50  220  6  ]
      [  67  2  8  -1  -1  -1  -1  -1  7  1  -1  3  1075  50  110  6  ]
      [  36  1  1  5  912  55  8  38  16  -1  -1  1  901  50  350  6  ]
      [  82  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  964  50  0  6  ]
      [  42  2  1  6  773  52  8  30  12  1  3  1  961  50  256  6  ]
      [  38  1  1  6  269  50  8  37  -1  1  3  1  996  50  -1  12  ]
      [  43  2  1  5  780  29  8  45  12  1  3  1  945  50  279  6  ]
      [  36  1  1  6  51  1  1  30  15  -1  -1  1  1018  50  300  6  ]
      [  26  2  1  5  787  64  8  40  13  3  3  1  1036  50  200  6  ]
      [  74  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  913  50  210  13  ]
      [  24  1  1  6  487  45  8  37  -1  1  1  1  929  50  -1  10  ]
      [  26  1  1  6  937  90  8  40  10  1  -1  1  923  50  210  10  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  918  50  -1  9  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1049  50  0  7  ]
      [  27  2  1  5  856  85  8  32  14  3  3  1  1001  50  250  6  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  929  50  0  6  ]
      [  21  2  1  5  858  75  1  38  17  3  4  1  1029  50  330  6  ]
      [  48  2  1  6  934  85  8  30  11  1  -1  1  949  50  200  6  ]
      [  41  2  1  5  821  92  8  12  11  5  9  1  1059  50  180  6  ]
      [  38  2  1  5  853  85  8  24  12  5  3  1  1054  50  244  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  9  1  3  3  993  50  156  6  ]
      [  66  2  8  -1  -1  -1  -1  -1  13  1  3  3  982  50  252  6  ]
      [  75  2  8  -1  -1  -1  -1  -1  11  1  3  3  904  50  223  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1085  50  200  6  ]
      [  49  2  1  6  23  1  8  40  -1  1  3  1  1059  50  300  6  ]
      [  74  1  8  -1  -1  -1  -1  -1  10  1  6  3  988  50  200  11  ]
      [  52  1  1  6  460  45  8  40  13  1  3  1  1022  50  260  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  12  1  3  3  906  50  251  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1093  50  -1  6  ]
      [  88  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1072  50  253  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1041  50  0  6  ]
      [  69  1  8  -1  -1  -1  -1  -1  12  1  5  3  1058  50  256  6  ]
      [  52  1  1  6  796  70  8  38  15  2  3  1  1090  50  280  10  ]
      [  88  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  957  50  200  6  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1016  50  262  9  ]
      [  71  2  8  -1  -1  -1  -1  -1  11  3  3  3  975  50  200  6  ]
      [  66  1  8  -1  -1  -1  -1  -1  12  1  3  3  1013  50  210  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  10  1  3  3  962  50  204  9  ]
      [  79  2  8  -1  -1  -1  -1  -1  5  5  6  3  1079  50  100  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  5  3  1062  50  225  6  ]
      [  32  1  1  5  788  51  8  39  14  4  3  1  1230  50  280  7  ]
      [  22  1  1  5  912  55  8  10  -1  5  -1  1  1282  50  -1  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  1183  50  195  7  ]
      [  78  2  8  -1  -1  -1  -1  -1  19  1  3  3  1297  50  330  7  ]
      [  26  1  1  6  741  36  8  40  6  1  3  1  1117  50  112  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  3  3  1111  50  157  7  ]
      [  28  2  1  5  662  52  8  38  -1  1  -1  1  1146  50  -1  7  ]
      [  78  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1189  50  280  7  ]
      [  26  2  1  5  873  80  1  50  12  5  9  1  1191  50  250  7  ]
      [  28  2  1  4  731  64  8  38  16  1  3  1  1191  50  320  7  ]
      [  35  2  1  5  672  52  8  39  15  3  1  1  1158  50  295  7  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1262  50  200  7  ]
      [  36  2  1  5  714  60  8  38  20  1  3  1  1213  50  385  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1163  50  -1  9  ]
      [  24  2  1  5  867  80  1  38  7  3  1  1  1170  50  130  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  -1  5  3  3  1282  50  -1  7  ]
      [  24  1  1  5  788  35  8  40  16  4  3  1  1106  50  330  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  11  -1  -1  3  1109  50  200  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  10  1  -1  3  1141  50  185  7  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1262  50  -1  7  ]
      [  31  2  1  6  661  15  8  30  14  3  -1  1  1238  50  290  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1237  50  0  8  ]
      [  46  2  1  5  531  32  8  35  17  1  -1  1  1249  50  340  8  ]
      [  27  1  1  5  672  52  8  40  14  1  -1  1  1101  50  300  11  ]
      [  56  1  1  6  440  45  8  38  14  1  -1  1  1282  50  300  7  ]
      [  21  1  1  6  997  50  8  40  9  3  3  1  1187  50  200  7  ]
      [  37  1  1  6  531  45  8  40  12  1  3  1  1287  50  276  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1222  50  -1  8  ]
      [  29  1  1  6  744  51  8  39  13  3  3  1  1108  50  270  7  ]
      [  38  2  1  5  626  75  1  39  13  5  4  1  1289  50  282  7  ]
      [  45  1  1  6  269  45  8  40  13  1  1  1  1274  50  266  7  ]
      [  39  2  1  5  854  85  1  39  -1  1  3  1  1244  50  200  7  ]
      [  21  1  1  5  673  52  8  37  17  3  3  1  1157  50  327  7  ]
      [  23  1  1  4  997  75  1  36  15  3  -1  1  1218  50  335  9  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  3  99  3  1296  50  -1  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1140  50  0  7  ]
      [  31  2  1  5  672  52  8  39  15  1  -1  1  1204  50  256  7  ]
      [  64  2  8  -1  -1  -1  -1  -1  14  1  -1  3  1194  50  300  7  ]
      [  28  2  1  5  673  52  8  38  10  3  3  1  1120  50  205  7  ]
      [  22  2  1  5  691  65  8  39  -1  5  3  1  1108  50  250  20  ]
      [  70  2  8  -1  -1  -1  -1  -1  14  1  -1  3  1250  50  250  7  ]
      [  44  2  1  5  774  72  9  40  14  4  8  1  1281  50  280  7  ]
      [  57  2  8  -1  -1  -1  -1  -1  12  9  5  8  1140  50  215  7  ]
      [  41  2  1  5  661  55  8  10  15  5  5  1  1258  50  284  10  ]
      [  75  2  8  -1  -1  -1  -1  -1  13  1  3  3  1292  50  226  7  ]
      [  36  1  1  6  442  45  8  39  12  2  3  1  1178  50  220  7  ]
      [  74  1  8  -1  -1  -1  -1  -1  9  1  3  3  1170  50  188  7  ]
      [  30  2  1  5  703  52  8  40  12  2  5  1  1160  50  260  7  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  5  3  1108  50  -1  7  ]
      [  76  2  8  -1  -1  -1  -1  -1  18  5  6  3  1147  50  350  7  ]
      [  72  1  8  -1  -1  -1  -1  -1  11  1  3  3  1213  50  215  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  5  3  3  1144  50  234  7  ]
      [  28  1  1  6  441  45  8  40  11  3  3  1  1185  50  228  7  ]
      [  32  1  1  6  268  45  8  40  -1  2  3  1  1206  50  -1  12  ]
      [  29  2  1  5  863  85  8  35  13  3  4  1  1348  50  240  8  ]
      [  44  1  8  -1  -1  -1  -1  -1  15  1  3  5  1445  50  350  12  ]
      [  90  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1316  50  -1  8  ]
      [  37  1  1  6  531  52  8  38  -1  3  99  1  1399  50  -1  8  ]
      [  32  2  1  5  861  85  8  38  15  4  8  1  1307  50  305  8  ]
      [  28  2  1  5  853  85  8  40  13  4  2  1  1327  50  258  8  ]
      [  31  1  1  5  714  15  8  50  13  1  3  1  1449  50  270  8  ]
      [  26  1  1  5  853  85  1  38  -1  3  5  1  1363  50  200  8  ]
      [  46  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  1459  50  260  13  ]
      [  73  1  8  -1  -1  -1  -1  -1  15  -1  -1  3  1496  50  279  8  ]
      [  72  1  8  -1  -1  -1  -1  -1  14  1  -1  3  1463  50  300  8  ]
      [  40  1  1  6  744  26  8  60  27  1  99  1  1324  50  500  10  ]
      [  79  1  8  -1  -1  -1  -1  -1  9  1  3  3  1449  50  150  8  ]
      [  61  1  1  5  254  85  1  38  -1  1  3  1  1419  50  -1  8  ]
      [  37  1  1  6  488  45  8  42  16  -1  -1  1  1476  50  340  8  ]
      [  52  1  1  5  787  80  1  38  14  4  3  1  1497  50  280  8  ]
      [  27  1  1  5  662  64  8  38  17  4  8  1  1331  50  350  8  ]
      [  50  2  1  5  662  52  8  28  -1  1  3  3  1493  50  -1  8  ]
      [  28  1  1  6  935  90  8  45  13  1  -1  1  1443  50  270  10  ]
      [  36  1  1  6  714  60  1  39  18  1  -1  1  1332  50  356  8  ]
      [  49  2  1  5  853  91  8  38  17  3  3  1  1391  50  390  8  ]
      [  29  2  1  6  540  26  8  40  12  2  3  1  1401  50  230  8  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1331  50  0  8  ]
      [  38  1  1  5  780  61  8  40  12  5  8  1  1398  50  250  16  ]
      [  34  1  1  6  311  31  8  40  10  3  3  1  1404  50  183  8  ]
      [  37  2  8  -1  -1  -1  -1  -1  13  2  6  6  1382  50  250  8  ]
      [  41  1  1  4  802  75  1  40  -1  2  3  1  1329  50  50  8  ]
      [  39  1  1  5  778  80  8  38  13  5  9  1  1391  50  241  8  ]
      [  22  1  1  5  305  33  8  40  14  3  3  1  1432  50  298  8  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1426  50  -1  8  ]
      [  38  2  1  5  863  85  8  37  9  2  6  1  1363  50  172  8  ]
      [  32  1  1  5  821  80  1  40  14  5  7  1  1332  50  311  8  ]
      [  87  2  8  -1  -1  -1  -1  -1  13  3  6  3  1433  50  240  8  ]
      [  25  2  1  4  765  75  1  40  17  4  7  1  1587  50  357  9  ]
      [  34  1  1  5  611  24  8  38  17  4  8  1  1523  50  311  16  ]
      [  45  1  1  6  254  34  8  35  17  -1  99  1  1645  50  250  9  ]
      [  36  2  1  5  750  85  1  50  20  5  9  1  1633  50  430  9  ]
      [  77  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  1687  50  210  9  ]
      [  27  1  1  5  701  51  8  43  21  5  4  1  1637  50  404  9  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  1  3  1531  50  -1  9  ]
      [  33  1  1  5  881  23  8  42  16  5  9  1  1635  50  337  9  ]
      [  55  1  1  1  777  72  8  10  14  3  3  3  1666  50  262  9  ]
      [  25  2  1  5  786  74  8  40  29  3  3  1  1658  50  600  9  ]
      [  44  2  1  5  751  65  8  40  18  3  3  1  1667  50  380  9  ]
      [  47  2  8  -1  -1  -1  -1  -1  -1  -1  -1  5  1534  50  -1  9  ]
      [  33  2  1  5  751  52  8  39  13  5  3  1  1501  50  243  9  ]
      [  35  2  1  5  789  34  8  35  21  3  99  1  1511  50  400  9  ]
      [  38  2  1  5  788  29  8  40  13  5  9  1  1509  50  252  9  ]
      [  43  1  1  6  316  29  8  30  15  3  3  1  1502  50  325  9  ]
      [  36  2  1  5  775  74  8  40  25  -1  -1  1  1521  50  450  9  ]
      [  35  1  1  6  310  26  8  38  7  3  3  1  1679  50  140  9  ]
      [  47  1  1  6  651  60  8  39  -1  1  3  1  1546  50  -1  13  ]
      [  44  1  1  2  821  92  8  40  12  5  10  1  1558  50  240  9  ]
      [  49  1  1  6  274  28  8  40  6  2  3  1  1688  50  111  9  ]
      [  47  1  1  5  796  45  8  40  11  2  3  1  1532  50  210  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  8  3  3  3  1640  50  150  10  ]
      [  43  1  1  6  531  75  1  40  13  2  6  1  1632  50  258  9  ]
      [  31  1  8  -1  -1  -1  -1  -1  21  5  9  4  1836  50  432  10  ]
      [  29  2  1  5  844  52  8  38  17  5  9  1  1791  50  360  10  ]
      [  36  2  1  5  789  24  8  40  -1  3  -1  1  1961  50  -1  10  ]
      [  43  1  1  6  714  63  8  48  15  9  -1  1  1772  50  300  10  ]
      [  50  1  1  5  853  85  8  38  -1  1  3  1  1955  50  -1  10  ]
      [  62  1  1  2  488  45  8  35  -1  1  5  1  1759  50  -1  10  ]
      [  30  2  1  5  787  40  8  38  18  5  3  1  1903  50  320  10  ]
      [  41  1  1  6  714  63  8  40  -1  1  3  1  1738  50  -1  10  ]
      [  50  1  1  6  741  28  8  40  15  1  3  1  1885  50  250  10  ]
      [  26  1  1  5  842  85  8  40  17  5  9  1  1819  50  365  10  ]
      [  25  2  1  5  757  74  8  40  -1  5  9  1  1791  50  390  15  ]
      [  47  1  1  6  310  45  8  37  10  1  3  1  1817  50  158  14  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  3  7  3  1958  50  -1  14  ]
      [  54  1  1  1  702  63  8  98  8  5  99  1  1941  50  147  10  ]
      [  25  1  1  5  689  64  8  40  -1  3  5  1  1889  50  -1  10  ]
      [  57  1  1  5  602  40  1  38  15  2  6  1  1866  50  270  14  ]
      [  56  1  8  -1  -1  -1  -1  -1  -1  1  3  8  1851  50  -1  12  ]
      [  65  1  8  -1  -1  -1  -1  -1  18  5  9  4  2084  50  345  11  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  2297  50  -1  11  ]
      [  35  1  1  6  602  33  8  40  16  5  9  1  2014  50  325  11  ]
      [  61  1  8  -1  -1  -1  -1  -1  23  3  3  3  2181  50  520  11  ]
      [  35  2  1  2  687  67  8  40  -1  2  3  1  2179  50  0  13  ]
      [  27  1  1  1  691  74  8  60  10  3  3  1  2398  50  200  12  ]
      [  39  1  1  5  780  28  8  35  15  5  8  1  2402  50  300  12  ]
      [  43  1  1  4  765  75  1  38  13  4  7  1  2480  50  250  12  ]
      [  36  1  1  5  676  52  8  65  12  1  5  1  2443  50  238  12  ]
      [  42  1  1  5  501  45  8  40  13  3  3  1  2547  50  280  12  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2584  50  -1  12  ]
      [  44  1  1  4  870  80  1  38  17  5  10  1  2385  50  360  12  ]
      [  35  1  1  5  600  24  8  40  16  5  8  1  2335  50  337  12  ]
      [  29  2  1  5  780  51  8  40  14  5  3  1  2600  50  276  13  ]
      [  50  1  1  1  821  92  8  50  24  5  -1  1  3048  50  550  14  ]
      [  38  1  1  5  623  40  8  35  18  2  3  1  3335  50  390  15  ]
      [  34  1  1  5  602  30  8  40  21  5  9  1  3650  50  480  16  ]
      [  56  1  1  5  603  29  8  60  25  -1  -1  1  7275  50  500  21  ]
      [  68  1  8  -1  -1  -1  -1  -1  16  -1  -1  3  188  49  323  6  ]
      [  18  2  1  7  921  80  8  38  13  1  -1  1  327  49  228  3  ]
      [  57  2  8  -1  -1  -1  -1  -1  9  1  3  6  302  49  142  3  ]
      [  32  2  1  6  934  92  8  15  16  1  -1  1  503  49  307  6  ]
      [  59  1  8  -1  -1  -1  -1  -1  8  1  3  2  650  49  113  4  ]
      [  59  1  8  -1  -1  -1  -1  -1  10  1  3  2  691  49  191  4  ]
      [  35  2  8  5  52  74  8  30  13  5  9  1  516  49  280  8  ]
      [  31  1  8  -1  -1  -1  -1  -1  14  3  3  3  786  49  225  5  ]
      [  74  2  8  -1  -1  -1  -1  -1  13  1  -1  3  897  49  240  5  ]
      [  86  2  8  -1  -1  -1  -1  -1  16  1  -1  3  813  49  300  5  ]
      [  89  2  8  -1  -1  -1  -1  -1  11  1  3  3  871  49  200  5  ]
      [  54  1  8  -1  -1  -1  -1  -1  10  -1  -1  6  715  49  210  5  ]
      [  51  2  1  6  162  21  8  40  11  1  -1  1  779  49  220  7  ]
      [  61  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  848  49  200  5  ]
      [  34  2  1  5  787  75  1  35  -1  3  3  1  872  49  -1  14  ]
      [  63  1  8  -1  -1  -1  -1  -1  13  1  3  3  798  49  240  11  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  3  3  725  49  -1  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  12  1  -1  3  897  49  250  5  ]
      [  66  2  1  5  931  93  8  15  15  1  99  3  1031  49  250  6  ]
      [  43  1  8  -1  -1  -1  -1  -1  7  5  9  5  934  49  120  6  ]
      [  68  2  8  6  934  74  8  11  15  1  -1  1  942  49  314  6  ]
      [  18  1  1  6  744  61  8  40  13  1  -1  1  969  49  250  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  15  -1  -1  3  942  49  299  9  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  3  5  3  1091  49  0  6  ]
      [  51  1  1  5  662  52  8  35  16  1  3  1  968  49  309  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1066  49  191  6  ]
      [  55  1  8  -1  -1  -1  -1  -1  10  2  1  4  1020  49  146  6  ]
      [  40  2  8  -1  -1  -1  -1  -1  13  5  9  2  968  49  215  6  ]
      [  73  2  8  -1  -1  -1  -1  -1  12  1  3  3  952  49  240  6  ]
      [  64  1  8  -1  -1  -1  -1  -1  13  1  3  3  1063  49  234  11  ]
      [  64  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1203  49  -1  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  13  1  3  3  1166  49  197  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1169  49  -1  7  ]
      [  71  2  8  -1  -1  -1  -1  -1  13  1  3  3  1296  49  270  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  10  1  6  3  1117  49  165  7  ]
      [  24  2  1  6  411  55  8  40  9  3  3  1  1133  49  160  7  ]
      [  69  2  8  -1  -1  -1  -1  -1  10  1  3  3  1206  49  195  7  ]
      [  60  2  1  6  788  75  1  40  8  2  4  1  1234  49  141  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  12  1  3  3  1131  49  242  7  ]
      [  60  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1148  49  -1  7  ]
      [  29  1  1  5  714  60  1  42  13  1  3  1  1368  49  239  8  ]
      [  40  2  1  5  853  85  1  30  11  3  3  1  1478  49  207  8  ]
      [  42  2  1  6  997  93  8  37  16  1  3  1  1348  49  330  8  ]
      [  91  2  8  -1  -1  -1  -1  -1  22  1  3  3  1401  49  460  8  ]
      [  50  1  1  5  411  85  1  39  14  1  3  1  1383  49  274  8  ]
      [  76  2  8  -1  -1  -1  -1  -1  15  1  3  3  1332  49  334  8  ]
      [  78  2  8  -1  -1  -1  -1  -1  19  1  3  3  1627  49  350  9  ]
      [  30  1  1  5  993  15  8  38  16  1  -1  1  1635  49  342  9  ]
      [  34  1  1  6  267  45  8  40  24  2  4  1  1603  49  560  9  ]
      [  37  1  1  5  837  74  8  40  11  3  3  1  1654  49  220  9  ]
      [  58  1  1  6  71  28  8  40  10  1  3  1  1525  49  144  9  ]
      [  53  1  1  4  784  75  1  38  15  1  3  1  2548  49  300  15  ]
      [  50  1  1  2  813  74  8  60  23  5  10  1  4864  49  535  18  ]
      [  69  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  233  48  250  6  ]
      [  44  1  8  -1  -1  -1  -1  -1  12  1  3  2  235  48  215  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  12  -1  -1  3  344  48  170  8  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  308  48  -1  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  50  -1  -1  3  420  48  -1  3  ]
      [  45  2  1  5  662  74  8  56  13  -1  -1  1  663  48  233  4  ]
      [  23  1  8  -1  -1  -1  -1  -1  16  5  -1  4  559  48  320  4  ]
      [  62  2  1  6  934  70  1  20  -1  1  -1  1  663  48  300  4  ]
      [  47  1  8  -1  -1  -1  -1  -1  -1  -1  -1  2  608  48  -1  4  ]
      [  67  2  8  -1  -1  -1  -1  -1  11  1  -1  3  599  48  215  4  ]
      [  24  2  1  6  934  74  8  10  8  1  3  4  554  48  155  9  ]
      [  76  1  8  -1  -1  -1  -1  -1  11  1  5  3  505  48  210  4  ]
      [  40  2  1  6  934  74  8  8  15  1  -1  6  618  48  320  5  ]
      [  88  2  8  -1  -1  -1  -1  -1  18  3  -1  3  521  48  400  4  ]
      [  59  2  8  -1  -1  -1  -1  -1  10  1  3  2  509  48  175  4  ]
      [  22  2  1  6  901  93  8  32  12  3  3  1  520  48  225  4  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  3  3  589  48  0  4  ]
      [  60  2  8  -1  -1  -1  -1  -1  10  1  3  3  694  48  208  4  ]
      [  84  1  8  -1  -1  -1  -1  -1  13  1  3  3  514  48  225  4  ]
      [  75  1  8  -1  -1  -1  -1  -1  9  3  3  3  630  48  154  9  ]
      [  23  1  1  5  714  60  8  40  10  3  3  1  609  48  170  4  ]
      [  62  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  614  48  200  4  ]
      [  81  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  815  48  155  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  8  -1  -1  3  761  48  140  5  ]
      [  28  1  1  6  531  15  8  40  12  4  3  1  815  48  200  5  ]
      [  22  2  8  -1  -1  -1  -1  -1  12  5  -1  8  833  48  200  5  ]
      [  86  2  8  -1  -1  -1  -1  -1  13  3  3  3  820  48  221  5  ]
      [  34  1  1  5  835  80  8  40  9  5  9  1  819  48  150  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  13  1  3  3  766  48  250  5  ]
      [  23  2  1  5  788  74  8  40  16  3  3  1  948  48  293  6  ]
      [  28  1  1  5  441  45  8  38  15  1  3  1  1019  48  266  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  -1  1  4  3  1098  48  -1  6  ]
      [  81  1  8  -1  -1  -1  -1  -1  15  1  5  3  945  48  240  6  ]
      [  38  1  8  -1  -1  -1  -1  -1  12  3  3  4  914  48  183  6  ]
      [  90  2  8  -1  -1  -1  -1  -1  14  1  -1  3  1015  48  255  6  ]
      [  32  1  1  6  511  20  8  40  15  1  -1  1  1034  48  250  6  ]
      [  52  2  1  5  912  55  8  40  21  1  99  1  909  48  400  6  ]
      [  20  1  1  6  255  28  8  35  13  1  3  1  1082  48  255  6  ]
      [  39  2  1  5  863  80  8  30  11  3  3  1  965  48  211  6  ]
      [  47  1  1  6  511  45  8  39  10  3  3  1  1042  48  190  6  ]
      [  29  2  1  5  931  93  8  39  10  1  -1  1  1037  48  145  6  ]
      [  27  2  1  5  692  66  8  30  10  3  3  1  1076  48  180  6  ]
      [  85  2  8  -1  -1  -1  -1  -1  12  1  3  3  1088  48  210  6  ]
      [  87  2  8  -1  -1  -1  -1  -1  10  1  3  3  1023  48  185  6  ]
      [  59  2  8  5  823  92  1  7  11  5  9  3  1021  48  224  6  ]
      [  62  1  8  -1  -1  -1  -1  -1  15  1  4  3  1085  48  300  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  14  1  6  3  1095  48  280  6  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1032  48  -1  6  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  3  5  3  960  48  -1  9  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  5  3  966  48  -1  6  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  99  3  1011  48  -1  9  ]
      [  33  2  1  5  788  30  8  39  17  3  3  1  1276  48  350  7  ]
      [  28  2  1  5  780  75  1  38  20  1  3  8  1107  48  279  7  ]
      [  28  2  1  2  911  55  8  70  10  1  -1  1  1135  48  150  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  10  1  3  3  1149  48  186  7  ]
      [  25  1  1  6  501  36  8  37  11  1  3  1  1226  48  220  7  ]
      [  33  2  1  5  754  74  8  38  -1  3  3  1  1298  48  -1  7  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1202  48  -1  10  ]
      [  35  1  1  6  310  45  8  35  13  2  4  1  1290  48  250  7  ]
      [  36  2  1  5  691  65  1  38  15  5  3  1  1222  48  300  7  ]
      [  91  2  8  -1  -1  -1  -1  -1  10  1  3  3  1294  48  190  7  ]
      [  48  1  1  6  521  25  8  38  10  9  3  1  1297  48  200  7  ]
      [  40  2  1  5  923  55  8  40  20  1  3  1  1261  48  430  7  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  1242  48  240  7  ]
      [  46  1  1  6  796  85  8  39  13  1  3  1  1235  48  259  9  ]
      [  30  2  1  5  780  22  8  38  13  4  3  1  1248  48  250  7  ]
      [  46  2  8  -1  -1  -1  -1  -1  12  -1  1  2  1113  48  218  7  ]
      [  64  2  8  -1  -1  -1  -1  -1  10  3  3  3  1189  48  160  7  ]
      [  47  1  8  5  780  60  8  38  -1  2  3  1  1191  48  -1  10  ]
      [  77  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1160  48  215  7  ]
      [  80  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1244  48  211  7  ]
      [  29  2  1  5  912  62  1  48  16  4  3  1  1474  48  310  8  ]
      [  38  2  8  -1  -1  -1  -1  -1  11  4  3  2  1399  48  241  8  ]
      [  37  1  1  5  701  29  8  35  10  1  -1  1  1425  48  150  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  15  1  3  3  1335  48  300  8  ]
      [  42  1  1  6  70  10  8  40  13  1  -1  1  1345  48  275  8  ]
      [  80  2  8  -1  -1  -1  -1  -1  9  1  3  3  1477  48  175  8  ]
      [  48  1  1  6  466  45  8  40  12  1  8  1  1480  48  265  8  ]
      [  42  1  1  6  788  34  8  35  15  1  -1  1  1449  48  320  8  ]
      [  72  2  8  -1  -1  -1  -1  -1  31  1  4  3  1416  48  605  8  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  2  3  3  1466  48  -1  8  ]
      [  36  1  1  6  174  22  8  35  12  3  3  1  1424  48  253  8  ]
      [  82  2  8  -1  -1  -1  -1  -1  12  -1  -1  3  1479  48  195  8  ]
      [  67  2  8  -1  -1  -1  -1  -1  -1  2  8  3  1455  48  -1  14  ]
      [  23  1  1  6  443  45  8  40  12  3  3  1  1306  48  227  10  ]
      [  84  1  8  -1  -1  -1  -1  -1  13  5  6  3  1412  48  238  11  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1394  48  -1  8  ]
      [  64  2  8  -1  -1  -1  -1  -1  8  5  9  3  1422  48  130  8  ]
      [  44  2  1  5  863  85  1  39  12  -1  -1  1  1671  48  242  9  ]
      [  36  1  1  5  701  63  8  35  20  5  3  1  1672  48  423  9  ]
      [  88  2  8  -1  -1  -1  -1  -1  18  3  3  3  1610  48  375  9  ]
      [  70  2  8  -1  -1  -1  -1  -1  24  -1  -1  3  1559  48  355  9  ]
      [  76  1  8  -1  -1  -1  -1  -1  8  3  1  3  1526  48  150  9  ]
      [  28  1  1  4  801  75  1  40  15  3  4  1  1649  48  270  9  ]
      [  28  2  1  5  755  36  8  45  18  5  5  1  1876  48  380  10  ]
      [  36  1  1  5  612  29  8  38  7  5  9  1  1939  48  150  10  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  3  6  3  1736  48  -1  10  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  2135  48  -1  14  ]
      [  30  1  1  5  777  72  8  45  22  5  -1  1  2503  48  450  12  ]
      [  71  1  8  -1  -1  -1  -1  -1  16  5  9  3  2854  48  269  13  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  3  3  2723  48  -1  13  ]
      [  56  2  8  -1  -1  -1  -1  -1  14  1  3  4  471  47  266  3  ]
      [  48  2  8  -1  -1  -1  -1  -1  16  1  -1  2  380  47  300  3  ]
      [  51  2  8  -1  -1  -1  -1  -1  16  1  3  4  315  47  300  3  ]
      [  58  2  8  -1  -1  -1  -1  -1  10  -1  -1  6  408  47  191  3  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  496  47  -1  3  ]
      [  22  2  1  6  661  52  8  10  -1  5  -1  1  320  47  -1  3  ]
      [  60  1  8  -1  -1  -1  -1  -1  13  1  3  2  688  47  247  4  ]
      [  74  1  8  -1  -1  -1  -1  -1  10  1  3  3  522  47  198  4  ]
      [  26  2  1  7  671  63  8  38  13  4  -1  1  500  47  280  5  ]
      [  42  1  8  -1  -1  -1  -1  -1  11  5  9  2  688  47  207  4  ]
      [  19  1  1  7  785  30  8  38  12  4  -1  1  544  47  195  6  ]
      [  47  1  8  -1  -1  -1  -1  -1  7  1  3  2  631  47  100  4  ]
      [  39  1  8  -1  -1  -1  -1  -1  11  5  3  2  609  47  182  4  ]
      [  65  2  8  -1  -1  -1  -1  -1  13  1  3  3  613  47  177  4  ]
      [  52  2  1  6  352  18  8  40  14  2  3  1  602  47  285  4  ]
      [  67  2  8  -1  -1  -1  -1  -1  13  1  -1  3  571  47  250  4  ]
      [  33  1  8  -1  -1  -1  -1  -1  11  2  3  2  555  47  186  4  ]
      [  39  2  8  -1  -1  -1  -1  -1  8  2  3  3  622  47  144  4  ]
      [  69  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  761  47  175  5  ]
      [  30  1  1  5  780  52  8  36  23  3  3  1  770  47  464  12  ]
      [  82  2  8  -1  -1  -1  -1  -1  14  1  -1  3  715  47  250  5  ]
      [  25  2  1  5  914  55  8  40  12  3  3  1  796  47  205  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  12  1  3  3  792  47  236  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  13  1  3  3  729  47  245  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  12  1  3  8  824  47  225  8  ]
      [  43  1  1  6  311  31  8  40  13  2  3  1  822  47  269  5  ]
      [  20  1  1  11  853  85  8  45  11  5  -1  1  900  47  222  5  ]
      [  79  2  8  -1  -1  -1  -1  -1  15  1  -1  3  990  47  288  6  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  921  47  -1  10  ]
      [  77  2  8  -1  -1  -1  -1  -1  15  1  3  3  972  47  285  6  ]
      [  94  1  8  -1  -1  -1  -1  -1  13  1  -1  3  1029  47  250  6  ]
      [  53  2  1  5  852  85  8  40  13  2  6  1  1057  47  254  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  12  1  -1  3  903  47  222  6  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1057  47  0  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  8  1  3  3  1283  47  130  8  ]
      [  75  2  8  -1  -1  -1  -1  -1  13  1  3  3  1167  47  245  7  ]
      [  69  2  8  -1  -1  -1  -1  -1  16  1  -1  3  1247  47  310  7  ]
      [  84  2  8  -1  -1  -1  -1  -1  11  1  3  3  1224  47  190  7  ]
      [  20  2  1  5  789  91  8  39  13  3  4  1  1199  47  220  7  ]
      [  91  2  8  -1  -1  -1  -1  -1  8  1  -1  3  1246  47  118  7  ]
      [  30  2  1  5  780  80  8  20  9  4  8  1  1149  47  160  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1149  47  200  7  ]
      [  38  2  1  5  911  91  1  38  17  3  3  1  1451  47  327  8  ]
      [  26  1  1  5  662  52  8  40  -1  5  9  1  1301  47  -1  8  ]
      [  38  2  1  2  750  55  8  70  11  4  8  1  1410  47  164  8  ]
      [  46  2  1  5  787  75  1  38  13  2  6  1  1423  47  213  8  ]
      [  39  2  1  5  861  85  1  38  18  4  5  1  1697  47  345  9  ]
      [  69  2  8  -1  -1  -1  -1  -1  7  1  3  3  1537  47  125  9  ]
      [  42  2  1  5  788  41  8  40  11  2  3  1  1661  47  195  9  ]
      [  40  1  1  5  600  91  1  20  18  5  10  1  1623  47  288  9  ]
      [  36  1  1  5  750  72  8  47  20  5  8  1  1978  47  420  10  ]
      [  28  1  1  5  620  21  8  38  15  1  3  1  1897  47  300  15  ]
      [  74  1  8  -1  -1  -1  -1  -1  13  5  5  3  1872  47  248  10  ]
      [  32  2  1  5  611  73  8  40  16  5  9  1  1803  47  265  10  ]
      [  43  1  1  6  161  21  8  38  14  1  3  1  2477  47  290  12  ]
      [  30  1  1  4  787  75  1  40  29  5  8  1  2662  47  540  13  ]
      [  38  1  1  5  692  66  8  40  -1  1  -1  1  3532  47  -1  15  ]
      [  26  2  8  -1  -1  -1  -1  -1  8  1  -1  8  261  46  136  2  ]
      [  50  1  8  -1  -1  -1  -1  -1  12  1  -1  6  279  46  185  3  ]
      [  72  2  8  -1  -1  -1  -1  -1  6  1  -1  3  404  46  122  3  ]
      [  40  1  8  -1  -1  -1  -1  -1  13  1  3  2  389  46  227  3  ]
      [  21  1  1  8  487  45  8  39  11  1  -1  1  647  46  220  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  675  46  253  4  ]
      [  42  1  8  -1  -1  -1  -1  -1  14  1  -1  2  616  46  250  4  ]
      [  80  1  8  -1  -1  -1  -1  -1  -1  4  9  6  559  46  -1  5  ]
      [  23  1  8  -1  -1  -1  -1  -1  18  5  -1  4  643  46  295  7  ]
      [  42  1  8  -1  -1  -1  -1  -1  7  -1  -1  2  558  46  116  4  ]
      [  62  2  8  -1  -1  -1  -1  -1  10  -1  -1  3  601  46  144  4  ]
      [  75  2  8  -1  -1  -1  -1  -1  9  1  -1  3  613  46  156  4  ]
      [  68  1  8  -1  -1  -1  -1  -1  15  1  -1  3  537  46  276  7  ]
      [  76  2  8  -1  -1  -1  -1  -1  11  1  1  3  565  46  196  4  ]
      [  39  2  1  8  51  1  8  40  22  3  3  1  819  46  390  5  ]
      [  75  1  8  -1  -1  -1  -1  -1  13  5  8  8  846  46  229  5  ]
      [  21  1  1  6  267  45  8  38  11  1  3  1  804  46  200  7  ]
      [  20  2  1  7  853  85  1  40  13  3  -1  1  736  46  215  5  ]
      [  28  1  1  6  401  15  8  40  10  4  3  1  866  46  180  5  ]
      [  43  1  8  -1  -1  -1  -1  -1  8  4  3  2  808  46  146  5  ]
      [  22  1  1  6  501  36  8  36  10  3  3  1  769  46  200  5  ]
      [  66  1  8  -1  -1  -1  -1  -1  7  1  3  3  794  46  117  5  ]
      [  60  2  8  -1  -1  -1  -1  -1  12  1  3  3  867  46  224  5  ]
      [  57  1  8  -1  -1  -1  -1  -1  16  1  3  2  890  46  300  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  3  3  740  46  -1  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  9  1  3  3  779  46  160  5  ]
      [  63  2  8  -1  -1  -1  -1  -1  14  1  3  3  916  46  252  6  ]
      [  37  2  8  -1  -1  -1  -1  -1  14  1  -1  6  917  46  237  6  ]
      [  32  1  1  5  854  85  8  40  15  3  4  8  1096  46  319  6  ]
      [  73  2  8  -1  -1  -1  -1  -1  14  1  -1  3  1081  46  280  6  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1021  46  194  6  ]
      [  52  1  8  -1  -1  -1  -1  -1  -1  9  -1  3  1053  46  -1  6  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  900  46  -1  6  ]
      [  58  2  1  5  661  52  8  25  17  1  -1  1  1097  46  300  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  19  1  -1  3  922  46  350  6  ]
      [  30  1  1  6  268  45  8  40  9  2  3  1  1065  46  140  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  12  1  3  3  1011  46  220  6  ]
      [  62  2  8  -1  -1  -1  -1  -1  11  1  6  3  998  46  195  6  ]
      [  81  2  8  -1  -1  -1  -1  -1  12  1  3  3  956  46  200  6  ]
      [  90  2  8  -1  -1  -1  -1  -1  11  1  -1  3  973  46  180  6  ]
      [  73  2  8  -1  -1  -1  -1  -1  12  1  3  3  984  46  240  6  ]
      [  31  2  1  1  902  93  8  70  14  5  3  1  1096  46  249  6  ]
      [  73  1  8  -1  -1  -1  -1  -1  11  1  5  3  944  46  185  10  ]
      [  64  2  8  -1  -1  -1  -1  -1  12  3  6  3  977  46  230  11  ]
      [  54  1  8  -1  -1  -1  -1  -1  17  1  -1  2  1166  46  350  7  ]
      [  48  2  8  -1  -1  -1  -1  -1  11  3  3  3  1175  46  170  7  ]
      [  27  1  1  1  833  92  8  90  -1  5  9  1  1117  46  0  7  ]
      [  58  2  1  5  787  75  1  40  12  4  8  1  1145  46  215  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  14  1  3  3  1186  46  270  7  ]
      [  73  1  8  -1  -1  -1  -1  -1  12  1  3  3  1299  46  242  10  ]
      [  74  2  8  -1  -1  -1  -1  -1  18  -1  -1  3  1300  46  333  8  ]
      [  46  2  1  5  521  74  8  40  13  5  3  1  1306  46  239  8  ]
      [  37  2  1  5  780  45  8  38  16  3  3  1  1348  46  300  8  ]
      [  42  2  1  6  411  55  8  20  24  -1  -1  1  1342  46  375  8  ]
      [  29  1  1  6  522  21  8  38  12  1  3  1  1369  46  225  8  ]
      [  22  2  1  4  801  75  1  40  8  4  3  1  1491  46  160  8  ]
      [  23  2  1  5  853  85  1  40  14  3  5  1  1471  46  260  8  ]
      [  30  2  1  5  705  74  8  40  15  3  3  1  1528  46  292  9  ]
      [  79  2  8  -1  -1  -1  -1  -1  10  3  3  3  1615  46  187  9  ]
      [  35  2  1  4  787  80  1  38  17  3  3  1  1784  46  350  10  ]
      [  23  1  1  6  254  28  8  38  16  1  3  1  1887  46  300  11  ]
      [  39  1  1  4  801  75  1  39  -1  3  3  1  1880  46  -1  10  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  2  6  3  1935  46  -1  10  ]
      [  57  1  1  4  801  75  1  40  12  3  8  1  2034  46  193  11  ]
      [  74  1  8  -1  -1  -1  -1  -1  -1  1  3  3  2346  46  -1  12  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  2431  46  -1  12  ]
      [  30  1  1  5  757  74  8  50  26  5  10  1  3083  46  550  14  ]
      [  40  1  1  5  751  24  8  40  14  5  9  1  3984  46  273  16  ]
      [  47  1  8  -1  -1  -1  -1  -1  -1  2  3  5  59  45  -1  1  ]
      [  51  1  8  -1  -1  -1  -1  -1  9  3  99  6  215  45  158  2  ]
      [  41  2  8  -1  -1  -1  -1  -1  -1  1  -1  6  200  45  -1  2  ]
      [  65  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  166  45  -1  2  ]
      [  67  2  8  -1  -1  -1  -1  -1  50  5  8  6  240  45  -1  2  ]
      [  38  1  8  -1  -1  -1  -1  -1  12  1  -1  6  348  45  232  6  ]
      [  29  1  8  -1  -1  -1  -1  -1  9  -1  -1  2  481  45  150  6  ]
      [  20  2  8  -1  -1  -1  -1  -1  -1  3  99  6  350  45  -1  3  ]
      [  24  2  1  5  780  74  8  8  17  5  -1  4  453  45  340  4  ]
      [  25  2  1  5  691  65  8  8  -1  5  3  1  491  45  200  3  ]
      [  24  2  1  6  323  28  8  14  9  5  -1  1  327  45  130  3  ]
      [  56  1  1  6  744  22  8  24  13  4  8  1  487  45  250  8  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  -1  -1  4  411  45  -1  3  ]
      [  65  2  8  -1  -1  -1  -1  -1  9  -1  -1  3  374  45  150  4  ]
      [  22  2  1  7  785  24  8  35  13  3  -1  1  418  45  232  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  15  1  3  3  343  45  260  3  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  1  3  3  327  45  -1  10  ]
      [  45  1  8  -1  -1  -1  -1  -1  11  4  3  6  377  45  180  5  ]
      [  60  1  8  -1  -1  -1  -1  -1  13  1  3  3  652  45  200  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  11  1  -1  6  624  45  210  4  ]
      [  65  2  8  -1  -1  -1  -1  -1  9  1  -1  3  521  45  159  4  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  672  45  -1  4  ]
      [  49  2  1  6  744  52  8  9  12  3  3  6  535  45  218  4  ]
      [  43  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  672  45  160  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  7  1  -1  3  505  45  116  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  3  3  607  45  -1  4  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  629  45  -1  4  ]
      [  83  2  8  -1  -1  -1  -1  -1  7  1  -1  3  581  45  119  4  ]
      [  73  2  8  -1  -1  -1  -1  -1  17  1  -1  3  569  45  320  4  ]
      [  80  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  606  45  0  4  ]
      [  75  2  1  6  744  22  8  8  -1  9  -1  3  646  45  -1  4  ]
      [  33  1  8  -1  -1  -1  -1  -1  11  3  3  4  647  45  200  4  ]
      [  56  2  8  -1  -1  -1  -1  -1  9  1  -1  3  689  45  150  4  ]
      [  30  1  8  -1  -1  -1  -1  -1  14  5  8  4  511  45  204  4  ]
      [  63  2  8  -1  -1  -1  -1  -1  13  1  3  6  611  45  250  4  ]
      [  55  2  8  -1  -1  -1  -1  -1  12  1  1  2  516  45  180  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  8  1  3  3  596  45  110  8  ]
      [  66  2  8  -1  -1  -1  -1  -1  11  1  -1  4  604  45  185  4  ]
      [  95  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  687  45  -1  4  ]
      [  39  1  1  1  501  36  8  50  12  2  3  1  573  45  200  4  ]
      [  61  2  8  -1  -1  -1  -1  -1  -1  1  6  2  586  45  -1  9  ]
      [  76  2  8  -1  -1  -1  -1  -1  8  1  3  3  523  45  129  4  ]
      [  95  2  8  -1  -1  -1  -1  -1  9  1  -1  3  644  45  160  4  ]
      [  38  1  8  -1  -1  -1  -1  -1  9  2  3  2  506  45  138  4  ]
      [  22  1  8  -1  -1  -1  -1  -1  8  3  3  8  549  45  136  4  ]
      [  32  2  1  5  780  63  8  40  -1  2  3  1  615  45  -1  9  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  506  45  -1  4  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  1  3  830  45  200  5  ]
      [  72  2  8  -1  -1  -1  -1  -1  12  1  -1  3  799  45  202  5  ]
      [  27  1  1  1  689  50  8  2  15  1  3  2  883  45  320  5  ]
      [  40  2  1  6  522  52  8  35  -1  1  -1  1  777  45  -1  5  ]
      [  38  2  1  6  997  55  8  5  15  1  -1  1  735  45  240  5  ]
      [  33  1  8  -1  -1  -1  -1  -1  16  5  9  5  886  45  300  5  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  806  45  -1  5  ]
      [  73  1  8  -1  -1  -1  -1  -1  -1  1  1  3  708  45  -1  5  ]
      [  36  2  8  -1  -1  -1  -1  -1  -1  3  6  2  868  45  -1  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  13  1  3  3  1052  45  225  7  ]
      [  35  2  1  6  833  74  8  35  14  3  -1  1  1098  45  259  6  ]
      [  77  2  8  -1  -1  -1  -1  -1  16  3  3  3  1043  45  240  6  ]
      [  44  1  8  -1  -1  -1  -1  -1  12  3  -1  2  993  45  245  6  ]
      [  28  2  1  4  872  80  1  40  21  5  -1  1  1096  45  308  6  ]
      [  23  2  1  5  676  52  8  38  10  3  3  1  1073  45  155  6  ]
      [  76  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  962  45  0  6  ]
      [  24  1  1  5  914  55  8  40  14  5  3  1  1019  45  240  6  ]
      [  39  1  8  -1  -1  -1  -1  -1  -1  1  3  2  1062  45  -1  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  8  1  -1  3  948  45  160  6  ]
      [  42  1  1  5  661  52  8  40  12  1  3  1  901  45  200  6  ]
      [  50  1  1  5  891  91  8  60  -1  5  10  1  949  45  0  6  ]
      [  63  2  8  -1  -1  -1  -1  -1  11  1  3  3  932  45  193  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  9  1  5  3  982  45  130  6  ]
      [  23  2  8  -1  -1  -1  -1  -1  9  1  3  6  1072  45  162  6  ]
      [  76  2  8  -1  -1  -1  -1  -1  11  3  3  3  996  45  236  6  ]
      [  36  1  1  5  145  24  8  40  14  -1  -1  1  1270  45  280  7  ]
      [  26  2  1  5  864  85  8  38  15  5  -1  1  1105  45  266  7  ]
      [  34  1  1  5  392  55  8  35  16  1  3  1  1258  45  300  7  ]
      [  28  1  1  5  603  45  8  39  12  5  9  1  1250  45  200  7  ]
      [  22  1  1  6  461  45  8  40  14  3  3  1  1173  45  243  7  ]
      [  27  1  1  5  775  72  8  40  12  3  3  1  1291  45  231  7  ]
      [  42  2  1  5  780  75  1  38  -1  3  3  1  1153  45  0  7  ]
      [  39  1  1  6  401  15  8  39  8  1  3  1  1249  45  138  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  15  1  -1  3  1273  45  240  7  ]
      [  21  1  1  6  270  24  8  38  -1  3  3  1  1169  45  0  7  ]
      [  32  1  1  6  651  64  8  20  -1  5  -1  1  1281  45  225  7  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1216  45  -1  7  ]
      [  26  2  1  5  771  74  8  40  12  5  3  1  1232  45  200  7  ]
      [  35  1  1  6  310  29  8  40  -1  3  3  1  1247  45  -1  7  ]
      [  79  2  8  -1  -1  -1  -1  -1  15  3  -1  3  1209  45  280  7  ]
      [  77  1  8  -1  -1  -1  -1  -1  11  1  -1  3  1209  45  194  7  ]
      [  85  2  8  -1  -1  -1  -1  -1  -1  5  -1  3  1220  45  -1  7  ]
      [  57  2  1  5  780  52  8  37  19  3  1  1  1137  45  370  7  ]
      [  34  1  1  5  663  55  8  40  8  1  -1  1  1152  45  150  7  ]
      [  73  1  8  -1  -1  -1  -1  -1  10  9  -1  3  1245  45  171  11  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1105  45  -1  7  ]
      [  40  1  1  6  531  74  8  40  14  -1  -1  1  1130  45  260  7  ]
      [  27  1  1  5  853  85  8  40  12  2  3  1  1257  45  210  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1158  45  204  7  ]
      [  81  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1296  45  161  7  ]
      [  28  1  1  6  540  60  8  60  13  5  -1  1  1156  45  220  7  ]
      [  47  1  1  5  858  52  8  50  14  5  -1  1  1315  45  240  8  ]
      [  40  1  1  6  141  24  8  38  15  4  3  1  1328  45  225  8  ]
      [  74  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1463  45  220  8  ]
      [  75  1  8  -1  -1  -1  -1  -1  14  1  1  3  1309  45  282  8  ]
      [  37  1  1  5  836  52  8  38  19  1  3  1  1451  45  350  8  ]
      [  76  1  8  -1  -1  -1  -1  -1  20  3  -1  3  1363  45  400  11  ]
      [  25  1  1  6  323  27  8  40  13  -1  -1  1  1378  45  250  8  ]
      [  40  1  1  6  626  34  8  38  11  3  3  1  1412  45  190  12  ]
      [  52  2  1  5  853  85  1  40  -1  3  3  1  1459  45  -1  8  ]
      [  30  2  1  5  863  91  8  39  16  3  3  1  1492  45  253  8  ]
      [  51  1  1  5  780  51  8  38  10  5  8  1  1469  45  200  8  ]
      [  45  1  1  6  741  34  8  37  12  1  -1  1  1372  45  190  8  ]
      [  91  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1432  45  0  8  ]
      [  70  2  8  -1  -1  -1  -1  -1  21  3  3  3  1346  45  400  8  ]
      [  56  2  1  5  788  75  1  39  11  3  3  1  1418  45  172  8  ]
      [  25  1  1  5  687  51  8  42  19  3  3  1  1441  45  305  8  ]
      [  38  1  1  5  883  13  8  38  15  5  4  1  1593  45  260  9  ]
      [  47  2  1  5  787  85  8  29  14  3  3  1  1542  45  240  9  ]
      [  35  2  1  5  689  73  8  40  13  5  9  1  1558  45  250  9  ]
      [  73  1  8  -1  -1  -1  -1  -1  14  1  3  3  1694  45  250  9  ]
      [  39  1  1  6  231  28  8  40  13  1  -1  1  1644  45  240  9  ]
      [  39  1  1  6  270  27  8  38  -1  1  3  1  1684  45  -1  9  ]
      [  29  1  1  5  791  24  8  40  13  5  3  1  1517  45  255  9  ]
      [  25  1  1  1  310  45  8  40  13  1  3  1  1581  45  210  9  ]
      [  68  1  8  -1  -1  -1  -1  -1  13  3  3  3  1579  45  218  9  ]
      [  33  1  1  6  651  45  8  40  13  2  3  1  1616  45  188  9  ]
      [  35  2  1  4  814  75  1  40  13  2  3  1  1679  45  250  9  ]
      [  60  2  1  5  751  72  8  40  12  3  6  1  1594  45  230  9  ]
      [  56  1  1  6  744  28  8  37  -1  -1  -1  1  1500  45  -1  9  ]
      [  37  1  1  6  311  22  8  35  17  3  3  1  1911  45  280  10  ]
      [  30  2  1  5  772  34  8  38  16  1  3  1  1990  45  300  10  ]
      [  43  1  1  5  750  63  8  39  17  5  9  1  1730  45  350  10  ]
      [  28  2  1  5  915  55  8  38  37  1  3  1  1886  45  800  10  ]
      [  32  1  1  6  487  45  8  40  10  2  3  1  1714  45  200  11  ]
      [  41  2  1  5  843  85  1  30  15  5  8  1  2002  45  280  11  ]
      [  78  2  8  -1  -1  -1  -1  -1  40  3  -1  3  2261  45  760  11  ]
      [  89  1  8  -1  -1  -1  -1  -1  -1  1  4  3  2122  45  -1  12  ]
      [  39  1  1  5  620  31  8  40  -1  3  8  1  2221  45  275  11  ]
      [  41  1  1  6  601  35  8  40  -1  5  8  1  2469  45  0  12  ]
      [  31  2  1  5  622  32  8  38  -1  5  8  1  2352  45  -1  12  ]
      [  64  1  8  -1  -1  -1  -1  -1  22  3  3  3  2307  45  450  12  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  5  8  3  3086  45  -1  14  ]
      [  71  1  8  -1  -1  -1  -1  -1  -1  5  -1  3  3018  45  -1  14  ]
      [  47  1  1  5  623  45  8  55  14  5  8  1  3206  45  270  15  ]
      [  46  1  8  -1  -1  -1  -1  -1  50  4  9  6  159  44  -1  2  ]
      [  42  1  8  -1  -1  -1  -1  -1  11  -1  -1  2  347  44  200  5  ]
      [  51  2  8  -1  -1  -1  -1  -1  8  -1  -1  2  409  44  135  3  ]
      [  25  2  8  -1  -1  -1  -1  -1  19  1  -1  2  630  44  344  4  ]
      [  39  1  8  -1  -1  -1  -1  -1  16  1  -1  2  628  44  274  4  ]
      [  46  1  8  -1  -1  -1  -1  -1  14  1  3  2  518  44  250  4  ]
      [  46  2  8  -1  -1  -1  -1  -1  14  1  3  2  513  44  209  4  ]
      [  39  1  8  -1  -1  -1  -1  -1  10  3  3  6  625  44  165  4  ]
      [  45  1  8  -1  -1  -1  -1  -1  13  1  -1  6  548  44  218  4  ]
      [  36  1  8  -1  -1  -1  -1  -1  11  2  5  3  551  44  201  4  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  890  44  -1  10  ]
      [  86  2  8  -1  -1  -1  -1  -1  18  1  3  3  1071  44  350  6  ]
      [  87  2  8  -1  -1  -1  -1  -1  9  1  3  3  923  44  143  6  ]
      [  41  1  8  -1  -1  -1  -1  -1  11  2  -1  2  1042  44  200  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1055  44  -1  6  ]
      [  43  1  1  6  162  22  8  37  17  1  3  1  1178  44  293  7  ]
      [  56  1  1  6  744  74  8  38  15  1  3  1  1128  44  235  7  ]
      [  39  2  1  6  660  55  8  30  15  3  3  1  1120  44  255  7  ]
      [  30  1  1  6  460  64  8  40  -1  1  99  1  1108  44  -1  12  ]
      [  82  1  8  -1  -1  -1  -1  -1  17  1  -1  3  1418  44  300  8  ]
      [  31  1  1  5  853  85  8  30  10  3  5  1  1304  44  185  11  ]
      [  41  1  1  6  714  45  8  40  9  2  3  1  1307  44  148  11  ]
      [  37  1  1  5  853  85  8  39  13  5  5  1  1572  44  219  9  ]
      [  57  2  1  5  792  74  8  39  11  1  4  3  1660  44  175  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  16  1  3  3  1563  44  260  11  ]
      [  78  2  8  -1  -1  -1  -1  -1  9  1  3  3  1683  44  158  9  ]
      [  30  1  1  6  51  1  8  40  14  2  3  1  1900  44  232  10  ]
      [  39  1  1  6  181  36  8  40  22  3  3  1  2156  44  396  11  ]
      [  84  2  8  -1  -1  -1  -1  -1  15  3  3  3  3121  44  170  14  ]
      [  19  2  8  6  934  74  8  10  10  3  3  8  355  43  180  3  ]
      [  20  1  1  6  290  28  1  39  11  1  3  1  363  43  170  3  ]
      [  56  2  8  -1  -1  -1  -1  -1  18  5  9  2  386  43  329  3  ]
      [  21  1  1  11  994  85  8  39  16  3  3  1  495  43  250  3  ]
      [  27  2  1  5  735  80  8  10  10  5  -1  1  388  43  161  3  ]
      [  31  2  8  -1  -1  -1  -1  -1  12  -1  -1  2  308  43  187  3  ]
      [  70  2  8  -1  -1  -1  -1  -1  13  1  -1  3  636  43  215  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  555  43  -1  4  ]
      [  66  2  8  -1  -1  -1  -1  -1  17  -1  -1  3  548  43  300  4  ]
      [  58  2  8  5  662  52  8  8  12  1  3  2  577  43  215  4  ]
      [  54  1  8  -1  -1  -1  -1  -1  13  5  8  6  585  43  239  4  ]
      [  56  2  8  -1  -1  -1  -1  -1  16  3  3  2  602  43  300  4  ]
      [  54  1  8  -1  -1  -1  -1  -1  13  -1  -1  2  526  43  210  4  ]
      [  23  2  8  5  856  85  8  39  19  3  3  6  618  43  326  6  ]
      [  37  1  8  -1  -1  -1  -1  -1  11  3  3  2  620  43  143  4  ]
      [  28  1  8  -1  -1  -1  -1  -1  14  5  7  4  656  43  253  4  ]
      [  39  1  8  -1  -1  -1  -1  -1  12  5  3  2  643  43  200  4  ]
      [  77  2  8  -1  -1  -1  -1  -1  3  1  1  3  501  43  50  4  ]
      [  28  1  1  1  687  51  8  10  12  5  -1  1  568  43  197  4  ]
      [  74  1  8  -1  -1  -1  -1  -1  10  -1  -1  3  885  43  137  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  14  1  -1  3  804  43  186  5  ]
      [  48  2  8  -1  -1  -1  -1  -1  16  1  -1  3  700  43  282  5  ]
      [  23  1  8  -1  -1  -1  -1  -1  12  5  -1  8  788  43  220  5  ]
      [  27  1  1  5  997  66  8  40  18  3  4  1  747  43  350  10  ]
      [  62  1  8  -1  -1  -1  -1  -1  11  2  3  3  821  43  186  6  ]
      [  87  2  8  -1  -1  -1  -1  -1  13  1  -1  3  1004  43  183  6  ]
      [  59  1  1  6  714  60  8  40  11  1  3  1  1096  43  172  6  ]
      [  82  2  8  -1  -1  -1  -1  -1  13  3  3  3  1020  43  220  6  ]
      [  26  1  1  5  411  55  8  40  16  1  3  1  1014  43  300  6  ]
      [  83  2  8  -1  -1  -1  -1  -1  16  1  3  3  929  43  264  6  ]
      [  21  2  1  5  788  34  8  37  14  3  3  1  1027  43  227  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  11  1  -1  3  987  43  176  6  ]
      [  25  2  1  5  867  80  8  40  24  3  3  1  963  43  480  6  ]
      [  31  1  1  5  254  29  8  40  12  2  3  1  914  43  180  6  ]
      [  33  2  1  5  691  65  8  39  13  3  3  1  1140  43  220  7  ]
      [  62  1  8  -1  -1  -1  -1  -1  15  -1  -1  3  1177  43  300  7  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  4  3  1492  43  -1  8  ]
      [  35  2  1  5  780  74  8  35  15  1  3  1  1402  43  230  8  ]
      [  25  1  1  9  801  75  1  47  11  4  3  1  1327  43  180  8  ]
      [  54  2  1  5  864  91  8  30  14  1  3  1  1389  43  270  8  ]
      [  55  2  1  5  771  75  1  40  10  2  3  1  1371  43  164  8  ]
      [  32  2  1  5  853  85  1  38  21  3  3  1  1601  43  362  14  ]
      [  38  1  1  2  670  55  8  65  9  1  3  1  1628  43  155  9  ]
      [  34  2  1  5  789  24  8  37  18  3  4  1  1681  43  350  9  ]
      [  43  1  1  5  620  29  8  39  13  1  3  1  1659  43  260  9  ]
      [  29  1  1  5  601  74  8  40  11  4  8  1  1523  43  194  9  ]
      [  32  1  1  5  997  80  1  40  11  5  9  1  1723  43  191  10  ]
      [  39  1  1  5  605  10  8  36  10  5  9  1  1804  43  169  10  ]
      [  23  2  1  5  787  75  8  39  32  5  3  1  2082  43  600  11  ]
      [  33  1  1  5  751  70  8  37  -1  5  9  1  2220  43  258  16  ]
      [  20  2  1  7  672  52  8  40  11  1  -1  1  430  42  170  3  ]
      [  20  2  1  7  774  66  1  39  18  5  -1  1  323  42  350  3  ]
      [  74  2  8  -1  -1  -1  -1  -1  10  1  -1  3  414  42  179  3  ]
      [  20  1  8  -1  -1  -1  -1  -1  9  1  -1  2  381  42  156  3  ]
      [  22  1  8  -1  -1  -1  -1  -1  15  1  -1  6  608  42  250  4  ]
      [  73  2  8  -1  -1  -1  -1  -1  10  1  -1  3  539  42  166  4  ]
      [  25  1  1  6  915  55  8  10  10  4  -1  1  540  42  182  4  ]
      [  71  2  8  -1  -1  -1  -1  -1  12  1  -1  3  537  42  225  4  ]
      [  21  1  1  11  853  85  8  40  7  3  3  1  670  42  123  4  ]
      [  24  1  8  -1  -1  -1  -1  -1  -1  1  -1  6  527  42  260  4  ]
      [  28  2  8  -1  -1  -1  -1  -1  8  1  -1  2  503  42  127  4  ]
      [  40  1  8  -1  -1  -1  -1  -1  11  3  -1  6  670  42  148  4  ]
      [  36  1  8  -1  -1  -1  -1  -1  9  3  3  2  601  42  132  4  ]
      [  29  1  8  -1  -1  -1  -1  -1  10  3  3  2  692  42  170  4  ]
      [  47  2  8  -1  -1  -1  -1  -1  11  2  3  3  561  42  205  4  ]
      [  71  2  8  -1  -1  -1  -1  -1  8  1  -1  3  529  42  118  4  ]
      [  38  1  1  5  864  85  8  39  15  3  3  1  769  42  213  5  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  1  3  3  708  42  280  5  ]
      [  51  1  1  5  870  80  1  25  12  3  3  1  836  42  200  5  ]
      [  32  1  1  2  52  1  8  40  13  1  -1  1  789  42  206  5  ]
      [  84  2  8  -1  -1  -1  -1  -1  11  1  -1  3  730  42  200  5  ]
      [  29  2  1  5  914  85  1  25  12  3  3  1  756  42  218  5  ]
      [  31  1  8  -1  -1  -1  -1  -1  10  1  3  3  900  42  180  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  17  1  -1  3  793  42  285  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  22  1  -1  6  851  42  400  5  ]
      [  49  1  8  -1  -1  -1  -1  -1  -1  3  3  8  868  42  -1  5  ]
      [  23  2  8  -1  -1  -1  -1  -1  18  4  3  4  839  42  280  5  ]
      [  55  1  1  5  714  85  8  38  13  1  3  1  736  42  220  5  ]
      [  26  2  1  4  764  75  1  45  18  5  9  1  754  42  325  5  ]
      [  74  1  8  -1  -1  -1  -1  -1  12  1  3  3  870  42  193  8  ]
      [  55  1  1  6  267  45  8  40  -1  2  3  1  799  42  -1  9  ]
      [  59  1  8  -1  -1  -1  -1  -1  12  1  3  3  846  42  210  7  ]
      [  43  1  1  5  662  50  8  40  10  2  3  1  797  42  150  5  ]
      [  46  1  1  6  316  29  8  35  -1  1  3  1  971  42  -1  6  ]
      [  52  2  1  6  773  52  8  40  20  5  -1  1  1070  42  350  6  ]
      [  22  1  1  5  780  51  8  38  -1  3  3  1  1055  42  -1  6  ]
      [  25  2  1  4  870  80  1  30  18  5  -1  1  901  42  310  6  ]
      [  71  2  8  5  937  95  8  2  14  1  5  3  911  42  237  6  ]
      [  87  2  8  -1  -1  -1  -1  -1  11  1  3  3  991  42  200  6  ]
      [  28  1  1  6  744  33  8  40  12  2  3  1  928  42  198  6  ]
      [  68  1  8  -1  -1  -1  -1  -1  12  1  3  3  953  42  180  9  ]
      [  26  2  1  5  857  85  1  38  17  5  99  1  1245  42  280  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  17  3  3  3  1216  42  320  7  ]
      [  29  2  1  5  863  80  8  39  13  3  3  1  1206  42  210  7  ]
      [  35  2  1  5  782  75  1  39  10  3  3  1  1269  42  165  7  ]
      [  63  2  8  5  934  25  8  7  13  -1  1  3  1239  42  218  7  ]
      [  25  2  1  5  787  75  1  38  13  3  3  1  1113  42  205  7  ]
      [  48  1  8  -1  -1  -1  -1  -1  16  -1  -1  2  1119  42  290  7  ]
      [  25  2  1  4  765  75  1  38  11  3  4  1  1220  42  183  7  ]
      [  40  1  1  6  281  34  8  39  7  2  3  1  1227  42  111  9  ]
      [  82  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1189  42  0  7  ]
      [  21  2  1  5  789  60  1  40  13  3  3  8  1299  42  210  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  17  1  -1  3  1201  42  300  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  19  1  -1  3  1490  42  332  8  ]
      [  36  1  1  5  835  74  8  38  18  5  -1  1  1496  42  293  8  ]
      [  81  2  8  -1  -1  -1  -1  -1  12  1  3  3  1355  42  225  8  ]
      [  58  1  1  5  714  75  1  46  15  1  3  1  1337  42  270  8  ]
      [  24  1  1  5  691  65  8  38  21  3  3  1  1427  42  390  8  ]
      [  41  1  1  6  141  24  8  40  20  1  3  1  1473  42  300  8  ]
      [  34  1  1  5  621  34  8  35  22  3  5  1  1369  42  350  8  ]
      [  21  2  1  4  787  75  1  39  12  5  3  1  1444  42  200  8  ]
      [  85  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1486  42  134  8  ]
      [  80  1  8  -1  -1  -1  -1  -1  17  1  3  3  1468  42  236  10  ]
      [  29  2  1  5  703  74  8  39  22  5  9  1  1543  42  354  9  ]
      [  30  2  1  4  787  75  1  39  -1  4  7  1  1535  42  -1  9  ]
      [  34  1  1  6  651  24  8  38  12  1  3  1  1523  42  200  9  ]
      [  75  1  8  -1  -1  -1  -1  -1  18  1  -1  3  1734  42  304  10  ]
      [  40  1  1  4  801  75  1  40  16  5  3  1  1817  42  290  10  ]
      [  24  1  1  6  441  45  8  40  13  1  3  1  2162  42  216  11  ]
      [  68  2  8  -1  -1  -1  -1  -1  7  -1  -1  6  162  41  117  2  ]
      [  67  2  8  -1  -1  -1  -1  -1  12  1  -1  3  450  41  200  3  ]
      [  48  1  8  -1  -1  -1  -1  -1  12  5  3  2  395  41  204  3  ]
      [  88  2  8  -1  -1  -1  -1  -1  12  1  -1  3  328  41  209  3  ]
      [  60  1  8  -1  -1  -1  -1  -1  -1  5  8  2  423  41  225  5  ]
      [  82  2  8  -1  -1  -1  -1  -1  17  1  -1  3  668  41  254  4  ]
      [  21  1  1  11  994  85  1  40  25  3  3  1  660  41  450  6  ]
      [  28  2  1  5  915  55  8  4  15  3  -1  2  545  41  200  4  ]
      [  18  2  1  7  853  85  8  40  14  3  -1  1  554  41  245  4  ]
      [  44  2  8  -1  -1  -1  -1  -1  9  1  -1  3  659  41  156  4  ]
      [  77  2  8  -1  -1  -1  -1  -1  12  1  -1  3  556  41  194  4  ]
      [  19  2  1  8  662  52  8  40  12  3  -1  1  608  41  217  4  ]
      [  48  2  8  -1  -1  -1  -1  -1  9  1  -1  2  661  41  130  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  19  1  3  3  777  41  330  5  ]
      [  40  2  8  6  934  80  8  21  10  1  -1  1  703  41  167  5  ]
      [  69  2  8  -1  -1  -1  -1  -1  13  1  1  3  843  41  223  5  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  3  3  890  41  140  5  ]
      [  26  2  8  -1  -1  -1  -1  -1  7  3  3  2  889  41  110  5  ]
      [  66  1  8  -1  -1  -1  -1  -1  -1  1  3  3  978  41  -1  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  19  -1  -1  3  1022  41  310  6  ]
      [  59  1  1  6  373  19  8  40  9  1  3  1  915  41  136  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  20  -1  -1  3  963  41  217  6  ]
      [  80  1  8  -1  -1  -1  -1  -1  14  -1  -1  3  1244  41  237  9  ]
      [  47  1  1  6  440  45  8  36  12  1  -1  1  1297  41  215  7  ]
      [  50  2  1  6  411  85  1  39  14  1  1  1  1106  41  197  7  ]
      [  24  2  1  6  912  55  8  45  15  3  3  1  1107  41  242  7  ]
      [  82  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1101  41  137  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  12  1  -1  3  1200  41  200  7  ]
      [  60  2  8  -1  -1  -1  -1  -1  12  3  3  3  1482  41  162  8  ]
      [  90  1  8  -1  -1  -1  -1  -1  12  1  3  3  1914  41  200  10  ]
      [  41  2  1  5  787  75  1  40  11  5  9  1  1745  41  180  10  ]
      [  19  2  8  -1  -1  -1  -1  -1  6  3  -1  8  187  40  60  2  ]
      [  20  2  1  6  411  55  8  8  -1  5  -1  4  278  40  -1  2  ]
      [  22  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  477  40  -1  3  ]
      [  22  1  8  -1  -1  -1  -1  -1  9  5  -1  4  307  40  150  5  ]
      [  21  1  8  -1  -1  -1  -1  -1  -1  3  3  2  371  40  0  3  ]
      [  27  2  8  -1  -1  -1  -1  -1  12  5  -1  8  364  40  200  3  ]
      [  37  2  1  6  823  92  1  20  4  3  -1  1  387  40  40  3  ]
      [  20  1  1  11  994  85  8  38  -1  4  -1  1  423  40  125  3  ]
      [  21  2  1  6  912  55  8  40  15  1  3  1  300  40  240  3  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  308  40  -1  3  ]
      [  19  2  1  7  914  55  8  38  -1  3  -1  1  391  40  -1  3  ]
      [  20  2  1  5  997  80  1  2  11  5  -1  4  385  40  100  3  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  2  381  40  0  3  ]
      [  66  2  8  -1  -1  -1  -1  -1  15  1  3  3  514  40  255  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  509  40  -1  4  ]
      [  53  2  8  -1  -1  -1  -1  -1  17  -1  -1  3  520  40  300  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  5  1  -1  3  626  40  80  4  ]
      [  51  1  8  -1  -1  -1  -1  -1  13  1  1  2  563  40  180  4  ]
      [  22  1  1  7  671  51  8  38  18  -1  -1  1  533  40  300  4  ]
      [  52  1  1  6  894  91  8  28  -1  1  3  1  515  40  260  10  ]
      [  37  2  8  -1  -1  -1  -1  -1  27  1  3  2  610  40  432  4  ]
      [  29  1  1  6  854  74  8  15  13  1  3  1  503  40  188  4  ]
      [  34  1  1  6  796  25  8  28  12  1  1  1  522  40  181  8  ]
      [  61  1  8  -1  -1  -1  -1  -1  14  1  3  3  689  40  241  4  ]
      [  53  1  8  -1  -1  -1  -1  -1  13  1  3  3  507  40  179  4  ]
      [  80  2  8  -1  -1  -1  -1  -1  13  1  3  3  552  40  225  4  ]
      [  88  2  8  -1  -1  -1  -1  -1  8  -1  -1  3  633  40  100  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  12  1  -1  3  633  40  210  4  ]
      [  69  2  8  -1  -1  -1  -1  -1  -1  1  3  3  634  40  -1  4  ]
      [  84  2  8  -1  -1  -1  -1  -1  -1  1  3  3  799  40  -1  5  ]
      [  31  2  1  5  853  85  1  40  25  -1  -1  1  777  40  360  5  ]
      [  35  1  1  6  997  37  8  38  -1  3  -1  1  884  40  259  5  ]
      [  59  2  8  -1  -1  -1  -1  -1  21  1  -1  4  805  40  290  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  3  3  776  40  -1  5  ]
      [  18  2  8  -1  -1  -1  -1  -1  16  -1  -1  4  895  40  260  5  ]
      [  95  1  8  -1  -1  -1  -1  -1  -1  4  3  3  748  40  0  5  ]
      [  71  1  8  -1  -1  -1  -1  -1  12  -1  -1  3  725  40  200  5  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  1  3  3  805  40  -1  9  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  743  40  0  5  ]
      [  65  2  8  -1  -1  -1  -1  -1  17  5  5  3  848  40  250  5  ]
      [  20  2  1  6  741  51  8  18  11  1  -1  1  848  40  190  5  ]
      [  37  1  8  6  714  63  8  60  18  -1  -1  1  795  40  288  5  ]
      [  78  1  8  -1  -1  -1  -1  -1  -1  1  3  3  883  40  0  5  ]
      [  46  2  8  -1  -1  -1  -1  -1  -1  4  3  3  899  40  -1  5  ]
      [  65  1  8  -1  -1  -1  -1  -1  10  1  -1  3  714  40  140  5  ]
      [  31  1  8  -1  -1  -1  -1  -1  12  3  3  5  751  40  164  5  ]
      [  25  2  1  5  921  95  8  40  11  1  3  1  868  40  125  5  ]
      [  22  1  1  5  821  92  8  20  -1  5  -1  1  831  40  -1  5  ]
      [  29  1  8  -1  -1  -1  -1  -1  13  5  9  5  851  40  200  5  ]
      [  27  1  8  -1  -1  -1  -1  -1  14  5  -1  4  885  40  220  5  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  886  40  0  5  ]
      [  24  1  1  6  714  63  8  40  7  3  3  1  762  40  100  11  ]
      [  20  2  1  5  997  80  1  4  -1  5  -1  8  808  40  -1  5  ]
      [  33  1  1  6  270  90  8  35  11  2  3  1  880  40  175  5  ]
      [  79  2  8  -1  -1  -1  -1  -1  17  3  4  3  798  40  277  5  ]
      [  35  2  1  2  911  55  8  60  -1  5  3  1  704  40  -1  5  ]
      [  29  1  1  5  841  85  1  40  -1  5  8  1  1064  40  0  8  ]
      [  32  2  1  5  901  93  8  38  -1  1  3  1  901  40  -1  6  ]
      [  30  1  1  6  492  36  8  38  -1  1  99  1  1087  40  -1  6  ]
      [  75  2  1  2  911  55  8  22  -1  1  3  1  1090  40  -1  6  ]
      [  33  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  1066  40  -1  6  ]
      [  32  1  8  -1  -1  -1  -1  -1  12  5  -1  4  923  40  200  6  ]
      [  30  1  8  -1  -1  -1  -1  -1  19  5  -1  4  1016  40  295  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  3  3  991  40  318  6  ]
      [  42  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1100  40  -1  6  ]
      [  38  1  1  6  51  1  8  39  7  1  -1  1  1034  40  108  6  ]
      [  58  1  1  1  601  29  8  39  -1  1  5  1  929  40  -1  6  ]
      [  21  1  1  8  501  45  8  39  10  -1  -1  1  922  40  140  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  14  5  9  3  998  40  257  10  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1013  40  0  6  ]
      [  40  1  1  5  787  75  1  40  16  2  3  1  1066  40  253  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  14  5  8  3  929  40  237  6  ]
      [  48  2  8  -1  -1  -1  -1  -1  15  2  3  3  942  40  256  6  ]
      [  72  1  8  -1  -1  -1  -1  -1  -1  1  5  3  956  40  0  7  ]
      [  63  1  8  -1  -1  -1  -1  -1  9  1  3  3  1052  40  165  6  ]
      [  59  1  1  5  757  74  8  42  18  5  -1  1  1202  40  300  7  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1243  40  316  7  ]
      [  25  2  1  5  786  74  8  40  -1  4  3  1  1111  40  -1  7  ]
      [  44  1  1  6  152  25  8  40  17  1  -1  1  1295  40  280  7  ]
      [  41  1  1  6  691  74  8  45  9  -1  3  1  1219  40  138  7  ]
      [  25  1  1  5  621  25  8  38  -1  1  3  1  1249  40  -1  7  ]
      [  44  2  1  6  522  28  8  35  14  1  3  1  1180  40  190  7  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1122  40  -1  7  ]
      [  82  1  8  -1  -1  -1  -1  -1  8  3  3  3  1134  40  150  12  ]
      [  64  2  8  -1  -1  -1  -1  -1  16  1  3  3  1288  40  203  7  ]
      [  47  2  8  5  858  52  8  8  -1  3  3  3  1255  40  0  7  ]
      [  76  1  8  -1  -1  -1  -1  -1  10  1  3  3  1270  40  155  7  ]
      [  43  1  1  6  322  85  8  38  -1  1  3  1  1119  40  0  7  ]
      [  76  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1174  40  200  7  ]
      [  30  1  1  5  937  28  8  40  12  -1  3  1  1117  40  194  7  ]
      [  75  1  8  -1  -1  -1  -1  -1  11  1  -1  3  1251  40  187  7  ]
      [  90  2  8  -1  -1  -1  -1  -1  16  1  -1  3  1142  40  246  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  11  1  -1  3  1289  40  164  7  ]
      [  36  1  1  6  546  45  8  39  15  2  3  1  1242  40  250  7  ]
      [  31  2  1  5  787  75  1  39  -1  4  3  1  1389  40  -1  8  ]
      [  42  2  1  2  995  74  8  50  23  2  3  1  1444  40  400  8  ]
      [  44  1  1  6  621  29  8  40  -1  1  -1  1  1478  40  -1  8  ]
      [  23  1  8  -1  -1  -1  -1  -1  14  1  3  2  1301  40  200  8  ]
      [  34  2  1  5  787  75  1  39  11  3  3  1  1433  40  179  8  ]
      [  46  1  1  5  912  55  8  40  18  3  3  1  1417  40  310  8  ]
      [  43  2  1  5  853  85  1  39  12  5  5  1  1497  40  192  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1320  40  -1  14  ]
      [  89  2  8  -1  -1  -1  -1  -1  -1  1  99  3  1388  40  -1  8  ]
      [  82  2  8  -1  -1  -1  -1  -1  11  3  3  3  1383  40  185  8  ]
      [  86  1  8  -1  -1  -1  -1  -1  15  3  -1  3  1448  40  195  8  ]
      [  27  1  1  6  441  45  8  40  10  1  3  1  1487  40  140  8  ]
      [  39  1  1  6  629  45  8  40  18  1  -1  1  1625  40  270  9  ]
      [  35  2  1  5  993  70  8  38  10  1  99  1  1632  40  155  9  ]
      [  34  1  1  5  774  72  8  40  -1  5  3  1  1608  40  0  9  ]
      [  66  2  8  -1  -1  -1  -1  -1  13  1  3  3  1640  40  225  9  ]
      [  33  1  1  6  191  29  8  35  13  3  3  1  1675  40  200  9  ]
      [  30  1  1  6  796  40  1  38  11  3  3  1  1576  40  200  9  ]
      [  71  2  8  -1  -1  -1  -1  -1  9  1  3  3  1600  40  120  9  ]
      [  47  1  1  5  854  85  1  40  18  2  4  1  1675  40  200  12  ]
      [  55  1  1  5  623  45  8  38  -1  2  3  1  1684  40  -1  12  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1788  40  -1  11  ]
      [  46  2  1  5  856  85  8  40  -1  3  3  1  1869  40  -1  10  ]
      [  32  2  1  5  683  22  8  40  34  5  9  1  1802  40  580  10  ]
      [  31  2  1  5  754  74  8  40  14  5  9  1  1914  40  250  10  ]
      [  52  1  1  6  441  45  8  40  -1  1  3  1  1780  40  -1  16  ]
      [  27  1  1  6  254  28  8  40  12  2  3  1  1964  40  195  10  ]
      [  38  2  1  5  756  16  8  35  14  5  9  1  2283  40  225  11  ]
      [  56  2  1  5  780  52  8  30  12  -1  -1  1  2591  40  187  12  ]
      [  40  1  1  5  841  85  8  40  18  5  9  1  2686  40  310  13  ]
      [  60  1  1  5  603  45  8  40  18  2  8  1  2613  40  264  13  ]
      [  30  1  1  5  605  15  8  40  18  5  8  1  2777  40  300  13  ]
      [  58  1  1  4  873  80  1  42  -1  5  8  1  2801  40  -1  13  ]
      [  52  1  1  5  750  52  8  40  -1  5  3  1  3968  40  -1  16  ]
      [  62  1  8  -1  -1  -1  -1  -1  8  1  -1  3  7642  40  120  22  ]
      [  20  1  1  7  672  52  8  40  7  3  -1  1  182  39  85  2  ]
      [  36  2  8  -1  -1  -1  -1  -1  11  2  3  6  242  39  170  3  ]
      [  45  1  8  -1  -1  -1  -1  -1  12  -1  -1  2  632  39  180  4  ]
      [  68  1  8  -1  -1  -1  -1  -1  9  -1  -1  3  573  39  108  4  ]
      [  59  1  8  -1  -1  -1  -1  -1  11  1  3  8  521  39  186  5  ]
      [  74  2  8  -1  -1  -1  -1  -1  8  1  3  3  639  39  106  4  ]
      [  31  1  8  -1  -1  -1  -1  -1  12  2  3  3  556  39  200  4  ]
      [  44  1  1  6  411  55  8  40  8  2  3  1  814  39  114  5  ]
      [  73  1  8  -1  -1  -1  -1  -1  16  1  3  3  1073  39  270  6  ]
      [  28  1  1  5  854  85  1  3  -1  5  5  4  905  39  -1  6  ]
      [  66  2  8  -1  -1  -1  -1  -1  12  1  3  3  1061  39  175  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  5  6  3  962  39  175  6  ]
      [  32  1  8  -1  -1  -1  -1  -1  16  2  3  2  924  39  250  6  ]
      [  30  2  1  5  856  85  8  40  17  3  3  1  1181  39  280  12  ]
      [  52  1  1  5  853  85  8  40  16  1  4  1  1154  39  250  7  ]
      [  38  1  1  1  831  92  8  42  19  5  9  1  1142  39  314  7  ]
      [  41  2  1  5  863  85  1  39  15  3  3  1  1264  39  250  7  ]
      [  27  1  1  6  482  45  8  40  -1  2  4  1  1234  39  -1  7  ]
      [  54  2  1  5  750  51  8  40  20  3  3  1  1360  39  325  8  ]
      [  79  1  8  -1  -1  -1  -1  -1  14  3  3  3  1413  39  220  8  ]
      [  63  1  8  -1  -1  -1  -1  -1  18  1  3  3  1455  39  287  8  ]
      [  54  1  1  5  787  75  1  39  11  -1  -1  1  1535  39  180  9  ]
      [  36  2  1  5  787  75  1  38  21  5  -1  1  2755  39  240  13  ]
      [  72  1  8  -1  -1  -1  -1  -1  14  -1  -1  3  481  38  200  6  ]
      [  44  1  8  -1  -1  -1  -1  -1  13  1  -1  2  557  38  198  4  ]
      [  91  2  8  -1  -1  -1  -1  -1  13  1  -1  3  646  38  160  4  ]
      [  24  1  8  -1  -1  -1  -1  -1  -1  1  -1  2  676  38  -1  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  14  9  -1  3  542  38  183  4  ]
      [  20  2  1  6  997  55  8  14  10  3  3  2  526  38  138  4  ]
      [  34  2  8  -1  -1  -1  -1  -1  8  1  -1  6  690  38  120  4  ]
      [  52  1  8  -1  -1  -1  -1  -1  14  1  3  2  614  38  240  4  ]
      [  27  1  8  -1  -1  -1  -1  -1  16  3  3  2  565  38  260  4  ]
      [  21  2  8  6  773  50  8  8  -1  5  -1  4  661  38  -1  4  ]
      [  45  1  8  -1  -1  -1  -1  -1  8  2  4  2  636  38  110  4  ]
      [  22  1  8  -1  -1  -1  -1  -1  9  1  -1  2  548  38  150  4  ]
      [  26  2  8  -1  -1  -1  -1  -1  12  3  3  4  704  38  190  5  ]
      [  54  2  8  -1  -1  -1  -1  -1  15  1  3  3  835  38  230  5  ]
      [  66  2  8  -1  -1  -1  -1  -1  -1  1  3  3  791  38  -1  5  ]
      [  33  1  1  5  411  55  8  45  19  -1  -1  1  790  38  300  5  ]
      [  18  2  1  8  912  55  8  42  15  3  -1  1  711  38  250  5  ]
      [  35  1  8  5  754  74  8  9  14  4  -1  4  839  38  250  5  ]
      [  72  1  8  -1  -1  -1  -1  -1  16  1  -1  3  810  38  208  5  ]
      [  49  1  8  -1  -1  -1  -1  -1  14  1  5  2  809  38  200  5  ]
      [  22  2  1  5  854  85  1  8  22  5  1  4  822  38  350  5  ]
      [  45  2  8  -1  -1  -1  -1  -1  11  1  -1  6  757  38  132  5  ]
      [  52  1  8  -1  -1  -1  -1  -1  14  -1  -1  2  739  38  190  5  ]
      [  77  2  8  -1  -1  -1  -1  -1  6  1  -1  3  748  38  80  5  ]
      [  75  2  8  -1  -1  -1  -1  -1  11  1  3  3  735  38  178  5  ]
      [  29  1  1  5  691  65  8  19  14  5  3  1  917  38  200  6  ]
      [  26  1  1  5  880  80  1  38  25  5  9  1  907  38  365  6  ]
      [  27  2  1  5  813  75  1  39  15  5  9  1  936  38  231  6  ]
      [  65  1  8  -1  -1  -1  -1  -1  12  1  3  3  909  38  150  6  ]
      [  53  1  1  1  704  65  8  23  29  5  8  5  979  38  490  6  ]
      [  54  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1081  38  -1  6  ]
      [  74  2  8  -1  -1  -1  -1  -1  13  3  3  3  1055  38  197  6  ]
      [  29  2  1  5  863  80  1  39  16  4  3  1  1300  38  240  7  ]
      [  33  1  1  5  510  45  8  39  12  5  -1  1  1202  38  180  7  ]
      [  39  2  1  5  772  85  8  38  13  5  3  1  1116  38  210  7  ]
      [  25  2  1  5  780  23  8  35  16  1  4  1  1284  38  250  7  ]
      [  72  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1147  38  0  7  ]
      [  34  1  1  5  735  93  8  25  13  5  -1  1  1496  38  195  8  ]
      [  36  1  1  6  441  26  8  37  19  1  1  1  1508  38  276  9  ]
      [  43  1  1  6  714  52  8  40  13  1  3  1  1973  38  200  10  ]
      [  70  2  8  -1  -1  -1  -1  -1  21  5  9  3  2270  38  328  11  ]
      [  22  1  1  5  751  51  8  60  -1  3  3  1  2326  38  280  12  ]
      [  21  2  1  6  672  52  8  39  -1  1  -1  1  484  37  269  3  ]
      [  21  1  8  -1  -1  -1  -1  -1  13  5  -1  4  626  37  155  4  ]
      [  21  2  1  7  869  85  1  40  8  4  -1  1  577  37  104  4  ]
      [  26  1  8  -1  -1  -1  -1  -1  8  2  3  2  517  37  119  4  ]
      [  33  1  8  -1  -1  -1  -1  -1  11  2  3  2  673  37  160  4  ]
      [  19  1  1  6  997  50  8  39  15  9  -1  1  753  37  219  5  ]
      [  41  1  1  6  23  1  8  24  12  5  8  1  822  37  180  5  ]
      [  39  2  1  5  784  85  1  30  -1  5  1  1  881  37  -1  5  ]
      [  91  2  8  -1  -1  -1  -1  -1  17  1  -1  3  774  37  279  5  ]
      [  37  1  8  -1  -1  -1  -1  -1  15  3  3  3  1049  37  200  6  ]
      [  20  2  1  5  674  52  8  39  8  5  3  1  1050  37  100  6  ]
      [  25  1  1  6  323  45  8  40  14  1  -1  1  1041  37  202  6  ]
      [  33  1  1  6  862  85  8  30  12  1  99  1  905  37  196  6  ]
      [  26  1  8  5  775  72  8  15  11  5  -1  1  997  37  150  6  ]
      [  24  1  8  -1  -1  -1  -1  -1  12  3  3  2  935  37  180  8  ]
      [  55  2  1  5  787  75  1  40  -1  1  3  1  1277  37  -1  7  ]
      [  34  2  1  5  882  91  8  35  23  5  9  1  1194  37  400  7  ]
      [  82  2  8  -1  -1  -1  -1  -1  16  1  6  3  1249  37  250  7  ]
      [  42  1  1  6  796  80  1  40  13  1  3  1  1403  37  180  8  ]
      [  52  1  1  6  540  40  1  56  12  3  5  1  1647  37  160  9  ]
      [  38  2  1  5  632  34  8  40  14  3  3  1  1973  37  180  10  ]
      [  48  1  1  5  835  92  8  39  28  3  -1  1  1848  37  490  10  ]
      [  66  1  8  -1  -1  -1  -1  -1  13  -1  -1  3  1732  37  203  10  ]
      [  32  1  1  4  801  75  1  40  16  5  3  1  1980  37  250  10  ]
      [  40  1  1  5  787  80  8  40  17  5  9  1  2322  37  270  12  ]
      [  26  1  8  -1  -1  -1  -1  -1  7  -1  -1  6  300  36  110  2  ]
      [  78  2  8  -1  -1  -1  -1  -1  13  1  3  3  403  36  176  3  ]
      [  37  1  8  -1  -1  -1  -1  -1  10  1  3  3  421  36  140  3  ]
      [  56  1  8  -1  -1  -1  -1  -1  6  5  3  2  389  36  80  3  ]
      [  51  2  8  -1  -1  -1  -1  -1  11  1  -1  3  664  36  150  4  ]
      [  50  1  8  -1  -1  -1  -1  -1  13  1  3  6  597  36  200  4  ]
      [  80  2  8  -1  -1  -1  -1  -1  16  1  3  3  612  36  218  4  ]
      [  36  1  1  8  250  28  8  40  9  1  -1  1  617  36  120  4  ]
      [  38  1  8  -1  -1  -1  -1  -1  14  1  3  2  653  36  210  4  ]
      [  38  1  8  -1  -1  -1  -1  -1  12  1  -1  2  686  36  115  4  ]
      [  19  2  8  -1  -1  -1  -1  -1  14  -1  -1  4  501  36  184  4  ]
      [  95  2  8  -1  -1  -1  -1  -1  13  1  -1  3  588  36  170  4  ]
      [  71  1  8  -1  -1  -1  -1  -1  12  -1  -1  3  693  36  169  4  ]
      [  23  1  8  -1  -1  -1  -1  -1  18  9  -1  4  760  36  300  5  ]
      [  93  2  8  -1  -1  -1  -1  -1  13  -1  -1  3  740  36  185  5  ]
      [  29  1  1  5  853  85  1  38  15  5  3  1  846  36  217  5  ]
      [  50  1  1  5  714  60  8  40  15  4  7  1  742  36  200  5  ]
      [  63  1  8  -1  -1  -1  -1  -1  -1  1  3  3  700  36  -1  5  ]
      [  62  2  8  -1  -1  -1  -1  -1  11  3  3  5  771  36  150  5  ]
      [  48  1  8  -1  -1  -1  -1  -1  12  2  3  3  895  36  160  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  7  1  5  3  892  36  90  5  ]
      [  79  2  8  -1  -1  -1  -1  -1  10  1  -1  3  703  36  124  5  ]
      [  50  1  8  -1  -1  -1  -1  -1  8  2  5  2  853  36  110  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  14  1  3  2  856  36  188  5  ]
      [  61  2  8  -1  -1  -1  -1  -1  14  1  3  3  901  36  220  6  ]
      [  71  1  8  -1  -1  -1  -1  -1  13  1  3  3  1001  36  170  10  ]
      [  52  1  1  6  744  51  8  40  11  2  99  1  1089  36  144  9  ]
      [  29  2  1  5  861  85  8  40  13  4  8  1  933  36  216  6  ]
      [  75  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1233  36  -1  7  ]
      [  47  1  1  6  441  45  8  39  16  1  3  1  1199  36  235  7  ]
      [  67  1  8  -1  -1  -1  -1  -1  11  4  9  3  1152  36  124  7  ]
      [  71  1  8  -1  -1  -1  -1  -1  10  1  6  3  1228  36  153  7  ]
      [  28  2  1  5  787  75  1  40  13  3  3  1  1454  36  200  8  ]
      [  24  1  1  6  310  45  8  40  12  1  3  1  1479  36  175  8  ]
      [  39  1  1  6  854  85  1  40  13  2  3  1  1469  36  185  10  ]
      [  56  1  1  2  601  45  8  40  19  5  7  1  1639  36  300  9  ]
      [  39  1  1  6  254  29  8  38  14  4  3  1  1714  36  200  10  ]
      [  57  2  1  5  864  85  8  39  -1  1  5  1  1960  36  0  10  ]
      [  45  1  1  6  220  35  8  35  -1  1  3  1  1898  36  -1  10  ]
      [  60  1  8  -1  -1  -1  -1  -1  17  -1  -1  4  27  35  200  23  ]
      [  70  1  8  -1  -1  -1  -1  -1  7  -1  -1  6  190  35  100  2  ]
      [  55  1  8  -1  -1  -1  -1  -1  15  1  1  6  496  35  180  3  ]
      [  27  2  8  -1  -1  -1  -1  -1  16  5  9  4  408  35  207  3  ]
      [  61  1  8  -1  -1  -1  -1  -1  19  -1  -1  3  381  35  247  5  ]
      [  20  2  1  5  661  52  8  10  -1  4  -1  1  360  35  250  3  ]
      [  21  2  1  5  854  85  8  5  16  5  -1  1  372  35  220  3  ]
      [  17  2  1  8  270  28  8  40  8  1  -1  1  363  35  107  3  ]
      [  19  2  1  5  915  92  8  12  13  3  -1  1  466  35  162  3  ]
      [  48  2  1  6  322  34  8  30  9  1  4  1  414  35  135  3  ]
      [  44  1  8  -1  -1  -1  -1  -1  14  1  3  2  685  35  182  4  ]
      [  26  1  8  -1  -1  -1  -1  -1  18  5  -1  4  619  35  242  4  ]
      [  28  1  8  -1  -1  -1  -1  -1  15  5  3  8  508  35  200  4  ]
      [  21  1  8  -1  -1  -1  -1  -1  17  5  -1  4  555  35  250  4  ]
      [  68  1  8  -1  -1  -1  -1  -1  19  1  3  3  684  35  286  4  ]
      [  21  2  1  5  997  80  1  5  11  -1  1  4  519  35  170  4  ]
      [  35  1  8  -1  -1  -1  -1  -1  -1  1  3  2  642  35  -1  4  ]
      [  44  1  8  -1  -1  -1  -1  -1  11  1  3  6  575  35  140  4  ]
      [  26  2  1  6  660  71  8  10  16  4  -1  4  654  35  216  4  ]
      [  37  1  8  -1  -1  -1  -1  -1  13  2  -1  3  505  35  150  4  ]
      [  53  1  8  -1  -1  -1  -1  -1  13  2  3  2  571  35  183  4  ]
      [  54  2  1  6  661  52  8  30  10  2  3  1  609  35  153  4  ]
      [  81  2  8  -1  -1  -1  -1  -1  21  1  3  3  509  35  303  4  ]
      [  77  2  8  -1  -1  -1  -1  -1  13  1  3  3  615  35  190  4  ]
      [  21  2  1  7  471  45  8  40  13  5  -1  4  523  35  175  4  ]
      [  25  1  1  6  792  74  8  40  16  -1  -1  1  808  35  180  5  ]
      [  57  1  8  -1  -1  -1  -1  -1  15  1  3  3  745  35  220  5  ]
      [  27  2  8  -1  -1  -1  -1  -1  -1  5  9  8  806  35  -1  5  ]
      [  30  2  8  -1  -1  -1  -1  -1  11  3  3  2  781  35  150  5  ]
      [  23  2  1  5  856  85  8  38  18  1  3  1  890  35  280  5  ]
      [  57  1  1  5  854  85  8  38  13  1  3  1  734  35  188  5  ]
      [  55  1  8  -1  -1  -1  -1  -1  12  1  3  3  899  35  160  5  ]
      [  83  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  806  35  0  5  ]
      [  88  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  806  35  160  5  ]
      [  32  1  1  6  791  74  8  40  18  1  -1  1  978  35  256  6  ]
      [  53  2  1  6  310  74  8  37  -1  1  3  1  1010  35  -1  6  ]
      [  22  1  1  6  864  85  8  39  13  1  4  1  931  35  180  6  ]
      [  23  2  1  5  853  85  1  40  -1  1  99  1  1041  35  -1  6  ]
      [  73  1  1  6  23  1  8  15  8  1  3  3  1055  35  110  6  ]
      [  60  1  8  -1  -1  -1  -1  -1  9  5  6  2  1069  35  108  6  ]
      [  79  2  8  -1  -1  -1  -1  -1  10  1  5  3  1066  35  130  6  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1082  35  0  6  ]
      [  23  1  1  5  841  85  1  45  9  5  9  1  953  35  112  6  ]
      [  28  1  1  5  411  55  8  40  13  2  3  1  1111  35  200  11  ]
      [  36  1  1  6  501  36  8  35  9  3  5  1  1231  35  100  7  ]
      [  64  1  8  -1  -1  -1  -1  -1  11  1  3  3  1242  35  142  7  ]
      [  31  1  1  5  837  85  1  38  18  5  9  1  1235  35  265  7  ]
      [  21  2  8  -1  -1  -1  -1  -1  14  5  -1  4  1207  35  200  7  ]
      [  26  1  1  5  626  73  1  39  11  5  5  1  1102  35  165  7  ]
      [  54  2  1  2  934  90  8  40  12  1  -1  1  1255  35  158  7  ]
      [  75  2  8  -1  -1  -1  -1  -1  15  1  3  3  1213  35  204  7  ]
      [  89  2  8  -1  -1  -1  -1  -1  12  1  1  3  1194  35  150  7  ]
      [  29  2  1  5  842  85  1  38  -1  5  9  1  1460  35  -1  8  ]
      [  28  2  1  5  778  75  1  39  26  3  3  1  1360  35  410  8  ]
      [  20  1  1  5  912  55  8  40  -1  1  3  1  1312  35  0  8  ]
      [  59  1  8  -1  -1  -1  -1  -1  -1  -1  -1  3  1460  35  -1  8  ]
      [  88  2  8  -1  -1  -1  -1  -1  7  1  -1  3  1466  35  100  8  ]
      [  87  2  8  -1  -1  -1  -1  -1  13  1  1  3  1414  35  174  8  ]
      [  30  1  1  5  778  93  8  40  23  3  3  1  1538  35  339  9  ]
      [  31  1  1  5  620  41  1  38  17  5  5  1  1581  35  257  9  ]
      [  38  1  1  5  861  85  1  45  14  5  9  1  1630  35  190  14  ]
      [  32  1  1  5  883  73  1  45  20  5  -1  1  1666  35  310  9  ]
      [  29  1  1  5  628  22  8  38  -1  3  5  1  1527  35  -1  9  ]
      [  46  1  1  1  842  85  8  21  18  5  10  1  1669  35  218  9  ]
      [  42  1  1  5  864  85  8  39  16  5  3  1  1746  35  225  10  ]
      [  33  1  1  5  600  29  8  40  10  3  5  1  1910  35  150  11  ]
      [  42  2  1  5  782  75  1  35  13  3  -1  1  1950  35  173  10  ]
      [  86  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  1710  35  0  10  ]
      [  61  1  1  5  861  85  1  55  15  3  8  1  2107  35  218  11  ]
      [  21  2  1  5  912  55  8  15  -1  5  -1  4  293  34  -1  2  ]
      [  27  2  8  -1  -1  -1  -1  -1  11  5  -1  4  327  34  139  3  ]
      [  20  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  398  34  -1  3  ]
      [  21  1  8  -1  -1  -1  -1  -1  -1  5  -1  8  418  34  -1  3  ]
      [  75  2  8  -1  -1  -1  -1  -1  10  1  -1  3  398  34  135  3  ]
      [  35  1  8  -1  -1  -1  -1  -1  22  1  -1  8  671  34  275  4  ]
      [  21  2  8  -1  -1  -1  -1  -1  17  -1  -1  7  544  34  254  4  ]
      [  76  2  8  -1  -1  -1  -1  -1  16  1  3  3  604  34  220  4  ]
      [  21  1  1  7  633  13  8  38  -1  5  -1  1  576  34  75  4  ]
      [  28  2  8  -1  -1  -1  -1  -1  10  3  -1  8  642  34  130  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  12  1  -1  3  632  34  186  4  ]
      [  61  1  8  -1  -1  -1  -1  -1  8  -1  -1  3  671  34  100  4  ]
      [  76  2  8  -1  -1  -1  -1  -1  11  1  4  3  611  34  131  4  ]
      [  82  1  8  -1  -1  -1  -1  -1  10  1  3  3  880  34  150  5  ]
      [  26  1  1  5  714  55  8  15  14  3  3  1  869  34  185  5  ]
      [  23  1  8  -1  -1  -1  -1  -1  21  5  -1  4  1021  34  300  6  ]
      [  23  1  1  5  310  74  8  40  10  3  3  1  980  34  110  6  ]
      [  67  1  8  -1  -1  -1  -1  -1  9  1  4  3  1035  34  106  6  ]
      [  40  1  1  5  714  60  1  40  13  3  3  1  1141  34  140  7  ]
      [  33  1  1  6  255  28  8  38  17  2  3  1  1466  34  240  14  ]
      [  77  2  8  -1  -1  -1  -1  -1  14  1  1  3  1456  34  200  8  ]
      [  46  2  1  5  789  74  8  37  20  1  3  1  1684  34  260  9  ]
      [  26  2  1  5  612  33  8  38  30  5  9  1  1947  34  435  10  ]
      [  31  2  1  5  859  85  1  38  15  5  10  1  2264  34  200  11  ]
      [  32  1  1  5  788  66  8  38  27  4  3  1  2258  34  348  11  ]
      [  38  1  1  1  774  72  8  60  -1  5  8  1  2963  34  -1  14  ]
      [  41  1  1  1  701  63  8  80  13  1  3  1  2954  34  180  14  ]
      [  24  2  1  5  997  80  1  10  14  5  -1  1  246  33  204  2  ]
      [  20  1  1  5  785  34  8  35  14  3  -1  1  481  33  180  3  ]
      [  63  2  8  -1  -1  -1  -1  -1  11  4  -1  6  338  33  137  3  ]
      [  57  1  1  6  934  74  8  20  12  2  3  1  498  33  156  3  ]
      [  55  1  8  -1  -1  -1  -1  -1  11  2  3  2  414  33  154  3  ]
      [  20  2  8  -1  -1  -1  -1  -1  10  5  -1  8  383  33  129  3  ]
      [  23  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  700  33  170  4  ]
      [  25  1  1  5  997  62  8  8  18  5  3  4  516  33  250  4  ]
      [  20  2  1  5  772  74  8  5  20  5  -1  4  515  33  290  4  ]
      [  56  2  8  -1  -1  -1  -1  -1  21  1  4  2  523  33  250  4  ]
      [  80  2  8  -1  -1  -1  -1  -1  17  1  -1  6  514  33  200  4  ]
      [  49  1  8  -1  -1  -1  -1  -1  13  1  3  6  610  33  160  4  ]
      [  78  2  8  -1  -1  -1  -1  -1  14  1  1  3  689  33  170  4  ]
      [  24  2  8  -1  -1  -1  -1  -1  12  1  3  2  543  33  150  4  ]
      [  23  2  8  -1  -1  -1  -1  -1  15  5  -1  4  534  33  190  4  ]
      [  33  1  8  -1  -1  -1  -1  -1  13  1  -1  2  887  33  163  5  ]
      [  31  1  8  -1  -1  -1  -1  -1  10  3  3  2  806  33  130  5  ]
      [  18  2  1  8  661  15  8  40  9  1  3  1  781  33  100  5  ]
      [  86  2  8  -1  -1  -1  -1  -1  10  1  5  3  762  33  100  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  11  1  3  3  1044  33  150  6  ]
      [  81  2  8  -1  -1  -1  -1  -1  14  -1  -1  3  1110  33  150  7  ]
      [  40  1  1  6  269  45  8  39  12  1  3  1  1157  33  150  7  ]
      [  88  2  8  -1  -1  -1  -1  -1  12  1  3  3  1219  33  162  7  ]
      [  36  1  1  5  482  45  8  38  12  2  -1  1  1195  33  130  7  ]
      [  77  2  8  -1  -1  -1  -1  -1  14  1  3  3  1151  33  198  7  ]
      [  65  1  1  2  779  72  8  20  11  5  8  3  1863  33  129  10  ]
      [  69  1  1  5  787  74  8  10  -1  -1  -1  3  1990  33  -1  12  ]
      [  32  1  1  1  796  93  8  40  31  -1  5  1  2289  33  400  11  ]
      [  34  1  1  5  750  64  8  50  20  5  8  1  2271  33  280  11  ]
      [  31  1  1  4  764  73  1  43  -1  5  9  1  2399  33  -1  12  ]
      [  38  1  1  5  751  24  8  60  11  4  8  1  4777  33  140  18  ]
      [  34  1  8  -1  -1  -1  -1  -1  16  1  -1  6  212  32  220  2  ]
      [  21  1  1  7  754  74  8  40  28  5  -1  1  211  32  350  2  ]
      [  26  2  8  -1  -1  -1  -1  -1  8  5  -1  4  266  32  97  2  ]
      [  20  1  8  -1  -1  -1  -1  -1  12  1  -1  2  478  32  140  3  ]
      [  32  1  8  -1  -1  -1  -1  -1  12  1  -1  2  467  32  157  3  ]
      [  22  2  1  6  912  55  8  8  14  5  -1  4  397  32  190  3  ]
      [  20  2  8  -1  -1  -1  -1  -1  9  -1  -1  8  438  32  108  3  ]
      [  40  1  8  -1  -1  -1  -1  -1  17  5  9  6  636  32  218  4  ]
      [  23  2  1  7  786  74  8  38  14  4  -1  4  508  32  158  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  13  1  3  6  519  32  152  4  ]
      [  31  1  1  6  51  85  8  20  14  1  -1  1  676  32  170  4  ]
      [  21  2  8  -1  -1  -1  -1  -1  8  5  -1  8  636  32  100  4  ]
      [  27  1  8  -1  -1  -1  -1  -1  23  5  9  6  610  32  288  4  ]
      [  22  2  8  -1  -1  -1  -1  -1  12  5  -1  8  684  32  163  4  ]
      [  87  2  8  -1  -1  -1  -1  -1  9  1  3  3  539  32  104  4  ]
      [  19  2  8  -1  -1  -1  -1  -1  10  1  1  8  540  32  122  4  ]
      [  79  2  8  -1  -1  -1  -1  -1  18  1  -1  3  548  32  260  4  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  1  4  2  636  32  -1  4  ]
      [  24  2  1  7  780  74  8  38  -1  3  3  1  730  32  0  5  ]
      [  37  1  1  5  852  85  8  38  22  5  3  1  875  32  300  5  ]
      [  92  2  8  -1  -1  -1  -1  -1  17  1  -1  3  886  32  221  5  ]
      [  46  1  1  6  254  28  8  40  10  2  3  1  898  32  109  5  ]
      [  55  2  8  -1  -1  -1  -1  -1  13  2  6  3  710  32  163  5  ]
      [  80  2  8  -1  -1  -1  -1  -1  19  -1  -1  3  1030  32  221  6  ]
      [  25  2  8  -1  -1  -1  -1  -1  15  1  -1  4  1025  32  200  6  ]
      [  31  2  1  5  841  85  8  39  11  5  9  1  995  32  99  6  ]
      [  69  2  8  -1  -1  -1  -1  -1  11  1  1  3  950  32  135  6  ]
      [  80  2  8  -1  -1  -1  -1  -1  9  1  3  3  1048  32  112  6  ]
      [  23  2  1  5  692  66  8  38  23  5  3  1  1235  32  288  7  ]
      [  51  1  1  5  754  74  8  40  30  1  3  1  1435  32  400  8  ]
      [  51  1  1  5  775  72  8  39  17  5  9  1  1753  32  250  10  ]
      [  38  1  1  5  880  80  1  38  12  5  9  1  1866  32  160  10  ]
      [  30  1  1  5  602  31  8  35  22  4  8  1  2246  32  284  11  ]
      [  51  1  1  5  780  75  1  38  21  5  -1  1  2461  32  300  12  ]
      [  48  1  1  2  753  74  8  60  -1  3  5  1  4632  32  -1  22  ]
      [  18  2  8  -1  -1  -1  -1  -1  16  1  -1  6  464  31  214  3  ]
      [  21  1  8  -1  -1  -1  -1  -1  15  1  -1  8  314  31  206  3  ]
      [  20  2  1  7  780  74  8  38  15  3  -1  1  572  31  184  4  ]
      [  25  1  8  -1  -1  -1  -1  -1  13  5  -1  4  611  31  133  6  ]
      [  53  1  8  -1  -1  -1  -1  -1  12  1  -1  3  542  31  136  4  ]
      [  23  2  8  -1  -1  -1  -1  -1  12  1  -1  6  823  31  138  5  ]
      [  79  2  8  -1  -1  -1  -1  -1  11  1  3  3  783  31  124  5  ]
      [  37  2  1  5  351  74  8  30  -1  5  -1  1  1016  31  -1  6  ]
      [  51  1  1  5  281  35  8  40  19  1  3  1  1178  31  250  7  ]
      [  86  2  8  -1  -1  -1  -1  -1  9  1  -1  3  1253  31  105  7  ]
      [  46  1  1  5  823  92  1  30  13  5  10  1  1643  31  150  9  ]
      [  43  2  1  5  691  65  8  39  12  5  8  1  1583  31  161  9  ]
      [  59  2  8  -1  -1  -1  -1  -1  -1  5  9  3  1907  31  -1  10  ]
      [  40  1  8  -1  -1  -1  -1  -1  -1  3  3  3  159  30  0  2  ]
      [  33  1  8  -1  -1  -1  -1  -1  14  5  9  6  285  30  175  2  ]
      [  23  2  8  -1  -1  -1  -1  -1  8  5  -1  8  192  30  100  2  ]
      [  26  2  1  6  912  55  8  14  19  5  -1  1  423  30  260  3  ]
      [  22  2  8  -1  -1  -1  -1  -1  14  5  4  8  423  30  185  3  ]
      [  39  1  1  6  531  50  8  10  -1  3  3  6  375  30  0  8  ]
      [  47  2  8  -1  -1  -1  -1  -1  15  1  3  2  340  30  165  3  ]
      [  50  1  8  -1  -1  -1  -1  -1  -1  1  3  2  386  30  -1  3  ]
      [  29  1  8  -1  -1  -1  -1  -1  18  5  -1  4  443  30  240  3  ]
      [  39  1  8  6  511  45  8  25  28  1  3  1  478  30  275  7  ]
      [  21  1  1  11  994  85  1  38  15  5  -1  1  385  30  189  3  ]
      [  72  2  8  -1  -1  -1  -1  -1  9  1  -1  3  406  30  95  3  ]
      [  79  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  451  30  -1  3  ]
      [  77  2  8  -1  -1  -1  -1  -1  7  -1  -1  3  553  30  80  4  ]
      [  67  2  8  -1  -1  -1  -1  -1  11  -1  -1  3  676  30  120  4  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  592  30  -1  4  ]
      [  30  1  8  -1  -1  -1  -1  -1  15  1  -1  2  613  30  180  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  15  1  3  3  525  30  200  4  ]
      [  28  2  1  1  834  74  8  20  14  5  3  1  623  30  176  4  ]
      [  21  1  8  -1  -1  -1  -1  -1  10  5  -1  4  587  30  130  4  ]
      [  20  2  1  7  853  85  1  38  6  3  -1  1  600  30  70  4  ]
      [  25  2  1  1  838  74  8  15  -1  5  -1  1  599  30  -1  4  ]
      [  53  1  8  -1  -1  -1  -1  -1  -1  4  4  2  656  30  -1  4  ]
      [  74  2  8  -1  -1  -1  -1  -1  -1  1  -1  3  646  30  0  4  ]
      [  18  1  1  8  441  45  8  40  -1  1  -1  1  630  30  -1  4  ]
      [  37  1  8  -1  -1  -1  -1  -1  11  1  3  5  603  30  98  4  ]
      [  28  2  8  6  744  52  8  15  9  5  -1  1  549  30  102  4  ]
      [  29  2  8  -1  -1  -1  -1  -1  -1  2  3  2  514  30  -1  4  ]
      [  52  1  1  6  222  33  8  35  17  1  3  1  754  30  220  5  ]
      [  39  2  8  -1  -1  -1  -1  -1  21  1  3  6  863  30  250  5  ]
      [  18  1  8  -1  -1  -1  -1  -1  20  -1  -1  6  753  30  239  5  ]
      [  74  1  8  -1  -1  -1  -1  -1  13  1  -1  3  719  30  123  5  ]
      [  23  1  1  5  997  80  1  8  20  5  9  1  805  30  275  5  ]
      [  43  1  1  5  735  74  8  38  14  5  -1  1  891  30  178  5  ]
      [  73  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  857  30  -1  5  ]
      [  46  1  8  -1  -1  -1  -1  -1  21  1  3  3  739  30  268  5  ]
      [  25  2  1  5  867  85  8  20  14  5  -1  1  822  30  180  5  ]
      [  47  1  1  6  323  85  8  37  11  1  -1  1  880  30  127  5  ]
      [  62  1  8  -1  -1  -1  -1  -1  9  1  -1  3  887  30  100  5  ]
      [  39  1  8  -1  -1  -1  -1  -1  15  3  3  2  811  30  160  5  ]
      [  23  2  1  5  788  29  8  10  14  5  -1  1  796  30  165  5  ]
      [  61  1  8  -1  -1  -1  -1  -1  -1  1  3  2  892  30  0  5  ]
      [  84  2  8  -1  -1  -1  -1  -1  6  1  -1  3  1025  30  75  6  ]
      [  21  1  1  5  780  51  8  40  -1  3  3  1  976  30  -1  6  ]
      [  34  1  1  6  531  34  8  5  17  5  -1  4  907  30  210  6  ]
      [  23  1  1  5  712  60  8  35  15  3  3  1  1078  30  160  6  ]
      [  43  1  1  5  780  52  8  39  21  3  3  1  1003  30  240  6  ]
      [  38  1  1  6  13  1  8  32  -1  -1  -1  1  965  30  -1  6  ]
      [  71  2  8  -1  -1  -1  -1  -1  -1  1  3  3  1095  30  -1  6  ]
      [  20  1  1  5  780  29  8  38  12  3  3  1  955  30  125  6  ]
      [  85  2  8  -1  -1  -1  -1  -1  29  1  -1  3  1004  30  380  6  ]
      [  37  2  1  5  854  85  8  20  -1  2  3  1  972  30  -1  6  ]
      [  80  1  8  -1  -1  -1  -1  -1  11  1  3  3  1042  30  110  6  ]
      [  47  1  1  6  731  64  8  38  18  5  3  1  1183  30  200  7  ]
      [  25  1  1  1  687  36  8  60  18  1  3  1  1283  30  220  7  ]
      [  70  2  8  -1  -1  -1  -1  -1  30  1  3  3  1216  30  420  7  ]
      [  42  1  1  6  442  45  8  60  31  1  -1  1  1252  30  350  11  ]
      [  22  1  1  6  441  45  8  40  -1  3  3  1  1207  30  -1  7  ]
      [  83  2  8  -1  -1  -1  -1  -1  15  1  -1  3  1158  30  121  7  ]
      [  30  1  1  6  487  45  8  40  11  2  3  1  1199  30  120  7  ]
      [  81  2  8  -1  -1  -1  -1  -1  10  1  -1  3  1226  30  90  7  ]
      [  88  2  8  -1  -1  -1  -1  -1  -1  -1  -1  7  1132  30  -1  7  ]
      [  48  1  1  5  267  45  8  40  19  2  6  1  1492  30  250  8  ]
      [  40  1  1  5  735  74  8  30  19  -1  -1  1  1370  30  244  8  ]
      [  63  1  1  6  460  45  8  40  -1  1  3  1  1570  30  -1  9  ]
      [  37  2  1  5  789  11  8  40  16  1  3  1  1695  30  175  9  ]
      [  81  2  8  -1  -1  -1  -1  -1  14  3  3  3  1678  30  164  9  ]
      [  27  1  1  2  660  52  8  50  17  1  3  1  2224  30  200  11  ]
      [  22  2  1  5  996  74  8  40  18  4  8  1  2667  30  204  13  ]
      [  64  1  1  5  601  45  8  38  -1  5  8  1  2949  30  0  14  ]
      [  79  2  8  -1  -1  -1  -1  -1  22  -1  -1  3  8591  30  300  22  ]
      [  22  2  1  5  912  55  8  12  18  5  -1  1  330  29  210  3  ]
      [  57  2  8  -1  -1  -1  -1  -1  -1  1  -1  2  501  29  -1  4  ]
      [  24  2  1  5  853  85  8  30  17  1  3  1  719  29  208  5  ]
      [  33  1  1  6  731  64  8  37  8  2  3  1  771  29  80  5  ]
      [  34  1  1  5  677  28  8  35  16  5  8  1  1635  29  210  9  ]
      [  30  2  1  5  841  85  1  37  16  5  9  1  1855  29  216  10  ]
      [  30  1  1  5  841  85  8  37  -1  5  9  1  1924  29  -1  10  ]
      [  29  1  1  5  841  85  1  37  -1  5  9  1  2127  29  -1  11  ]
      [  62  2  8  -1  -1  -1  -1  -1  -1  1  3  3  430  28  -1  3  ]
      [  19  2  8  6  773  52  8  10  31  5  -1  8  476  28  400  7  ]
      [  26  1  8  -1  -1  -1  -1  -1  11  1  -1  2  444  28  122  3  ]
      [  75  1  8  -1  -1  -1  -1  -1  20  3  8  6  644  28  252  4  ]
      [  45  1  8  6  714  60  1  17  16  5  -1  1  603  28  170  4  ]
      [  67  2  8  -1  -1  -1  -1  -1  10  1  -1  3  782  28  116  5  ]
      [  80  1  8  -1  -1  -1  -1  -1  20  5  3  3  790  28  205  5  ]
      [  69  2  8  -1  -1  -1  -1  -1  15  1  -1  3  874  28  180  5  ]
      [  82  2  8  -1  -1  -1  -1  -1  27  -1  -1  6  857  28  300  5  ]
      [  44  2  8  -1  -1  -1  -1  -1  -1  3  3  3  880  28  250  5  ]
      [  90  2  8  -1  -1  -1  -1  -1  18  1  -1  3  890  28  170  5  ]
      [  51  1  1  5  787  80  1  26  14  5  3  1  918  28  139  6  ]
      [  40  1  8  6  250  93  8  40  10  2  3  1  1039  28  95  6  ]
      [  22  1  1  6  935  90  1  39  25  3  3  1  1226  28  280  7  ]
      [  46  1  1  6  792  92  1  60  16  2  -1  1  1132  28  135  7  ]
      [  86  2  8  -1  -1  -1  -1  -1  8  1  3  3  301  27  80  3  ]
      [  24  1  8  -1  -1  -1  -1  -1  10  3  3  2  675  27  112  4  ]
      [  53  1  8  -1  -1  -1  -1  -1  12  1  3  2  671  27  120  4  ]
      [  37  1  1  6  714  64  8  30  13  3  3  1  856  27  145  5  ]
      [  22  2  1  5  660  52  8  39  16  1  3  1  1005  27  170  6  ]
      [  42  2  1  5  856  85  8  42  -1  9  99  1  1097  27  -1  6  ]
      [  83  2  8  -1  -1  -1  -1  -1  9  1  -1  3  491  26  100  3  ]
      [  22  1  8  5  784  25  8  5  -1  5  -1  1  499  26  -1  3  ]
      [  23  2  8  -1  -1  -1  -1  -1  16  5  -1  4  606  26  184  4  ]
      [  25  2  1  6  523  37  8  40  8  2  -1  1  792  26  70  5  ]
      [  23  2  1  5  780  45  8  39  12  5  3  1  978  26  105  6  ]
      [  49  2  1  5  788  34  8  39  21  1  3  1  4313  26  240  17  ]
      [  66  2  1  5  869  85  8  40  -1  1  3  8  144  25  -1  1  ]
      [  29  2  8  -1  -1  -1  -1  -1  -1  2  3  2  222  25  0  2  ]
      [  26  2  8  -1  -1  -1  -1  -1  25  5  -1  4  330  25  250  3  ]
      [  30  2  8  -1  -1  -1  -1  -1  10  5  -1  4  315  25  100  3  ]
      [  69  2  8  -1  -1  -1  -1  -1  16  -1  -1  3  597  25  120  4  ]
      [  21  2  8  -1  -1  -1  -1  -1  17  5  -1  4  562  25  180  4  ]
      [  23  1  1  1  757  74  8  10  22  5  3  4  616  25  220  4  ]
      [  19  2  1  5  853  85  1  39  15  3  -1  1  617  25  148  4  ]
      [  46  1  1  6  51  1  8  20  17  1  3  1  691  25  180  4  ]
      [  77  1  8  -1  -1  -1  -1  -1  -1  1  3  3  566  25  0  4  ]
      [  40  1  8  -1  -1  -1  -1  -1  16  2  3  3  505  25  120  4  ]
      [  21  2  1  5  778  67  8  13  23  5  -1  1  896  25  228  5  ]
      [  27  1  1  1  875  80  8  20  21  5  -1  1  857  25  200  5  ]
      [  24  1  8  -1  -1  -1  -1  -1  11  2  3  8  768  25  110  5  ]
      [  31  1  8  -1  -1  -1  -1  -1  26  5  9  8  1100  25  266  6  ]
      [  72  2  8  -1  -1  -1  -1  -1  18  1  3  3  1048  25  187  6  ]
      [  23  1  8  -1  -1  -1  -1  -1  -1  -1  -1  5  985  25  -1  6  ]
      [  53  1  8  -1  -1  -1  -1  -1  17  1  3  2  1007  25  185  6  ]
      [  58  2  1  5  867  95  8  20  19  1  -1  1  1067  25  194  6  ]
      [  21  1  1  5  751  34  8  38  20  4  3  1  1159  25  225  7  ]
      [  65  1  8  -1  -1  -1  -1  -1  21  1  3  3  1157  25  219  7  ]
      [  29  1  1  5  411  55  8  40  30  1  -1  1  1290  25  302  7  ]
      [  43  2  1  5  787  60  8  40  17  2  5  1  1110  25  158  7  ]
      [  24  1  1  6  411  55  8  40  -1  1  3  1  1327  25  0  8  ]
      [  39  1  1  6  274  35  8  35  -1  1  3  1  1421  25  0  8  ]
      [  60  1  1  5  788  85  8  37  19  4  1  1  1571  25  220  9  ]
      [  29  1  1  5  602  33  8  43  -1  5  8  1  1951  25  -1  10  ]
      [  33  1  1  5  692  75  1  39  29  5  10  1  1867  25  300  10  ]
      [  28  1  1  5  270  32  8  39  -1  3  3  1  1772  25  0  10  ]
      [  20  2  1  8  51  1  8  40  -1  -1  -1  1  266  24  0  2  ]
      [  41  1  8  6  997  52  8  20  -1  -1  3  6  175  24  -1  2  ]
      [  43  2  8  -1  -1  -1  -1  -1  15  1  -1  2  583  24  122  4  ]
      [  26  1  8  -1  -1  -1  -1  -1  16  5  -1  8  643  24  150  4  ]
      [  22  1  8  -1  -1  -1  -1  -1  23  3  3  8  558  24  216  4  ]
      [  63  1  8  -1  -1  -1  -1  -1  24  3  99  6  615  24  228  4  ]
      [  26  2  1  5  784  85  8  10  14  5  -1  4  703  24  110  5  ]
      [  38  1  1  4  787  75  1  38  -1  3  3  1  1493  24  -1  9  ]
      [  34  1  1  6  290  29  8  35  16  3  1  1  1529  24  140  9  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  183  23  -1  2  ]
      [  77  2  8  -1  -1  -1  -1  -1  12  1  -1  3  477  23  90  3  ]
      [  60  1  1  6  487  45  8  40  35  1  3  1  2010  23  315  11  ]
      [  17  2  8  -1  -1  -1  -1  -1  12  3  -1  4  247  22  108  2  ]
      [  18  2  8  -1  -1  -1  -1  -1  -1  3  -1  4  311  22  -1  3  ]
      [  43  1  8  -1  -1  -1  -1  -1  10  1  -1  2  311  22  100  3  ]
      [  32  2  1  6  934  74  8  10  30  1  -1  1  662  22  266  4  ]
      [  24  1  8  -1  -1  -1  -1  -1  33  5  9  4  1292  22  320  7  ]
      [  29  2  1  5  692  66  8  38  -1  5  4  1  1597  22  -1  9  ]
      [  24  2  8  -1  -1  -1  -1  -1  20  5  -1  4  341  21  160  3  ]
      [  24  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  647  21  -1  4  ]
      [  65  1  8  -1  -1  -1  -1  -1  24  -1  -1  3  1297  21  210  7  ]
      [  47  1  1  6  531  85  1  36  50  -1  -1  6  226  20  -1  2  ]
      [  63  2  8  -1  -1  -1  -1  -1  -1  -1  -1  3  480  20  -1  3  ]
      [  21  1  8  -1  -1  -1  -1  -1  16  5  -1  8  311  20  120  3  ]
      [  21  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  307  20  -1  3  ]
      [  24  1  8  -1  -1  -1  -1  -1  18  5  -1  4  435  20  150  3  ]
      [  22  2  8  6  661  15  8  8  -1  5  -1  1  470  20  -1  3  ]
      [  35  1  8  -1  -1  -1  -1  -1  28  1  -1  4  464  20  200  3  ]
      [  20  2  8  5  982  52  8  38  -1  5  -1  1  347  20  -1  3  ]
      [  41  1  1  6  51  1  1  40  11  -1  -1  1  422  20  80  3  ]
      [  22  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  418  20  -1  3  ]
      [  52  1  8  -1  -1  -1  -1  -1  15  -1  -1  3  397  20  105  3  ]
      [  34  1  1  1  861  80  8  12  -1  5  -1  1  662  20  -1  15  ]
      [  23  2  8  -1  -1  -1  -1  -1  16  5  -1  8  640  20  100  4  ]
      [  24  1  1  6  865  85  8  4  -1  5  4  4  527  20  -1  4  ]
      [  22  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  662  20  -1  4  ]
      [  29  2  1  5  854  85  1  19  -1  5  -1  1  631  20  -1  4  ]
      [  22  2  8  6  784  52  8  10  24  5  -1  1  667  20  200  4  ]
      [  45  1  8  -1  -1  -1  -1  -1  -1  1  3  2  576  20  0  6  ]
      [  68  2  1  6  923  55  8  10  12  -1  -1  3  617  20  100  4  ]
      [  69  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  759  20  0  5  ]
      [  23  1  8  -1  -1  -1  -1  -1  16  5  -1  4  723  20  110  5  ]
      [  25  2  1  6  662  52  8  16  14  5  8  1  861  20  100  5  ]
      [  75  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  866  20  0  5  ]
      [  48  1  1  6  502  45  8  38  20  1  3  1  1031  20  175  6  ]
      [  27  1  1  6  912  55  8  16  -1  5  -1  4  920  20  -1  6  ]
      [  68  1  8  -1  -1  -1  -1  -1  -1  1  3  3  952  20  -1  6  ]
      [  27  1  1  5  620  29  8  35  -1  5  3  1  1019  20  -1  6  ]
      [  52  1  1  2  670  52  8  40  -1  5  7  1  1023  20  100  6  ]
      [  22  1  1  5  997  80  1  8  13  5  -1  1  988  20  100  6  ]
      [  24  1  1  5  775  60  8  20  16  5  -1  1  1076  20  135  6  ]
      [  22  1  8  -1  -1  -1  -1  -1  12  5  -1  8  1064  20  102  6  ]
      [  91  2  8  -1  -1  -1  -1  -1  35  1  3  3  1416  20  300  8  ]
      [  36  1  1  6  714  60  1  40  22  1  -1  1  1451  20  163  8  ]
      [  42  1  1  5  628  34  8  35  15  -1  4  1  1510  20  122  9  ]
      [  34  1  1  5  757  74  8  40  -1  5  9  1  2873  20  -1  13  ]
      [  22  2  1  5  787  75  1  39  27  5  -1  1  583  19  150  4  ]
      [  43  1  8  -1  -1  -1  -1  -1  24  1  1  6  592  19  183  4  ]
      [  34  1  1  6  391  15  8  40  -1  1  -1  1  833  19  -1  5  ]
      [  20  1  1  8  853  85  1  38  13  3  -1  1  807  19  97  5  ]
      [  30  1  1  8  982  22  8  40  14  5  9  1  902  19  120  6  ]
      [  27  2  8  -1  -1  -1  -1  -1  18  5  -1  8  566  18  120  4  ]
      [  19  2  1  7  672  52  8  38  27  3  -1  1  506  18  185  4  ]
      [  48  2  1  6  742  63  8  39  14  1  -1  1  908  18  100  6  ]
      [  51  2  1  5  921  55  8  38  8  1  5  1  1473  18  60  8  ]
      [  41  1  1  5  778  75  1  39  -1  5  9  1  1630  18  -1  9  ]
      [  20  2  8  -1  -1  -1  -1  -1  16  5  -1  4  391  17  98  3  ]
      [  23  1  8  -1  -1  -1  -1  -1  22  4  -1  4  493  17  160  3  ]
      [  28  2  8  -1  -1  -1  -1  -1  19  5  -1  4  464  17  127  3  ]
      [  24  1  8  -1  -1  -1  -1  -1  18  5  3  8  453  17  120  3  ]
      [  29  2  8  -1  -1  -1  -1  -1  19  4  5  8  529  17  98  4  ]
      [  44  1  8  -1  -1  -1  -1  -1  22  1  3  2  181  16  150  2  ]
      [  20  2  8  -1  -1  -1  -1  -1  -1  5  -1  4  389  16  -1  3  ]
      [  23  2  1  5  997  80  1  12  -1  5  -1  4  447  16  -1  3  ]
      [  19  2  1  7  853  85  1  39  -1  3  -1  1  324  16  -1  3  ]
      [  23  1  8  -1  -1  -1  -1  -1  22  3  -1  3  457  16  150  3  ]
      [  20  2  8  -1  -1  -1  -1  -1  17  5  -1  4  673  16  75  4  ]
      [  66  2  8  -1  -1  -1  -1  -1  28  1  -1  3  516  16  146  4  ]
      [  21  2  1  7  853  85  1  38  6  5  -1  1  574  16  40  4  ]
      [  21  1  1  6  686  50  8  6  18  5  -1  4  879  16  125  5  ]
      [  46  1  1  6  488  45  8  40  13  2  3  1  945  16  85  6  ]
      [  79  1  8  -1  -1  -1  -1  -1  -1  1  3  3  1941  16  -1  14  ]
      [  43  1  1  6  322  85  8  38  -1  -1  -1  1  68  15  -1  1  ]
      [  18  1  1  8  281  50  8  40  -1  -1  -1  1  98  15  -1  1  ]
      [  26  1  8  1  775  72  8  10  19  4  -1  4  240  15  115  2  ]
      [  22  2  8  -1  -1  -1  -1  -1  18  5  -1  8  367  15  105  3  ]
      [  63  1  8  -1  -1  -1  -1  -1  13  1  3  3  854  15  80  5  ]
      [  25  2  1  5  755  31  8  80  -1  5  8  1  2174  15  -1  11  ]
      [  22  1  8  -1  -1  -1  -1  -1  17  1  -1  6  280  14  75  2  ]
      [  22  2  8  -1  -1  -1  -1  -1  22  5  -1  4  414  14  121  3  ]
      [  22  2  1  5  411  80  1  9  20  5  -1  4  335  13  108  3  ]
      [  29  1  8  -1  -1  -1  -1  -1  35  1  3  2  678  13  170  4  ]
      [  27  1  8  -1  -1  -1  -1  -1  -1  1  -1  6  223  12  -1  2  ]
      [  23  2  8  -1  -1  -1  -1  -1  20  5  -1  8  418  12  108  3  ]
      [  20  2  8  -1  -1  -1  -1  -1  21  5  -1  4  352  12  100  3  ]
      [  27  1  8  -1  -1  -1  -1  -1  21  5  -1  8  391  12  115  3  ]
      [  21  1  1  5  997  93  8  15  -1  5  -1  1  316  12  -1  3  ]
      [  21  1  8  -1  -1  -1  -1  -1  -1  5  -1  4  306  12  175  3  ]
      [  24  1  8  -1  -1  -1  -1  -1  24  5  -1  4  333  12  130  3  ]
      [  43  2  8  -1  -1  -1  -1  -1  -1  1  -1  8  527  12  -1  4  ]
      [  24  1  1  5  784  80  1  20  -1  5  -1  1  572  12  80  4  ]
      [  25  2  8  -1  -1  -1  -1  -1  27  5  -1  8  558  12  115  4  ]
      [  36  1  8  -1  -1  -1  -1  -1  27  5  3  4  601  12  135  4  ]
      [  52  1  1  5  222  29  8  40  21  3  -1  1  2396  12  101  12  ]
      [  25  1  8  -1  -1  -1  -1  -1  25  5  -1  8  347  11  115  3  ]
      [  20  2  8  -1  -1  -1  -1  -1  24  5  -1  4  511  11  100  4  ]
      [  22  2  1  5  912  55  8  15  -1  5  -1  1  686  11  180  4  ]
      [  66  2  8  -1  -1  -1  -1  -1  28  1  -1  3  787  11  119  5  ]
      [  55  2  8  -1  -1  -1  -1  -1  -1  5  10  4  104  10  -1  1  ]
      [  55  2  8  -1  -1  -1  -1  -1  -1  -1  -1  6  164  10  -1  2  ]
      [  22  2  1  5  780  91  8  16  26  5  -1  1  440  10  99  3  ]
      [  20  2  1  5  997  52  8  8  32  5  -1  8  579  10  110  4  ]
      [  51  2  8  -1  -1  -1  -1  -1  -1  1  3  6  573  10  -1  4  ]
      [  20  1  1  4  765  75  1  23  -1  -1  -1  1  761  10  90  5  ]
      [  51  2  8  -1  -1  -1  -1  -1  -1  -1  -1  2  1059  10  -1  6  ]
      [  45  1  1  6  51  20  8  40  -1  1  -1  1  1134  10  0  7  ]
      [  70  1  8  -1  -1  -1  -1  -1  -1  1  -1  3  1462  10  -1  8  ]
      [  29  1  1  6  481  45  8  35  -1  1  3  1  1588  10  -1  9  ]
    ]
    foreach microdata [
      create-consumers 1 [setxy random-pxcor random-pycor set color white set shape "square" set attributes ? set zi item 12 ?]
    ]
  ]
end
@#$#@#$#@
GRAPHICS-WINDOW
8
19
219
139
68
30
1.4741
1
10
1
1
1
0
1
1
1
-68
68
-30
30
0
0
1
ticks

BUTTON
13
44
68
77
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

BUTTON
67
44
122
77
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

PLOT
8
137
168
257
Demand Function
Demand
Price
0.0
100.0
0.0
25.0
true
false
PENS
"Potentials" 1.0 0 -16777216 true
"Regression" 1.0 0 -955883 true

PLOT
328
255
648
381
Non-cumulative Diffusion
Time
Adopters
0.0
20.0
0.0
1.0
true
true
PENS
"Overall" 1.0 0 -16777216 true
"Innovation" 1.0 0 -13791810 true
"Imitation" 1.0 0 -955883 true
"Bass-Overall" 1.0 0 -6459832 true
"Bass-Innovation" 1.0 0 -11221820 true
"Bass-Imitation" 1.0 0 -1184463 true

PLOT
328
137
488
257
Market Price
Time
Price 
0.0
20.0
500.0
1500.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
168
137
328
257
Industry Lifecycle
Time
Rivals
0.0
20.0
1.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
328
19
488
139
Willingness-to-pay
z(i)
Agents
0.0
10000.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

PLOT
488
19
648
139
Neighbors
n(i)
Agents
0.0
25.0
0.0
10.0
true
false
PENS
"default" 1.0 1 -16777216 true

MONITOR
435
37
485
82
 z(i)
mean [zi] of consumers
0
1
11

MONITOR
594
37
644
82
 n(i)
mean [ni] of consumers
1
1
11

PLOT
8
255
328
381
Supplier Profits
Time
Profit T
0.0
20.0
0.0
1.0
true
true
PENS
"S1" 1.0 0 -16777216 true
"S2" 1.0 0 -955883 true
"S3" 1.0 0 -13345367 true
"S4" 1.0 0 -10899396 true
"S5" 1.0 0 -1184463 true
"S6" 1.0 0 -7500403 true
"S7" 1.0 0 -2064490 true
"S8" 1.0 0 -6459832 true
"S9" 1.0 0 -16777216 true
"S10" 1.0 0 -16777216 true

PLOT
488
137
648
257
Cumulative Diffusion
Time
Adopters
0.0
20.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true
"bass" 1.0 2 -16777216 true

CHOOSER
685
90
857
135
input-validation
input-validation
"no" "random-normal" "aggregated-microdata" "microdata-file" "microdata-code"
3

INPUTBOX
276
19
329
79
M
300
1
0
Number

TEXTBOX
134
155
162
174
- z(i)
12
0.0
1

TEXTBOX
96
166
171
185
- regression
12
25.0
1

INPUTBOX
276
79
328
139
H
0.65
1
0
Number

TEXTBOX
14
25
74
43
The world
12
0.0
0

MONITOR
219
19
276
64
N
count consumers
17
1
11

MONITOR
219
57
276
102
NIL
Cfix
17
1
11

MONITOR
219
94
276
139
NIL
Cvar
17
1
11

SWITCH
686
178
800
211
show-bass
show-bass
0
1
-1000

PLOT
686
255
969
381
Error-to-Bass
NIL
NIL
0.0
10.0
0.0
10.0
true
true
PENS
"overall" 1.0 0 -16777216 true
"innovation" 1.0 0 -13345367 true
"imitation" 1.0 0 -955883 true

MONITOR
686
210
768
255
NIL
error-overall
17
1
11

TEXTBOX
687
73
837
91
Input validation
12
0.0
1

TEXTBOX
686
162
836
180
Output validation
12
0.0
1

BUTTON
684
18
757
52
clear all
ca
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

OUTPUT
8
423
647
655
11

TEXTBOX
10
404
160
422
Adopter heterogeneity
14
0.0
1

TEXTBOX
814
15
964
66
Validated calibration:\nM = 300\nH = 0.65
14
0.0
1

MONITOR
687
466
798
511
Consumer surplus
CPLUS
0
1
11

MONITOR
687
510
787
555
Supplier surplus
SPLUS
0
1
11

MONITOR
687
422
777
467
Diffusion level
(LEVEL / 10036) * 100
1
1
11

TEXTBOX
862
90
1073
188
Please notice:\nIf \"microdata-file\" is selected, the simulation opens a textfile called \"microdata.txt\" in the local folder. An error occurs if the file is in another location than the simulation.
11
0.0
1

@#$#@#$#@
WHAT IS IT?
-----------
This is an Agent-based model to simulate the diffusion of innovations. Both Epidemic and Probit diffusion theories were combined in an Agent-based model to simulate innovation adoption. Key functionality is the option to select different ways to (empirically) calibrate and validate Agents.


HOW IT WORKS
------------
The model integrates both demand and supply in a single model. The underlying demand function links both sides. It is determined by consumers learning status, the awareness for the new technology, and consumers individual price thresholds  their willingness-to-pay. In brief, diffusion proceeds in our model if awareness spreads due to interactions and firms rivalry reduces the market price. Endogeneity begins when consumers awareness and willingness-to-pay (demand function) drives supply-side rivalry. Market entry and exit decisions as well as quantity and price settings are completely determined by the underlying demand function. We utilize Cournot competition to calculate competitive dynamics within our model. It is a widely accepted economic theory that explains an oligopolistic industry structure in which companies compete on the quantity of output they will produce.


HOW TO USE IT
-------------
M is the number of periodic mass media interactions, H is the probability for word-of-mouth interactions. Both variables can be adjusted to simulate shifts in Innovation and Imitation ratios. Furthemrore, the input-validation dropdown selection determines the way consumers are calibrated. In case of microdata validation, each consumer receives 16 parameters including INCOME. The INCOME is the primary parameter that determines Willingness-to-Pay.

Please note: The microdata-file and microdata-code input validation leads basically to the same results. With the first option, NetLogo reads a local file. With the second option, the content of the file is directly integrated into the model code.


THINGS TO TRY
-------------
Try different values for M and H and compare the diffusion results with the Bass-benchmark. Try the behavior space functionality to simulate numerous parameter spaces and use the error variables to evaluate the outcome of each parameter configuration. Furthermore, observe the impact of different input-validation techniques with static M and H values. Huge deviations occur with "no" or "random-normal" validation, while only small deviations occur between "aggregated-microdata" and both "microdata" validation taxonomies.


EXTENDING THE MODEL
-------------------
To maximize validity, further parameters may be empirically validated. E.g. the geographical dispersion of Agents.



NETLOGO FEATURES
----------------
Regression analysis is performed with the 'Matrix' extension. Aware consumers are sorted by individual price threshold z(i). Then, linear regression across these consumers calculates the Demand Function. Empirical census microdata is integreted via file-read command.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.3
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
